@@ -34,9 +34,8 @@
 #include <Select3D_SensitiveSegment.hxx>
 #include <SelectMgr_EntityOwner.hxx>
 #include <SelectMgr_Selection.hxx>
+#include <Standard_NumericError.hxx>
 #include <StdPrs_Curve.hxx>
-#include <TColgp_Array1OfPnt.hxx>
-#include <TopoDS.hxx>
 #include <UnitsAPI.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(AIS_Axis,AIS_InteractiveObject)
@@ -56,7 +55,6 @@ myIsXYZAxis(Standard_False)
 
   gp_Dir thedir = myComponent->Position().Direction();
   gp_Pnt loc = myComponent->Position().Location();
-//POP  Standard_Real aLength = UnitsAPI::CurrentToLS (250000. ,"LENGTH");
   Standard_Real aLength = UnitsAPI::AnyToLS(250000., "mm");
   myPfirst = loc.XYZ() + aLength*thedir.XYZ();
   myPlast = loc.XYZ() - aLength*thedir.XYZ();
@@ -73,7 +71,6 @@ myTypeOfAxis(anAxisType),
 myIsXYZAxis(Standard_True)
 {
   Handle (Prs3d_DatumAspect) DA = new Prs3d_DatumAspect();
-//POP  Standard_Real aLength = UnitsAPI::CurrentToLS (100. ,"LENGTH"); 
   Standard_Real aLength;
   try {
     aLength = UnitsAPI::AnyToLS(100. ,"mm");
@@ -82,9 +79,9 @@ myIsXYZAxis(Standard_True)
   }
   DA->SetAxisLength(aLength,aLength,aLength);
   Quantity_Color col (Quantity_NOC_TURQUOISE);
-  DA->LineAspect(Prs3d_DP_XAxis)->SetColor(col);
-  DA->LineAspect(Prs3d_DP_YAxis)->SetColor(col);
-  DA->LineAspect(Prs3d_DP_ZAxis)->SetColor(col);
+  DA->LineAspect(Prs3d_DatumParts_XAxis)->SetColor(col);
+  DA->LineAspect(Prs3d_DatumParts_YAxis)->SetColor(col);
+  DA->LineAspect(Prs3d_DatumParts_ZAxis)->SetColor(col);
   myDrawer->SetDatumAspect(DA); 
   
   ComputeFields();
@@ -104,12 +101,36 @@ AIS_Axis::AIS_Axis(const Handle(Geom_Axis1Placement)& anAxis)
 
   gp_Dir thedir = myComponent->Position().Direction();
   gp_Pnt loc = myComponent->Position().Location();
-//POP  Standard_Real aLength = UnitsAPI::CurrentToLS (250000. ,"LENGTH");
   Standard_Real aLength = UnitsAPI::AnyToLS(250000. ,"mm"); 
   myPfirst = loc.XYZ() + aLength*thedir.XYZ();
   myPlast = loc.XYZ() - aLength*thedir.XYZ();
 }
 
+//=======================================================================
+//function : AIS_Axis
+//purpose :
+//=======================================================================
+AIS_Axis::AIS_Axis (const gp_Ax1& theAxis, const Standard_Real theLength)
+: myComponent (new Geom_Line (theAxis)),
+  myTypeOfAxis (AIS_TOAX_ZAxis),
+  myIsXYZAxis (Standard_True)
+{
+  myDir = theAxis.Direction();
+  myPfirst = theAxis.Location();
+  if (theLength <= 0 && theLength != -1)
+  {
+    throw Standard_NumericError ("AIS_Axis::AIS_Axis : invalid value for theLength parameter");
+  }
+  myVal = (theLength == -1) ? UnitsAPI::AnyToLS (250000., "mm") : theLength;
+  myPlast = myPfirst.XYZ() + myVal * myDir.XYZ();
+  SetInfiniteState();
+  Handle(Prs3d_DatumAspect) aDatumAspect = new Prs3d_DatumAspect();
+  aDatumAspect->SetDrawLabels (Standard_False);
+  myDrawer->SetDatumAspect (aDatumAspect);
+  Handle(Prs3d_LineAspect) aDefaultLineAspect = new Prs3d_LineAspect (Quantity_NOC_RED, Aspect_TOL_SOLID, 1.0);
+  myDrawer->SetLineAspect (aDefaultLineAspect);
+  myLineAspect = myDrawer->LineAspect();
+}
 
 //=======================================================================
 //function : SetComponent
@@ -125,7 +146,6 @@ void AIS_Axis::SetComponent(const Handle(Geom_Line)& aComponent)
 
   gp_Dir thedir = myComponent->Position().Direction();
   gp_Pnt loc = myComponent->Position().Location();
-//POP  Standard_Real aLength = UnitsAPI::CurrentToLS (250000. ,"LENGTH");
   Standard_Real aLength = UnitsAPI::AnyToLS(250000. ,"mm");
   myPfirst = loc.XYZ() + aLength*thedir.XYZ();
   myPlast = loc.XYZ() - aLength*thedir.XYZ();
@@ -161,24 +181,22 @@ void AIS_Axis::SetAxis1Placement(const Handle(Geom_Axis1Placement)& anAxis)
 //function : Compute
 //purpose  : 
 //=======================================================================
-void AIS_Axis::Compute(const Handle(PrsMgr_PresentationManager3d)&,
-		       const Handle(Prs3d_Presentation)& aPresentation, 
-		       const Standard_Integer)
+void AIS_Axis::Compute (const Handle(PrsMgr_PresentationManager)& ,
+		        const Handle(Prs3d_Presentation)& thePrs,
+		        const Standard_Integer )
 {
-  aPresentation->SetInfiniteState (myInfiniteState);
-
-  aPresentation->SetDisplayPriority(5);
-  if (!myIsXYZAxis ){
-    GeomAdaptor_Curve curv(myComponent);
-    StdPrs_Curve::Add(aPresentation,curv,myDrawer);
+  thePrs->SetInfiniteState (myInfiniteState);
+  if (!myIsXYZAxis)
+  {
+    GeomAdaptor_Curve curv (myComponent);
+    StdPrs_Curve::Add (thePrs, curv, myDrawer);
   }
   else
   {
-    DsgPrs_XYZAxisPresentation::Add (aPresentation,myLineAspect,myDir,myVal,
+    DsgPrs_XYZAxisPresentation::Add (thePrs, myLineAspect, myDir, myVal,
                                      myDrawer->DatumAspect()->ToDrawLabels() ? myText : "",
                                      myPfirst, myPlast);
   }
-
 }
 
 //=======================================================================
@@ -207,9 +225,9 @@ void AIS_Axis::SetColor(const Quantity_Color &aCol)
   myDrawer->LineAspect()->SetColor(aCol);
   
   const Handle(Prs3d_DatumAspect)& DA = myDrawer->DatumAspect();
-  DA->LineAspect(Prs3d_DP_XAxis)->SetColor(aCol);
-  DA->LineAspect(Prs3d_DP_YAxis)->SetColor(aCol);
-  DA->LineAspect(Prs3d_DP_ZAxis)->SetColor(aCol);
+  DA->LineAspect(Prs3d_DatumParts_XAxis)->SetColor(aCol);
+  DA->LineAspect(Prs3d_DatumParts_YAxis)->SetColor(aCol);
+  DA->LineAspect(Prs3d_DatumParts_ZAxis)->SetColor(aCol);
   SynchronizeAspects();
 }
 
@@ -225,12 +243,23 @@ void AIS_Axis::SetWidth(const Standard_Real aValue)
   myDrawer->LineAspect()->SetWidth(aValue);
   
   const Handle(Prs3d_DatumAspect)& DA = myDrawer->DatumAspect();
-  DA->LineAspect(Prs3d_DP_XAxis)->SetWidth(aValue);
-  DA->LineAspect(Prs3d_DP_YAxis)->SetWidth(aValue);
-  DA->LineAspect(Prs3d_DP_ZAxis)->SetWidth(aValue);
+  DA->LineAspect(Prs3d_DatumParts_XAxis)->SetWidth(aValue);
+  DA->LineAspect(Prs3d_DatumParts_YAxis)->SetWidth(aValue);
+  DA->LineAspect(Prs3d_DatumParts_ZAxis)->SetWidth(aValue);
   SynchronizeAspects();
 }
 
+//=======================================================================
+//function : SetDisplayAspect
+//purpose  : 
+//=======================================================================
+void AIS_Axis::SetDisplayAspect (const Handle(Prs3d_LineAspect)& theNewLineAspect)
+{
+  myDrawer->SetLineAspect (theNewLineAspect);
+  myLineAspect = myDrawer->LineAspect();
+  SetColor (theNewLineAspect->Aspect()->Color());
+}
+
 //=======================================================================
 //function : ComputeFields
 //purpose  : 
@@ -253,27 +282,27 @@ void AIS_Axis::ComputeFields()
     case AIS_TOAX_XAxis:
       {
 	oX.Coord(x,y,z);
-    myVal = DA->AxisLength(Prs3d_DP_XAxis);
+    myVal = DA->AxisLength(Prs3d_DatumParts_XAxis);
 	myDir = oX;
-	myLineAspect = DA->LineAspect(Prs3d_DP_XAxis);
+	myLineAspect = DA->LineAspect(Prs3d_DatumParts_XAxis);
 	myText = Standard_CString ("X");
 	break;
       }
     case AIS_TOAX_YAxis:
       {
 	oY.Coord(x,y,z);
-	myVal = DA->AxisLength(Prs3d_DP_YAxis);
+	myVal = DA->AxisLength(Prs3d_DatumParts_YAxis);
 	myDir = oY;
-	myLineAspect = DA->LineAspect(Prs3d_DP_YAxis);
+	myLineAspect = DA->LineAspect(Prs3d_DatumParts_YAxis);
 	myText = Standard_CString ("Y");
 	break;
       }
     case AIS_TOAX_ZAxis:
       {
 	oZ.Coord(x,y,z); 
-	myVal = DA->AxisLength(Prs3d_DP_ZAxis);
+	myVal = DA->AxisLength(Prs3d_DatumParts_ZAxis);
 	myDir = oZ;
-	myLineAspect = DA->LineAspect(Prs3d_DP_ZAxis);
+	myLineAspect = DA->LineAspect(Prs3d_DatumParts_ZAxis);
 	myText = Standard_CString ("Z");
 	break;
       }
@@ -306,9 +335,9 @@ void AIS_Axis::UnsetColor()
   myDrawer->LineAspect()->SetColor(Quantity_NOC_RED);
   hasOwnColor = Standard_False;
 
-  myDrawer->DatumAspect()->LineAspect(Prs3d_DP_XAxis)->SetColor(Quantity_NOC_TURQUOISE);
-  myDrawer->DatumAspect()->LineAspect(Prs3d_DP_YAxis)->SetColor(Quantity_NOC_TURQUOISE);
-  myDrawer->DatumAspect()->LineAspect(Prs3d_DP_ZAxis)->SetColor(Quantity_NOC_TURQUOISE);
+  myDrawer->DatumAspect()->LineAspect(Prs3d_DatumParts_XAxis)->SetColor(Quantity_NOC_TURQUOISE);
+  myDrawer->DatumAspect()->LineAspect(Prs3d_DatumParts_YAxis)->SetColor(Quantity_NOC_TURQUOISE);
+  myDrawer->DatumAspect()->LineAspect(Prs3d_DatumParts_ZAxis)->SetColor(Quantity_NOC_TURQUOISE);
   SynchronizeAspects();
 }
 //=======================================================================
@@ -320,8 +349,8 @@ void AIS_Axis::UnsetWidth()
 {
   myOwnWidth = 0.0f;
   myDrawer->LineAspect()->SetWidth(1.);
-  myDrawer->DatumAspect()->LineAspect(Prs3d_DP_XAxis)->SetWidth(1.);
-  myDrawer->DatumAspect()->LineAspect(Prs3d_DP_YAxis)->SetWidth(1.);
-  myDrawer->DatumAspect()->LineAspect(Prs3d_DP_ZAxis)->SetWidth(1.);
+  myDrawer->DatumAspect()->LineAspect(Prs3d_DatumParts_XAxis)->SetWidth(1.);
+  myDrawer->DatumAspect()->LineAspect(Prs3d_DatumParts_YAxis)->SetWidth(1.);
+  myDrawer->DatumAspect()->LineAspect(Prs3d_DatumParts_ZAxis)->SetWidth(1.);
   SynchronizeAspects();
 }
