@@ -263,9 +263,9 @@ void AIS_TextLabel::SetColorSubTitle (const Quantity_Color& theColor)
 //function : Compute
 //purpose  :
 //=======================================================================
-void AIS_TextLabel::Compute (const Handle(PrsMgr_PresentationManager3d)& /*thePrsMgr*/,
-                             const Handle(Prs3d_Presentation)&             thePrs,
-                             const Standard_Integer                        theMode)
+void AIS_TextLabel::Compute (const Handle(PrsMgr_PresentationManager)& ,
+                             const Handle(Prs3d_Presentation)& thePrs,
+                             const Standard_Integer theMode)
 {
   switch (theMode)
   {
@@ -404,9 +404,11 @@ Standard_Boolean AIS_TextLabel::calculateLabelParams (const gp_Pnt& thePosition,
 {
   // Get width and height of text
   Handle(Prs3d_TextAspect) anAsp = myDrawer->TextAspect();
+  const Graphic3d_RenderingParams& aRendParams = GetContext()->CurrentViewer()->DefaultRenderingParams();
   Font_FTFontParams aFontParams;
   aFontParams.PointSize = (unsigned int) anAsp->Height();
-  aFontParams.Resolution = GetContext()->CurrentViewer()->DefaultRenderingParams().Resolution;
+  aFontParams.Resolution = aRendParams.Resolution;
+  aFontParams.FontHinting = aRendParams.FontHinting;
 
   Handle(Font_FTFont) aFont = Font_FTFont::FindAndCreate (anAsp->Aspect()->Font(),
                                                           anAsp->Aspect()->GetTextFontAspect(),
