@@ -18,22 +18,20 @@
 #include <AIS_AnimationCamera.hxx>
 #include <AIS_InteractiveContext.hxx>
 #include <gp_Ax2.hxx>
-#include <Graphic3d_ViewAffinity.hxx>
 #include <Graphic3d_Text.hxx>
 #include <NCollection_Lerp.hxx>
 #include <Prs3d.hxx>
 #include <Prs3d_Arrow.hxx>
 #include <Prs3d_DatumAspect.hxx>
 #include <Prs3d_Text.hxx>
-#include <Prs3d_ToolDisk.hxx>
 #include <Prs3d_ToolSphere.hxx>
-#include <Select3D_SensitivePrimitiveArray.hxx>
 #include <SelectMgr_SequenceOfOwner.hxx>
 #include <V3d.hxx>
 #include <V3d_View.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(AIS_ViewCube, AIS_InteractiveObject)
 IMPLEMENT_STANDARD_RTTIEXT(AIS_ViewCubeOwner, SelectMgr_EntityOwner)
+IMPLEMENT_STANDARD_RTTIEXT(AIS_ViewCubeSensitive, Select3D_SensitivePrimitiveArray)
 
 namespace
 {
@@ -56,46 +54,48 @@ namespace
   }
 }
 
-//! Simple sensitive element for picking by point only.
-class AIS_ViewCubeSensitive : public Select3D_SensitivePrimitiveArray
+//=======================================================================
+//function : AIS_ViewCubeSensitive
+//purpose  :
+//=======================================================================
+AIS_ViewCubeSensitive::AIS_ViewCubeSensitive (const Handle(SelectMgr_EntityOwner)& theOwner,
+                                              const Handle(Graphic3d_ArrayOfTriangles)& theTris)
+: Select3D_SensitivePrimitiveArray (theOwner)
 {
-  DEFINE_STANDARD_RTTI_INLINE(AIS_ViewCubeSensitive, Select3D_SensitivePrimitiveArray)
-public:
-  //! Constructor.
-  AIS_ViewCubeSensitive (const Handle(SelectMgr_EntityOwner)& theOwner,
-                         const Handle(Graphic3d_ArrayOfTriangles)& theTris)
-  : Select3D_SensitivePrimitiveArray (theOwner)
+  InitTriangulation (theTris->Attributes(), theTris->Indices(), TopLoc_Location());
+}
+
+//=======================================================================
+//function : Matches
+//purpose  :
+//=======================================================================
+Standard_Boolean AIS_ViewCubeSensitive::Matches (SelectBasics_SelectingVolumeManager& theMgr,
+                                                 SelectBasics_PickResult& thePickResult)
+{
+  return isValidRay (theMgr) && Select3D_SensitivePrimitiveArray::Matches (theMgr, thePickResult);
+}
+
+//=======================================================================
+//function : isValidRay
+//purpose  :
+//=======================================================================
+bool AIS_ViewCubeSensitive::isValidRay (const SelectBasics_SelectingVolumeManager& theMgr) const
+{
+  if (theMgr.GetActiveSelectionType() != SelectMgr_SelectionType_Point)
   {
-    InitTriangulation (theTris->Attributes(), theTris->Indices(), TopLoc_Location());
+    // disallow rectangular selection
+    return false;
   }
 
-  //! Checks whether element overlaps current selecting volume.
-  virtual Standard_Boolean Matches (SelectBasics_SelectingVolumeManager& theMgr,
-                                    SelectBasics_PickResult& thePickResult) Standard_OVERRIDE
+  if (AIS_ViewCubeOwner* anOwner = dynamic_cast<AIS_ViewCubeOwner* >(myOwnerId.get()))
   {
-    return isValidRay (theMgr)
-        && Select3D_SensitivePrimitiveArray::Matches (theMgr, thePickResult);
+    const Standard_Real anAngleToler = 10.0 * M_PI / 180.0;
+    const gp_Dir aRay = theMgr.GetViewRayDirection();
+    const gp_Dir aDir = V3d::GetProjAxis (anOwner->MainOrientation());
+    return !aRay.IsNormal (aDir, anAngleToler);
   }
-
-  //! Checks if picking ray can be used for detection.
-  bool isValidRay (const SelectBasics_SelectingVolumeManager& theMgr) const
-  {
-    if (theMgr.GetActiveSelectionType() != SelectBasics_SelectingVolumeManager::Point)
-    {
-      // disallow rectangular selection
-      return false;
-    }
-
-    if (AIS_ViewCubeOwner* anOwner = dynamic_cast<AIS_ViewCubeOwner* >(myOwnerId.get()))
-    {
-      const Standard_Real anAngleToler = 10.0 * M_PI / 180.0;
-      const gp_Vec aRay (theMgr.GetNearPickedPnt(), theMgr.GetFarPickedPnt());
-      const gp_Dir aDir = V3d::GetProjAxis (anOwner->MainOrientation());
-      return !aRay.IsNormal (aDir, anAngleToler);
-    }
-    return true;
-  }
-};
+  return true;
+}
 
 //=======================================================================
 //function : IsBoxSide
@@ -177,9 +177,9 @@ AIS_ViewCube::AIS_ViewCube()
   myBoxSideLabels.Bind (V3d_TypeOfOrientation_Zup_Left,   "LEFT");
   myBoxSideLabels.Bind (V3d_TypeOfOrientation_Zup_Right,  "RIGHT");
 
-  myAxesLabels.Bind (Prs3d_DP_XAxis, "X");
-  myAxesLabels.Bind (Prs3d_DP_YAxis, "Y");
-  myAxesLabels.Bind (Prs3d_DP_ZAxis, "Z");
+  myAxesLabels.Bind (Prs3d_DatumParts_XAxis, "X");
+  myAxesLabels.Bind (Prs3d_DatumParts_YAxis, "Y");
+  myAxesLabels.Bind (Prs3d_DatumParts_ZAxis, "Z");
 
   // define default size
   SetSize (70.0);
@@ -198,7 +198,7 @@ void AIS_ViewCube::setDefaultAttributes()
   myDrawer->TextAspect()->SetHeight (16.0);
   myDrawer->TextAspect()->Aspect()->SetTextZoomable (true); // the whole object is drawn within transformation-persistence
   // this should be forced back-face culling regardless Closed flag
-  myDrawer->TextAspect()->Aspect()->SetSuppressBackFaces (true);
+  myDrawer->TextAspect()->Aspect()->SetFaceCulling (Graphic3d_TypeOfBackfacingModel_BackCulled);
 
   Graphic3d_MaterialAspect aMat (Graphic3d_NameOfMaterial_UserDefined);
   aMat.SetColor (Quantity_NOC_WHITE);
@@ -207,7 +207,7 @@ void AIS_ViewCube::setDefaultAttributes()
   const Handle(Graphic3d_AspectFillArea3d)& aShading = myDrawer->ShadingAspect()->Aspect();
   aShading->SetInteriorStyle (Aspect_IS_SOLID);
   // this should be forced back-face culling regardless Closed flag
-  aShading->SetSuppressBackFaces (true);
+  aShading->SetFaceCulling (Graphic3d_TypeOfBackfacingModel_BackCulled);
   aShading->SetInteriorColor (aMat.Color());
   aShading->SetFrontMaterial (aMat);
   myDrawer->SetFaceBoundaryDraw (false);
@@ -563,7 +563,7 @@ void AIS_ViewCube::createBoxCornerTriangles (const Handle(Graphic3d_ArrayOfTrian
 //function : Compute
 //purpose  :
 //=======================================================================
-void AIS_ViewCube::Compute (const Handle(PrsMgr_PresentationManager3d)& ,
+void AIS_ViewCube::Compute (const Handle(PrsMgr_PresentationManager)& ,
                             const Handle(Prs3d_Presentation)& thePrs,
                             const Standard_Integer theMode)
 {
@@ -580,7 +580,7 @@ void AIS_ViewCube::Compute (const Handle(PrsMgr_PresentationManager3d)& ,
   {
     const Standard_Real anAxisSize = mySize + 2.0 * myBoxFacetExtension + myAxesPadding;
     const Handle(Prs3d_DatumAspect)& aDatumAspect = myDrawer->DatumAspect();
-    for (Standard_Integer anAxisIter = Prs3d_DP_XAxis; anAxisIter <= Prs3d_DP_ZAxis; ++anAxisIter)
+    for (Standard_Integer anAxisIter = Prs3d_DatumParts_XAxis; anAxisIter <= Prs3d_DatumParts_ZAxis; ++anAxisIter)
     {
       const Prs3d_DatumParts aPart = (Prs3d_DatumParts )anAxisIter;
       if (!aDatumAspect->DrawDatumPart (aPart))
@@ -591,9 +591,9 @@ void AIS_ViewCube::Compute (const Handle(PrsMgr_PresentationManager3d)& ,
       gp_Ax1 anAx1;
       switch (aPart)
       {
-        case Prs3d_DP_XAxis: anAx1 = gp_Ax1 (aLocation, gp::DX()); break;
-        case Prs3d_DP_YAxis: anAx1 = gp_Ax1 (aLocation, gp::DY()); break;
-        case Prs3d_DP_ZAxis: anAx1 = gp_Ax1 (aLocation, gp::DZ()); break;
+        case Prs3d_DatumParts_XAxis: anAx1 = gp_Ax1 (aLocation, gp::DX()); break;
+        case Prs3d_DatumParts_YAxis: anAx1 = gp_Ax1 (aLocation, gp::DY()); break;
+        case Prs3d_DatumParts_ZAxis: anAx1 = gp_Ax1 (aLocation, gp::DZ()); break;
         default: break;
       }
 
@@ -614,7 +614,7 @@ void AIS_ViewCube::Compute (const Handle(PrsMgr_PresentationManager3d)& ,
         gp_Pnt aTextOrigin = anAx1.Location().Translated (gp_Vec (anAx1.Direction().X() * (anAxisSize + anArrowLength),
                                                                   anAx1.Direction().Y() * (anAxisSize + anArrowLength),
                                                                   anAx1.Direction().Z() * (anAxisSize + anArrowLength)));
-        Prs3d_Text::Draw (anAxisLabelGroup, aDatumAspect->TextAspect(), TCollection_ExtendedString (anAxisLabel), aTextOrigin);
+        Prs3d_Text::Draw (anAxisLabelGroup, aDatumAspect->TextAspect (aPart), TCollection_ExtendedString (anAxisLabel), aTextOrigin);
       }
     }
 
@@ -671,7 +671,7 @@ void AIS_ViewCube::Compute (const Handle(PrsMgr_PresentationManager3d)& ,
 
       {
         Handle(Graphic3d_Group) aGroupSides = thePrs->NewGroup();
-        aGroupSides->SetClosed (true); // should be replaced by forced back-face culling aspect
+        aGroupSides->SetClosed (true);
         aGroupSides->SetGroupPrimitivesAspect (myDrawer->ShadingAspect()->Aspect());
         aGroupSides->AddPrimitiveArray (aTris);
       }
@@ -859,7 +859,7 @@ Standard_Boolean AIS_ViewCube::HasAnimation() const
 void AIS_ViewCube::viewFitAll (const Handle(V3d_View)& theView,
                                const Handle(Graphic3d_Camera)& theCamera)
 {
-  Bnd_Box aBndBox = myToFitSelected ? GetContext()->BoundingBoxOfSelection() : theView->View()->MinMaxValues();
+  Bnd_Box aBndBox = myToFitSelected ? GetContext()->BoundingBoxOfSelection (theView) : theView->View()->MinMaxValues();
   if (aBndBox.IsVoid()
    && myToFitSelected)
   {
@@ -1001,7 +1001,7 @@ void AIS_ViewCube::HandleClick (const Handle(AIS_ViewCubeOwner)& theOwner)
 //function : HilightOwnerWithColor
 //purpose  :
 //=======================================================================
-void AIS_ViewCube::HilightOwnerWithColor (const Handle(PrsMgr_PresentationManager3d)& thePrsMgr,
+void AIS_ViewCube::HilightOwnerWithColor (const Handle(PrsMgr_PresentationManager)& thePrsMgr,
                                           const Handle(Prs3d_Drawer)& theStyle,
                                           const Handle(SelectMgr_EntityOwner)& theOwner)
 {
@@ -1016,7 +1016,7 @@ void AIS_ViewCube::HilightOwnerWithColor (const Handle(PrsMgr_PresentationManage
 
   Handle(Prs3d_Presentation) aHiPrs = GetHilightPresentation (thePrsMgr);
   aHiPrs->Clear();
-  aHiPrs->CStructure()->ViewAffinity = thePrsMgr->StructureManager()->ObjectAffinity (Handle(Standard_Transient)(this));
+  aHiPrs->CStructure()->ViewAffinity = myViewAffinity;
   aHiPrs->SetTransformPersistence (TransformPersistence());
   aHiPrs->SetZLayer (aLayer);
 
@@ -1044,7 +1044,7 @@ void AIS_ViewCube::HilightOwnerWithColor (const Handle(PrsMgr_PresentationManage
 //function : HilightSelected
 //purpose  :
 //=======================================================================
-void AIS_ViewCube::HilightSelected (const Handle(PrsMgr_PresentationManager3d)& ,
+void AIS_ViewCube::HilightSelected (const Handle(PrsMgr_PresentationManager)& ,
                                     const SelectMgr_SequenceOfOwner& theSeq)
 {
   // this method should never be called since AIS_InteractiveObject::HandleClick() has been overridden
