@@ -22,7 +22,6 @@
 // Modified     PMN 15/04/1997 : Gestion fine de la continuite aux lieux de decoupes 
 
 #include <AdvApprox_ApproxAFunction.hxx>
-#include <AdvApprox_Cutting.hxx>
 #include <AdvApprox_DichoCutting.hxx>
 #include <AdvApprox_EvaluatorFunction.hxx>
 #include <AdvApprox_SimpleApprox.hxx>
@@ -34,7 +33,6 @@
 #include <math_Vector.hxx>
 #include <PLib.hxx>
 #include <PLib_JacobiPolynomial.hxx>
-#include <Precision.hxx>
 #include <Standard_ConstructionError.hxx>
 #include <Standard_OutOfRange.hxx>
 #include <TColgp_Array1OfPnt.hxx>
