@@ -14,9 +14,6 @@
 
 
 #include <ApproxInt_SvSurfaces.hxx>
-#include <gp_Pnt.hxx>
-#include <gp_Vec.hxx>
-#include <gp_Vec2d.hxx>
 
 //=======================================================================
 //function : ~ApproxInt_SvSurfaces
