@@ -36,7 +36,6 @@
 #include <TopTools_IndexedMapOfShape.hxx>
 #include <TopTools_MapOfOrientedShape.hxx>
 
-
 //=======================================================================
 //function : 
 //purpose  : 
@@ -177,7 +176,7 @@ void BOPAlgo_Builder::Prepare()
 //function : Perform
 //purpose  : 
 //=======================================================================
-void BOPAlgo_Builder::Perform()
+void BOPAlgo_Builder::Perform(const Message_ProgressRange& theRange)
 {
   GetReport()->Clear();
   //
@@ -195,25 +194,22 @@ void BOPAlgo_Builder::Perform()
   //
   pPF->SetArguments(myArguments);
   pPF->SetRunParallel(myRunParallel);
-  if (myProgressScope != NULL)
-  {
-    pPF->SetProgressIndicator(*myProgressScope);
-  }
+  Message_ProgressScope aPS(theRange, "Performing General Fuse operation", 10);
   pPF->SetFuzzyValue(myFuzzyValue);
   pPF->SetNonDestructive(myNonDestructive);
   pPF->SetGlue(myGlue);
   pPF->SetUseOBB(myUseOBB);
   //
-  pPF->Perform();
+  pPF->Perform(aPS.Next(9));
   //
   myEntryPoint=1;
-  PerformInternal(*pPF);
+  PerformInternal(*pPF, aPS.Next(1));
 }
 //=======================================================================
 //function : PerformWithFiller
 //purpose  : 
 //=======================================================================
-void BOPAlgo_Builder::PerformWithFiller(const BOPAlgo_PaveFiller& theFiller)
+void BOPAlgo_Builder::PerformWithFiller(const BOPAlgo_PaveFiller& theFiller, const Message_ProgressRange& theRange)
 {
   GetReport()->Clear();
   myEntryPoint=0;
@@ -221,30 +217,118 @@ void BOPAlgo_Builder::PerformWithFiller(const BOPAlgo_PaveFiller& theFiller)
   myFuzzyValue = theFiller.FuzzyValue();
   myGlue = theFiller.Glue();
   myUseOBB = theFiller.UseOBB();
-  PerformInternal(theFiller);
+  PerformInternal(theFiller, theRange);
 }
 //=======================================================================
 //function : PerformInternal
 //purpose  : 
 //=======================================================================
-void BOPAlgo_Builder::PerformInternal(const BOPAlgo_PaveFiller& theFiller)
+void BOPAlgo_Builder::PerformInternal(const BOPAlgo_PaveFiller& theFiller, const Message_ProgressRange& theRange)
 {
   GetReport()->Clear();
   //
   try {
     OCC_CATCH_SIGNALS
-    PerformInternal1(theFiller);
+    PerformInternal1(theFiller, theRange);
   }
   //
   catch (Standard_Failure const&) {
     AddError (new BOPAlgo_AlertBuilderFailed);
   }
 }
+
+//=======================================================================
+//function : getNbShapes
+//purpose  : 
+//=======================================================================
+BOPAlgo_Builder::NbShapes BOPAlgo_Builder::getNbShapes() const
+{
+  NbShapes aCounter;
+  aCounter.NbVertices() = myDS->ShapesSD().Size();
+  for (Standard_Integer i = 0; i < myDS->NbSourceShapes(); ++i)
+  {
+    const BOPDS_ShapeInfo& aSI = myDS->ShapeInfo(i); 
+    switch (aSI.ShapeType())
+    {
+      case TopAbs_EDGE:
+      {
+        if (myDS->HasPaveBlocks(i))
+        {
+          aCounter.NbEdges()++;
+        }
+        break;
+      }
+      case TopAbs_WIRE:
+        aCounter.NbWires()++;
+        break;
+      case TopAbs_FACE:
+      {
+        if (myDS->HasFaceInfo(i))
+        {
+          aCounter.NbFaces()++;
+        }
+        break;
+      }
+      case TopAbs_SHELL:
+        aCounter.NbShells()++;
+        break;
+      case TopAbs_SOLID:
+        aCounter.NbSolids()++;
+        break;
+      case TopAbs_COMPSOLID:
+        aCounter.NbCompsolids()++;
+        break;
+      case TopAbs_COMPOUND:
+        aCounter.NbCompounds()++;
+        break;
+      default: break;
+    }
+  }
+  return aCounter;
+}
+
+//=======================================================================
+// function: fillPIConstants
+// purpose: 
+//=======================================================================
+void BOPAlgo_Builder::fillPIConstants (const Standard_Real theWhole,
+                                       BOPAlgo_PISteps& theSteps) const
+{
+  // Fill in the constants:
+  if (myFillHistory)
+  {
+    // for FillHistroty, which takes about 5% of the whole operation
+    theSteps.SetStep(PIOperation_FillHistory, 0.05 * theWhole);
+  }
+
+  // and for PostTreat, which takes about 3% of the whole operation 
+  theSteps.SetStep(PIOperation_PostTreat, 0.03 * theWhole);
+}
+
+//=======================================================================
+// function: fillPISteps
+// purpose: 
+//=======================================================================
+void BOPAlgo_Builder::fillPISteps (BOPAlgo_PISteps& theSteps) const
+{
+  // Compute the rest of the operations - all depend on the number of sub-shapes of certain type
+  NbShapes aNbShapes = getNbShapes();
+
+  theSteps.SetStep(PIOperation_TreatVertices, aNbShapes.NbVertices());
+  theSteps.SetStep(PIOperation_TreatEdges, aNbShapes.NbEdges());
+  theSteps.SetStep(PIOperation_TreatWires, aNbShapes.NbWires());
+  theSteps.SetStep(PIOperation_TreatFaces, 20 * aNbShapes.NbFaces());
+  theSteps.SetStep(PIOperation_TreatShells, aNbShapes.NbShells());
+  theSteps.SetStep(PIOperation_TreatSolids, 50 * aNbShapes.NbSolids());
+  theSteps.SetStep(PIOperation_TreatCompsolids, aNbShapes.NbCompsolids());
+  theSteps.SetStep(PIOperation_TreatCompounds, aNbShapes.NbCompounds());
+}
+
 //=======================================================================
 //function : PerformInternal1
 //purpose  : 
 //=======================================================================
-void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
+void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller, const Message_ProgressRange& theRange)
 {
   myPaveFiller=(BOPAlgo_PaveFiller*)&theFiller;
   myDS=myPaveFiller->PDS();
@@ -252,6 +336,7 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
   myFuzzyValue = myPaveFiller->FuzzyValue();
   myNonDestructive = myPaveFiller->NonDestructive();
   //
+  Message_ProgressScope aPS(theRange, "Building the result of General Fuse operation", 100);
   // 1. CheckData
   CheckData();
   if (HasErrors()) {
@@ -264,9 +349,11 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
     return;
   }
   //
+  BOPAlgo_PISteps aSteps(PIOperation_Last);
+  analyzeProgress(100., aSteps);
   // 3. Fill Images
   // 3.1 Vertice
-  FillImagesVertices();
+  FillImagesVertices(aPS.Next(aSteps.GetStep(PIOperation_TreatVertices)));
   if (HasErrors()) {
     return;
   }
@@ -276,7 +363,7 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
     return;
   }
   // 3.2 Edges
-  FillImagesEdges();
+  FillImagesEdges(aPS.Next(aSteps.GetStep(PIOperation_TreatEdges)));
   if (HasErrors()) {
     return;
   }
@@ -287,7 +374,7 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
   }
   //
   // 3.3 Wires
-  FillImagesContainers(TopAbs_WIRE);
+  FillImagesContainers(TopAbs_WIRE, aPS.Next(aSteps.GetStep(PIOperation_TreatWires)));
   if (HasErrors()) {
     return;
   }
@@ -298,7 +385,7 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
   }
   
   // 3.4 Faces
-  FillImagesFaces();
+  FillImagesFaces(aPS.Next(aSteps.GetStep(PIOperation_TreatFaces)));
   if (HasErrors()) {
     return;
   }
@@ -308,7 +395,7 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
     return;
   }
   // 3.5 Shells
-  FillImagesContainers(TopAbs_SHELL);
+  FillImagesContainers(TopAbs_SHELL, aPS.Next(aSteps.GetStep(PIOperation_TreatShells)));
   if (HasErrors()) {
     return;
   }
@@ -318,7 +405,7 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
     return;
   }
   // 3.6 Solids
-  FillImagesSolids();
+  FillImagesSolids(aPS.Next(aSteps.GetStep(PIOperation_TreatSolids)));
   if (HasErrors()) {
     return;
   }
@@ -328,7 +415,7 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
     return;
   }
   // 3.7 CompSolids
-  FillImagesContainers(TopAbs_COMPSOLID);
+  FillImagesContainers(TopAbs_COMPSOLID, aPS.Next(aSteps.GetStep(PIOperation_TreatCompsolids)));
   if (HasErrors()) {
     return;
   }
@@ -339,7 +426,7 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
   }
   
   // 3.8 Compounds
-  FillImagesCompounds();
+  FillImagesCompounds(aPS.Next(aSteps.GetStep(PIOperation_TreatCompounds)));
   if (HasErrors()) {
     return;
   }
@@ -349,19 +436,21 @@ void BOPAlgo_Builder::PerformInternal1(const BOPAlgo_PaveFiller& theFiller)
     return;
   }
   //
-  // 4.History
-  PrepareHistory();
-  //
+  // 4 History
+  PrepareHistory(aPS.Next(aSteps.GetStep(PIOperation_FillHistory)));
+  if (HasErrors()) {
+    return;
+  }
   //
   // 5 Post-treatment 
-  PostTreat();
-  
+  PostTreat(aPS.Next(aSteps.GetStep(PIOperation_PostTreat)));
 }
+
 //=======================================================================
 //function : PostTreat
 //purpose  : 
 //=======================================================================
-void BOPAlgo_Builder::PostTreat()
+void BOPAlgo_Builder::PostTreat(const Message_ProgressRange& theRange)
 {
   Standard_Integer i, aNbS;
   TopAbs_ShapeEnum aType;
@@ -381,7 +470,9 @@ void BOPAlgo_Builder::PostTreat()
     }
   }
   //
+  Message_ProgressScope aPS(theRange, "Post treatment of result shape", 2);
   BOPTools_AlgoTools::CorrectTolerances(myShape, aMA, 0.05, myRunParallel);
+  aPS.Next();
   BOPTools_AlgoTools::CorrectShapeTolerances(myShape, aMA, myRunParallel);
 }
 
@@ -389,11 +480,12 @@ void BOPAlgo_Builder::PostTreat()
 //function : BuildBOP
 //purpose  : 
 //=======================================================================
-void BOPAlgo_Builder::BuildBOP(const TopTools_ListOfShape& theObjects,
-                               const TopAbs_State          theObjState,
-                               const TopTools_ListOfShape& theTools,
-                               const TopAbs_State          theToolsState,
-                               Handle(Message_Report)      theReport)
+void BOPAlgo_Builder::BuildBOP(const TopTools_ListOfShape&  theObjects,
+                               const TopAbs_State           theObjState,
+                               const TopTools_ListOfShape&  theTools,
+                               const TopAbs_State           theToolsState,
+                               const Message_ProgressRange& theRange,
+                               Handle(Message_Report)       theReport)
 {
   if (HasErrors())
     return;
@@ -406,7 +498,6 @@ void BOPAlgo_Builder::BuildBOP(const TopTools_ListOfShape& theObjects,
     aReport->AddAlert(Message_Fail, new BOPAlgo_AlertBuilderFailed());
     return;
   }
-
   // Check the input data
   if ((theObjState   != TopAbs_IN && theObjState   != TopAbs_OUT) ||
       (theToolsState != TopAbs_IN && theToolsState != TopAbs_OUT))
@@ -626,7 +717,7 @@ void BOPAlgo_Builder::BuildBOP(const TopTools_ListOfShape& theObjects,
     if (!aMFToAvoid.Contains(aRF))
       aResFaces.Append(aRF);
   }
-
+  Message_ProgressScope aPS(theRange, NULL, 2);
   BRep_Builder aBB;
 
   // Try to build closed solids from the faces
@@ -635,11 +726,7 @@ void BOPAlgo_Builder::BuildBOP(const TopTools_ListOfShape& theObjects,
   aBS.SetRunParallel(myRunParallel);
   aBS.SetContext(myContext);
   aBS.SetFuzzyValue(myFuzzyValue);
-  if (myProgressScope != NULL)
-  {
-    aBS.SetProgressIndicator(*myProgressScope);
-  }
-  aBS.Perform();
+  aBS.Perform(aPS.Next());
 
   // Resulting solids
   TopTools_ListOfShape aResSolids;
@@ -668,6 +755,10 @@ void BOPAlgo_Builder::BuildBOP(const TopTools_ListOfShape& theObjects,
       }
     }
   }
+  else
+  {
+    return;
+  }
 
   // Collect unused faces
   TopoDS_Compound anUnUsedFaces;
@@ -748,5 +839,5 @@ void BOPAlgo_Builder::BuildBOP(const TopTools_ListOfShape& theObjects,
     aBB.Add(aResult, itLS.Value());
 
   myShape = aResult;
-  PrepareHistory();
+  PrepareHistory(aPS.Next());
 }
