@@ -18,21 +18,14 @@
 
 #include <BOPAlgo_PaveFiller.hxx>
 #include <BOPAlgo_Alerts.hxx>
-#include <BOPAlgo_SectionAttribute.hxx>
-#include <BOPDS_Curve.hxx>
 #include <BOPDS_DS.hxx>
 #include <BOPDS_FaceInfo.hxx>
 #include <BOPDS_Interf.hxx>
 #include <BOPDS_Iterator.hxx>
 #include <BOPDS_MapOfPaveBlock.hxx>
-#include <BOPDS_PaveBlock.hxx>
 #include <BOPDS_SubIterator.hxx>
 #include <BOPDS_VectorOfInterfVF.hxx>
 #include <BOPTools_Parallel.hxx>
-#include <BRep_Builder.hxx>
-#include <BRep_Tool.hxx>
-#include <BRepBndLib.hxx>
-#include <gp_Pnt.hxx>
 #include <IntTools_Context.hxx>
 #include <NCollection_Vector.hxx>
 #include <TColStd_MapOfInteger.hxx>
@@ -43,12 +36,12 @@
 //class    : BOPAlgo_VertexFace
 //purpose  : 
 //=======================================================================
-class BOPAlgo_VertexFace : public BOPAlgo_Algo {
+class BOPAlgo_VertexFace : public BOPAlgo_ParallelAlgo {
  public:
   DEFINE_STANDARD_ALLOC
 
   BOPAlgo_VertexFace() : 
-    BOPAlgo_Algo(),
+    BOPAlgo_ParallelAlgo(),
     myIV(-1), myIF(-1),
     myFlag(-1), myT1(-1.),  myT2(-1.), myTolVNew(-1.) {
   }
@@ -107,7 +100,11 @@ class BOPAlgo_VertexFace : public BOPAlgo_Algo {
   }
   //
   virtual void Perform() {
-    BOPAlgo_Algo::UserBreak();
+    Message_ProgressScope aPS(myProgressRange, NULL, 1);
+    if (UserBreak(aPS))
+    {
+      return;
+    }
     try
     {
       OCC_CATCH_SIGNALS
@@ -138,13 +135,14 @@ typedef NCollection_Vector<BOPAlgo_VertexFace> BOPAlgo_VectorOfVertexFace;
 // function: PerformVF
 // purpose: 
 //=======================================================================
-void BOPAlgo_PaveFiller::PerformVF()
+void BOPAlgo_PaveFiller::PerformVF(const Message_ProgressRange& theRange)
 {
   myIterator->Initialize(TopAbs_VERTEX, TopAbs_FACE);
   Standard_Integer iSize = myIterator->ExpectedLength();
   //
   Standard_Integer nV, nF;
   //
+  Message_ProgressScope aPSOuter(theRange, NULL, 10);
   if (myGlue == BOPAlgo_GlueFull) {
     // there is no need to intersect vertices with faces in this mode
     // just initialize FaceInfo for all faces
@@ -174,9 +172,12 @@ void BOPAlgo_PaveFiller::PerformVF()
   //
   // Avoid repeated intersection of the same vertex with face in case
   // the group of vertices formed a single SD vertex
-  NCollection_DataMap<BOPDS_Pair, TColStd_MapOfInteger, BOPDS_PairMapHasher> aMVFPairs;
-
+  NCollection_DataMap<BOPDS_Pair, TColStd_MapOfInteger> aMVFPairs;
   for (; myIterator->More(); myIterator->Next()) {
+    if (UserBreak(aPSOuter))
+    {
+      return;
+    }
     myIterator->Value(nV, nF);
     //
     if (myDS->IsSubShape(nV, nF)) {
@@ -217,18 +218,29 @@ void BOPAlgo_PaveFiller::PerformVF()
     aVertexFace.SetVertex(aV);
     aVertexFace.SetFace(aF);
     aVertexFace.SetFuzzyValue(myFuzzyValue);
-    if (myProgressScope != NULL)
-    {
-      aVertexFace.SetProgressIndicator(*myProgressScope);
-    }
+    
   }//for (; myIterator->More(); myIterator->Next()) {
   //
   aNbVF=aVVF.Length();
+  Message_ProgressScope aPS(aPSOuter.Next(9), "Performing Vertex-Face intersection", aNbVF);
+  for (k = 0; k < aNbVF; k++)
+  {
+    BOPAlgo_VertexFace& aVertexFace = aVVF.ChangeValue(k);
+    aVertexFace.SetProgressRange(aPS.Next());
+  }
   //================================================================
   BOPTools_Parallel::Perform (myRunParallel, aVVF, myContext);
   //================================================================
+  if (UserBreak(aPSOuter))
+  {
+    return;
+  }
   //
   for (k=0; k < aNbVF; ++k) {
+    if (UserBreak(aPSOuter))
+    {
+      return;
+    }
     const BOPAlgo_VertexFace& aVertexFace=aVVF(k);
     // 
     iFlag=aVertexFace.Flag();
