@@ -23,8 +23,10 @@
 #include <BRepAlgo_Loop.hxx>
 #include <Geom2d_Curve.hxx>
 #include <Geom_Surface.hxx>
+#include <GeomLib.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Pnt2d.hxx>
+#include <gp_Ax2.hxx>
 #include <Precision.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
@@ -34,20 +36,20 @@
 #include <TopoDS_Iterator.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeListOfShape.hxx>
 #include <TopTools_DataMapIteratorOfDataMapOfShapeShape.hxx>
 #include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_MapOfShape.hxx>
 #include <TopTools_SequenceOfShape.hxx>
 
 #include <stdio.h>
+//#define OCCT_DEBUG_ALGO
+//#define DRAW
 #ifdef DRAW
 #include <DBRep.hxx>
 #pragma comment(lib,"TKDraw")
 #endif
 #ifdef OCCT_DEBUG_ALGO
-Standard_Boolean AffichLoop  = Standard_False;
+Standard_Boolean AffichLoop  = Standard_True;
 Standard_Integer NbLoops     = 0;
 Standard_Integer NbWires     = 1;
 static char* name = new char[100];
@@ -58,7 +60,8 @@ static char* name = new char[100];
 //purpose  : 
 //=======================================================================
 
-BRepAlgo_Loop::BRepAlgo_Loop()
+BRepAlgo_Loop::BRepAlgo_Loop():
+  myTolConf (0.001)
 {
 }
 
@@ -160,6 +163,15 @@ void BRepAlgo_Loop::AddConstEdges(const TopTools_ListOfShape& LE)
   }
 }
 
+//=======================================================================
+//function : SetImageVV
+//purpose  : 
+//=======================================================================
+
+void BRepAlgo_Loop::SetImageVV (const BRepAlgo_Image& theImageVV)
+{
+  myImageVV = theImageVV;
+}
 
 //=======================================================================
 //function : UpdateClosedEdge
@@ -176,7 +188,6 @@ static TopoDS_Vertex  UpdateClosedEdge(const TopoDS_Edge&         E,
   Standard_Boolean OnStart = 0, OnEnd = 0;
   //// modified by jgv, 13.04.04 for OCC5634 ////
   TopExp::Vertices (E,V1,V2);
-  //Standard_Real    Tol = Precision::Confusion();
   Standard_Real    Tol = BRep_Tool::Tolerance( V1 );
   ///////////////////////////////////////////////
   
@@ -273,7 +284,7 @@ static void RemovePendingEdges(TopTools_IndexedDataMapOfShapeListOfShape& MVE)
 //purpose  : 
 //=======================================================================
 
-static Standard_Boolean  SamePnt2d(TopoDS_Vertex  V,
+static Standard_Boolean  SamePnt2d(const TopoDS_Vertex&  V,
 				   TopoDS_Edge&   E1,
 				   TopoDS_Edge&   E2,
 				   TopoDS_Face&   F)
@@ -418,13 +429,12 @@ static void StoreInMVE (const TopoDS_Face&                  F,
 			TopoDS_Edge&                  E,
 			TopTools_IndexedDataMapOfShapeListOfShape& MVE,
 			Standard_Boolean&                   YaCouture,
-			TopTools_DataMapOfShapeShape& VerticesForSubstitute )
+			TopTools_DataMapOfShapeShape& VerticesForSubstitute,
+            const Standard_Real theTolConf)
 {      
   TopoDS_Vertex V1, V2, V;
   TopTools_ListOfShape Empty;
   
-  Standard_Real Tol = 0.001; //5.e-05; //5.e-07;
-//  gp_Pnt P1, P2, P;
   gp_Pnt P1, P;
   BRep_Builder BB;
   for (Standard_Integer iV = 1; iV <= MVE.Extent(); iV++)
@@ -440,7 +450,7 @@ static void StoreInMVE (const TopoDS_Face&                  F,
 	{
 	  V1 = TopoDS::Vertex( itl.Value() );
 	  P1 = BRep_Tool::Pnt( V1 );
-	  if (P.IsEqual( P1, Tol ) && !V.IsSame(V1))
+	  if (P.IsEqual( P1, theTolConf ) && !V.IsSame(V1))
 	    {
 	      V.Orientation( V1.Orientation() );
 	      if (VerticesForSubstitute.IsBound( V1 ))
@@ -562,10 +572,10 @@ void BRepAlgo_Loop::Perform()
     if (pLCE)
     {
       for (itl1.Initialize(*pLCE); itl1.More(); itl1.Next()) {
-        TopoDS_Edge& E = TopoDS::Edge(itl1.Value());
+        TopoDS_Edge& E = TopoDS::Edge(itl1.ChangeValue());
         if (!Emap.Add(E))
           continue;
-        StoreInMVE(myFace,E,MVE,YaCouture,myVerticesForSubstitute);
+        StoreInMVE(myFace,E,MVE,YaCouture,myVerticesForSubstitute, myTolConf);
       }
     }
   }
@@ -575,9 +585,9 @@ void BRepAlgo_Loop::Perform()
   // => call only once StoreInMVE which should double them
   TopTools_MapOfShape DejaVu;
   for (itl.Initialize(myConstEdges); itl.More(); itl.Next()) {
-    TopoDS_Edge& E = TopoDS::Edge(itl.Value());
+    TopoDS_Edge& E = TopoDS::Edge(itl.ChangeValue());
     if (DejaVu.Add(E))
-      StoreInMVE(myFace,E,MVE,YaCouture,myVerticesForSubstitute);
+      StoreInMVE(myFace,E,MVE,YaCouture,myVerticesForSubstitute, myTolConf);
   }
 
 #ifdef DRAW
@@ -606,6 +616,8 @@ void BRepAlgo_Loop::Perform()
   TopoDS_Wire      NW;
   Standard_Boolean End;
 
+  UpdateVEmap (MVE);
+
   TopTools_MapOfShape UsedEdges;
 
   while (MVE.Extent() > 0) {
@@ -615,42 +627,42 @@ void BRepAlgo_Loop::Perform()
     //--------------------------------
     RemovePendingEdges(MVE);
 
-    if (MVE.Extent() == 0) break; 
+    if (MVE.Extent() == 0) break;
     //--------------------------------
     // Start edge.
     //--------------------------------
     EF = CE = TopoDS::Edge(MVE(1).First());
-    TopExp::Vertices(CE,V1,V2);
+    TopExp::Vertices(CE, V1, V2);
     //--------------------------------
     // VF vertex start of new wire
     //--------------------------------
-    if (CE.Orientation() == TopAbs_FORWARD) { CV = VF = V1;}
-    else                                    { CV = VF = V2;}
+    if (CE.Orientation() == TopAbs_FORWARD) { CV = VF = V1; }
+    else { CV = VF = V2; }
     if (!MVE.Contains(CV)) continue;
     TopTools_ListOfShape& aListEdges = MVE.ChangeFromKey(CV);
-    for ( itl.Initialize(aListEdges); itl.More(); itl.Next()) {
+    for (itl.Initialize(aListEdges); itl.More(); itl.Next()) {
       if (itl.Value().IsEqual(CE)) {
-	aListEdges.Remove(itl);
-	break;
+        aListEdges.Remove(itl);
+        break;
       }
     }
-    End  = Standard_False;
-    
+    End = Standard_False;
+
     while (!End) {
       //-------------------------------
       // Construction of a wire.
       //-------------------------------
-      TopExp::Vertices(CE,V1,V2);
+      TopExp::Vertices(CE, V1, V2);
       if (!CV.IsSame(V1)) CV = V1; else CV = V2;
 
-      B.Add (NW,CE);
+      B.Add(NW, CE);
       UsedEdges.Add(CE);
 
       if (!MVE.Contains(CV) || MVE.FindFromKey(CV).IsEmpty()) {
         End = Standard_True;
       }
       else {
-        End = !SelectEdge(myFace,CE,CV,NE,MVE.ChangeFromKey(CV));
+        End = !SelectEdge(myFace, CE, CV, NE, MVE.ChangeFromKey(CV));
         if (!End) {
           CE = NE;
           if (MVE.FindFromKey(CV).IsEmpty())
@@ -661,35 +673,41 @@ void BRepAlgo_Loop::Perform()
     //--------------------------------------------------
     // Add new wire to the set of wires
     //------------------------------------------------
-    Standard_Real Tol = 0.001; //5.e-05; //5.e-07;
-    TopExp_Explorer explo( NW, TopAbs_VERTEX );
-    for (; explo.More(); explo.Next())
-      {
-      const TopoDS_Vertex& aV = TopoDS::Vertex( explo.Current() );
-      Handle(BRep_TVertex)& TV = *((Handle(BRep_TVertex)*) &(aV).TShape());
-      TV->Tolerance( Tol );
-      TV->Modified( Standard_True );
-      }
-    for (explo.Init( NW, TopAbs_EDGE ); explo.More(); explo.Next())
-      {
-      const TopoDS_Edge& aE = TopoDS::Edge( explo.Current() );
-      Handle(BRep_TEdge)& TE = *((Handle(BRep_TEdge)*) &(aE).TShape());
-      TE->Tolerance( Tol );
-      TE->Modified( Standard_True );
-      }
 
-    if (VF.IsSame(CV) && SamePnt2d(VF,EF,CE,myFace))
+    if (VF.IsSame(CV))
     {
-      NW.Closed (Standard_True);
-      myNewWires.Append (NW);
+      if (SamePnt2d(VF, EF, CE, myFace))
+      {
+        NW.Closed(Standard_True);
+        myNewWires.Append(NW);
+      }
+      else if(BRep_Tool::Tolerance(VF) < myTolConf)
+      {
+        BRep_Builder aBB;
+        aBB.UpdateVertex(VF, myTolConf);
+        if (SamePnt2d(VF, EF, CE, myFace))
+        {
+          NW.Closed(Standard_True);
+          myNewWires.Append(NW);
+        }
+#ifdef OCCT_DEBUG_ALGO
+        else
+        {
+          std::cout << "BRepAlgo_Loop: Open Wire" << std::endl;
+          if (AffichLoop)
+            std::cout << "OpenWire is : NW_" << NbLoops << "_" << NbWires << std::endl;
+        }
+#endif
+      }
     }
 #ifdef OCCT_DEBUG_ALGO
     else {
-      std::cout <<"BRepAlgo_Loop: Open Wire"<<std::endl;
+      std::cout << "BRepAlgo_Loop: Open Wire" << std::endl;
       if (AffichLoop)
-        std::cout << "OpenWire is : NW_"<<NbLoops<<"_"<<NbWires<<std::endl;
-      }
+        std::cout << "OpenWire is : NW_" << NbLoops << "_" << NbWires << std::endl;
+    }
 #endif
+
 #ifdef DRAW
     if (AffichLoop) {
       sprintf(name,"NW_%d_%d",NbLoops,NbWires++);	
@@ -766,8 +784,6 @@ void BRepAlgo_Loop::CutEdge (const TopoDS_Edge&          E,
       VF = TopoDS::Vertex(aLocalV);
       aLocalV = VCEI.Oriented(TopAbs_REVERSED); 
       VL = TopoDS::Vertex(aLocalV);
-//      VF = TopoDS::Vertex(VCEI.Oriented(TopAbs_FORWARD));
-//      VL = TopoDS::Vertex(VCEI.Oriented(TopAbs_REVERSED)); 
     }
     SV.Prepend(VF);
     SV.Append(VL);
@@ -802,13 +818,9 @@ void BRepAlgo_Loop::CutEdge (const TopoDS_Edge&          E,
       B.Add  (NewEdge,aLocalEdge);
       aLocalEdge = V2.Oriented(TopAbs_REVERSED);
       B.Add  (TopoDS::Edge(NewEdge),aLocalEdge);
-//      B.Add  (NewEdge,V1.Oriented(TopAbs_FORWARD));
-//      B.Add  (NewEdge,V2.Oriented(TopAbs_REVERSED));
       if (V1.IsSame(VF)) 
 	U1 = f;
       else 
-//	U1=BRep_Tool::Parameter
-//	  (TopoDS::Vertex(V1.Oriented(TopAbs_INTERNAL)),WE);
 	{
 	  TopoDS_Shape aLocalV = V1.Oriented(TopAbs_INTERNAL);
 	  U1=BRep_Tool::Parameter(TopoDS::Vertex(aLocalV),WE);
@@ -819,8 +831,6 @@ void BRepAlgo_Loop::CutEdge (const TopoDS_Edge&          E,
 	{
 	  TopoDS_Shape aLocalV = V2.Oriented(TopAbs_INTERNAL);
 	  U2=BRep_Tool::Parameter(TopoDS::Vertex(aLocalV),WE);
-//	U2=BRep_Tool::Parameter
-//	  (TopoDS::Vertex(V2.Oriented(TopAbs_INTERNAL)),WE);
 	}
       B.Range (TopoDS::Edge(NewEdge),U1,U2);
 #ifdef DRAW
@@ -890,7 +900,7 @@ void  BRepAlgo_Loop::WiresToFaces()
 //	     Standard_False);
     TopTools_ListIteratorOfListOfShape it(myNewWires);
     for (; it.More(); it.Next()) {
-      FR.Add(TopoDS::Wire(it.Value()));
+      FR.Add(TopoDS::Wire(it.ChangeValue()));
     }
 
     FR.Perform();
@@ -924,6 +934,7 @@ void  BRepAlgo_Loop::GetVerticesForSubstitute( TopTools_DataMapOfShapeShape& Ver
 {
   VerVerMap = myVerticesForSubstitute;
 }
+
 //=======================================================================
 //function : VerticesForSubstitute
 //purpose  : 
@@ -933,3 +944,123 @@ void  BRepAlgo_Loop::VerticesForSubstitute( TopTools_DataMapOfShapeShape& VerVer
 {
   myVerticesForSubstitute = VerVerMap;
 }
+
+//=======================================================================
+//function : UpdateVEmap
+//purpose  : 
+//=======================================================================
+
+void  BRepAlgo_Loop::UpdateVEmap (TopTools_IndexedDataMapOfShapeListOfShape& theVEmap)
+{
+  TopTools_IndexedDataMapOfShapeListOfShape VerLver;
+
+  for (Standard_Integer ii = 1; ii <= theVEmap.Extent(); ii++)
+  {
+    const TopoDS_Vertex& aVertex = TopoDS::Vertex (theVEmap.FindKey(ii));
+    const TopTools_ListOfShape& aElist = theVEmap(ii);
+    if (aElist.Extent() == 1 && myImageVV.IsImage(aVertex))
+    {
+      const TopoDS_Vertex& aProVertex = TopoDS::Vertex (myImageVV.ImageFrom(aVertex));
+      if (VerLver.Contains(aProVertex))
+      {
+        TopTools_ListOfShape& aVlist = VerLver.ChangeFromKey(aProVertex);
+        aVlist.Append (aVertex.Oriented(TopAbs_FORWARD));
+      }
+      else
+      {
+        TopTools_ListOfShape aVlist;
+        aVlist.Append (aVertex.Oriented(TopAbs_FORWARD));
+        VerLver.Add (aProVertex,  aVlist);
+      }
+    }
+  }
+
+  if (VerLver.IsEmpty())
+    return;
+
+  BRep_Builder aBB;
+  for (Standard_Integer ii = 1; ii <= VerLver.Extent(); ii++)
+  {
+    const TopTools_ListOfShape& aVlist = VerLver(ii);
+    if (aVlist.Extent() == 1)
+      continue;
+    
+    Standard_Real aMaxTol = 0.;
+    TColgp_Array1OfPnt Points (1, aVlist.Extent());
+
+    TopTools_ListIteratorOfListOfShape itl (aVlist);
+    Standard_Integer jj = 0;
+    for (; itl.More(); itl.Next())
+    {
+      const TopoDS_Vertex& aVertex = TopoDS::Vertex (itl.Value());
+      Standard_Real aTol = BRep_Tool::Tolerance(aVertex);
+      aMaxTol = Max (aMaxTol, aTol);
+      gp_Pnt aPnt = BRep_Tool::Pnt(aVertex);
+      Points(++jj) = aPnt;
+    }
+
+    gp_Ax2 anAxis;
+    Standard_Boolean IsSingular;
+    GeomLib::AxeOfInertia (Points, anAxis, IsSingular);
+    gp_Pnt aCentre = anAxis.Location();
+    Standard_Real aMaxDist = 0.;
+    for (jj = 1; jj <= Points.Upper(); jj++)
+    {
+      Standard_Real aSqDist = aCentre.SquareDistance (Points(jj));
+      aMaxDist = Max (aMaxDist, aSqDist);
+    }
+    aMaxDist = Sqrt(aMaxDist);
+    aMaxTol = Max (aMaxTol, aMaxDist);
+
+    //Find constant vertex
+    TopoDS_Vertex aConstVertex;
+    for (itl.Initialize(aVlist); itl.More(); itl.Next())
+    {
+      const TopoDS_Vertex& aVertex = TopoDS::Vertex (itl.Value());
+      const TopTools_ListOfShape& aElist = theVEmap.FindFromKey(aVertex);
+      const TopoDS_Shape& anEdge = aElist.First();
+      TopTools_ListIteratorOfListOfShape itcedges (myConstEdges);
+      for (; itcedges.More(); itcedges.Next())
+        if (anEdge.IsSame (itcedges.Value()))
+        {
+          aConstVertex = aVertex;
+          break;
+        }
+      if (!aConstVertex.IsNull())
+        break;
+    }
+    if (aConstVertex.IsNull())
+      aConstVertex = TopoDS::Vertex(aVlist.First());
+    aBB.UpdateVertex (aConstVertex, aCentre, aMaxTol);
+
+    for (itl.Initialize(aVlist); itl.More(); itl.Next())
+    {
+      const TopoDS_Vertex& aVertex = TopoDS::Vertex (itl.Value());
+      if (aVertex.IsSame(aConstVertex))
+        continue;
+      
+      const TopTools_ListOfShape& aElist = theVEmap.FindFromKey (aVertex);
+      TopoDS_Edge anEdge = TopoDS::Edge (aElist.First());
+      anEdge.Orientation(TopAbs_FORWARD);
+      TopoDS_Vertex aV1, aV2;
+      TopExp::Vertices (anEdge, aV1, aV2);
+      TopoDS_Vertex aVertexToRemove = (aV1.IsSame(aVertex))? aV1 : aV2;
+      anEdge.Free(Standard_True);
+      aBB.Remove (anEdge, aVertexToRemove);
+      aBB.Add (anEdge, aConstVertex.Oriented (aVertexToRemove.Orientation()));
+    }
+  }
+
+  TopTools_IndexedMapOfShape Emap;
+  for (Standard_Integer ii = 1; ii <= theVEmap.Extent(); ii++)
+  {
+    const TopTools_ListOfShape& aElist = theVEmap(ii);
+    TopTools_ListIteratorOfListOfShape itl (aElist);
+    for (; itl.More(); itl.Next())
+      Emap.Add (itl.Value());
+  }
+
+  theVEmap.Clear();
+  for (Standard_Integer ii = 1; ii <= Emap.Extent(); ii++)
+    TopExp::MapShapesAndAncestors (Emap(ii), TopAbs_VERTEX, TopAbs_EDGE, theVEmap);
+}
