@@ -19,7 +19,6 @@
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
 #include <BRepCheck.hxx>
-#include <BRepCheck_ListIteratorOfListOfStatus.hxx>
 #include <BRepCheck_ListOfStatus.hxx>
 #include <Standard_Type.hxx>
 #include <TopExp.hxx>
@@ -29,12 +28,9 @@
 #include <TopoDS_Face.hxx>
 #include <TopoDS_Shape.hxx>
 #include <TopoDS_Shell.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeInteger.hxx>
 #include <TopTools_DataMapOfShapeInteger.hxx>
 #include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_ListOfShape.hxx>
-#include <TopTools_MapIteratorOfMapOfShape.hxx>
 #include <TopTools_MapOfShape.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(BRepCheck_Shell,BRepCheck_Result)
@@ -86,9 +82,9 @@ Standard_EXPORT Standard_Integer BRepCheck_Trace(const Standard_Integer phase) {
   return BRC_Trace;
 }
 
-void PrintShape(const TopoDS_Shape& theShape, const Standard_Integer upper) {
+void PrintShape(const TopoDS_Shape& theShape) {
   if (!theShape.IsNull()) {
-    Standard_Integer code = theShape.HashCode(upper);
+    size_t code = TopTools_ShapeMapHasher{}(theShape);
     std::cout << TopAbs::ShapeTypeToString (theShape.ShapeType()) << " : " << code
        << " " << TopAbs::ShapeOrientationToString(theShape.Orientation()) << std::endl;
   }
@@ -496,10 +492,9 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
 #ifdef OCCT_DEBUG
   if (BRepCheck_Trace(0) > 1) {
     TopTools_DataMapIteratorOfDataMapOfShapeInteger itt(MapOfShapeOrientation);
-    Standard_Integer upper = MapOfShapeOrientation.NbBuckets();
     std::cout << "La map shape Orientation :" << std::endl;
     for (; itt.More(); itt.Next()) {
-      PrintShape(itt.Key(), upper);
+      PrintShape(itt.Key());
     }
     std::cout << std::endl;
   }
@@ -720,7 +715,7 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
   if (BRepCheck_Trace(0) > 3)
   {
     std::cout << "Fref : " ;
-    PrintShape(Fref, MapOfShapeOrientation.NbBuckets());
+    PrintShape(Fref);
   }
 #endif
 
@@ -770,7 +765,7 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
   if (BRepCheck_Trace(0) > 3)
   {
     std::cout << "    Fcur : " ;
-    PrintShape(Fcur, MapOfShapeOrientation.NbBuckets());
+    PrintShape(Fcur);
   }
 #endif
             for (edFcur.Init(Fcur, TopAbs_EDGE); edFcur.More(); edFcur.Next())
@@ -798,7 +793,7 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
     Fcur.Orientation(orf);
     std::cout << "    Error : this face has been already examined " << std::endl;
     std::cout << "    Impossible to return it ";
-    PrintShape(Fcur, MapOfShapeOrientation.NbBuckets());
+    PrintShape(Fcur);
   }
 #endif
                 return myOstat;
@@ -813,7 +808,7 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
     orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
     Fcur.Orientation(orf);
     std::cout << "    Resulting Fcur is returned : " ;
-    PrintShape(Fcur, MapOfShapeOrientation.NbBuckets());
+    PrintShape(Fcur);
   }
 #endif
 
