@@ -34,20 +34,17 @@
 // Modified:	Mon Oct 12 09:42:33 1998
 //              number of edges in EdgesFromVertex (CTS21570) 
 
+#include <BRepFill.hxx>
+
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
-#include <BRepAdaptor_Curve.hxx>
 #include <BRepExtrema_DistShapeShape.hxx>
 #include <BRepExtrema_ExtPC.hxx>
-#include <BRepFill.hxx>
-#include <BRepGProp.hxx>
 #include <BRepLib.hxx>
 #include <BRepLib_FindSurface.hxx>
 #include <BRepLib_MakeEdge.hxx>
 #include <BRepLib_MakeFace.hxx>
-#include <BRepLib_MakeVertex.hxx>
 #include <BRepLib_MakeWire.hxx>
-#include <BRepLProp.hxx>
 #include <BRepTools_WireExplorer.hxx>
 #include <GCPnts_AbscissaPoint.hxx>
 #include <Geom2d_Line.hxx>
@@ -55,23 +52,15 @@
 #include <Geom_Plane.hxx>
 #include <Geom_Surface.hxx>
 #include <Geom_TrimmedCurve.hxx>
-#include <GeomAdaptor_Curve.hxx>
 #include <GeomFill_Generator.hxx>
 #include <gp_Ax3.hxx>
-#include <gp_Circ.hxx>
-#include <gp_Dir.hxx>
 #include <gp_Dir2d.hxx>
-#include <gp_Elips.hxx>
-#include <gp_Lin.hxx>
 #include <gp_Pln.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Pnt2d.hxx>
 #include <gp_Vec.hxx>
-#include <GProp_GProps.hxx>
-#include <GProp_PrincipalProps.hxx>
 #include <Precision.hxx>
 #include <Standard_NoSuchObject.hxx>
-#include <TColStd_Array1OfInteger.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
 #include <TopLoc_Location.hxx>
@@ -83,12 +72,8 @@
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
 #include <TopTools_Array1OfShape.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeListOfShape.hxx>
-#include <TopTools_DataMapOfShapeListOfShape.hxx>
-#include <TopTools_HSequenceOfShape.hxx>
 #include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
 #include <TopTools_IndexedMapOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_ListOfShape.hxx>
 #include <TopTools_SequenceOfShape.hxx>
 
@@ -1001,8 +986,8 @@ TopoDS_Wire BRepFill::InsertACR(const TopoDS_Wire& wire,
       }
     }
 
-    TopoDS_Edge E = anExp.Current();
-    TopoDS_Vertex V = anExp.CurrentVertex();
+    const TopoDS_Edge& E = anExp.Current();
+    const TopoDS_Vertex& V = anExp.CurrentVertex();
 
     if (ndec==0 || BRep_Tool::Degenerated(E)) {
       // copy the edge
