@@ -14,10 +14,8 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
+#include <BRepFill_Draft.hxx>
 
-#include <Adaptor3d_HCurve.hxx>
-#include <Adaptor3d_Surface.hxx>
-#include <Bnd_Box.hxx>
 #include <BndLib_Add3dCurve.hxx>
 #include <BndLib_AddSurface.hxx>
 #include <BOPAlgo_Builder.hxx>
@@ -25,15 +23,11 @@
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
 #include <BRepAdaptor_Curve.hxx>
-#include <BRepAdaptor_Surface.hxx>
 #include <BRepAlgoAPI_Section.hxx>
 #include <BRepBuilderAPI_Sewing.hxx>
 #include <BRepClass3d_SolidClassifier.hxx>
 #include <BRepExtrema_DistShapeShape.hxx>
-#include <BRepFill_DataMapOfShapeHArray2OfShape.hxx>
-#include <BRepFill_Draft.hxx>
 #include <BRepFill_DraftLaw.hxx>
-#include <BRepFill_SectionLaw.hxx>
 #include <BRepFill_ShapeLaw.hxx>
 #include <BRepFill_Sweep.hxx>
 #include <BRepLib_FindSurface.hxx>
@@ -47,22 +41,17 @@
 #include <Geom_RectangularTrimmedSurface.hxx>
 #include <Geom_Surface.hxx>
 #include <Geom_TrimmedCurve.hxx>
-#include <GeomAdaptor_HSurface.hxx>
 #include <GeomAdaptor_Surface.hxx>
 #include <GeomFill_LocationDraft.hxx>
 #include <GeomLProp_SLProps.hxx>
 #include <gp_Ax3.hxx>
 #include <gp_Dir.hxx>
-#include <gp_Lin.hxx>
 #include <gp_Mat.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Trsf.hxx>
 #include <Precision.hxx>
-#include <Standard_NoSuchObject.hxx>
 #include <StdFail_NotDone.hxx>
 #include <TColgp_Array1OfPnt.hxx>
-#include <TColStd_Array1OfReal.hxx>
-#include <TopAbs.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
 #include <TopoDS.hxx>
@@ -72,7 +61,6 @@
 #include <TopoDS_Shell.hxx>
 #include <TopoDS_Solid.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_ListOfShape.hxx>
 
 #ifdef DRAW
@@ -189,7 +177,7 @@ static Standard_Boolean GoodOrientation(const Bnd_Box& B,
   Nb++; // Number of points
 
   TColgp_Array1OfPnt Pnts(1, Nb);
-  Handle(Adaptor3d_HCurve) AC;
+  Handle(Adaptor3d_Curve) AC;
   gp_XYZ Bary(0.,0.,0.);
   
   for (ii=1; ii<=Nb; ii++) {
@@ -286,7 +274,7 @@ static Standard_Boolean GoodOrientation(const Bnd_Box& B,
     TopExp::Vertices(myWire, Vf, Vl);
     if (Vf.IsSame(Vl)) myWire.Closed(Standard_True);
   }
-#if DRAW
+#ifdef DRAW
   if (Affich) {
     DBRep::Set("TheWire", myWire);
   }
@@ -426,7 +414,7 @@ static Standard_Boolean GoodOrientation(const Bnd_Box& B,
   Handle(Geom_Plane) Plan = new (Geom_Plane)(Pt, myDir);
   Surf = new (Geom_RectangularTrimmedSurface) (Plan,-L, L, -L, L); 
 
-#if DRAW
+#ifdef DRAW
   if (Affich) {
     char* Temp = "ThePlan" ;
     DrawTrSurf::Set(Temp, Surf);
@@ -487,7 +475,7 @@ static Standard_Boolean GoodOrientation(const Bnd_Box& B,
   Handle(Geom_Curve) TC = new (Geom_TrimmedCurve) (L, 0, Length);
 
 
-#if DRAW
+#ifdef DRAW
   if (Affich > 2) {
      TC = new (Geom_Circle) (gp::XOY(), Length);
   }
@@ -723,7 +711,7 @@ static Standard_Boolean GoodOrientation(const Bnd_Box& B,
     TopTools_ListOfShape aLO, aLT;
     aLO.Append(Sol1);
     aLT.Append(Sol2);
-    aBuilder.BuildBOP(aLO, aLT, BOPAlgo_CUT);
+    aBuilder.BuildBOP(aLO, aLT, BOPAlgo_CUT, Message_ProgressRange());
     if (!aBuilder.HasErrors())
     {
       TopoDS_Solid aCutMin;
@@ -770,7 +758,7 @@ static Standard_Boolean GoodOrientation(const Bnd_Box& B,
 
         aLO.Clear();
         aLO.Append(aCutMin);
-        aGluer.BuildBOP(aLO, State1, aLT, State2);
+        aGluer.BuildBOP(aLO, State1, aLT, State2, Message_ProgressRange());
 
         if (!aGluer.HasErrors())
         {
@@ -792,7 +780,7 @@ static Standard_Boolean GoodOrientation(const Bnd_Box& B,
     aLO.Append(Sol1);
     aLT.Append(Sol2);
 
-    aBuilder.BuildBOP(aLO, State1, aLT, State2);
+    aBuilder.BuildBOP(aLO, State1, aLT, State2, Message_ProgressRange());
     if (aBuilder.HasErrors())
       return Standard_False;
 
