@@ -18,7 +18,6 @@
 #include <Adaptor3d_CurveOnSurface.hxx>
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
-#include <BRepBuilderAPI_Copy.hxx>
 #include <BRepBuilderAPI_Transform.hxx>
 #include <BRepClass3d_SolidClassifier.hxx>
 #include <BRepFill_Edge3DLaw.hxx>
@@ -44,11 +43,7 @@
 #include <Precision.hxx>
 #include <ShapeUpgrade_RemoveLocations.hxx>
 #include <Standard_DomainError.hxx>
-#include <Standard_ErrorHandler.hxx>
 #include <Standard_NotImplemented.hxx>
-#include <StdFail_NotDone.hxx>
-#include <TColStd_DataMapIteratorOfDataMapOfIntegerInteger.hxx>
-#include <TColStd_DataMapOfIntegerInteger.hxx>
 #include <TopAbs_ShapeEnum.hxx>
 #include <TopExp.hxx>
 #include <TopoDS.hxx>
@@ -61,9 +56,7 @@
 #include <TopoDS_Solid.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_DataMapOfShapeInteger.hxx>
 #include <TopTools_DataMapOfIntegerShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_SequenceOfShape.hxx>
 
 #ifdef DRAW
@@ -753,7 +746,7 @@ TopoDS_Shape BRepFill_Pipe::MakeShape(const TopoDS_Shape& S,
     TopExp_Explorer Explo(result, TopAbs_FACE);
     for (; Explo.More(); Explo.Next())
     {
-      TopoDS_Shape aFace = Explo.Current();
+      const TopoDS_Shape& aFace = Explo.Current();
       RebuildTopOrBottomFace(aFace.Reversed(), Standard_True); //top face was reversed
     }
     /////
@@ -994,7 +987,7 @@ void BRepFill_Pipe::RebuildTopOrBottomFace(const TopoDS_Shape& aFace,
     TopoDS_Iterator itw(aWire);
     for (; itw.More(); itw.Next())
     {
-      TopoDS_Shape anEdge = itw.Value();
+      const TopoDS_Shape& anEdge = itw.Value();
       for (ii = myCurIndexOfSectionEdge; ii <= mySections->ColLength(); ii++)
       {
         TopoDS_Shape aVisoEdge = mySections->Value(ii, IndexOfSection);
