@@ -21,11 +21,9 @@
 #include <BRepLib.hxx>
 #include <BRepMAT2d_Explorer.hxx>
 #include <BRepTools_WireExplorer.hxx>
-#include <GCE2d_MakeArcOfCircle.hxx>
 #include <GCE2d_MakeSegment.hxx>
 #include <Geom2d_BezierCurve.hxx>
 #include <Geom2d_BoundedCurve.hxx>
-#include <Geom2d_BSplineCurve.hxx>
 #include <Geom2d_Circle.hxx>
 #include <Geom2d_Curve.hxx>
 #include <Geom2d_Ellipse.hxx>
@@ -35,19 +33,12 @@
 #include <Geom2d_Parabola.hxx>
 #include <Geom2d_TrimmedCurve.hxx>
 #include <Geom2dConvert.hxx>
-#include <Geom_Curve.hxx>
-#include <Geom_TrimmedCurve.hxx>
 #include <GeomAbs_CurveType.hxx>
-#include <GeomAPI.hxx>
-#include <gp.hxx>
-#include <gp_Pln.hxx>
 #include <MAT2d_SequenceOfSequenceOfCurve.hxx>
 #include <Precision.hxx>
 #include <TColGeom2d_SequenceOfCurve.hxx>
-#include <TopAbs.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
-#include <TopLoc_Location.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Face.hxx>
 #include <TopoDS_Shape.hxx>
@@ -172,7 +163,7 @@ void BRepMAT2d_Explorer::Add(const TopoDS_Wire& Spine,
 
   // Treatment of the next edges:
   for (; anExp.More(); anExp.Next()) {
-    TopoDS_Edge  anEdge = anExp.Current();
+    const TopoDS_Edge&  anEdge = anExp.Current();
 
     anOldNewE.Add(anEdge, anEdge);
     C2d  = BRep_Tool::CurveOnSurface (anEdge, aFace, UFirst, ULast);
