@@ -14,11 +14,13 @@
 // commercial license or contractual agreement.
 
 #include <BRepMesh_EdgeTessellationExtractor.hxx>
+
 #include <BRepMesh_ShapeTool.hxx>
-#include <gp_Pnt.hxx>
 #include <BRep_Tool.hxx>
-#include <IMeshData_Face.hxx>
+#include <gp_Pnt.hxx>
 #include <IMeshData_Edge.hxx>
+#include <IMeshData_Face.hxx>
+#include <Poly_Triangulation.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(BRepMesh_EdgeTessellationExtractor, IMeshTools_CurveTessellator)
 
@@ -36,7 +38,7 @@ BRepMesh_EdgeTessellationExtractor::BRepMesh_EdgeTessellationExtractor (
   Handle (Poly_PolygonOnTriangulation) aPolygon =
     BRep_Tool::PolygonOnTriangulation (theEdge->GetEdge(), aTriangulation, myLoc);
 
-  myNodes   = &aTriangulation->Nodes ();
+  myTriangulation = aTriangulation.get();
   myIndices = &aPolygon->Nodes ();
   myProvider.Init (theEdge, TopAbs_FORWARD, theFace, aPolygon->Parameters ());
 }
@@ -67,8 +69,8 @@ Standard_Boolean BRepMesh_EdgeTessellationExtractor::Value (
   gp_Pnt&                thePoint,
   Standard_Real&         theParameter) const
 {
-  const gp_Pnt& theRefPnt = (*myNodes) ((*myIndices) (theIndex));
-  thePoint = BRepMesh_ShapeTool::UseLocation (theRefPnt, myLoc);
+  const gp_Pnt aRefPnt = myTriangulation->Node (myIndices->Value (theIndex));
+  thePoint = BRepMesh_ShapeTool::UseLocation (aRefPnt, myLoc);
 
   theParameter = myProvider.Parameter (theIndex, thePoint);
   return Standard_True;
