@@ -15,7 +15,6 @@
 
 #include <BRepMesh_ModelHealer.hxx>
 #include <BRepMesh_Deflection.hxx>
-#include <BRepMesh_ShapeTool.hxx>
 #include <BRepMesh_FaceChecker.hxx>
 #include <BRepMesh_EdgeDiscret.hxx>
 #include <IMeshData_Face.hxx>
@@ -51,14 +50,32 @@ namespace
     void operator()(const IMeshData::IEdgePtr& theDEdge) const
     {
       const IMeshData::IEdgeHandle aDEdge = theDEdge;
+
+      Standard_Integer aPointsNb = aDEdge->GetCurve()->ParametersNb();
+
       aDEdge->Clear(Standard_True);
       aDEdge->SetDeflection(Max(aDEdge->GetDeflection() / 3., Precision::Confusion()));
 
+      for (Standard_Integer aPCurveIt = 0; aPCurveIt < aDEdge->PCurvesNb(); ++aPCurveIt)
+      {
+        const IMeshData::IPCurveHandle& aPCurve = aDEdge->GetPCurve(aPCurveIt);
+        const IMeshData::IFaceHandle    aDFace  = aPCurve->GetFace();
+
+        // Check that outer wire contains 2 edges or less and add an additional point.
+        const IMeshData::IWireHandle&   aDWire  = aDFace->GetWire(0);
+        if (aDWire->EdgesNb() <= 2)
+        {
+          ++aPointsNb;
+          break;
+        }
+      }
+
       const IMeshData::IPCurveHandle& aPCurve = aDEdge->GetPCurve(0);
       const IMeshData::IFaceHandle    aDFace = aPCurve->GetFace();
       Handle(IMeshTools_CurveTessellator) aTessellator =
         BRepMesh_EdgeDiscret::CreateEdgeTessellator(
-          aDEdge, aPCurve->GetOrientation(), aDFace, myParameters);
+          aDEdge, aPCurve->GetOrientation(), aDFace,
+          myParameters, aPointsNb);
 
       BRepMesh_EdgeDiscret::Tessellate3d(aDEdge, aTessellator, Standard_False);
       BRepMesh_EdgeDiscret::Tessellate2d(aDEdge, Standard_False);
