@@ -15,8 +15,6 @@
 
 #include <BRepMeshData_Wire.hxx>
 #include <IMeshData_Edge.hxx>
-#include <BRepMesh_OrientedEdge.hxx>
-#include <BRepMesh_Vertex.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(BRepMeshData_Wire, IMeshData_Wire)
 
