@@ -17,11 +17,12 @@
 
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
+#include <BRepAdaptor_Curve.hxx>
 #include <BRepAdaptor_Surface.hxx>
+#include <BRepAlgo.hxx>
 #include <BRepAlgo_FaceRestrictor.hxx>
 #include <BRepBuilderAPI_MakeFace.hxx>
-#include <BRepFill_ListIteratorOfListOfOffsetWire.hxx>
-#include <BRepFill_OffsetWire.hxx>
+#include <BRepLib.hxx>
 #include <BRepOffsetAPI_MakeOffset.hxx>
 #include <BRepTopAdaptor_FClass2d.hxx>
 #include <Extrema_ExtPS.hxx>
@@ -37,13 +38,56 @@
 #include <TopoDS_Shape.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 #ifdef OCCT_DEBUG
 #include <BRepTools.hxx>
 static Standard_Boolean AffichSpine = Standard_False;
 #endif
 
+static Standard_Boolean NeedsConvertion (const TopoDS_Wire& theWire)
+{
+  TopoDS_Iterator anIter (theWire);
+  for (; anIter.More(); anIter.Next())
+  {
+    const TopoDS_Edge& anEdge = TopoDS::Edge (anIter.Value());
+    BRepAdaptor_Curve aBAcurve (anEdge);
+    GeomAbs_CurveType aType = aBAcurve.GetType();
+    if (aType != GeomAbs_Line &&
+        aType != GeomAbs_Circle)
+      return Standard_True;
+  }
+
+  return Standard_False;
+}
+
+TopoDS_Face BRepOffsetAPI_MakeOffset::ConvertFace (const TopoDS_Face&  theFace,
+                                                   const Standard_Real theAngleTolerance)
+{
+  TopAbs_Orientation anOr = theFace.Orientation();
+  TopoDS_Face aFace = theFace;
+  aFace.Orientation (TopAbs_FORWARD);
+
+  TopoDS_Face aNewFace = TopoDS::Face (aFace.EmptyCopied());
+  BRep_Builder aBB;
+  TopoDS_Iterator anIter (aFace);
+  for (; anIter.More(); anIter.Next())
+  {
+    TopoDS_Wire aWire = TopoDS::Wire (anIter.Value());
+    if (NeedsConvertion (aWire))
+    {
+      TopAbs_Orientation anOrOfWire = aWire.Orientation();
+      aWire.Orientation (TopAbs_FORWARD);
+      aWire = BRepAlgo::ConvertWire (aWire, theAngleTolerance, aFace);
+      BRepLib::BuildCurves3d (aWire);
+      aWire.Orientation (anOrOfWire);
+    }
+    aBB.Add (aNewFace, aWire);
+  }
+  aNewFace.Orientation (anOr);
+
+  return aNewFace;
+}
+
 //=======================================================================
 //function : BRepOffsetAPI_MakeOffset
 //purpose  : 
@@ -52,7 +96,8 @@ static Standard_Boolean AffichSpine = Standard_False;
 BRepOffsetAPI_MakeOffset::BRepOffsetAPI_MakeOffset()
   : myIsInitialized( Standard_False),
     myJoin(GeomAbs_Arc),
-    myIsOpenResult(Standard_False)
+    myIsOpenResult(Standard_False),
+    myIsToApprox(Standard_False)
 {
 }
 
@@ -83,6 +128,7 @@ void BRepOffsetAPI_MakeOffset::Init(const TopoDS_Face&     Spine,
   myIsInitialized = Standard_True;
   myJoin          = Join;
   myIsOpenResult  = IsOpenResult;
+  myIsToApprox = Standard_False;
   TopExp_Explorer exp;
   for (exp.Init(myFace,TopAbs_WIRE); exp.More();exp.Next()) {
     myWires.Append(exp.Current());
@@ -102,6 +148,7 @@ BRepOffsetAPI_MakeOffset::BRepOffsetAPI_MakeOffset(const TopoDS_Wire& Spine,
   myIsInitialized = Standard_True;
   myJoin = Join;
   myIsOpenResult  = IsOpenResult;
+  myIsToApprox = Standard_False;
 }
 
 //=======================================================================
@@ -116,6 +163,18 @@ void BRepOffsetAPI_MakeOffset::Init(const GeomAbs_JoinType Join,
   myIsOpenResult  = IsOpenResult;
 }
 
+//=======================================================================
+//function : SetApprox
+//purpose  : Set approximation flag
+//           for convertion input contours into ones consisting of
+//           2D circular arcs and 2D linear segments only
+//=======================================================================
+
+void BRepOffsetAPI_MakeOffset::SetApprox(const Standard_Boolean ToApprox)
+{
+  myIsToApprox = ToApprox;
+}
+
 //=======================================================================
 //function : BRepOffsetAPI_MakeOffset
 //purpose  : 
@@ -176,7 +235,7 @@ static void BuildDomains(TopoDS_Face&               myFace,
   //====================================================
   TopTools_ListIteratorOfListOfShape itl(WorkWires);
   for (; itl.More(); itl.Next()) {
-    TopoDS_Wire& W = TopoDS::Wire(itl.Value());
+    TopoDS_Wire& W = TopoDS::Wire(itl.ChangeValue());
     if (W.Closed()){
       FR.Add(W);
       continue;
@@ -232,7 +291,7 @@ static void BuildDomains(TopoDS_Face&               myFace,
 //  for (TopTools_ListIteratorOfListOfShape itF(Faces); itF.More(); itF.Next()) {
   TopTools_ListIteratorOfListOfShape itF;
   for (itF.Initialize(Faces) ; itF.More(); itF.Next()) {
-    TopoDS_Face&          F = TopoDS::Face(itF.Value());
+    TopoDS_Face&          F = TopoDS::Face(itF.ChangeValue());
     BRepAdaptor_Surface   S(F,0);
     Standard_Real         Tol = BRep_Tool::Tolerance(F); 
 
@@ -240,7 +299,7 @@ static void BuildDomains(TopoDS_Face&               myFace,
 
     TopTools_ListIteratorOfListOfShape itW(LOW);
     while (itW.More()) {
-      TopoDS_Wire& W = TopoDS::Wire(itW.Value());
+      const TopoDS_Wire& W = TopoDS::Wire(itW.Value());
       //=======================================================
       // Choice of a point on the wire. + projection on the face.
       //=======================================================
@@ -292,6 +351,46 @@ void BRepOffsetAPI_MakeOffset::Perform(const Standard_Real Offset,
 
   try
   {
+    if (myIsToApprox)
+    {
+      Standard_Real aTol = 0.1;
+      if (myFace.IsNull())
+      {
+        TopoDS_Face aFace;
+        Standard_Boolean OnlyPlane = Standard_True;
+        TopTools_ListIteratorOfListOfShape anItl (myWires);
+        for (; anItl.More(); anItl.Next())
+        {
+          BRepBuilderAPI_MakeFace aFaceMaker (TopoDS::Wire(anItl.Value()), OnlyPlane);
+          if (aFaceMaker.Error() == BRepBuilderAPI_FaceDone)
+          {
+            aFace = aFaceMaker.Face();
+            break;
+          }
+        }
+        for (anItl.Initialize(myWires); anItl.More(); anItl.Next())
+        {
+          const TopoDS_Wire& aWire = TopoDS::Wire(anItl.Value());
+          if (NeedsConvertion (aWire))
+          {
+            TopoDS_Wire aNewWire = BRepAlgo::ConvertWire (aWire, aTol, aFace);
+            BRepLib::BuildCurves3d (aNewWire);
+            aNewWire.Orientation (aWire.Orientation());
+            anItl.ChangeValue() = aNewWire;
+          }
+        }
+      }
+      else
+      {
+        myFace = ConvertFace (myFace, aTol);
+        BRepLib::BuildCurves3d (myFace);
+        myWires.Clear();
+        TopoDS_Iterator anIter (myFace);
+        for (; anIter.More(); anIter.Next())
+          myWires.Append (anIter.Value());
+      }
+    }
+    
     Standard_Integer i = 1;
     BRepFill_ListIteratorOfListOfOffsetWire itOW;
     TopoDS_Compound Res;
@@ -310,7 +409,7 @@ void BRepOffsetAPI_MakeOffset::Perform(const Standard_Real Offset,
 
       for (itOW.Initialize(myLeft); itOW.More(); itOW.Next())
       {
-        BRepFill_OffsetWire& Algo = itOW.Value();
+        BRepFill_OffsetWire& Algo = itOW.ChangeValue();
         Algo.Perform(Abs(Offset),Alt);
         if (Algo.IsDone() && !Algo.Shape().IsNull())
         {
@@ -333,7 +432,7 @@ void BRepOffsetAPI_MakeOffset::Perform(const Standard_Real Offset,
 
       for(itOW.Initialize(myRight); itOW.More(); itOW.Next())
       {
-        BRepFill_OffsetWire& Algo = itOW.Value();
+        BRepFill_OffsetWire& Algo = itOW.ChangeValue();
         Algo.Perform(Offset,Alt);
 
         if (Algo.IsDone() && !Algo.Shape().IsNull())
@@ -395,7 +494,7 @@ const TopTools_ListOfShape& BRepOffsetAPI_MakeOffset::Generated
     Algos = &myRight;
   }
   for (itOW.Initialize(*Algos); itOW.More(); itOW.Next()) {
-    BRepFill_OffsetWire& OW = itOW.Value();
+    BRepFill_OffsetWire& OW = itOW.ChangeValue();
     TopTools_ListOfShape L;
     L =  OW.GeneratedShapes(S.Oriented(TopAbs_FORWARD));
     myGenerated.Append(L);
