@@ -15,12 +15,9 @@
 // commercial license or contractual agreement.
 
 
-#include <BRepOffset_MakeOffset.hxx>
 #include <BRepOffsetAPI_MakeThickSolid.hxx>
-#include <Standard_ConstructionError.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Shape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 
 //=======================================================================
@@ -112,7 +109,7 @@ const TopTools_ListOfShape& BRepOffsetAPI_MakeThickSolid::Modified (const TopoDS
       // Useful only for faces without influence on others.
       TopTools_ListIteratorOfListOfShape it(myGenerated);
       for (; it.More(); it.Next())
-        it.Value().Reverse();
+        it.ChangeValue().Reverse();
     }
   }
   else if (myLastUsedAlgo == OffsetAlgo_SIMPLE)
