@@ -15,8 +15,6 @@
 // commercial license or contractual agreement.
 
 
-#include <BRepPrim_Builder.hxx>
-#include <BRepPrim_Direction.hxx>
 #include <BRepPrim_GWedge.hxx>
 #include <ElCLib.hxx>
 #include <ElSLib.hxx>
@@ -27,12 +25,9 @@
 #include <gp_Vec.hxx>
 #include <Precision.hxx>
 #include <Standard_DomainError.hxx>
-#include <Standard_OutOfRange.hxx>
 #include <TopoDS_Edge.hxx>
-#include <TopoDS_Face.hxx>
 #include <TopoDS_Shell.hxx>
 #include <TopoDS_Vertex.hxx>
-#include <TopoDS_Wire.hxx>
 
 #define NBFACES 6
 #define NBWIRES 6
