@@ -16,16 +16,10 @@
 
 
 #include <BRepBuilderAPI.hxx>
-#include <BRepPrim_Direction.hxx>
-#include <BRepPrim_Wedge.hxx>
 #include <BRepPrimAPI_MakeBox.hxx>
 #include <gp_Ax2.hxx>
 #include <gp_Pnt.hxx>
-#include <Standard_DomainError.hxx>
-#include <Standard_OutOfRange.hxx>
-#include <StdFail_NotDone.hxx>
 #include <TopoDS.hxx>
-#include <TopoDS_Face.hxx>
 #include <TopoDS_Shell.hxx>
 #include <TopoDS_Solid.hxx>
 
