@@ -19,18 +19,14 @@
 #include <BinLDrivers_DocumentSection.hxx>
 #include <BinLDrivers_Marker.hxx>
 #include <BinMDataStd.hxx>
-#include <BinMDF_ADriver.hxx>
 #include <BinMDF_ADriverTable.hxx>
 #include <BinObjMgt_Persistent.hxx>
 #include <CDM_Application.hxx>
-#include <CDM_Document.hxx>
 #include <Message_Messenger.hxx>
 #include <FSD_BinaryFile.hxx>
 #include <FSD_FileHeader.hxx>
 #include <OSD_FileSystem.hxx>
-#include <PCDM_Document.hxx>
 #include <PCDM_ReadWriter.hxx>
-#include <Standard_ErrorHandler.hxx>
 #include <Standard_Stream.hxx>
 #include <Standard_Type.hxx>
 #include <Storage_HeaderData.hxx>
@@ -40,7 +36,6 @@
 #include <TDF_Attribute.hxx>
 #include <TDF_Data.hxx>
 #include <TDF_Label.hxx>
-#include <TDF_Tool.hxx>
 #include <TDocStd_Document.hxx>
 #include <TDocStd_FormatVersion.hxx>
 #include <TDocStd_Owner.hxx>
@@ -78,7 +73,7 @@ void BinLDrivers_DocumentRetrievalDriver::Read
                           const Message_ProgressRange&      theRange)
 {
   const Handle(OSD_FileSystem)& aFileSystem = OSD_FileSystem::DefaultFileSystem();
-  opencascade::std::shared_ptr<std::istream> aFileStream = aFileSystem->OpenIStream (theFileName, std::ios::in | std::ios::binary);
+  std::shared_ptr<std::istream> aFileStream = aFileSystem->OpenIStream (theFileName, std::ios::in | std::ios::binary);
 
   if (aFileStream.get() != NULL && aFileStream->good())
   {
@@ -234,11 +229,12 @@ void BinLDrivers_DocumentRetrievalDriver::Read (Standard_IStream&
   if (aFileVer >= TDocStd_FormatVersion_VERSION_3) {
     BinLDrivers_DocumentSection aSection;
     do {
-      BinLDrivers_DocumentSection::ReadTOC (aSection, theIStream, aFileVer);
+      if (!BinLDrivers_DocumentSection::ReadTOC (aSection, theIStream, aFileVer))
+        break;
       mySections.Append(aSection);
     } while (!aSection.Name().IsEqual (aQuickPart ? ENDSECTION_POS : SHAPESECTION_POS) && !theIStream.eof());
 
-    if (theIStream.eof()) {
+    if (mySections.IsEmpty() || theIStream.eof()) {
       // There is no shape section in the file.
       myMsgDriver->Send (aMethStr + "error: shape section is not found", Message_Fail);
       myReaderStatus = PCDM_RS_ReaderException;
