@@ -22,8 +22,6 @@
 #include <BinObjMgt_SRelocationTable.hxx>
 #include <Message_Messenger.hxx>
 #include <Standard_Type.hxx>
-#include <TCollection_ExtendedString.hxx>
-#include <TColStd_HPackedMapOfInteger.hxx>
 #include <TColStd_MapIteratorOfPackedMapOfInteger.hxx>
 #include <TColStd_PackedMapOfInteger.hxx>
 #include <TDataStd_IntPackedMap.hxx>
