@@ -13,10 +13,9 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
+#include <BinMXCAFDoc.hxx>
 
 #include <BinMDF_ADriverTable.hxx>
-#include <BinMNaming_NamedShapeDriver.hxx>
-#include <BinMXCAFDoc.hxx>
 #include <BinMXCAFDoc_AssemblyItemRefDriver.hxx>
 #include <BinMXCAFDoc_CentroidDriver.hxx>
 #include <BinMXCAFDoc_ColorDriver.hxx>
@@ -26,7 +25,6 @@
 #include <BinMXCAFDoc_LengthUnitDriver.hxx>
 #include <BinMXCAFDoc_LocationDriver.hxx>
 #include <BinMXCAFDoc_MaterialDriver.hxx>
-#include <BinMXCAFDoc_NoteDriver.hxx>
 #include <BinMXCAFDoc_NoteBinDataDriver.hxx>
 #include <BinMXCAFDoc_NoteCommentDriver.hxx>
 #include <BinMXCAFDoc_VisMaterialDriver.hxx>
