@@ -16,15 +16,12 @@
 
 #include <BinTools.hxx>
 #include <BinTools_Curve2dSet.hxx>
-#include <BinTools_CurveSet.hxx>
-#include <BinTools_LocationSet.hxx>
 #include <BinTools_ShapeSet.hxx>
 #include <BinTools_SurfaceSet.hxx>
 #include <BRep_CurveOnClosedSurface.hxx>
 #include <BRep_CurveOnSurface.hxx>
 #include <BRep_CurveRepresentation.hxx>
 #include <BRep_GCurve.hxx>
-#include <BRep_ListIteratorOfListOfCurveRepresentation.hxx>
 #include <BRep_ListIteratorOfListOfPointRepresentation.hxx>
 #include <BRep_PointOnCurve.hxx>
 #include <BRep_PointOnCurveOnSurface.hxx>
@@ -37,14 +34,10 @@
 #include <BRep_Tool.hxx>
 #include <BRep_TVertex.hxx>
 #include <BRepTools.hxx>
-#include <gp_Trsf.hxx>
-#include <Poly_Polygon2D.hxx>
 #include <Poly_Polygon3D.hxx>
 #include <Poly_PolygonOnTriangulation.hxx>
 #include <Poly_Triangulation.hxx>
-#include <Precision.hxx>
 #include <Standard_ErrorHandler.hxx>
-#include <TColgp_Array1OfPnt2d.hxx>
 #include <TColStd_HArray1OfInteger.hxx>
 #include <TColStd_HArray1OfReal.hxx>
 #include <TopoDS.hxx>
@@ -486,8 +479,7 @@ void BinTools_ShapeSet::ReadFlagsAndSubs(TopoDS_Shape& S, const TopAbs_ShapeEnum
 
   S.Free(aFree);
   S.Modified(aMod);
-  if (FormatNb() != BinTools_FormatVersion_VERSION_2 &&
-      FormatNb() != BinTools_FormatVersion_VERSION_3)
+  if (FormatNb() == BinTools_FormatVersion_VERSION_1)
   {
     aChecked = false; // force check at reading
   }
