@@ -22,10 +22,8 @@
 #include <GccAna_Circ2dBisec.hxx>
 #include <GccAna_CircLin2dBisec.hxx>
 #include <GccAna_CircPnt2dBisec.hxx>
-#include <GccAna_Lin2dBisec.hxx>
 #include <GccAna_LinPnt2dBisec.hxx>
 #include <GccAna_Pnt2dBisec.hxx>
-#include <GccInt_Bisec.hxx>
 #include <GccInt_BLine.hxx>
 #include <GccInt_IType.hxx>
 #include <Geom2d_Circle.hxx>
@@ -38,19 +36,11 @@
 #include <Geom2d_Point.hxx>
 #include <Geom2d_TrimmedCurve.hxx>
 #include <Geom2dAdaptor_Curve.hxx>
-#include <Geom2dInt_GInter.hxx>
-#include <gp.hxx>
 #include <gp_Pnt2d.hxx>
 #include <gp_Trsf2d.hxx>
 #include <gp_Vec2d.hxx>
 #include <IntAna2d_AnaIntersection.hxx>
-#include <IntAna2d_IntPoint.hxx>
-#include <IntRes2d_Domain.hxx>
-#include <IntRes2d_IntersectionSegment.hxx>
 #include <Precision.hxx>
-#include <Standard_DomainError.hxx>
-#include <Standard_NotImplemented.hxx>
-#include <Standard_RangeError.hxx>
 #include <Standard_Type.hxx>
 #include <StdFail_NotDone.hxx>
 
