@@ -18,20 +18,14 @@
 #include <Bisector.hxx>
 #include <Bisector_BisecCC.hxx>
 #include <Bisector_BisecPC.hxx>
-#include <Bisector_Curve.hxx>
 #include <Bisector_FunctionH.hxx>
 #include <Bisector_PointOnBis.hxx>
 #include <Bisector_PolyBis.hxx>
-#include <Geom2d_Circle.hxx>
 #include <Geom2d_Curve.hxx>
 #include <Geom2d_Geometry.hxx>
 #include <Geom2d_Line.hxx>
-#include <Geom2d_TrimmedCurve.hxx>
-#include <Geom2dAdaptor_Curve.hxx>
 #include <Geom2dAPI_ProjectPointOnCurve.hxx>
-#include <Geom2dGcc.hxx>
 #include <Geom2dGcc_Circ2d2TanRad.hxx>
-#include <Geom2dGcc_QualifiedCurve.hxx>
 #include <Geom2dInt_GInter.hxx>
 #include <Geom2dLProp_CLProps2d.hxx>
 #include <gp.hxx>
@@ -43,11 +37,8 @@
 #include <math_FunctionRoot.hxx>
 #include <math_FunctionRoots.hxx>
 #include <Precision.hxx>
-#include <Standard_DivideByZero.hxx>
-#include <Standard_DomainError.hxx>
 #include <Standard_NotImplemented.hxx>
 #include <Standard_OutOfRange.hxx>
-#include <Standard_RangeError.hxx>
 #include <Standard_Type.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(Bisector_BisecCC,Bisector_Curve)
