@@ -15,9 +15,6 @@
 
 #include <Blend_AppFunction.hxx>
 #include <Blend_Point.hxx>
-#include <gp_Pnt.hxx>
-#include <math_Matrix.hxx>
-#include <Standard_DomainError.hxx>
 
 //=======================================================================
 //function : Parameter
