@@ -18,11 +18,6 @@
 #include <Blend_Point.hxx>
 #include <Blend_RstRstFunction.hxx>
 #include <gp_Pnt.hxx>
-#include <gp_Pnt2d.hxx>
-#include <gp_Vec.hxx>
-#include <gp_Vec2d.hxx>
-#include <math_Matrix.hxx>
-#include <Standard_DomainError.hxx>
 #include <Standard_NotImplemented.hxx>
 
 const gp_Pnt& Blend_RstRstFunction::Pnt1() const
