@@ -16,12 +16,9 @@
 
 
 #include <Adaptor2d_Curve2d.hxx>
-#include <Adaptor3d_Curve.hxx>
-#include <Adaptor3d_Surface.hxx>
 #include <BlendFunc.hxx>
 #include <BlendFunc_ChamfInv.hxx>
 #include <math_Matrix.hxx>
-#include <Precision.hxx>
 
 //=======================================================================
 //function : BlendFunc_ChamfInv
