@@ -15,9 +15,7 @@
 // commercial license or contractual agreement.
 
 
-#include <Adaptor2d_HCurve2d.hxx>
-#include <Adaptor3d_HCurve.hxx>
-#include <Adaptor3d_HSurface.hxx>
+#include <Adaptor2d_Curve2d.hxx>
 #include <BlendFunc.hxx>
 #include <BlendFunc_ConstRadInv.hxx>
 #include <math_Matrix.hxx>
@@ -26,9 +24,9 @@
 #define Eps 1.e-15
 
 
-BlendFunc_ConstRadInv::BlendFunc_ConstRadInv(const Handle(Adaptor3d_HSurface)& S1,
-					     const Handle(Adaptor3d_HSurface)& S2,
-					     const Handle(Adaptor3d_HCurve)& C)
+BlendFunc_ConstRadInv::BlendFunc_ConstRadInv(const Handle(Adaptor3d_Surface)& S1,
+					     const Handle(Adaptor3d_Surface)& S2,
+					     const Handle(Adaptor3d_Curve)& C)
 : surf1(S1),
   surf2(S2),
   curv(C),
@@ -79,7 +77,7 @@ void BlendFunc_ConstRadInv::Set(const Standard_Real R,
 }
 
 void BlendFunc_ConstRadInv::Set(const Standard_Boolean OnFirst,
-				const Handle(Adaptor2d_HCurve2d)& C)
+				const Handle(Adaptor2d_Curve2d)& C)
 {
   first = OnFirst;
   csurf = C;
