@@ -21,7 +21,6 @@
 #include <Bnd_Box.hxx>
 #include <BndLib.hxx>
 #include <BndLib_AddSurface.hxx>
-#include <BSplCLib.hxx>
 #include <ElSLib.hxx>
 #include <ElCLib.hxx>
 #include <Geom_BezierSurface.hxx>
@@ -29,17 +28,12 @@
 #include <GeomAbs_SurfaceType.hxx>
 #include <gp_Pln.hxx>
 #include <gp_Pnt.hxx>
-#include <gp_Cylinder.hxx>
 #include <gp_Cone.hxx>
-#include <gp_Lin.hxx>
 #include <Precision.hxx>
 #include <TColgp_Array2OfPnt.hxx>
 #include <TColStd_Array1OfInteger.hxx>
 #include <TColStd_Array1OfReal.hxx>
-#include <BndLib_Add3dCurve.hxx>
-#include <math_MultipleVarFunction.hxx>
 #include <math_PSO.hxx>
-#include <math_Matrix.hxx>
 #include <math_Powell.hxx>
 //
 static Standard_Integer NbUSamples(const Adaptor3d_Surface& S, 
@@ -726,7 +720,8 @@ public:
   myVMin(VMin),
   myVMax(VMax),
   myCoordIndx(CoordIndx),
-  mySign(Sign)
+  mySign(Sign),
+  myPenalty(0.)
   {
     math_Vector X(1,2);
     X(1) = UMin;
@@ -804,7 +799,7 @@ public:
 private:
   SurfMaxMinCoord & operator = (const SurfMaxMinCoord & theOther);
 
-  Standard_Boolean CheckInputData(const math_Vector theParams)
+  Standard_Boolean CheckInputData(const math_Vector& theParams)
   {
     if (theParams(1) < myUMin || 
         theParams(1) > myUMax || 
