@@ -16,30 +16,15 @@
 
 
 #include <Adaptor2d_Curve2d.hxx>
-#include <Adaptor3d_CurveOnSurface.hxx>
-#include <Adaptor3d_Surface.hxx>
-#include <Adaptor3d_TopolTool.hxx>
-#include <AppBlend_Approx.hxx>
 #include <Blend_CurvPointFuncInv.hxx>
 #include <Blend_FuncInv.hxx>
-#include <Blend_Function.hxx>
-#include <Blend_RstRstFunction.hxx>
-#include <Blend_SurfCurvFuncInv.hxx>
-#include <Blend_SurfPointFuncInv.hxx>
-#include <Blend_SurfRstFunction.hxx>
-#include <BRep_Tool.hxx>
-#include <BRepAdaptor_Curve.hxx>
-#include <BRepAdaptor_Curve2d.hxx>
-#include <BRepAdaptor_Surface.hxx>
 #include <BRepBlend_Line.hxx>
 #include <BRepTopAdaptor_TopolTool.hxx>
-#include <ChFi3d.hxx>
 #include <ChFi3d_Builder.hxx>
 #include <ChFi3d_Builder_0.hxx>
 #include <ChFiDS_CommonPoint.hxx>
 #include <ChFiDS_FaceInterference.hxx>
 #include <ChFiDS_HData.hxx>
-#include <ChFiDS_ElSpine.hxx>
 #include <ChFiDS_ListIteratorOfListOfStripe.hxx>
 #include <ChFiDS_SequenceOfSurfData.hxx>
 #include <ChFiDS_Spine.hxx>
@@ -51,30 +36,16 @@
 #include <Geom_BoundedCurve.hxx>
 #include <Geom_Curve.hxx>
 #include <Geom_Surface.hxx>
-#include <GeomAbs_Shape.hxx>
 #include <GeomAdaptor_Curve.hxx>
 #include <GeomAdaptor_Surface.hxx>
-#include <GeomAdaptor_Surface.hxx>
 #include <GeomLib.hxx>
-#include <gp_Ax3.hxx>
-#include <gp_Dir.hxx>
-#include <gp_Dir2d.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Pnt2d.hxx>
-#include <gp_Vec.hxx>
-#include <gp_Vec2d.hxx>
-#include <Precision.hxx>
-#include <Standard_ConstructionError.hxx>
-#include <Standard_Failure.hxx>
-#include <Standard_NoSuchObject.hxx>
 #include <Standard_NotImplemented.hxx>
-#include <Standard_OutOfRange.hxx>
-#include <StdFail_NotDone.hxx>
 #include <TColStd_Array1OfReal.hxx>
 #include <TopAbs.hxx>
 #include <TopAbs_Orientation.hxx>
 #include <TopAbs_ShapeEnum.hxx>
-#include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Edge.hxx>
@@ -87,10 +58,7 @@
 #include <TopOpeBRepDS_DataStructure.hxx>
 #include <TopOpeBRepDS_HDataStructure.hxx>
 #include <TopOpeBRepDS_ListOfInterference.hxx>
-#include <TopOpeBRepDS_Point.hxx>
-#include <TopOpeBRepDS_Surface.hxx>
 #include <TopOpeBRepDS_SurfaceCurveInterference.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 static void Reduce(const Standard_Real& p1,
 		   const Standard_Real& p2,
@@ -151,7 +119,7 @@ Standard_Boolean ChFi3d_Builder::PerformTwoCornerbyInter(const Standard_Integer
   //----------
   ChFiDS_ListIteratorOfListOfStripe It;
   It.Initialize(myVDataMap(Index));
-  Handle(ChFiDS_Stripe)& Corner1 = It.Value(); 
+  Handle(ChFiDS_Stripe)& Corner1 = It.ChangeValue();
   Standard_Integer Sens1;
   Standard_Integer IFd1 = 
     ChFi3d_IndexOfSurfData(Vtx,Corner1,Sens1);
@@ -162,7 +130,7 @@ Standard_Boolean ChFi3d_Builder::PerformTwoCornerbyInter(const Standard_Integer
   //the second
   //----------
   It.Next();
-  Handle(ChFiDS_Stripe)& Corner2 = It.Value(); 
+  Handle(ChFiDS_Stripe)& Corner2 = It.ChangeValue();
   Standard_Integer Sens2;
   Standard_Integer IFd2;
   if(Corner2 == Corner1) {
@@ -262,7 +230,7 @@ Standard_Boolean ChFi3d_Builder::PerformTwoCornerbyInter(const Standard_Integer
   }
   gp_Pnt psp1 = Hpivot->Value(parCP1);
   gp_Pnt psp2 = Hpivot->Value(parCP2);
-  Standard_Real sameparam = (psp1.Distance(psp2) < 10 * tolesp);
+  Standard_Real sameparam = (psp1.Distance(psp2) < 10.0 * tolapp3d);
    
   TopoDS_Face FF1 = TopoDS::Face(DStr.Shape(Fd1->Index(IFaArc1)));
   TopoDS_Face FF2 = TopoDS::Face(DStr.Shape(Fd2->Index(IFaArc2)));
@@ -321,10 +289,10 @@ Standard_Boolean ChFi3d_Builder::PerformTwoCornerbyInter(const Standard_Integer
       Reduce(UIntPC1,UIntPC2,HS1,HS2);
     }
     
-    Standard_Real tolreached = tolesp;
+    Standard_Real tolreached = tolapp3d;
     if (IFaCo1 == 1 && 
 	!ChFi3d_ComputeCurves(HS1,HS2,Pardeb,Parfin,Gc,
-			      PGc1,PGc2,tolesp,tol2d,tolreached)) {
+			      PGc1,PGc2,tolapp3d,tol2d,tolreached)) {
 #ifdef OCCT_DEBUG
       std::cout<<"failed to calculate bevel error interSS"<<std::endl;
 #endif
@@ -333,7 +301,7 @@ Standard_Boolean ChFi3d_Builder::PerformTwoCornerbyInter(const Standard_Integer
     }
     else if (IFaCo1 == 2 && 
 	     !ChFi3d_ComputeCurves(HS1,HS2,Parfin,Pardeb,Gc,
-				   PGc1,PGc2,tolesp,tol2d,tolreached)) {
+				   PGc1,PGc2,tolapp3d,tol2d,tolreached)) {
 #ifdef OCCT_DEBUG
       std::cout<<"failed to calculate bevel error interSS"<<std::endl;
 #endif
@@ -483,7 +451,7 @@ Standard_Boolean ChFi3d_Builder::PerformTwoCornerbyInter(const Standard_Integer
     
     Standard_Real tolreached;
     if (!ChFi3d_ComputeCurves(SmaHS,BigHS,Pardeb,Parfin,Gc,
-			      PGc1,PGc2,tolesp,tol2d,tolreached)) {
+			      PGc1,PGc2,tolapp3d,tol2d,tolreached)) {
 #ifdef OCCT_DEBUG
       std::cout<<"failed to calculate bevel failed interSS"<<std::endl;
 #endif
@@ -605,7 +573,7 @@ Standard_Boolean ChFi3d_Builder::PerformTwoCornerbyInter(const Standard_Integer
     ChFi3d_BoundFac (*HF, uu1, uu2, vv1, vv2, Standard_True);
 
     if (!ChFi3d_ComputeCurves(HF,BigHS,Pardeb,Parfin,Gc,
-			      PGc1,PGc2,tolesp,tol2d,tolreached)) {
+			      PGc1,PGc2,tolapp3d,tol2d,tolreached)) {
 #ifdef OCCT_DEBUG
       std::cout<<"fail calculation bevel fail interSS"<<std::endl;
 #endif
@@ -670,7 +638,26 @@ Standard_Boolean ChFi3d_Builder::PerformTwoCornerbyInter(const Standard_Integer
 }
 
 
+//=======================================================================
+//function : UpdateTolesp
+//purpose  : Update tolesp field to fit it to range of parameter of spine curve
+//=======================================================================
 
+void ChFi3d_Builder::UpdateTolesp()
+{
+  ChFiDS_ListIteratorOfListOfStripe itel;
+  // tolesp = Precision::Infinite();
+  for (itel.Initialize(myListStripe); itel.More(); itel.Next())
+  {
+    Handle(ChFiDS_Stripe)& curStripe = itel.ChangeValue();
+    Handle(ChFiDS_Spine)& Spine = curStripe->ChangeSpine();
+    const Standard_Real current_stripe_tolesp = Spine->GetTolesp();
+    if (tolesp > current_stripe_tolesp)
+    {
+      tolesp = current_stripe_tolesp;
+    }
+  }
+}
 
 
 
