@@ -16,12 +16,6 @@
 
 
 #include <Adaptor3d_TopolTool.hxx>
-#include <Blend_Point.hxx>
-#include <BlendFunc_SectionShape.hxx>
-#include <BRepAdaptor_Curve2d.hxx>
-#include <BRepAdaptor_Curve2d.hxx>
-#include <BRepAdaptor_Surface.hxx>
-#include <BRepAdaptor_Surface.hxx>
 #include <BRepBlend_Chamfer.hxx>
 #include <BRepBlend_ChamfInv.hxx>
 #include <BRepBlend_ConstThroat.hxx>
@@ -40,7 +34,6 @@
 #include <ChFiDS_CircSection.hxx>
 #include <ChFiDS_HData.hxx>
 #include <ChFiDS_ElSpine.hxx>
-#include <ChFiDS_ListIteratorOfListOfStripe.hxx>
 #include <ChFiDS_ListIteratorOfRegularities.hxx>
 #include <ChFiDS_ListOfStripe.hxx>
 #include <ChFiDS_Regul.hxx>
@@ -50,18 +43,15 @@
 #include <ChFiDS_SurfData.hxx>
 #include <ElSLib.hxx>
 #include <Extrema_GenLocateExtPS.hxx>
-#include <GeomAdaptor_Curve.hxx>
 #include <Standard_ConstructionError.hxx>
 #include <Standard_DomainError.hxx>
 #include <Standard_NotImplemented.hxx>
-#include <TopAbs.hxx>
 #include <TopoDS_Edge.hxx>
 #include <TopoDS_Face.hxx>
 #include <TopoDS_Shape.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopOpeBRepBuild_HBuilder.hxx>
 #include <TopOpeBRepDS_HDataStructure.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <memory>
 
 #ifdef OCCT_DEBUG
@@ -600,7 +590,7 @@ void ChFi3d_ChBuilder::Simulate (const Standard_Integer IC)
   Standard_Integer i = 1;
   for (itel.Initialize(myListStripe);itel.More(); itel.Next(), i++) {
     if(i == IC){
-      PerformSetOfSurf(itel.Value(), Standard_True);
+      PerformSetOfSurf(itel.ChangeValue(), Standard_True);
       break;
     }
   }
@@ -789,13 +779,8 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
     radius = Max(dis, radiusspine);
     locfleche = radius*1.e-2; //graphic criterion
 
-#if (defined(_MSC_VER) && (_MSC_VER < 1600))
-    std::auto_ptr<BlendFunc_GenChamfer>  pFunc;
-    std::auto_ptr<BlendFunc_GenChamfInv> pFInv;
-#else
     std::unique_ptr<BlendFunc_GenChamfer>  pFunc;
     std::unique_ptr<BlendFunc_GenChamfInv> pFInv;
-#endif  
     if (chsp->Mode() == ChFiDS_ClassicChamfer)
     {
       pFunc.reset(new BRepBlend_Chamfer(S1,S2,HGuide));
@@ -837,13 +822,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
     Data->SetSimul(sec);
     Data->Set2dPoints(pf1,pl1,pf2,pl2);
     ChFi3d_FilCommonPoint(lin->StartPointOnFirst(),lin->TransitionOnS1(),
-			  Standard_True, Data->ChangeVertexFirstOnS1(),tolesp);
+			  Standard_True, Data->ChangeVertexFirstOnS1(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->EndPointOnFirst(),lin->TransitionOnS1(),
-			  Standard_False,Data->ChangeVertexLastOnS1(),tolesp);
+			  Standard_False,Data->ChangeVertexLastOnS1(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->StartPointOnSecond(),lin->TransitionOnS2(),
-			  Standard_True, Data->ChangeVertexFirstOnS2(),tolesp);
+			  Standard_True, Data->ChangeVertexFirstOnS2(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->EndPointOnSecond(),lin->TransitionOnS2(),
-			  Standard_False, Data->ChangeVertexLastOnS2(),tolesp);
+			  Standard_False, Data->ChangeVertexLastOnS2(),tolapp3d);
     
     Standard_Boolean reverse = (!Forward || Inside);
     if(intf && reverse){
@@ -886,13 +871,8 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
     radius = Max(radius, radiusspine);
     locfleche = radius*1.e-2; //graphic criterion
 
-#if (defined(_MSC_VER) && (_MSC_VER < 1600))
-    std::auto_ptr<BlendFunc_GenChamfer>  pFunc;
-    std::auto_ptr<BlendFunc_GenChamfInv> pFInv;
-#else
     std::unique_ptr<BlendFunc_GenChamfer>  pFunc;
     std::unique_ptr<BlendFunc_GenChamfInv> pFInv;
-#endif  
     if (chsp->Mode() == ChFiDS_ClassicChamfer)
     {
       pFunc.reset(new BRepBlend_Chamfer(S1,S2,HGuide));
@@ -952,13 +932,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
     Data->SetSimul(sec);
     Data->Set2dPoints(pf1,pl1,pf2,pl2);
     ChFi3d_FilCommonPoint(lin->StartPointOnFirst(),lin->TransitionOnS1(),
-			Standard_True, Data->ChangeVertexFirstOnS1(),tolesp);
+			Standard_True, Data->ChangeVertexFirstOnS1(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->EndPointOnFirst(),lin->TransitionOnS1(),
-			  Standard_False,Data->ChangeVertexLastOnS1(),tolesp);
+			  Standard_False,Data->ChangeVertexLastOnS1(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->StartPointOnSecond(),lin->TransitionOnS2(),
-			  Standard_True, Data->ChangeVertexFirstOnS2(),tolesp);
+			  Standard_True, Data->ChangeVertexFirstOnS2(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->EndPointOnSecond(),lin->TransitionOnS2(),
-			  Standard_False, Data->ChangeVertexLastOnS2(),tolesp);
+			  Standard_False, Data->ChangeVertexLastOnS2(),tolapp3d);
     
     Standard_Boolean reverse = (!Forward || Inside);
     if(intf && reverse){
@@ -1037,13 +1017,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
     Data->SetSimul(sec);
     Data->Set2dPoints(pf1,pl1,pf2,pl2);
     ChFi3d_FilCommonPoint(lin->StartPointOnFirst(),lin->TransitionOnS1(),
-                          Standard_True, Data->ChangeVertexFirstOnS1(),tolesp);
+                          Standard_True, Data->ChangeVertexFirstOnS1(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->EndPointOnFirst(),lin->TransitionOnS1(),
-                          Standard_False,Data->ChangeVertexLastOnS1(),tolesp);
+                          Standard_False,Data->ChangeVertexLastOnS1(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->StartPointOnSecond(),lin->TransitionOnS2(),
-                          Standard_True, Data->ChangeVertexFirstOnS2(),tolesp);
+                          Standard_True, Data->ChangeVertexFirstOnS2(),tolapp3d);
     ChFi3d_FilCommonPoint(lin->EndPointOnSecond(),lin->TransitionOnS2(),
-                          Standard_False, Data->ChangeVertexLastOnS2(),tolesp);
+                          Standard_False, Data->ChangeVertexLastOnS2(),tolapp3d);
     
     Standard_Boolean reverse = (!Forward || Inside);
     if(intf && reverse){
@@ -1195,18 +1175,14 @@ Standard_Boolean ChFi3d_ChBuilder::PerformFirstSection
   if (chsp.IsNull()) 
     throw Standard_ConstructionError("PerformSurf : this is not the spine of a chamfer");
 
-  Standard_Real TolGuide = HGuide->Resolution(tolesp) ;
+  Standard_Real TolGuide = HGuide->Resolution(tolapp3d);
 
 
   if (chsp->IsChamfer() == ChFiDS_Sym) {
     Standard_Real dis;
     chsp->GetDist(dis);
     
-#if (defined(_MSC_VER) && (_MSC_VER < 1600))
-    std::auto_ptr<BlendFunc_GenChamfer>  pFunc;
-#else
     std::unique_ptr<BlendFunc_GenChamfer>  pFunc;
-#endif  
     if (chsp->Mode() == ChFiDS_ClassicChamfer)
     {
       pFunc.reset(new BRepBlend_Chamfer(S1,S2,HGuide));
@@ -1268,17 +1244,13 @@ Standard_Boolean ChFi3d_ChBuilder::PerformFirstSection
     }
     
     return TheWalk.PerformFirstSection(*pFunc,Par,SolDep,
-				       tolesp,TolGuide,Pos1,Pos2);
+				       tolapp3d,TolGuide,Pos1,Pos2);
   }
   else if (chsp->IsChamfer() == ChFiDS_TwoDist)  {
     Standard_Real dis1, dis2;
     chsp->Dists(dis1, dis2);
     
-#if (defined(_MSC_VER) && (_MSC_VER < 1600))
-    std::auto_ptr<BlendFunc_GenChamfer>  pFunc;
-#else
     std::unique_ptr<BlendFunc_GenChamfer>  pFunc;
-#endif  
     if (chsp->Mode() == ChFiDS_ClassicChamfer)
     {
       pFunc.reset(new BRepBlend_Chamfer(S1,S2,HGuide));
@@ -1375,7 +1347,7 @@ Standard_Boolean ChFi3d_ChBuilder::PerformFirstSection
     }
     
     return TheWalk.PerformFirstSection(*pFunc,Par,SolDep,
-				       tolesp,TolGuide,Pos1,Pos2);
+				       tolapp3d,TolGuide,Pos1,Pos2);
   }
   else { //distance and angle
     Standard_Real dis1, angle;
@@ -1443,7 +1415,7 @@ Standard_Boolean ChFi3d_ChBuilder::PerformFirstSection
     }
     
     return TheWalk.PerformFirstSection(Func,Par,SolDep,
-                                       tolesp,TolGuide,Pos1,Pos2);
+                                       tolapp3d,TolGuide,Pos1,Pos2);
   } //distance and angle
 }
 
@@ -1493,13 +1465,8 @@ ChFi3d_ChBuilder::PerformSurf(ChFiDS_SequenceOfSurfData&          SeqData,
 
   if (chsp->IsChamfer() == ChFiDS_Sym) {
     
-#if (defined(_MSC_VER) && (_MSC_VER < 1600))
-    std::auto_ptr<BlendFunc_GenChamfer>  pFunc;
-    std::auto_ptr<BlendFunc_GenChamfInv> pFInv;
-#else
     std::unique_ptr<BlendFunc_GenChamfer>  pFunc;
     std::unique_ptr<BlendFunc_GenChamfInv> pFInv;
-#endif  
     if (chsp->Mode() == ChFiDS_ClassicChamfer)
     {
       pFunc.reset(new BRepBlend_Chamfer(S1,S2,HGuide));
@@ -1527,13 +1494,8 @@ ChFi3d_ChBuilder::PerformSurf(ChFiDS_SequenceOfSurfData&          SeqData,
     Standard_Real d1, d2;
     chsp->Dists(d1,d2);
     
-#if (defined(_MSC_VER) && (_MSC_VER < 1600))
-    std::auto_ptr<BlendFunc_GenChamfer>  pFunc;
-    std::auto_ptr<BlendFunc_GenChamfInv> pFInv;
-#else
     std::unique_ptr<BlendFunc_GenChamfer>  pFunc;
     std::unique_ptr<BlendFunc_GenChamfInv> pFInv;
-#endif  
     if (chsp->Mode() == ChFiDS_ClassicChamfer)
     {
       pFunc.reset(new BRepBlend_Chamfer(S1,S2,HGuide));
