@@ -17,59 +17,37 @@
 
 #include <Adaptor3d_TopolTool.hxx>
 #include <BRep_Tool.hxx>
-#include <BRepAdaptor_Curve2d.hxx>
-#include <BRepAdaptor_Surface.hxx>
-#include <BRepAdaptor_Surface.hxx>
-#include <BRepLib_MakeEdge.hxx>
 #include <ChFi3d_Builder_0.hxx>
 #include <ChFi3d_ChBuilder.hxx>
 #include <ChFiDS_ChamfSpine.hxx>
 #include <ChFiDS_HData.hxx>
-#include <ChFiDS_ElSpine.hxx>
-#include <ChFiDS_ListIteratorOfListOfStripe.hxx>
 #include <ChFiDS_Regul.hxx>
-#include <ChFiDS_Spine.hxx>
 #include <ChFiDS_Stripe.hxx>
 #include <ChFiDS_SurfData.hxx>
 #include <ChFiKPart_ComputeData_Fcts.hxx>
 #include <ElCLib.hxx>
 #include <ElSLib.hxx>
 #include <Geom2d_Curve.hxx>
-#include <Geom2d_Line.hxx>
-#include <Geom2dAdaptor_Curve.hxx>
-#include <Geom2dAdaptor_Curve.hxx>
-#include <Geom2dInt_GInter.hxx>
 #include <Geom_BSplineSurface.hxx>
 #include <Geom_Curve.hxx>
-#include <Geom_Line.hxx>
 #include <Geom_Plane.hxx>
 #include <Geom_Surface.hxx>
 #include <Geom_TrimmedCurve.hxx>
-#include <GeomAbs_SurfaceType.hxx>
 #include <GeomAdaptor_Curve.hxx>
 #include <GeomAdaptor_Surface.hxx>
 #include <GeomAPI_ProjectPointOnCurve.hxx>
 #include <GeomAPI_ProjectPointOnSurf.hxx>
+#include <GeomFill_ConstrainedFilling.hxx>
 #include <GeomInt_IntSS.hxx>
-#include <gp.hxx>
 #include <gp_Dir.hxx>
-#include <gp_Dir2d.hxx>
-#include <gp_Lin2d.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Pnt2d.hxx>
 #include <gp_Vec.hxx>
 #include <gp_Vec2d.hxx>
-#include <IntCurveSurface_HInter.hxx>
-#include <IntCurveSurface_IntersectionPoint.hxx>
-#include <IntRes2d_IntersectionPoint.hxx>
 #include <Precision.hxx>
-#include <ProjLib_ProjectedCurve.hxx>
-#include <Standard_ConstructionError.hxx>
-#include <Standard_DomainError.hxx>
 #include <Standard_NotImplemented.hxx>
 #include <StdFail_NotDone.hxx>
 #include <TColStd_ListOfInteger.hxx>
-#include <TopoDS_Edge.hxx>
 #include <TopoDS_Face.hxx>
 #include <TopoDS_Shape.hxx>
 #include <TopoDS_Vertex.hxx>
@@ -82,10 +60,10 @@
 //           la distance de PntD par rapport au plan passant par les trois 
 //           points PntA, PntB, PntC
 //=======================================================================
-static Standard_Boolean CoPlanar(const gp_Pnt  PntA,
-	            const gp_Pnt  PntB,
-		    const gp_Pnt  PntC,
-		    const gp_Pnt  PntD)
+static Standard_Boolean CoPlanar(const gp_Pnt& PntA,
+                                 const gp_Pnt& PntB,
+                                 const gp_Pnt& PntC,
+                                 const gp_Pnt& PntD)
 {
   gp_Vec vecAB(PntA, PntB);
   gp_Vec vecAC(PntA, PntC);
@@ -500,7 +478,7 @@ void ChFi3d_ChBuilder::PerformThreeCorner(const Standard_Integer Jndex)
     if (!ComputeIntersection(DStr,fdpiv,coin,
 			     p3d[fin],p2d[fin],p3d[deb],p2d[deb],
 			     gcpiv,pivpc1,pivpc2,deru,derv,ptbid,
-			     tolesp,tol2d,tolrcoinpiv))
+			     tolapp3d,tol2d,tolrcoinpiv))
       throw StdFail_NotDone("echec calcul intersection coin-pivot");
     gp_Vec norpiv = deru.Crossed(derv);
     
@@ -517,7 +495,7 @@ void ChFi3d_ChBuilder::PerformThreeCorner(const Standard_Integer Jndex)
     if (!ComputeIntersection(DStr,fddeb,coin,
 			     p3d[pivot],p2d1,p3d[fin],p2d2,
 			     gcdeb,debpc1,debpc2,deru,derv,ptbid,
-			     tolesp,tol2d,tolrcoindeb))
+			     tolapp3d,tol2d,tolrcoindeb))
       throw StdFail_NotDone("echec calcul intersection coin-deb");
     Icf = DStr.AddCurve(TopOpeBRepDS_Curve(gcdeb,tolrcoindeb));    
 
@@ -536,7 +514,7 @@ void ChFi3d_ChBuilder::PerformThreeCorner(const Standard_Integer Jndex)
     if (!ComputeIntersection(DStr,fdfin,coin,
 			     p3dface,p2d1,p3d[deb],p2d2,
 			     gcfin,finpc1,finpc2,deru,derv,ptbid,
-			     tolesp,tol2d,tolrcoinfin)) 
+			     tolapp3d,tol2d,tolrcoinfin)) 
       throw StdFail_NotDone("echec calcul intersection coin-face");
     Icl = DStr.AddCurve(TopOpeBRepDS_Curve(gcfin,tolrcoinfin));  
     
@@ -565,8 +543,8 @@ void ChFi3d_ChBuilder::PerformThreeCorner(const Standard_Integer Jndex)
 	  gaf->Initialize(face[pivot]);
 	  
 	  Standard_Real tolr;
-	  ChFi3d_ProjectPCurv(gac,gaf,facepc1,tolesp,tolr);
-	  ChFi3d_ProjectPCurv(gac,gas,facepc2,tolesp,tolr);
+	  ChFi3d_ProjectPCurv(gac,gaf,facepc1,tolapp3d,tolr);
+	  ChFi3d_ProjectPCurv(gac,gas,facepc2,tolapp3d,tolr);
 	}
       }
     }
@@ -638,18 +616,18 @@ void ChFi3d_ChBuilder::PerformThreeCorner(const Standard_Integer Jndex)
       // les bords de coin sont des lignes courbes qui suivent les 
       // tangentes donnees
       Bfac = ChFi3d_mkbound(Fac,PCurveOnFace,sens[deb],p2d[pivot],Tgpiv,
-			    sens[fin],p2d[3],Tg3,tolesp,2.e-4);
+			    sens[fin],p2d[3],Tg3,tolapp3d,2.e-4);
       Bpiv = ChFi3d_mkbound(Surf,PCurveOnPiv,sens[deb],p2d[fin],vpfin,
-			    sens[fin],p2d[deb],vpdeb,tolesp,2.e-4);
+			    sens[fin],p2d[deb],vpdeb,tolapp3d,2.e-4);
     }
     else {
       // les bords de coin sont des segments
       //      Bfac = ChFi3d_mkbound(Fac,PCurveOnFace,p2d[pivot],
       //			    p2d[3],tolesp,2.e-4);
       Bfac = ChFi3d_mkbound(Fac,PCurveOnFace,p2d[pivot],
-			    p2d[3],tolesp,2.e-4);
+			    p2d[3],tolapp3d,2.e-4);
       Bpiv = ChFi3d_mkbound(Surf,PCurveOnPiv,p2d[fin],
-			    p2d[deb],tolesp,2.e-4);
+			    p2d[deb],tolapp3d,2.e-4);
     }
     
     gp_Pnt2d pdeb1 = fddeb->Interference(jf[deb][pivot]).PCurveOnSurf()->Value(p[deb][pivot]);
@@ -659,15 +637,15 @@ void ChFi3d_ChBuilder::PerformThreeCorner(const Standard_Integer Jndex)
     
     if (issmooth) {
       // il faut homogeneiser, mettre les bords "BoundWithSurf"
-      Bdeb = ChFi3d_mkbound(DStr.Surface(fddeb->Surf()).Surface(),pdeb1,pdeb2,tolesp,2.e-4);
-      Bfin = ChFi3d_mkbound(DStr.Surface(fdfin->Surf()).Surface(),pfin1,pfin2,tolesp,2.e-4);
+      Bdeb = ChFi3d_mkbound(DStr.Surface(fddeb->Surf()).Surface(),pdeb1,pdeb2,tolapp3d,2.e-4);
+      Bfin = ChFi3d_mkbound(DStr.Surface(fdfin->Surf()).Surface(),pfin1,pfin2,tolapp3d,2.e-4);
     }
     else {
       // ou les 4 bords de type "FreeBoundary"
       Bdeb = ChFi3d_mkbound(DStr.Surface(fddeb->Surf()).Surface(),pdeb1,pdeb2,
-			    tolesp,2.e-4,Standard_True);
+			    tolapp3d,2.e-4,Standard_True);
       Bfin = ChFi3d_mkbound(DStr.Surface(fdfin->Surf()).Surface(),pfin1,pfin2,
-			    tolesp,2.e-4,Standard_True);
+			    tolapp3d,2.e-4,Standard_True);
     }
     GeomFill_ConstrainedFilling fil(8,20);
     fil.Init(Bpiv,Bfin,Bfac,Bdeb);
@@ -726,7 +704,7 @@ void ChFi3d_ChBuilder::PerformThreeCorner(const Standard_Integer Jndex)
       ChFi3d_ComputeArete(Pf1,pp1,Pf2,pp2,
 			  DStr.Surface(coin->Surf()).Surface(),C3d,
 			  corner->ChangeFirstPCurve(),P1deb,P2deb,
-			  tolesp,tol2d,tolreached,0);
+        tolapp3d,tol2d,tolreached,0);
       TopOpeBRepDS_Curve Tcurv(C3d,tolreached);
       Icf = DStr.AddCurve(Tcurv);
     }
@@ -755,7 +733,7 @@ void ChFi3d_ChBuilder::PerformThreeCorner(const Standard_Integer Jndex)
       ChFi3d_ComputeArete(Pl1,pp1,Pl2,pp2,
 			  DStr.Surface(coin->Surf()).Surface(),C3d,
 			  corner->ChangeLastPCurve(),P1fin,P2fin,
-			  tolesp,tol2d,tolreached,0);
+        tolapp3d,tol2d,tolreached,0);
       TopOpeBRepDS_Curve Tcurv(C3d,tolreached);
       Icl = DStr.AddCurve(Tcurv);
     }
