@@ -17,15 +17,7 @@
 
 #include <Adaptor3d_CurveOnSurface.hxx>
 #include <Adaptor3d_CurveOnSurface.hxx>
-#include <Adaptor3d_TopolTool.hxx>
 #include <BRep_Tool.hxx>
-#include <BRepAdaptor_Curve.hxx>
-#include <BRepAdaptor_Curve2d.hxx>
-#include <BRepAdaptor_Curve.hxx>
-#include <BRepAdaptor_Curve2d.hxx>
-#include <BRepAdaptor_Surface.hxx>
-#include <BRepAdaptor_Surface.hxx>
-#include <BRepBlend_CSCircular.hxx>
 #include <BRepBlend_Line.hxx>
 #include <BRepLProp_CLProps.hxx>
 #include <BRepTopAdaptor_TopolTool.hxx>
@@ -37,8 +29,6 @@
 #include <ChFiDS_FaceInterference.hxx>
 #include <ChFiDS_FilSpine.hxx>
 #include <ChFiDS_HData.hxx>
-#include <ChFiDS_ElSpine.hxx>
-#include <ChFiDS_ListIteratorOfListOfStripe.hxx>
 #include <ChFiDS_Regul.hxx>
 #include <ChFiDS_SequenceOfSurfData.hxx>
 #include <ChFiDS_Spine.hxx>
@@ -46,40 +36,22 @@
 #include <ChFiDS_Stripe.hxx>
 #include <ChFiDS_SurfData.hxx>
 #include <ChFiKPart_ComputeData.hxx>
-#include <Geom2d_BSplineCurve.hxx>
+#include <Geom_BSplineSurface.hxx>
 #include <Geom2d_TrimmedCurve.hxx>
 #include <Geom2dAdaptor_Curve.hxx>
-#include <Geom2dAdaptor_Curve.hxx>
 #include <Geom2dConvert.hxx>
-#include <Geom_BSplineCurve.hxx>
-#include <Geom_BSplineSurface.hxx>
 #include <GeomAdaptor_Curve.hxx>
-#include <GeomAdaptor_Curve.hxx>
-#include <GeomAdaptor_Surface.hxx>
 #include <GeomAdaptor_Surface.hxx>
 #include <GeomFill_ConstrainedFilling.hxx>
 #include <GeomFill_SimpleBound.hxx>
 #include <gp_Ax3.hxx>
 #include <gp_Dir.hxx>
-#include <gp_Lin.hxx>
 #include <gp_Pln.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Pnt2d.hxx>
-#include <gp_XY.hxx>
-#include <IntCurveSurface_HInter.hxx>
-#include <IntCurveSurface_IntersectionPoint.hxx>
-#include <IntSurf_LineOn2S.hxx>
-#include <IntSurf_Transition.hxx>
-#include <IntSurf_TypeTrans.hxx>
-#include <Law_Function.hxx>
-#include <Law_Linear.hxx>
-#include <math_Vector.hxx>
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_NotImplemented.hxx>
 #include <StdFail_NotDone.hxx>
-#include <TColgp_Array1OfPnt.hxx>
-#include <TColgp_Array1OfPnt2d.hxx>
-#include <TColStd_Array1OfInteger.hxx>
 #include <TColStd_Array1OfReal.hxx>
 #include <TColStd_ListOfInteger.hxx>
 #include <TopAbs.hxx>
@@ -92,8 +64,6 @@
 #include <TopoDS_Vertex.hxx>
 #include <TopOpeBRepDS_DataStructure.hxx>
 #include <TopOpeBRepDS_HDataStructure.hxx>
-#include <TopOpeBRepDS_ListOfInterference.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 #ifdef DRAW
 #include <DrawTrSurf.hxx>
@@ -351,7 +321,7 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
     parCP2 = CP2.ParameterOnArc();
     gp_Pnt tst1 = Hpivot->Value(parCP1);
     gp_Pnt tst2 = Hpivot->Value(parCP2);
-    sameparam = tst1.Distance(tst2) <= tolesp;
+    sameparam = tst1.Distance(tst2) <= tolapp3d;
   }
   Handle(BRepAdaptor_Surface) HFaCo = new BRepAdaptor_Surface();
   Handle(BRepAdaptor_Surface) HFaPiv;
@@ -507,18 +477,18 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
 #ifdef OCCT_DEBUG
 	ChFi3d_InitChron(ch ); // init perf filling
 #endif 
-	B1 = ChFi3d_mkbound(surf1,p2df1,p2da1,tolesp,2.e-4);
-	B2 = ChFi3d_mkbound(surf2,p2df2,p2da2,tolesp,2.e-4);
+	B1 = ChFi3d_mkbound(surf1,p2df1,p2da1,tolapp3d,2.e-4);
+	B2 = ChFi3d_mkbound(surf2,p2df2,p2da2,tolapp3d,2.e-4);
 	Handle(Geom2d_Curve) PCurveOnFace;
 	Bfac = ChFi3d_mkbound(HFaCo,PCurveOnFace,Sens1,p2dfac1,v2dfac1,
-			      Sens2,p2dfac2,v2dfac2,tolesp,2.e-4);
+			      Sens2,p2dfac2,v2dfac2,tolapp3d,2.e-4);
 	GeomFill_ConstrainedFilling fil(8,20);
 	if(sameparam) {
 	  fil.Init(Bfac,B2,B1,1);
 	}
 	else {
 	  Handle(Adaptor3d_Curve) HPivTrim = Hpivot->Trim(Min(parCP1,parCP2),Max(parCP1,parCP2),tolesp);
-	  Bpiv = new GeomFill_SimpleBound(HPivTrim,tolesp,2.e-4);
+	  Bpiv = new GeomFill_SimpleBound(HPivTrim,tolapp3d,2.e-4);
 	  fil.Init(Bfac,B2,Bpiv,B1,1);
 	  BRepAdaptor_Curve2d pcpivot;
 	  gp_Vec dArc,dcf;
@@ -627,14 +597,14 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
 	ChFi3d_ComputeArete(Pf1,pp1,Pf2,pp2,
 			    DStr.Surface(coin->Surf()).Surface(),C3d,
 			    corner->ChangeFirstPCurve(),P1deb,P2deb,
-			    tolesp,tol2d,tolreached,0);
+			    tolapp3d,tol2d,tolreached,0);
 	Standard_Real par1 = sd1->Interference(IFaArc1).Parameter(isfirst1);
 	pp1 = sd1->Interference(IFaCo1).PCurveOnSurf()->Value(par1);
 	pp2 = sd1->Interference(IFaArc1).PCurveOnSurf()->Value(par1);
 	Standard_Real tolr1;
 	ChFi3d_ComputePCurv(C3d,pp1,pp2,st1->ChangePCurve(isfirst1),
 			    DStr.Surface(sd1->Surf()).Surface(),
-			    P1deb,P2deb,tolesp,tolr1);
+			    P1deb,P2deb,tolapp3d,tolr1);
 	tolreached = Max(tolreached,tolr1);
 	TopOpeBRepDS_Curve Tcurv1(C3d,tolreached);
 	Icf = DStr.AddCurve(Tcurv1);
@@ -654,14 +624,14 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
 	ChFi3d_ComputeArete(Pl1,pp1,Pl2,pp2,
 			    DStr.Surface(coin->Surf()).Surface(),C3d,
 			    corner->ChangeLastPCurve(),P1fin,P2fin,
-			    tolesp,tol2d,tolreached,0);
+			    tolapp3d,tol2d,tolreached,0);
 	Standard_Real par2 = sd2->Interference(IFaArc2).Parameter(isfirst2);
 	pp1 = sd2->Interference(IFaCo2).PCurveOnSurf()->Value(par2);
 	pp2 = sd2->Interference(IFaArc2).PCurveOnSurf()->Value(par2);
 	Standard_Real tolr2;
 	ChFi3d_ComputePCurv(C3d,pp1,pp2,st2->ChangePCurve(isfirst2),
 			    DStr.Surface(sd2->Surf()).Surface(),
-			    P1deb,P2deb,tolesp,tolr2);
+			    P1deb,P2deb,tolapp3d,tolr2);
 	tolreached = Max(tolreached,tolr2);
 	TopOpeBRepDS_Curve Tcurv2(C3d,tolreached);
 	Icl = DStr.AddCurve(Tcurv2);
@@ -762,7 +732,7 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
       Handle(Geom_Surface) surfsam = DStr.Surface(sdsam->Surf()).Surface();
       Handle(GeomAdaptor_Surface) Hsurfsam = new GeomAdaptor_Surface(surfsam);
       Handle(Geom2d_Curve) pcsurfsam;
-      Bsam = ChFi3d_mkbound(Hsurfsam,pcsurfsam,ppopsam,ppcosam,tolesp,2.e-4);
+      Bsam = ChFi3d_mkbound(Hsurfsam,pcsurfsam,ppopsam,ppcosam,tolapp3d,2.e-4);
       Standard_Real upcopdif = sddif->Interference(ifaopdif).Parameter(isfirstdif);
       gp_Pnt2d ppopdif = 
 	sddif->Interference(ifaopdif).PCurveOnSurf()->Value(upcopdif);
@@ -771,7 +741,7 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
       Handle(Geom_Surface) surfdif = DStr.Surface(sddif->Surf()).Surface();
       Handle(GeomAdaptor_Surface) Hsurfdif = new GeomAdaptor_Surface(surfdif);
       Handle(Geom2d_Curve) pcsurfdif;
-      Bdif = ChFi3d_mkbound(Hsurfdif,pcsurfdif,ppcodif,ppopdif,tolesp,2.e-4);
+      Bdif = ChFi3d_mkbound(Hsurfdif,pcsurfdif,ppcodif,ppopdif,tolapp3d,2.e-4);
       gp_Pnt2d ppfacsam,ppfacdif;
       gp_Pnt PPfacsam,PPfacdif;
       gp_Vec VVfacsam,VVfacdif;
@@ -803,7 +773,7 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
       Handle(Geom2d_Curve) pcFopsam = ChFi3d_BuildPCurve(HBRFopsam,
 							 ppfacsam,VVfacsam,
 							 ppfacdif,VVfacdif,1);
-      Bfac = ChFi3d_mkbound(HBRFopsam,pcFopsam,tolesp,2.e-4);
+      Bfac = ChFi3d_mkbound(HBRFopsam,pcFopsam,tolapp3d,2.e-4);
       GeomFill_ConstrainedFilling fil(8,20);
       fil.Init(Bsam,Bdif,Bfac,1);
 #if 0
@@ -857,10 +827,10 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
       ChFi3d_ComputeArete(Pf1,pp1,Pf2,pp2,
 			  DStr.Surface(coin->Surf()).Surface(),C3d,
 			  corner->ChangeFirstPCurve(),P1deb,P2deb,
-			  tolesp,tol2d,tolreached,0);
+			  tolapp3d,tol2d,tolreached,0);
       Standard_Real tolr1;
       Handle(GeomAdaptor_Curve) HC3d = new GeomAdaptor_Curve(C3d);
-      ChFi3d_SameParameter(HC3d,pcFopsam,HBRFopsam,tolesp,tolr1);
+      ChFi3d_SameParameter(HC3d,pcFopsam,HBRFopsam,tolapp3d,tolr1);
       tolreached = Max(tolreached,tolr1);
       TopOpeBRepDS_Curve Tcurv1(C3d,tolreached);
       Icf = DStr.AddCurve(Tcurv1);
@@ -888,10 +858,10 @@ void ChFi3d_FilBuilder::PerformTwoCorner(const Standard_Integer Index)
       ChFi3d_ComputeArete(Pl1,pp1,Pl2,pp2,
 			  DStr.Surface(coin->Surf()).Surface(),C3d,
 			  corner->ChangeLastPCurve(),P1fin,P2fin,
-			  tolesp,tol2d,tolreached,0);
+        tolapp3d,tol2d,tolreached,0);
       Standard_Real tolr2;
       HC3d->Load(C3d);
-      ChFi3d_SameParameter(HC3d,pcsurfdif,Hsurfdif,tolesp,tolr2);
+      ChFi3d_SameParameter(HC3d,pcsurfdif,Hsurfdif,tolapp3d,tolr2);
       tolreached = Max(tolreached,tolr2);
       TopOpeBRepDS_Curve Tcurv2(C3d,tolreached);
       Icl = DStr.AddCurve(Tcurv2);
