@@ -23,19 +23,10 @@
 #include <ChFiKPart_ComputeData_Fcts.hxx>
 #include <ElCLib.hxx>
 #include <ElSLib.hxx>
-#include <Geom2d_Circle.hxx>
-#include <Geom2d_Line.hxx>
-#include <Geom_Circle.hxx>
-#include <Geom_ConicalSurface.hxx>
-#include <gp.hxx>
-#include <gp_Ax2.hxx>
 #include <gp_Ax3.hxx>
 #include <gp_Circ.hxx>
 #include <gp_Dir.hxx>
-#include <gp_Dir2d.hxx>
-#include <gp_Lin2d.hxx>
 #include <gp_Pnt.hxx>
-#include <gp_Pnt2d.hxx>
 #include <gp_Vec.hxx>
 #include <Precision.hxx>
 #include <TopOpeBRepDS_DataStructure.hxx>
