@@ -26,7 +26,6 @@
 #include <Cocoa_LocalPool.hxx>
 
 #include <Image_AlienPixMap.hxx>
-#include <Aspect_Convert.hxx>
 #include <Aspect_WindowDefinitionError.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(Cocoa_Window,Aspect_Window)
@@ -111,7 +110,7 @@ Cocoa_Window::Cocoa_Window (const Standard_CString theTitle,
   myYBottom (thePxTop + thePxHeight)
 {
 #if defined(TARGET_OS_IPHONE) && TARGET_OS_IPHONE
-  //
+  (void )theTitle;
 #else
   if (thePxWidth <= 0 || thePxHeight <= 0)
   {
@@ -437,15 +436,6 @@ void Cocoa_Window::InvalidateContent (const Handle(Aspect_DisplayConnection)& )
     return;
   }
 
-  if ([NSThread isMainThread])
-  {
-  #if defined(TARGET_OS_IPHONE) && TARGET_OS_IPHONE
-    [myHView setNeedsDisplay];
-  #else
-    [myHView setNeedsDisplay: YES];
-  #endif
-  }
-  else
   {
     [myHView performSelectorOnMainThread: @selector(invalidateContentOcct:)
                               withObject: NULL
