@@ -16,14 +16,12 @@
 
 // jag 940616 Tolpetit = 1.e-16
 
-#include <Adaptor3d_Surface.hxx>
 #include <Adaptor3d_HSurfaceTool.hxx>
 #include <Contap_HContTool.hxx>
 #include <Contap_SurfFunction.hxx>
 #include <Contap_SurfProps.hxx>
 #include <gp_Dir.hxx>
 #include <gp_Dir2d.hxx>
-#include <gp_Pnt.hxx>
 #include <gp_Vec.hxx>
 #include <math_Matrix.hxx>
 #include <StdFail_UndefinedDerivative.hxx>
