@@ -128,7 +128,8 @@ IDirect3DSurface9* D3DHost_View::D3dColorSurface() const
 // function : SetWindow
 // purpose  :
 // =======================================================================
-void D3DHost_View::SetWindow (const Handle(Aspect_Window)& theWindow,
+void D3DHost_View::SetWindow (const Handle(Graphic3d_CView)& theParentVIew,
+                              const Handle(Aspect_Window)& theWindow,
                               const Aspect_RenderingContext theContext)
 {
   if (!myD3dWglFbo.IsNull())
@@ -142,7 +143,7 @@ void D3DHost_View::SetWindow (const Handle(Aspect_Window)& theWindow,
     myD3dDevice = NULL;
   }
 
-  OpenGl_View::SetWindow (theWindow, theContext);
+  OpenGl_View::SetWindow (theParentVIew, theWindow, theContext);
 
   if (!myWindow.IsNull())
   {
@@ -370,7 +371,7 @@ bool D3DHost_View::d3dSwap()
   }
 
   const HRESULT isOK = myD3dDevice->Present (NULL, NULL, NULL, NULL);
-  if (isOK != D3D_OK)
+  if (isOK != D3D_OK && isOK != S_PRESENT_OCCLUDED)
   {
     myWorkspace->GetGlContext()->PushMessage (GL_DEBUG_SOURCE_APPLICATION, GL_DEBUG_TYPE_ERROR, 0, GL_DEBUG_SEVERITY_HIGH,
                                               TCollection_AsciiString("Direct3D9, Present device failed, ") + d3dFormatError (isOK));
