@@ -14,6 +14,7 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
+#include <DBRep.hxx>
 
 #include <BRep_TEdge.hxx>
 #include <BRepAdaptor_Surface.hxx>
@@ -22,20 +23,14 @@
 #include <BRepTools_ShapeSet.hxx>
 #include <BRepTools_WireExplorer.hxx>
 #include <BinTools.hxx>
-#include <DBRep.hxx>
 #include <DBRep_DrawableShape.hxx>
-#include <Draw.hxx>
 #include <Draw_Appli.hxx>
 #include <Draw_ProgressIndicator.hxx>
 #include <Message_ProgressRange.hxx>
 #include <Draw_Segment3D.hxx>
-#include <gp_Ax2.hxx>
-#include <GProp.hxx>
 #include <GProp_GProps.hxx>
 #include <NCollection_Vector.hxx>
-#include <Poly_Triangulation.hxx>
-#include <Precision.hxx>
-#include <Standard.hxx>
+#include <OSD_FileSystem.hxx>
 #include <TColStd_Array1OfInteger.hxx>
 #include <TColStd_Array1OfReal.hxx>
 #include <TopAbs.hxx>
@@ -44,9 +39,7 @@
 #include <TopoDS.hxx>
 #include <TopoDS_Compound.hxx>
 #include <TopoDS_Iterator.hxx>
-#include <TopoDS_Shape.hxx>
 #include <TopTools_Array1OfShape.hxx>
-#include <TopTools_ListOfShape.hxx>
 #include <TopTools_MapOfShape.hxx>
 
 #include <stdio.h>
@@ -96,62 +89,64 @@ Standard_EXPORT Draw_Color DBRep_ColorOrientation (const TopAbs_Orientation Or)
   return col;
 }
 
-//==========================================
-// static variables
-//==========================================
-
-static Standard_Integer nbIsos  = 2;
-static Standard_Real    size    = 100.;
-static Standard_Integer discret = 30;
-static Standard_Boolean disptriangles = Standard_False;
-static Standard_Boolean disppolygons = Standard_False;
-static Standard_Real    anglHLR = 35 * M_PI / 180;
-static Standard_Real    HAngMin =  1 * M_PI / 180;
-static Standard_Real    HAngMax = 35 * M_PI / 180;
-static Standard_Boolean withHLR = Standard_False;
-static Standard_Boolean withRg1 = Standard_True;
-static Standard_Boolean withRgN = Standard_False;
-static Standard_Boolean withHid = Standard_False;
+//=======================================================================
+//function : Parameters
+//purpose  :
+//=======================================================================
+DBRep_Params& DBRep::Parameters()
+{
+  static DBRep_Params aParams;
+  return aParams;
+}
 
 //=======================================================================
 // isos
 //=======================================================================
 
-static Standard_Integer isos (Draw_Interpretor& di,
-			      Standard_Integer NbArg, const char **Arg)
+static Standard_Integer isos(Draw_Interpretor& di, Standard_Integer NbArg, const char **Arg)
 {
+  DBRep_Params& aParams = DBRep::Parameters();
   NbArg-- ;
-  
-  if (NbArg <= 0) {
-    di << "Current number of isos : " << nbIsos << "\n" ;
+  if (NbArg <= 0)
+  {
+    di << "Current number of isos : " << aParams.NbIsos << "\n" ;
     return 0 ;
   }
 
-  Standard_Integer NbIsos = 0 ;
+  Standard_Integer aNbIsos = 0;
   Standard_Boolean Change = Standard_False ;
   if (!Characters (NbArg) && Float (NbArg)) return 1 ;
-  if (!Characters (NbArg)) {
-    NbIsos = Draw::Atoi (Arg[NbArg]) ;
+  if (!Characters (NbArg))
+  {
+    aNbIsos = Draw::Atoi (Arg[NbArg]);
     NbArg-- ;
     Change = Standard_True ;
   }
 
-  if (NbArg <= 0) {
-    nbIsos = NbIsos ;
-    di << "New current number of isos : " << nbIsos << "\n" ;
-  } else {
-    for (Standard_Integer IArg = 1 ; IArg <= NbArg ; IArg++) {
+  if (NbArg <= 0)
+  {
+    aParams.NbIsos = aNbIsos;
+    di << "New current number of isos : " << aParams.NbIsos << "\n";
+  }
+  else
+  {
+    for (Standard_Integer IArg = 1 ; IArg <= NbArg ; IArg++)
+    {
       Handle (Draw_Drawable3D) Shape1 = Draw::Get (Arg[IArg]) ;
-      if (!Shape1.IsNull()) {
-	Handle (DBRep_DrawableShape) Shape2 =
-	  Handle (DBRep_DrawableShape)::DownCast (Shape1) ;	
-	if (!Shape2.IsNull()) {
-	  if (Change) {
-	    Shape2->ChangeNbIsos (NbIsos) ;
-	  } else {
-	    di << "Number of isos for " << Arg[IArg] << " : " << Shape2->NbIsos() << "\n";
-	  }
-	}
+      if (!Shape1.IsNull())
+      {
+        Handle (DBRep_DrawableShape) Shape2 = Handle (DBRep_DrawableShape)::DownCast (Shape1);
+        if (!Shape2.IsNull())
+        {
+          if (Change)
+          {
+            Shape2->ChangeNbIsos (aNbIsos);
+          }
+          else
+          {
+            di << "Number of isos for " << Arg[IArg] << " : " << Shape2->NbIsos() << "\n";
+          }
+        }
       }
     }
     if (Change) dout.RepaintAll() ;
@@ -164,23 +159,23 @@ static Standard_Integer isos (Draw_Interpretor& di,
 // hlr
 //=======================================================================
 
-static Standard_Integer hlr (Draw_Interpretor& di,
-			     Standard_Integer n, const char **a)
+static Standard_Integer hlr (Draw_Interpretor& di, Standard_Integer n, const char **a)
 {
-  if (n <= 1) {
-    if (withHLR) {
+  DBRep_Params& aParams = DBRep::Parameters();
+  if (n <= 1)
+  {
+    if (aParams.WithHLR)
+    {
       di << " HLR";
-      if (withRgN) di << " RgNLines";
-      else {
-	if (withRg1) di << " Rg1Lines";
-	else         di << " no RegLines";
-      }
-      if (withHid) di << " HiddenLines";
-      else         di << " no HiddenLines";
+      di << (aParams.WithRgN
+           ? " RgNLines"
+           : (aParams.WithRg1 ? " Rg1Lines" : " no RegLines"));
+      di << (aParams.WithHid ? " HiddenLines" : " no HiddenLines");
       di << "\n";
-      if (withHLR) {
-	di << "Angle of discretization : ";
-	di << anglHLR * 180 / M_PI << " degrees\n";
+      if (aParams.WithHLR)
+      {
+        di << "Angle of discretization : ";
+        di << aParams.HLRAngle * 180 / M_PI << " degrees\n";
       }
     }
     else di << " wireframe";
@@ -188,102 +183,141 @@ static Standard_Integer hlr (Draw_Interpretor& di,
     return 0 ;
   }
 
-  if (n == 2) {
-    if      (!strcasecmp(a[1],"nohlr")) withHLR = Standard_False;
-    else if (!strcasecmp(a[1],"hlr"  )) withHLR = Standard_True;
-    else if (!strcasecmp(a[1],"nohid")) withHid = Standard_False;
-    else if (!strcasecmp(a[1],"hid"  )) {
-      withHLR = Standard_True;
-      withHid = Standard_True;
+  if (n == 2)
+  {
+    if (!strcasecmp(a[1], "nohlr"))
+    {
+      aParams.WithHLR = Standard_False;
     }
-    else if (!strcasecmp(a[1],"norg1")) {
-      withRg1 = Standard_False;
-      withRgN = Standard_False;
+    else if (!strcasecmp (a[1], "hlr"))
+    {
+      aParams.WithHLR = Standard_True;
     }
-    else if (!strcasecmp(a[1],"rg1"  )) {
-      withHLR = Standard_True;
-      withRg1 = Standard_True;
-      withRgN = Standard_False;
+    else if (!strcasecmp (a[1], "nohid"))
+    {
+      aParams.WithHid = Standard_False;
     }
-    else if (!strcasecmp(a[1],"norgn")) {
-      withRgN = Standard_False;
+    else if (!strcasecmp(a[1], "hid"))
+    {
+      aParams.WithHLR = Standard_True;
+      aParams.WithHid = Standard_True;
     }
-    else if (!strcasecmp(a[1],"rgn"  )) {
-      withHLR = Standard_True;
-      withRg1 = Standard_True;
-      withRgN = Standard_True;
+    else if (!strcasecmp(a[1], "norg1"))
+    {
+      aParams.WithRg1 = Standard_False;
+      aParams.WithRgN = Standard_False;
     }
-    else if (!strcasecmp(a[1],"ang"  )) {
+    else if (!strcasecmp (a[1], "rg1"))
+    {
+      aParams.WithHLR = Standard_True;
+      aParams.WithRg1 = Standard_True;
+      aParams.WithRgN = Standard_False;
+    }
+    else if (!strcasecmp (a[1], "norgn"))
+    {
+      aParams.WithRgN = Standard_False;
+    }
+    else if (!strcasecmp (a[1], "rgn"))
+    {
+      aParams.WithHLR = Standard_True;
+      aParams.WithRg1 = Standard_True;
+      aParams.WithRgN = Standard_True;
+    }
+    else if (!strcasecmp (a[1], "ang"))
+    {
       di << "Angle de discretisation : ";
-      di << anglHLR * 180 / M_PI << " degres\n";
+      di << aParams.HLRAngle * 180 / M_PI << " degres\n";
     }
     else return 1;
   }
 
   Standard_Integer nFirst = 2;
 
-  if (n >= 3 && !strcasecmp(a[1],"ang"  )) {
+  if (n >= 3 && !strcasecmp (a[1], "ang"))
+  {
     nFirst = 3;
-    if (n == 3) {
+    if(n == 3)
+    {
       Standard_Real ang = Draw::Atof(a[2]);
-      anglHLR = ang * M_PI / 180;
-      if (anglHLR < HAngMin) anglHLR = HAngMin;
-      if (anglHLR > HAngMax) anglHLR = HAngMax;
-    }
-    di << "Angle of discretization : ";
-    di << anglHLR * 180 / M_PI << " degrees\n";
-  }
-
-  if (n >= nFirst + 1) {
-
-    for (Standard_Integer i = nFirst ; i < n; i++) {
-      Handle (Draw_Drawable3D) D = Draw::Get (a[i]) ;
-      if (!D.IsNull()) {
-	Handle (DBRep_DrawableShape) S =
-	  Handle (DBRep_DrawableShape)::DownCast (D) ;	
-	if (!S.IsNull()) {
-	  Standard_Boolean localHLR, localRg1, localRgN, localHid;
-	  Standard_Real localAng;
-	  S->GetDisplayHLR(localHLR, localRg1, localRgN, localHid,
-			   localAng);
-	  if      (!strcasecmp(a[1],"nohlr")) localHLR = Standard_False;
-	  else if (!strcasecmp(a[1],"hlr"  )) localHLR = Standard_True;
-	  else if (!strcasecmp(a[1],"nohid")) localHid = Standard_False;
-	  else if (!strcasecmp(a[1],"hid"  )) {
-	    localHLR = Standard_True;
-	    localHid = Standard_True;
-	  }
-	  else if (!strcasecmp(a[1],"norg1")) {
-	    localRg1 = Standard_False;
-	    localRgN = Standard_False;
-	  }
-	  else if (!strcasecmp(a[1],"rg1"  )) {
-	    localHLR = Standard_True;
-	    localRg1 = Standard_True;
-	    localRgN = Standard_False;
-	  }
-	  else if (!strcasecmp(a[1],"norgn")) {
-	    localRgN = Standard_False;
-	  }
-	  else if (!strcasecmp(a[1],"rgn"  )) {
-	    localHLR = Standard_True;
-	    localRg1 = Standard_True;
-	    localRgN = Standard_True;
-	  }
-	  else if (!strcasecmp(a[1],"ang"  )) {
-	    Standard_Real ang = Draw::Atof(a[2]);
-	    localAng = ang * M_PI / 180;
-	  }
-	  else return 1;
-	  S->DisplayHLR(localHLR, localRg1, localRgN, localHid,
-			localAng);
-	}
+      aParams.HLRAngle = ang * M_PI / 180;
+      if(aParams.HLRAngle < aParams.HAngMin)
+      {
+        aParams.HLRAngle = aParams.HAngMin;
+      }
+      if (aParams.HLRAngle > aParams.HAngMax)
+      {
+        aParams.HLRAngle = aParams.HAngMax;
       }
     }
+    di << "Angle of discretization : ";
+    di << aParams.HLRAngle * 180 / M_PI << " degrees\n";
   }
-  dout.RepaintAll() ;
 
-  return 0 ;
+  for (Standard_Integer i = nFirst; i < n; i++)
+  {
+    Handle(Draw_Drawable3D) D = Draw::Get (a[i]);
+    Handle(DBRep_DrawableShape) S = Handle(DBRep_DrawableShape)::DownCast (D);
+    if (S.IsNull())
+    {
+      continue;
+    }
+
+    bool localHLR = false, localRg1 = false, localRgN = false, localHid = false;
+    Standard_Real localAng = 0.0;
+    S->GetDisplayHLR(localHLR, localRg1, localRgN, localHid, localAng);
+    if (!strcasecmp (a[1], "nohlr"))
+    {
+      localHLR = Standard_False;
+    }
+    else if (!strcasecmp (a[1], "hlr"))
+    {
+      localHLR = Standard_True;
+    }
+    else if (!strcasecmp (a[1], "nohid"))
+    {
+      localHid = Standard_False;
+    }
+    else if (!strcasecmp (a[1], "hid"))
+    {
+      localHLR = Standard_True;
+      localHid = Standard_True;
+    }
+    else if (!strcasecmp (a[1], "norg1"))
+    {
+      localRg1 = Standard_False;
+      localRgN = Standard_False;
+    }
+    else if (!strcasecmp (a[1], "rg1"))
+    {
+      localHLR = Standard_True;
+      localRg1 = Standard_True;
+      localRgN = Standard_False;
+    }
+    else if (!strcasecmp (a[1], "norgn"))
+    {
+      localRgN = Standard_False;
+    }
+    else if (!strcasecmp (a[1], "rgn"))
+    {
+      localHLR = Standard_True;
+      localRg1 = Standard_True;
+      localRgN = Standard_True;
+    }
+    else if (!strcasecmp (a[1], "ang"))
+    {
+      Standard_Real ang = Draw::Atof (a[2]);
+      localAng = ang * M_PI / 180;
+    }
+    else
+    {
+      di << "Syntax error";
+      return 1;
+    }
+
+    S->DisplayHLR (localHLR, localRg1, localRgN, localHid, localAng);
+  }
+  dout.RepaintAll();
+  return 0;
 }
 
 
@@ -291,24 +325,21 @@ static Standard_Integer hlr (Draw_Interpretor& di,
 // dispor, dispcon
 //=======================================================================
 
-static Standard_Integer dispor (Draw_Interpretor& ,
-				Standard_Integer n, const char** a)
+static Standard_Integer dispor (Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   Standard_Boolean d = !strcasecmp(a[0],"vori");
-
   if (d)
+  {
     DBRep_WriteColorOrientation();
+  }
 
-  Standard_Integer i;
-  for (i = 1; i < n; i++) {
-    Handle(Draw_Drawable3D) d1 = Draw::Get(a[i]);
-    if (!d1.IsNull()) {
-      Handle(DBRep_DrawableShape) d2 = 
-	Handle(DBRep_DrawableShape)::DownCast(d1);
-      if (!d2.IsNull()) {
-	d2->DisplayOrientation(d);
+  for (Standard_Integer i = 1; i < n; i++)
+  {
+    Handle(Draw_Drawable3D) d1 = Draw::Get (a[i]);
+    if (Handle(DBRep_DrawableShape) d2 = Handle(DBRep_DrawableShape)::DownCast(d1))
+    {
+      d2->DisplayOrientation (d);
       Draw::Repaint();
-      }
     }
   }
   return 0;
@@ -318,13 +349,16 @@ static Standard_Integer dispor (Draw_Interpretor& ,
 // discretisation
 //=======================================================================
 
-static Standard_Integer discretisation(Draw_Interpretor& di,
-				       Standard_Integer n, const char** a)
+static Standard_Integer discretisation(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
+  DBRep_Params& aParams = DBRep::Parameters();
   if (n <= 1)
-    di << "Current number of points : "<<discret<<"\n";
-  else {
-    discret = Draw::Atoi(a[1]);
+  {
+    di << "Current number of points : "<< aParams.Discretization <<"\n";
+  }
+  else
+  {
+    aParams.Discretization = Draw::Atoi(a[1]);
   }
   return 0;
 }
@@ -334,28 +368,25 @@ static Standard_Integer discretisation(Draw_Interpretor& di,
 // triangles
 //=======================================================================
 
-static Standard_Integer triangles(Draw_Interpretor& , 
-				  Standard_Integer n, const char** a)
+static Standard_Integer triangles(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
-  if (n < 1) return 1;
-
-  if (n == 1) {
-    disptriangles = !disptriangles;
-#ifdef OCCT_DEBUG
-    if (disptriangles) std::cout <<"Triangulations are always displayed"<<std::endl;
-    else std::cout <<"Triangulations are displayed only if there is no geometric representation"<<std::endl;
-#endif
+  DBRep_Params& aParams = DBRep::Parameters();
+  if (n < 1)
+  {
+    return 1;
   }
-  else {
-    Standard_Integer i;
-    for (i = 1; i <= n-1; i++) {
+  if(n == 1)
+  {
+    aParams.DispTriangles = !aParams.DispTriangles;
+  }
+  else
+  {
+    for (Standard_Integer i = 1; i <= n-1; i++)
+    {
       Handle(Draw_Drawable3D) d1 = Draw::Get(a[i]);
-      if (!d1.IsNull()) {
-	Handle(DBRep_DrawableShape) d2 = 
-	  Handle(DBRep_DrawableShape)::DownCast(d1);
-	if (!d2.IsNull()) {
-	  d2->DisplayTriangulation(!(d2->DisplayTriangulation()));
-	}
+      if (Handle(DBRep_DrawableShape) d2 = Handle(DBRep_DrawableShape)::DownCast(d1))
+      {
+        d2->DisplayTriangulation(!(d2->DisplayTriangulation()));
       }
     }
   }
@@ -368,26 +399,56 @@ static Standard_Integer triangles(Draw_Interpretor& ,
 // tclean
 //=======================================================================
 
-static Standard_Integer tclean(Draw_Interpretor& , 
-			       Standard_Integer n, const char** a)
+static Standard_Integer tclean(Draw_Interpretor& di,
+  Standard_Integer n, const char** a)
 {
-  if (n == 1) return 1;
-
-  Standard_Integer aStart = 1;
   Standard_Boolean toRemoveGeometry = Standard_False;
-  if (strcmp(a[1], "-geom") == 0)
+  Standard_Boolean isForceClean = Standard_False;
+
+  if (n <= 1)
   {
-    aStart++;
-    toRemoveGeometry = Standard_True;
+    di.PrintHelp(a[0]);
+    return 1;
+  }
+  TopoDS_Compound aCompound;
+  BRep_Builder().MakeCompound(aCompound);
+  for (Standard_Integer anArgIter = 1; anArgIter < n; ++anArgIter)
+  {
+    if (strcmp(a[anArgIter], "-geom") == 0)
+    {
+      toRemoveGeometry = Standard_True;
+    }
+    else if (strcmp(a[anArgIter], "-force") == 0)
+    {
+      isForceClean = Standard_True;
+    }
+    else
+    {
+      TopoDS_Shape aShape = DBRep::Get(a[anArgIter]);
+      if (aShape.IsNull())
+      {
+        di << "Syntax error : NULL shape '"<< a[anArgIter] << "'";
+        return 1;
+      }
+      BRep_Builder().Add(aCompound, aShape);
+    }
+  }
+  if (aCompound.NbChildren() == 0)
+  {
+    di << "Syntax error : wrong number of arguments";
+    di.PrintHelp(a[0]);
+    return 1;
+  }
+  if (isForceClean && toRemoveGeometry)
+  {
+    di << "Syntax error: wrong usage of arguments: do not use 'force' and 'geom' flags together";
+    return 1;
   }
 
-  for (Standard_Integer i = aStart; i < n; i++) {
-    TopoDS_Shape S = DBRep::Get(a[i]);
-    if (toRemoveGeometry)
-      BRepTools::CleanGeometry(S);
-    else
-      BRepTools::Clean(S);
-  }
+  if (toRemoveGeometry)
+    BRepTools::CleanGeometry(aCompound);
+  else
+    BRepTools::Clean(aCompound, isForceClean);
   return 0;
 }
 
@@ -395,32 +456,28 @@ static Standard_Integer tclean(Draw_Interpretor& ,
 // polygons
 //=======================================================================
 
-static Standard_Integer polygons(Draw_Interpretor& , 
-				 Standard_Integer n, const char** a)
+static Standard_Integer polygons(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
-  if (n < 1)  return 1;
-
-  if (n == 1) {
-    disppolygons = !disppolygons;
-#ifdef OCCT_DEBUG
-    if (disppolygons) std::cout <<"Polygons are always displayed"<<std::endl;
-    else std::cout <<"Polygons are displayed only if there is no geometric representation"<<std::endl;
-#endif
+  DBRep_Params& aParams = DBRep::Parameters();
+  if (n < 1)
+  {
+    return 1;
   }
-  else {
-    Standard_Integer i;
-    for (i = 1; i <= n-1; i++) {
+  if (n == 1)
+  {
+    aParams.DisplayPolygons = !aParams.DisplayPolygons;
+  }
+  else
+  {
+    for (Standard_Integer i = 1; i <= n-1; i++)
+    {
       Handle(Draw_Drawable3D) d1 = Draw::Get(a[i]);
-      if (!d1.IsNull()) {
-	Handle(DBRep_DrawableShape) d2 = 
-	  Handle(DBRep_DrawableShape)::DownCast(d1);
-	if (!d2.IsNull()) {
-	  d2->DisplayPolygons(!(d2->DisplayPolygons()));
-	}
+      if (Handle(DBRep_DrawableShape) d2 = Handle(DBRep_DrawableShape)::DownCast(d1))
+      {
+        d2->DisplayPolygons(!(d2->DisplayPolygons()));
       }
     }
   }
-
   Draw::Repaint();
   return 0;
 }
@@ -1077,17 +1134,17 @@ static Standard_Integer setFlags(Draw_Interpretor& ,
 
   setProp(Sh, a, n);
   for (ex.Init (Sh,TopAbs_VERTEX); ex.More(); ex.Next()) {
-    TopoDS_Shape S = ex.Current();
+    const TopoDS_Shape& S = ex.Current();
     setProp(S, a, n);
   }
 
   for (ex.Init (Sh,TopAbs_EDGE); ex.More(); ex.Next()) {
-    TopoDS_Shape S = ex.Current();
+    const TopoDS_Shape& S = ex.Current();
     setProp(S, a, n);
   }
 
   for (ex.Init (Sh,TopAbs_FACE); ex.More(); ex.Next()) {
-    TopoDS_Shape S = ex.Current();
+    const TopoDS_Shape& S = ex.Current();
     setProp(S, a, n);
   }
 
@@ -1275,21 +1332,16 @@ static Standard_Integer normals (Draw_Interpretor& theDI,
 //function : Set
 //purpose  : 
 //=======================================================================
-void  DBRep::Set(const Standard_CString Name, const TopoDS_Shape& S)
+void DBRep::Set (const Standard_CString theName, const TopoDS_Shape& theShape)
 {
-  Handle(DBRep_DrawableShape) D =
-    new DBRep_DrawableShape(S,
-			    Draw_vert,
-			    Draw_jaune,
-			    Draw_rouge,
-			    Draw_bleu,
-			    size,
-			    nbIsos,
-			    discret);
-  D->DisplayTriangulation(disptriangles);
-  D->DisplayPolygons(disppolygons);
-  D->DisplayHLR(withHLR,withRg1,withRgN,withHid,anglHLR);
-  Draw::Set(Name,D);
+  DBRep_Params& aParams = DBRep::Parameters();
+  Handle(DBRep_DrawableShape) aDrawShape =
+    new DBRep_DrawableShape (theShape, Draw_vert, Draw_jaune, Draw_rouge, Draw_bleu,
+                             aParams.Size, aParams.NbIsos, aParams.Discretization);
+  aDrawShape->DisplayTriangulation (aParams.DispTriangles);
+  aDrawShape->DisplayPolygons (aParams.DisplayPolygons);
+  aDrawShape->DisplayHLR (aParams.WithHLR, aParams.WithRg1, aParams.WithRgN, aParams.WithHid, aParams.HLRAngle);
+  Draw::Set (theName, aDrawShape);
 }
 //=======================================================================
 //function : getShape
@@ -1376,47 +1428,191 @@ static Standard_Integer XProgress (Draw_Interpretor& di, Standard_Integer argc,
 }
 
 //=======================================================================
-// binsave
+// writebrep
 //=======================================================================
-
-static Standard_Integer binsave(Draw_Interpretor& di, Standard_Integer n, const char** a)
+static Standard_Integer writebrep (Draw_Interpretor& theDI,
+                                   Standard_Integer theNbArgs,
+                                   const char** theArgVec)
 {
-  if (n <= 2) return 1;
-
-  TopoDS_Shape aShape = DBRep::Get (a[1]);
-  if (aShape.IsNull())
+  Standard_Integer aVersion = -1;
+  TCollection_AsciiString aShapeName, aFileName;
+  TopoDS_Shape aShape;
+  Standard_Boolean isBinaryFormat(Standard_False);
+  Standard_Boolean isWithTriangles(Standard_True);
+  Standard_Boolean isWithNormals(Standard_False);
+  if (!strcasecmp (theArgVec[0], "binsave"))
   {
-    di << a[1] << " is not a shape";
+    isBinaryFormat = Standard_True;
+  }
+
+  for (Standard_Integer anArgIter = 1; anArgIter < theNbArgs; ++anArgIter)
+  {
+    TCollection_AsciiString aParam (theArgVec[anArgIter]);
+    aParam.LowerCase();
+    if (aParam == "-binary")
+    {
+      isBinaryFormat = Draw::ParseOnOffNoIterator (theNbArgs, theArgVec, anArgIter);
+    }
+    else if (aParam == "-version"
+          && anArgIter + 1 < theNbArgs)
+    {
+      aVersion = Draw::Atoi (theArgVec[++anArgIter]);
+      if (aVersion <= 0)
+      {
+        theDI << "Syntax error: unknown version";
+        return 1;
+      }
+    }
+    else if (aParam == "-notriangles"
+          || aParam == "-triangles")
+    {
+      isWithTriangles = Draw::ParseOnOffNoIterator (theNbArgs, theArgVec, anArgIter);
+    }
+    else if (aParam == "-nonormals"
+          || aParam == "-normals")
+    {
+      isWithNormals = Draw::ParseOnOffIterator (theNbArgs, theArgVec, anArgIter);
+      if (aParam == "-nonormals")
+      {
+        isWithNormals = !isWithNormals;
+      }
+    }
+    else if (aShapeName.IsEmpty())
+    {
+      aShapeName = theArgVec[anArgIter];
+      aShape = DBRep::Get (aShapeName);
+      if (aShape.IsNull())
+      {
+        theDI << "Syntax error: " << aShapeName << " is not a shape";
+        return 1;
+      }
+    }
+    else if (aFileName.IsEmpty())
+    {
+      aFileName = theArgVec[anArgIter];
+    }
+    else
+    {
+      theDI << "Syntax error: unknown argument '" << aParam << "'";
+      return 1;
+    }
+  }
+  if (aFileName.IsEmpty())
+  {
+    theDI << "Syntax error: wrong number of arguments";
     return 1;
   }
 
-  if (!BinTools::Write (aShape, a[2]))
+  Handle(Draw_ProgressIndicator) aProgress = new Draw_ProgressIndicator (theDI);
+  if (isBinaryFormat)
   {
-    di << "Cannot write to the file " << a[2];
-    return 1;
-  }
+    if (aVersion > BinTools_FormatVersion_UPPER)
+    {
+      theDI << "Syntax error: unknown format version";
+      return 1;
+    }
+    if (isWithNormals
+     && aVersion > 0
+     && aVersion < BinTools_FormatVersion_VERSION_4)
+    {
+      theDI << "Error: vertex normals require binary format version 4 or later";
+      return 1;
+    }
 
-  di << a[1];
+    BinTools_FormatVersion aBinToolsVersion = aVersion > 0
+                                            ? static_cast<BinTools_FormatVersion> (aVersion)
+                                            : BinTools_FormatVersion_CURRENT;
+    if (!BinTools::Write (aShape, aFileName.ToCString(), isWithTriangles, isWithNormals, aBinToolsVersion, aProgress->Start()))
+    {
+      theDI << "Cannot write to the file " << aFileName;
+      return 1;
+    }
+  }
+  else
+  {
+    if (aVersion > TopTools_FormatVersion_UPPER)
+    {
+      theDI << "Syntax error: unknown format version";
+      return 1;
+    }
+    if (isWithNormals
+     && aVersion > 0
+     && aVersion < TopTools_FormatVersion_VERSION_3)
+    {
+      theDI << "Error: vertex normals require ascii format version 3 or later";
+      return 1;
+    }
+
+    TopTools_FormatVersion aTopToolsVersion = aVersion > 0
+                                            ? static_cast<TopTools_FormatVersion> (aVersion)
+                                            : TopTools_FormatVersion_CURRENT;
+    if (!BRepTools::Write (aShape, aFileName.ToCString(), isWithTriangles, isWithNormals, aTopToolsVersion, aProgress->Start()))
+    {
+      theDI << "Cannot write to the file " << aFileName;
+      return 1;
+    }
+  }
+  theDI << aShapeName;
   return 0;
 }
 
 //=======================================================================
-// binrestore
+// readbrep
 //=======================================================================
-
-static Standard_Integer binrestore(Draw_Interpretor& di, Standard_Integer n, const char** a)
+static Standard_Integer readbrep (Draw_Interpretor& theDI,
+                                  Standard_Integer theNbArgs,
+                                  const char** theArgVec)
 {
-  if (n <= 2) return 1;
-
-  TopoDS_Shape aShape;
-  if (!BinTools::Read (aShape, a[1]))
+  if (theNbArgs != 3)
   {
-    di << "Cannot read from the file " << a[1];
+    theDI << "Syntax error: wrong number of arguments";
     return 1;
   }
 
-  DBRep::Set (a[2], aShape);
-  di << a[2];
+  Standard_CString aFileName  = theArgVec[1];
+  Standard_CString aShapeName = theArgVec[2];
+  bool isBinaryFormat = true;
+  {
+    // probe file header to recognize format
+    const Handle(OSD_FileSystem)& aFileSystem = OSD_FileSystem::DefaultFileSystem();
+    std::shared_ptr<std::istream> aFile = aFileSystem->OpenIStream (aFileName, std::ios::in | std::ios::binary);
+    if (aFile.get() == NULL)
+    {
+      theDI << "Error: cannot read the file '" << aFileName << "'";
+      return 1;
+    }
+
+    char aStringBuf[255] = {};
+    aFile->read (aStringBuf, 255);
+    if (aFile->fail())
+    {
+      theDI << "Error: cannot read the file '" << aFileName << "'";
+      return 1;
+    }
+    isBinaryFormat = !(::strncmp (aStringBuf, "DBRep_DrawableShape", 19) == 0);
+  }
+
+  Handle(Draw_ProgressIndicator) aProgress = new Draw_ProgressIndicator (theDI);
+  TopoDS_Shape aShape;
+  if (isBinaryFormat)
+  {
+    if (!BinTools::Read (aShape, aFileName, aProgress->Start()))
+    {
+      theDI << "Error: cannot read from the file '" << aFileName << "'";
+      return 1;
+    }
+  }
+  else
+  {
+    if (!BRepTools::Read (aShape, aFileName, BRep_Builder(), aProgress->Start()))
+    {
+      theDI << "Error: cannot read from the file '" << aFileName << "'";
+      return 1;
+    }
+  }
+
+  DBRep::Set (aShapeName, aShape);
+  theDI << aShapeName;
   return 0;
 }
 
@@ -1465,15 +1661,20 @@ void  DBRep::BasicCommands(Draw_Interpretor& theCommands)
   done = Standard_True;
   Draw::Commands(theCommands);
 
+  // Register save/restore tools
+  DBRep_DrawableShape::RegisterFactory();
+
   const char* g = "Basic shape commands";
 
   theCommands.Add("isos","isos [name1 ...] [nbisos]",__FILE__,isos,g);
   theCommands.Add("hlr" ,"[no]hlr, rg1, rgn, hid, ang",__FILE__,hlr ,g);
   theCommands.Add("vori","vori [name1 ...], edges are colored by orientation (see vconn)",__FILE__,dispor,g);
   theCommands.Add("triangles", "triangles [name1]..., display triangles of shapes if exists",__FILE__, triangles, g);
-  theCommands.Add("tclean", "tclean [-geom] [name1]..., depending on using or not key -geom, \n" 
-                   "\t erase geometry objects from shapes - key is used or \n"
-                   "\t erase triangulations and polygons on triangulations from shapes - key is omitted \n",
+  theCommands.Add("tclean", "tclean [-force] [-geom] [name1]..., depending on using or not key -geom, \n" 
+                   "\t\t -geom  : erase geometry\n"
+                   "\t\t          if [-geom] is omitted - erase triangulations and \n"
+                   "\t\t          polygons on triangulations from shapes \n"
+                   "\t\t -force : force delete all representations not relevant to the given shape \n",
                     __FILE__, tclean, g); 
   theCommands.Add("polygons", "polygons [name1]..., display polygons of shapes if exists",__FILE__, polygons, g);
   theCommands.Add("vconn","vconn [name1 ...] , edges are colored by number of faces (see vori)",__FILE__,dispor,g);
@@ -1500,11 +1701,9 @@ void  DBRep::BasicCommands(Draw_Interpretor& theCommands)
   theCommands.Add("numshapes","numshapes s; size of shape",__FILE__,numshapes,g);
   theCommands.Add("countshapes","countshapes s; count of shape",__FILE__,countshapes,g);
   theCommands.Add("setflags",
-                  "setflags shape_name flag1[flag2...]\n sets flags for shape(free, modidfied, checked, orientable, closed, infinite, convex, locked), for exmple <setflags a free> or <setflags a -free> if necessary unflag ",
+                  "setflags shape_name flag1[flag2...]\n sets flags for shape(free, modified, checked, orientable, closed, infinite, convex, locked), for example <setflags a free> or <setflags a -free> if necessary unflag ",
                   __FILE__,setFlags,g);
 
-//  theCommands.Add("dumpmmgt",
-//		  "dump le contenu du gestionnaire de memoire",__FILE__,dumpmmgt,g);
   theCommands.Add("purgemmgt",
 		  "returns the free memory from the system to the memory manager",
 		  __FILE__,purgemmgt,g);
@@ -1516,14 +1715,27 @@ void  DBRep::BasicCommands(Draw_Interpretor& theCommands)
                     "\n\t\t   +|-t :  switch on/off output to tcl of Progress Indicator"
                     "\n\t\t   +|-c :  switch on/off output to cout of Progress Indicator"
                     "\n\t\t   +|-g :  switch on/off graphical mode of Progress Indicator",
-                    XProgress,"DE: General");
-
-  theCommands.Add("binsave", "binsave shape filename\n"
-                  "\t\tsave the shape in the binary format file",
-                  __FILE__, binsave, g);
-  theCommands.Add("binrestore", "binrestore filename shape\n"
-                  "\t\trestore the shape from the binary format file",
-                  __FILE__, binrestore, g);
+                   __FILE__, XProgress,"DE: General");
+  theCommands.Add("writebrep",
+                  "writebrep shape filename [-binary {0|1}]=0 [-version Version]=4"
+                  "\n\t\t:                          [-triangles {0|1}]=1 [-normals {0|1}]=0"
+                  "\n\t\t: Save the shape in the ASCII (default) or binary format file."
+                  "\n\t\t:  -binary  write into the binary format (ASCII when unspecified)"
+                  "\n\t\t:  -version a number of format version to save;"
+                  "\n\t\t:           ASCII  versions: 1, 2 and 3    (3 for ASCII  when unspecified);"
+                  "\n\t\t:           Binary versions: 1, 2, 3 and 4 (4 for Binary when unspecified)."
+                  "\n\t\t:  -triangles write triangulation data (TRUE when unspecified)."
+                  "\n\t\t:           Ignored (always written) if face defines only triangulation (no surface)."
+                  "\n\t\t:  -normals include vertex normals while writing triangulation data (FALSE when unspecified).",
+                  __FILE__, writebrep, g);
+  theCommands.Add("readbrep",
+                  "readbrep filename shape"
+                  "\n\t\t: Restore the shape from the binary or ASCII format file.",
+                  __FILE__, readbrep, g);
+  theCommands.Add("binsave", "binsave shape filename", __FILE__, writebrep, g);
+  theCommands.Add("binrestore",
+                  "alias to readbrep command",
+                  __FILE__, readbrep, g);
 
   theCommands.Add ("removeinternals", "removeinternals shape [force flag {0/1}]"
                    "\n\t\t             Removes sub-shapes with internal orientation from the shape.\n"
@@ -1531,120 +1743,3 @@ void  DBRep::BasicCommands(Draw_Interpretor& theCommands)
                                        "removes all internal sub-shapes\n",
                   __FILE__, removeInternals, g);
 }
-
-//=======================================================================
-//function : HLRMode
-//purpose  : 
-//=======================================================================
-
-Standard_Boolean DBRep::HLRMode()
-{ return withHLR; }
-
-//=======================================================================
-//function : Rg1Mode
-//purpose  : 
-//=======================================================================
-
-Standard_Boolean DBRep::Rg1Mode()
-{ return withRg1; }
-
-//=======================================================================
-//function : RgNMode
-//purpose  : 
-//=======================================================================
-
-Standard_Boolean DBRep::RgNMode()
-{ return withRgN; }
-
-//=======================================================================
-//function : HidMode
-//purpose  : 
-//=======================================================================
-
-Standard_Boolean DBRep::HidMode()
-{ return withHid; }
-
-//=======================================================================
-//function : HLRAngle
-//purpose  : 
-//=======================================================================
-
-Standard_Real DBRep::HLRAngle()
-{ return anglHLR; }
-
-//=======================================================================
-//function : 
-//purpose  : save and restore shapes
-//=======================================================================
-
-static Standard_Boolean stest(const Handle(Draw_Drawable3D)& d) 
-{
-  return d->IsInstance(STANDARD_TYPE(DBRep_DrawableShape));
-}
-
-static void ssave(const Handle(Draw_Drawable3D)&d, std::ostream& OS)
-{
-  Handle(DBRep_DrawableShape) 
-    N = Handle(DBRep_DrawableShape)::DownCast(d);
-  BRep_Builder B;
-  BRepTools_ShapeSet S(B);
-  S.Add (N->Shape());
-  Handle(Draw_ProgressIndicator) aProgress = Draw::GetProgressBar();
-  S.Write(OS, Message_ProgressIndicator::Start(aProgress));
-  if (! aProgress.IsNull() && aProgress->UserBreak())
-    return;
-  S.Write(N->Shape(),OS);
-}
-
-static Handle(Draw_Drawable3D) srestore (std::istream& IS)
-{
-  BRep_Builder B;
-  BRepTools_ShapeSet S(B);
-  Handle(Draw_ProgressIndicator) aProgress = Draw::GetProgressBar();
-  S.Read(IS, Message_ProgressIndicator::Start(aProgress));
-  Handle(DBRep_DrawableShape) N;
-  if (! aProgress.IsNull() && aProgress->UserBreak())
-    return N;
-  TopoDS_Shape theShape;
-  S.Read(theShape,IS );
-  N = new DBRep_DrawableShape(theShape,
-			    Draw_vert,
-			    Draw_jaune,
-			    Draw_rouge,
-			    Draw_bleu,
-			    size,
-			    nbIsos,
-			    discret);
-  N->DisplayTriangulation(disptriangles);
-  N->DisplayPolygons(disppolygons);
-  N->DisplayHLR(withHLR,withRg1,withRgN,withHid,anglHLR);
-  
-  return N;
-}
-
-
-static Draw_SaveAndRestore ssr("DBRep_DrawableShape",
-			       stest,ssave,srestore);
-
-
-void dumps (const TopoDS_Shape& S)
-{
- BRepTools::Dump(S,std::cout);
-}
-
-//=======================================================================
-//function : NbIsos
-//purpose  : 
-//=======================================================================
-
-Standard_Integer DBRep::NbIsos()
-{ return nbIsos; }
-
-
-//=======================================================================
-//function : Discretisation
-//purpose  : 
-//=======================================================================
-
-Standard_Integer DBRep::Discretisation()
-{ return discret; }
