@@ -18,18 +18,12 @@
 #include <DDataStd.hxx>
 #include <DDataStd_TreeBrowser.hxx>
 #include <DDF.hxx>
-#include <Draw.hxx>
 #include <Draw_Appli.hxx>
-#include <Draw_Drawable3D.hxx>
 #include <Draw_Interpretor.hxx>
 #include <Message.hxx>
-#include <Standard_GUID.hxx>
 #include <TCollection_AsciiString.hxx>
-#include <TCollection_ExtendedString.hxx>
 #include <TDataStd_ChildNodeIterator.hxx>
 #include <TDataStd_TreeNode.hxx>
-#include <TDataXtd_Constraint.hxx>
-#include <TDF.hxx>
 #include <TDF_Data.hxx>
 #include <TDF_Label.hxx>
 #include <TDF_Tool.hxx>
