@@ -23,13 +23,9 @@
 #include <Expr.hxx>
 #include <Expr_GeneralExpression.hxx>
 #include <Expr_NamedUnknown.hxx>
-#include <Expr_NotEvaluable.hxx>
-#include <Expr_NumericValue.hxx>
 #include <Expr_Operators.hxx>
 #include <Expr_Product.hxx>
 #include <Expr_Sum.hxx>
-#include <Expr_UnaryMinus.hxx>
-#include <Standard_NumericError.hxx>
 #include <Standard_Type.hxx>
 #include <TCollection_AsciiString.hxx>
 #include <TColStd_Array1OfInteger.hxx>
