@@ -16,11 +16,9 @@
 #include <ElCLib.hxx>
 #include <Extrema_ExtElC.hxx>
 #include <Extrema_ExtElC2d.hxx>
-#include <Extrema_ExtPElC.hxx>
 #include <Extrema_POnCurv.hxx>
 #include <gp_Ax1.hxx>
 #include <gp_Ax2.hxx>
-#include <gp_Ax3.hxx>
 #include <gp_Circ.hxx>
 #include <gp_Circ2d.hxx>
 #include <gp_Dir.hxx>
@@ -31,7 +29,6 @@
 #include <gp_Parab.hxx>
 #include <gp_Pln.hxx>
 #include <gp_Pnt.hxx>
-#include <IntAna_QuadQuadGeo.hxx>
 #include <IntAna2d_AnaIntersection.hxx>
 #include <math_DirectPolynomialRoots.hxx>
 #include <math_TrigonometricFunctionRoots.hxx>
@@ -39,7 +36,6 @@
 #include <Standard_OutOfRange.hxx>
 #include <StdFail_NotDone.hxx>
 
-#include <stdio.h>
 static
   void RefineDir(gp_Dir& aDir);
 
@@ -119,6 +115,8 @@ ExtremaExtElC_TrigonometricRoots::
 				   const Standard_Real Cte,
 				   const Standard_Real Binf,
 				   const Standard_Real Bsup) 
+: NbRoots(0),
+  infinite_roots(Standard_False)
 {
   Standard_Integer i, nbessai;
   Standard_Real cc ,sc, c, s, cte;
@@ -232,10 +230,9 @@ Extrema_ExtElC::Extrema_ExtElC ()
   myDone = Standard_False; 
   myIsPar = Standard_False;
   myNbExt = 0;
-
-  for (Standard_Integer i = 0; i < 6; i++)
+  for (size_t anIdx = 0; anIdx < sizeof (mySqDist) / sizeof (mySqDist[0]); anIdx++)
   {
-    mySqDist[i] = RealLast();
+    mySqDist[anIdx] = RealLast();
   }
 }
 //=======================================================================
@@ -294,6 +291,10 @@ Extrema_ExtElC::Extrema_ExtElC (const gp_Lin& theC1,
   myDone = Standard_False;
   myNbExt = 0;
   myIsPar = Standard_False;
+  for (size_t anIdx = 0; anIdx < sizeof (mySqDist) / sizeof (mySqDist[0]); anIdx++)
+  {
+    mySqDist[anIdx] = RealLast();
+  }
 
   const gp_Dir &aD1 = theC1.Position().Direction(),
                &aD2 = theC2.Position().Direction();
@@ -460,6 +461,10 @@ Extrema_ExtElC::Extrema_ExtElC (const gp_Lin& C1,
   myIsPar = Standard_False;
   myDone = Standard_False;
   myNbExt = 0;
+  for (size_t anIdx = 0; anIdx < sizeof (mySqDist) / sizeof (mySqDist[0]); anIdx++)
+  {
+    mySqDist[anIdx] = RealLast();
+  }
 
   if (PlanarLineCircleExtrema(C1, C2))
   {
@@ -631,6 +636,10 @@ Method:
   myIsPar = Standard_False;
   myDone = Standard_False;
   myNbExt = 0;
+  for (size_t anIdx = 0; anIdx < sizeof (mySqDist) / sizeof (mySqDist[0]); anIdx++)
+  {
+    mySqDist[anIdx] = RealLast();
+  }
 
 // Calculate T1 the reference of the ellipse ...
   gp_Dir D = C1.Direction();
@@ -744,6 +753,10 @@ Method:
   myIsPar = Standard_False;
   myDone = Standard_False;
   myNbExt = 0;
+  for (size_t anIdx = 0; anIdx < sizeof (mySqDist) / sizeof (mySqDist[0]); anIdx++)
+  {
+    mySqDist[anIdx] = RealLast();
+  }
 
 // Calculate T1 in the reference of the hyperbola...
   gp_Dir D = C1.Direction();
@@ -839,6 +852,10 @@ Method:
   myIsPar = Standard_False;
   myDone = Standard_False;
   myNbExt = 0;
+  for (size_t anIdx = 0; anIdx < sizeof (mySqDist) / sizeof (mySqDist[0]); anIdx++)
+  {
+    mySqDist[anIdx] = RealLast();
+  }
 
 // Calculate T1 in the reference of the parabola...
   gp_Dir D = C1.Direction();
@@ -900,6 +917,10 @@ Extrema_ExtElC::Extrema_ExtElC (const gp_Circ& C1,
   myIsPar = Standard_False;
   myDone = Standard_False;
   myNbExt = 0;
+  for (size_t anIdx = 0; anIdx < sizeof (mySqDist) / sizeof (mySqDist[0]); anIdx++)
+  {
+    mySqDist[anIdx] = RealLast();
+  }
   //
   aTolA=Precision::Angular();
   aTolD=Precision::Confusion();
