@@ -16,12 +16,9 @@
 
 #include <Extrema_LocateExtCC2d.hxx>
 
-#include <GeomAbs_CurveType.hxx>
 #include <StdFail_NotDone.hxx>
 #include <Extrema_POnCurv2d.hxx>
-#include <Precision.hxx>
 
-#include <Adaptor2d_Curve2d.hxx>
 #include <Extrema_Curve2dTool.hxx>
 #include <Extrema_LocECC2d.hxx>
 
