@@ -31,8 +31,6 @@
 
 
 #include <BSplCLib.hxx>
-#include <BSplCLib_KnotDistribution.hxx>
-#include <BSplCLib_MultDistribution.hxx>
 #include <ElCLib.hxx>
 #include <Geom_BSplineCurve.hxx>
 #include <Geom_Geometry.hxx>
@@ -42,12 +40,10 @@
 #include <gp_Trsf.hxx>
 #include <gp_Vec.hxx>
 #include <Standard_ConstructionError.hxx>
-#include <Standard_DimensionError.hxx>
 #include <Standard_DomainError.hxx>
 #include <Standard_NoSuchObject.hxx>
 #include <Standard_NotImplemented.hxx>
 #include <Standard_OutOfRange.hxx>
-#include <Standard_RangeError.hxx>
 #include <Standard_Real.hxx>
 #include <Standard_Type.hxx>
 
