@@ -16,17 +16,14 @@
 
 #include <BSplCLib.hxx>
 #include <Geom2d_BSplineCurve.hxx>
-#include <Geom2d_Geometry.hxx>
 #include <Geom2d_UndefinedDerivative.hxx>
 #include <gp.hxx>
 #include <gp_Pnt2d.hxx>
 #include <gp_Trsf2d.hxx>
 #include <gp_Vec2d.hxx>
 #include <Precision.hxx>
-#include <Standard_ConstructionError.hxx>
 #include <Standard_DimensionError.hxx>
 #include <Standard_DomainError.hxx>
-#include <Standard_NoSuchObject.hxx>
 #include <Standard_OutOfRange.hxx>
 #include <Standard_RangeError.hxx>
 
