@@ -22,7 +22,6 @@
 #include <Geom2d_Circle.hxx>
 #include <Geom2d_Line.hxx>
 #include <Geom2d_Point.hxx>
-#include <Geom2dAdaptor_Curve.hxx>
 #include <Geom2dGcc_Circ2d2TanRad.hxx>
 #include <Geom2dGcc_Circ2d2TanRadGeo.hxx>
 #include <Geom2dGcc_QCurve.hxx>
@@ -71,8 +70,8 @@ Geom2dGcc_Circ2d2TanRad::
   else {
     Geom2dAdaptor_Curve C1 = Qualified1.Qualified();
     Geom2dAdaptor_Curve C2 = Qualified2.Qualified();
-    Handle(Geom2d_Curve) CC1 = C1.Curve();
-    Handle(Geom2d_Curve) CC2 = C2.Curve();
+    const Handle(Geom2d_Curve)& CC1 = C1.Curve();
+    const Handle(Geom2d_Curve)& CC2 = C2.Curve();
     GeomAbs_CurveType Type1 = C1.GetType();
     GeomAbs_CurveType Type2 = C2.GetType();
 
@@ -277,7 +276,7 @@ Geom2dGcc_Circ2d2TanRad::
   if (Radius < 0.) { throw Standard_NegativeValue(); }
   else {
     Geom2dAdaptor_Curve C1 = Qualified1.Qualified();
-    Handle(Geom2d_Curve) CC1 = C1.Curve();
+    const Handle(Geom2d_Curve)& CC1 = C1.Curve();
     GeomAbs_CurveType Type1 = C1.GetType();
 
 //=============================================================================
