@@ -19,19 +19,16 @@
 #include <AdvApprox_ApproxAFunction.hxx>
 #include <BSplCLib.hxx>
 #include <Geom_BSplineSurface.hxx>
-#include <GeomFill_Boundary.hxx>
 #include <GeomFill_BoundWithSurf.hxx>
 #include <GeomFill_ConstrainedFilling.hxx>
 #include <GeomFill_CoonsAlgPatch.hxx>
 #include <GeomFill_DegeneratedBound.hxx>
-#include <GeomFill_TgtField.hxx>
 #include <GeomFill_TgtOnCoons.hxx>
 #include <gp_XYZ.hxx>
 #include <Law.hxx>
 #include <Law_BSpFunc.hxx>
 #include <Law_BSpline.hxx>
 #include <Law_Linear.hxx>
-#include <PLib.hxx>
 #include <Standard_Failure.hxx>
 #include <Standard_NotImplemented.hxx>
 #include <TColgp_Array1OfPnt.hxx>
