@@ -28,24 +28,16 @@
 #include <Adaptor3d_Curve.hxx>
 #include <Approx_SweepApproximation.hxx>
 #include <ElCLib.hxx>
-#include <Geom2d_Curve.hxx>
 #include <Geom2dAdaptor_Curve.hxx>
 #include <Geom_BSplineCurve.hxx>
 #include <Geom_BSplineSurface.hxx>
 #include <Geom_Circle.hxx>
-#include <Geom_ConicalSurface.hxx>
 #include <Geom_Curve.hxx>
 #include <Geom_CylindricalSurface.hxx>
 #include <Geom_Line.hxx>
-#include <Geom_Plane.hxx>
 #include <Geom_RectangularTrimmedSurface.hxx>
-#include <Geom_SphericalSurface.hxx>
 #include <Geom_Surface.hxx>
-#include <Geom_SurfaceOfLinearExtrusion.hxx>
 #include <Geom_ToroidalSurface.hxx>
-#include <Geom_TrimmedCurve.hxx>
-#include <GeomAbs_SurfaceType.hxx>
-#include <GeomAdaptor_Curve.hxx>
 #include <GeomAdaptor_Surface.hxx>
 #include <GeomFill_AppSweep.hxx>
 #include <GeomFill_CircularBlendFunc.hxx>
@@ -61,7 +53,6 @@
 #include <GeomFill_LocationGuide.hxx>
 #include <GeomFill_LocationLaw.hxx>
 #include <GeomFill_NSections.hxx>
-#include <GeomFill_Profiler.hxx>
 #include <GeomFill_SectionLaw.hxx>
 #include <GeomFill_SectionPlacement.hxx>
 #include <GeomFill_Sweep.hxx>
@@ -96,7 +87,7 @@ static Standard_Boolean CheckSense(const TColGeom_SequenceOfCurve& Seq1,
   Standard_Boolean no_sing = Standard_True;
   Seq2.Clear();
 
-  Handle(Geom_Curve) C1 = Seq1.Value(1);
+  const Handle(Geom_Curve)& C1 = Seq1.Value(1);
   Standard_Real f = C1->FirstParameter(), l = C1->LastParameter();
   Standard_Integer iP, NP = 21;
   TColgp_Array1OfPnt Tab(1,NP);
@@ -134,7 +125,7 @@ static Standard_Boolean CheckSense(const TColGeom_SequenceOfCurve& Seq1,
 
   for (Standard_Integer iseq=2; iseq<=Seq1.Length(); iseq++) {
     // discretisation de C2
-    Handle(Geom_Curve) C2 = Seq1.Value(iseq);
+    const Handle(Geom_Curve)& C2 = Seq1.Value(iseq);
     f = C2->FirstParameter();
     l = C2->LastParameter();
     u = f;
@@ -205,7 +196,7 @@ static Standard_Boolean CheckSense(const TColGeom_SequenceOfCurve& Seq1,
 //purpose  : constructor with no parameters. 
 //=======================================================================
 
-GeomFill_Pipe::GeomFill_Pipe() : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+GeomFill_Pipe::GeomFill_Pipe() : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 {
   Init();
 }
@@ -218,7 +209,7 @@ GeomFill_Pipe::GeomFill_Pipe() : myIsDone(Standard_False),myExchUV(Standard_Fals
 
 GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path, 
                              const Standard_Real Radius) 
-     : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 {
   Init();
   Init(Path, Radius);
@@ -232,7 +223,7 @@ GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
 GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
                              const Handle(Geom_Curve)& FirstSect,
                              const GeomFill_Trihedron Option) 
-     : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 {
   Init();
   Init(Path, FirstSect, Option);
@@ -246,7 +237,7 @@ GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
 GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom2d_Curve)& Path,
                              const Handle(Geom_Surface)& Support,
                              const Handle(Geom_Curve)& FirstSect) 
-     : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 {
   Init();
   Init(Path, Support, FirstSect);
@@ -260,7 +251,7 @@ GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom2d_Curve)& Path,
 GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
                              const Handle(Geom_Curve)& FirstSect,
                              const Handle(Geom_Curve)& LastSect)
-     : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 {
   Init();
   Init(Path, FirstSect, LastSect);
@@ -274,7 +265,7 @@ GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
 
 GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
                              const TColGeom_SequenceOfCurve& NSections)
-     : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 {
   Init();
   Init(Path, NSections);
@@ -288,7 +279,7 @@ GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
 GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
                              const Handle(Geom_Curve)& Curve1,
                              const gp_Dir& Direction)
-     : myIsDone(Standard_False),myExchUV(Standard_False), myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False), myKPart(Standard_False)
 {
  Init(Path, Curve1, Direction); 
 }
@@ -301,7 +292,7 @@ GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
                              const Handle(Geom_Curve)& Curve1,
                              const Handle(Geom_Curve)& Curve2,
                              const Standard_Real       Radius)
-     : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 {
   Init();
   Handle(GeomAdaptor_Curve) AdpPath = 
@@ -324,7 +315,7 @@ GeomFill_Pipe::GeomFill_Pipe(const Handle(Adaptor3d_Curve)& Path,
                              const Handle(Adaptor3d_Curve)& Curve1,
                              const Handle(Adaptor3d_Curve)& Curve2,
                              const Standard_Real Radius)
-     : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 {
   Init();
   Init(Path,Curve1,Curve2,Radius);
@@ -344,7 +335,7 @@ GeomFill_Pipe::GeomFill_Pipe(const Handle(Geom_Curve)& Path,
 			     const Handle(Geom_Curve)& FirstSect,
 			     const Standard_Boolean byACR,
 			     const Standard_Boolean rotat)
-     : myIsDone(Standard_False),myExchUV(Standard_False),myKPart(Standard_False)
+     : myStatus(GeomFill_PipeNotOk), myExchUV(Standard_False),myKPart(Standard_False)
 // Path : trajectoire
 // Guide : courbe guide
 // FirstSect : section
@@ -751,31 +742,37 @@ void GeomFill_Pipe::Init(const Handle(Geom_Curve)& Path,
 
   if (!TLaw.IsNull()) {
     myLoc = new (GeomFill_CurveAndTrihedron) (TLaw);
-    myLoc->SetCurve(myAdpPath);
-    TColGeom_SequenceOfCurve SeqC;
-    TColStd_SequenceOfReal SeqP;
-    SeqC.Clear();
-    SeqP.Clear();
-    // sequence des sections
-    GeomFill_SectionPlacement Pl1(myLoc, FirstSect);
-    Pl1.Perform(first,Precision::Confusion());
-    SeqC.Append(Pl1.Section(Standard_False));
-    GeomFill_SectionPlacement Pl2(myLoc, LastSect);
-    Pl2.Perform(first,Precision::Confusion());
-    SeqC.Append(Pl2.Section(Standard_False));
-    // sequence des parametres associes
-    SeqP.Append(first);
-    SeqP.Append(last);
 
-    // verification de l'orientation
-    TColGeom_SequenceOfCurve NewSeq;
-    if (CheckSense(SeqC,NewSeq)) SeqC = NewSeq;
+   if (!(myLoc->SetCurve(myAdpPath)))
+   {
+     myStatus = GeomFill_ImpossibleContact;
+     return;
+   }
 
-    // creation de la NSections
-    Standard_Real deb,fin;
-    deb =  SeqC.First()->FirstParameter();
-    fin =  SeqC.First()->LastParameter();
-    mySec = new (GeomFill_NSections) (SeqC,SeqP,deb,fin,first,last);
+   TColGeom_SequenceOfCurve SeqC;
+   TColStd_SequenceOfReal SeqP;
+   SeqC.Clear();
+   SeqP.Clear();
+   // sequence of sections
+   GeomFill_SectionPlacement Pl1(myLoc, FirstSect);
+   Pl1.Perform(first, Precision::Confusion());
+   SeqC.Append(Pl1.Section(Standard_False));
+   GeomFill_SectionPlacement Pl2(myLoc, LastSect);
+   Pl2.Perform(first, Precision::Confusion());
+   SeqC.Append(Pl2.Section(Standard_False));
+   // sequence of associated parameters
+   SeqP.Append(first);
+   SeqP.Append(last);
+   
+   // orientation verification
+   TColGeom_SequenceOfCurve NewSeq;
+   if (CheckSense(SeqC, NewSeq)) SeqC = NewSeq;
+
+   // creation of the NSections
+   Standard_Real deb, fin;
+   deb = SeqC.First()->FirstParameter();
+   fin = SeqC.First()->LastParameter();
+   mySec = new (GeomFill_NSections) (SeqC, SeqP, deb, fin, first, last);
   }
 }
 
@@ -831,6 +828,11 @@ void GeomFill_Pipe::Perform(const Standard_Real Tol,
 			    const Standard_Integer DegMax,
 			    const Standard_Integer NbMaxSegment)
 {
+  if (myStatus == GeomFill_ImpossibleContact)
+  {
+    return;
+  }
+
  GeomAbs_Shape TheConti;
  switch (Conti) {
  case GeomAbs_C0:
@@ -884,7 +886,7 @@ void GeomFill_Pipe::Perform(const Standard_Real Tol,
 					   App.UDegree(),
 					   App.VDegree());
        myError = App.MaxErrorOnSurf();
-       myIsDone = Standard_True;
+       myStatus = GeomFill_PipeOk;
      }
      //else {
      //  throw Standard_ConstructionError("GeomFill_Pipe::Perform : Cannot make a surface");
@@ -898,7 +900,7 @@ void GeomFill_Pipe::Perform(const Standard_Real Tol,
    if (Sweep.IsDone()) {
       mySurface = Sweep.Surface();
       myError = Sweep.ErrorOnSurface();
-      myIsDone = Standard_True;
+      myStatus = GeomFill_PipeOk;
    }
    //else {
    //  throw Standard_ConstructionError("GeomFill_Pipe::Perform : Cannot make a surface");
@@ -975,7 +977,7 @@ Standard_Boolean GeomFill_Pipe::KPartT4()
 					  myAdpPath->FirstParameter(),
 					  myAdpPath->LastParameter());
      Ok = Standard_True; //C'est bien un cylindre
-     myIsDone = Standard_True;
+     myStatus = GeomFill_PipeOk;
    }
  // -----------    Cas du tore  ----------------------------------
  else if (myAdpPath->GetType()      == GeomAbs_Circle &&
@@ -1038,7 +1040,7 @@ Standard_Boolean GeomFill_Pipe::KPartT4()
       myAdpPath->FirstParameter(),myAdpPath->LastParameter(),VV1,VV2);
    myExchUV = Standard_True;
    Ok = Standard_True;
-   myIsDone = Standard_True;
+   myStatus = GeomFill_PipeOk;
  }
 
  return Ok;
@@ -1137,6 +1139,6 @@ void GeomFill_Pipe::ApproxSurf(const Standard_Boolean WithParameters) {
 					App.VDegree());
     Standard_Real t2d;
     App.TolReached(myError, t2d);
-    myIsDone = Standard_True;
+    myStatus = GeomFill_PipeOk;
   }
 }
