@@ -12,20 +12,15 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <Adaptor2d_HCurve2d.hxx>
+#include <GeomLib_CheckCurveOnSurface.hxx>
+
 #include <Adaptor3d_Curve.hxx>
 #include <Adaptor3d_CurveOnSurface.hxx>
-#include <Adaptor3d_HSurface.hxx>
 #include <Geom_BSplineCurve.hxx>
-#include <Geom_TrimmedCurve.hxx>
 #include <Geom2d_BSplineCurve.hxx>
-#include <Geom2d_TrimmedCurve.hxx>
-#include <Geom2dAdaptor_GHCurve.hxx>
+#include <Geom2dAdaptor_Curve.hxx>
 #include <GeomAdaptor_Curve.hxx>
-#include <GeomAdaptor_HSurface.hxx>
-#include <GeomLib_CheckCurveOnSurface.hxx>
 #include <gp_Pnt.hxx>
-#include <math_Matrix.hxx>
 #include <math_MultipleVarFunctionWithHessian.hxx>
 #include <math_NewtonMinimum.hxx>
 #include <math_PSO.hxx>
@@ -35,6 +30,8 @@
 #include <TColStd_Array1OfReal.hxx>
 #include <TColStd_HArray1OfReal.hxx>
 
+typedef NCollection_Array1<Handle(Adaptor3d_Curve)> Array1OfHCurve;
+
 class GeomLib_CheckCurveOnSurface_TargetFunc;
 
 static 
@@ -45,11 +42,11 @@ Standard_Boolean MinComputing(
                 Standard_Real& theBestValue,
                 Standard_Real& theBestParameter);
 
-static Standard_Integer FillSubIntervals( const Handle(Geom_Curve)& theCurve3d,
-                                          const Handle(Geom2d_Curve)& theCurve2d,
+static Standard_Integer FillSubIntervals( const Handle(Adaptor3d_Curve)& theCurve3d,
+                                          const Handle(Adaptor2d_Curve2d)& theCurve2d,
                                           const Standard_Real theFirst,
                                           const Standard_Real theLast,
-                                          Standard_Integer &theNbParticles,
+                                          Standard_Integer& theNbParticles,
                                           TColStd_Array1OfReal* const theSubIntervals = 0);
 
 //=======================================================================
@@ -61,11 +58,11 @@ class GeomLib_CheckCurveOnSurface_TargetFunc :
 {
  public:
   GeomLib_CheckCurveOnSurface_TargetFunc( const Adaptor3d_Curve& theC3D,
-                                          const Adaptor3d_Curve& theAdCS,
+                                          const Adaptor3d_Curve& theCurveOnSurface,
                                           const Standard_Real theFirst,
                                           const Standard_Real theLast):
   myCurve1(theC3D),
-  myCurve2(theAdCS),
+  myCurve2(theCurveOnSurface),
   myFirst(theFirst),
   myLast(theLast)
   {
@@ -121,7 +118,7 @@ class GeomLib_CheckCurveOnSurface_TargetFunc :
     return Derive(theX(1), theGrad(1));
   }
 
-  //returns 1st derivative of the the one-dimension-function when
+  //returns 1st derivative of the one-dimension-function when
   //parameter is equal to theX
   Standard_Boolean Derive(const Standard_Real theX, Standard_Real& theDeriv1, Standard_Real* const theDeriv2 = 0) const
   {
@@ -213,7 +210,7 @@ class GeomLib_CheckCurveOnSurface_TargetFunc :
   }
   
  private:
-  GeomLib_CheckCurveOnSurface_TargetFunc operator=(GeomLib_CheckCurveOnSurface_TargetFunc&);
+  GeomLib_CheckCurveOnSurface_TargetFunc operator=(GeomLib_CheckCurveOnSurface_TargetFunc&) Standard_DELETE;
 
   //checks if the function can be computed when its parameter is
   //equal to theParam
@@ -236,50 +233,43 @@ class GeomLib_CheckCurveOnSurface_Local
 {
 public:
   GeomLib_CheckCurveOnSurface_Local(
-              const Handle(Geom_Curve)& theCurve3D,
-              const Handle(Geom2d_Curve)& theCurve2D,
-              const Handle(Geom_Surface)& theSurface,
-              const TColStd_Array1OfReal& theIntervalsArr,
-              const Standard_Real theEpsilonRange,
-              const Standard_Integer theNbParticles):
-  myCurve3D(theCurve3D),
-  myCurve2D(theCurve2D),
-  mySurface(theSurface),
-  mySubIntervals(theIntervalsArr),
-  myEpsilonRange(theEpsilonRange),
-  myNbParticles(theNbParticles),
-  myArrOfDist(theIntervalsArr.Lower(), theIntervalsArr.Upper()-1),
-  myArrOfParam(theIntervalsArr.Lower(), theIntervalsArr.Upper()-1)
+    const Array1OfHCurve& theCurveArray,
+    const Array1OfHCurve& theCurveOnSurfaceArray,
+    const TColStd_Array1OfReal& theIntervalsArr,
+    const Standard_Real theEpsilonRange,
+    const Standard_Integer theNbParticles):
+    myCurveArray(theCurveArray),
+    myCurveOnSurfaceArray(theCurveOnSurfaceArray),
+    mySubIntervals(theIntervalsArr),
+    myEpsilonRange(theEpsilonRange),
+    myNbParticles(theNbParticles),
+    myArrOfDist(theIntervalsArr.Lower(), theIntervalsArr.Upper() - 1),
+    myArrOfParam(theIntervalsArr.Lower(), theIntervalsArr.Upper() - 1)
   {
   }
   
-  void operator()(const Standard_Integer& theIndex) const
+  void operator()(Standard_Integer theThreadIndex, Standard_Integer theElemIndex) const
   {
     //For every sub-interval (which is set by mySubIntervals array) this method
     //computes optimal value of GeomLib_CheckCurveOnSurface_TargetFunc function.
     //This optimal value will be put in corresponding (depending on theIndex - the
     //identificator of the current interval in mySubIntervals array) cell of 
     //myArrOfDist and myArrOfParam arrays.
-    const GeomAdaptor_Curve anAC(myCurve3D);
-    const Handle(Adaptor2d_HCurve2d) anAd2dC = new Geom2dAdaptor_GHCurve(myCurve2D);
-    const Handle(Adaptor3d_HSurface) anAdS = new GeomAdaptor_HSurface(mySurface);
-
-    const Adaptor3d_CurveOnSurface anACS(anAd2dC, anAdS);
-
-    GeomLib_CheckCurveOnSurface_TargetFunc aFunc( anAC, anACS,
-                                                  mySubIntervals.Value(theIndex),
-                                                  mySubIntervals.Value(theIndex+1));
+    GeomLib_CheckCurveOnSurface_TargetFunc aFunc(*(myCurveArray.Value(theThreadIndex).get()),
+                                                 *(myCurveOnSurfaceArray.Value(theThreadIndex).get()),
+                                                 mySubIntervals.Value(theElemIndex),
+                                                 mySubIntervals.Value(theElemIndex + 1));
 
     Standard_Real aMinDist = RealLast(), aPar = 0.0;
-    if(!MinComputing(aFunc, myEpsilonRange, myNbParticles, aMinDist, aPar))
+    if (!MinComputing(aFunc, myEpsilonRange, myNbParticles, aMinDist, aPar))
     {
-      myArrOfDist(theIndex) = RealLast();
-      myArrOfParam(theIndex) = aFunc.FirstParameter();
+      myArrOfDist(theElemIndex) = RealLast();
+      myArrOfParam(theElemIndex) = aFunc.FirstParameter();
       return;
     }
 
-    myArrOfDist(theIndex) = aMinDist;
-    myArrOfParam(theIndex) = aPar;
+    myArrOfDist(theElemIndex) = aMinDist;
+    myArrOfParam(theElemIndex) = aPar;
   }
 
   //Returns optimal value (inverse of square of maximal distance)
@@ -301,10 +291,11 @@ public:
   }
 
 private:
-  GeomLib_CheckCurveOnSurface_Local operator=(GeomLib_CheckCurveOnSurface_Local&);
-  const Handle(Geom_Curve)& myCurve3D;
-  const Handle(Geom2d_Curve)& myCurve2D;
-  const Handle(Geom_Surface)& mySurface;
+  GeomLib_CheckCurveOnSurface_Local operator=(const GeomLib_CheckCurveOnSurface_Local&) Standard_DELETE;
+
+private:
+  const Array1OfHCurve& myCurveArray;
+  const Array1OfHCurve& myCurveOnSurfaceArray;
 
   const TColStd_Array1OfReal& mySubIntervals;
   const Standard_Real myEpsilonRange;
@@ -319,12 +310,11 @@ private:
 //=======================================================================
 GeomLib_CheckCurveOnSurface::GeomLib_CheckCurveOnSurface()
 :
-  myFirst(0.),
-  myLast(0.),
   myErrorStatus(0),
   myMaxDistance(RealLast()),
   myMaxParameter(0.),
-  myTolRange(Precision::PConfusion())
+  myTolRange(Precision::PConfusion()),
+  myIsParallel(Standard_False)
 {
 }
 
@@ -333,19 +323,14 @@ GeomLib_CheckCurveOnSurface::GeomLib_CheckCurveOnSurface()
 //purpose  : 
 //=======================================================================
 GeomLib_CheckCurveOnSurface::
-  GeomLib_CheckCurveOnSurface(const Handle(Geom_Curve)& theCurve,
-                              const Handle(Geom_Surface)& theSurface,
-                              const Standard_Real theFirst,
-                              const Standard_Real theLast,
+  GeomLib_CheckCurveOnSurface(const Handle(Adaptor3d_Curve)& theCurve,
                               const Standard_Real theTolRange):
   myCurve(theCurve),
-  mySurface(theSurface),
-  myFirst(theFirst),
-  myLast(theLast),
   myErrorStatus(0),
   myMaxDistance(RealLast()),
   myMaxParameter(0.),
-  myTolRange(theTolRange)
+  myTolRange(theTolRange),
+  myIsParallel(Standard_False)
 {
 }
 
@@ -356,9 +341,6 @@ GeomLib_CheckCurveOnSurface::
 void GeomLib_CheckCurveOnSurface::Init()
 {
   myCurve.Nullify();
-  mySurface.Nullify();
-  myFirst = 0.0;
-  myLast = 0.0;
   myErrorStatus = 0;
   myMaxDistance = RealLast();
   myMaxParameter = 0.0;
@@ -369,16 +351,10 @@ void GeomLib_CheckCurveOnSurface::Init()
 //function : Init
 //purpose  : 
 //=======================================================================
-void GeomLib_CheckCurveOnSurface::Init( const Handle(Geom_Curve)& theCurve,
-                                        const Handle(Geom_Surface)& theSurface,
-                                        const Standard_Real theFirst,
-                                        const Standard_Real theLast,
+void GeomLib_CheckCurveOnSurface::Init( const Handle(Adaptor3d_Curve)& theCurve,
                                         const Standard_Real theTolRange)
 {
   myCurve = theCurve;
-  mySurface = theSurface;
-  myFirst = theFirst;
-  myLast = theLast;
   myErrorStatus = 0;
   myMaxDistance = RealLast();
   myMaxParameter = 0.0;
@@ -389,31 +365,17 @@ void GeomLib_CheckCurveOnSurface::Init( const Handle(Geom_Curve)& theCurve,
 //function : Perform
 //purpose  : 
 //=======================================================================
-#ifndef HAVE_TBB
-//After fixing bug # 26365, this fragment should be deleted
-//(together the text "#ifdef HAVE_TBB")
-
-void GeomLib_CheckCurveOnSurface::Perform(const Handle(Geom2d_Curve)& thePCurve,
-                                          const Standard_Boolean)
+void GeomLib_CheckCurveOnSurface::Perform(const Handle(Adaptor3d_CurveOnSurface)& theCurveOnSurface)
 {
-  const Standard_Boolean isTheMTDisabled = Standard_True;
-#else
-void GeomLib_CheckCurveOnSurface::Perform(const Handle(Geom2d_Curve)& thePCurve,
-                                          const Standard_Boolean isTheMTDisabled)
-{
-#endif
   if( myCurve.IsNull() ||
-      mySurface.IsNull() ||
-      thePCurve.IsNull())
+      theCurveOnSurface.IsNull())
   {
     myErrorStatus = 1;
     return;
   }
 
-  if(((myCurve->FirstParameter() - myFirst) > myTolRange) ||
-     ((myCurve->LastParameter() - myLast) < -myTolRange) ||
-     ((thePCurve->FirstParameter() - myFirst) > myTolRange) ||
-     ((thePCurve->LastParameter() - myLast) < -myTolRange))
+  if ((myCurve->FirstParameter() - theCurveOnSurface->FirstParameter() >  myTolRange) ||
+      (myCurve->LastParameter()  - theCurveOnSurface->LastParameter()  < -myTolRange))
   {
     myErrorStatus = 2;
     return;
@@ -430,9 +392,9 @@ void GeomLib_CheckCurveOnSurface::Perform(const Handle(Geom2d_Curve)& thePCurve,
   //at least one particle in every monotonicity interval. Therefore,
   //number of particles should be equal to n. 
 
-  const Standard_Integer aNbSubIntervals = 
-                              FillSubIntervals( myCurve, thePCurve,
-                                                myFirst, myLast, aNbParticles);
+  const Standard_Integer aNbSubIntervals =
+    FillSubIntervals(myCurve, theCurveOnSurface->GetCurve(),
+                     myCurve->FirstParameter(), myCurve->LastParameter(), aNbParticles);
 
   if(!aNbSubIntervals)
   {
@@ -440,22 +402,45 @@ void GeomLib_CheckCurveOnSurface::Perform(const Handle(Geom2d_Curve)& thePCurve,
     return;
   }
 
-  try {
+  try
+  {
     OCC_CATCH_SIGNALS
 
-    TColStd_Array1OfReal anIntervals(1, aNbSubIntervals+1);
-    FillSubIntervals(myCurve, thePCurve, myFirst, myLast, aNbParticles, &anIntervals);
-
-    GeomLib_CheckCurveOnSurface_Local aComp(myCurve, thePCurve,
-                                mySurface, anIntervals, anEpsilonRange, aNbParticles);
-
-    OSD_Parallel::For(anIntervals.Lower(), anIntervals.Upper(), aComp, isTheMTDisabled);
+    TColStd_Array1OfReal anIntervals(1, aNbSubIntervals + 1);
+    FillSubIntervals(myCurve, theCurveOnSurface->GetCurve(),
+                     myCurve->FirstParameter(), myCurve->LastParameter(), aNbParticles, &anIntervals);
 
+    const Standard_Integer aNbThreads = myIsParallel ? Min(anIntervals.Size(), OSD_ThreadPool::DefaultPool()->NbDefaultThreadsToLaunch()) : 1;
+    Array1OfHCurve aCurveArray(0, aNbThreads - 1);
+    Array1OfHCurve aCurveOnSurfaceArray(0, aNbThreads - 1);
+    for (Standard_Integer anI = 0; anI < aNbThreads; ++anI)
+    {
+      aCurveArray.SetValue(anI, aNbThreads > 1 ? myCurve->ShallowCopy() : myCurve);
+      aCurveOnSurfaceArray.SetValue(anI, aNbThreads > 1
+                                    ? theCurveOnSurface->ShallowCopy()
+                                    : static_cast<const Handle(Adaptor3d_Curve)&> (theCurveOnSurface));
+    }
+    GeomLib_CheckCurveOnSurface_Local aComp(aCurveArray, aCurveOnSurfaceArray, anIntervals,
+                                            anEpsilonRange, aNbParticles);
+    if (aNbThreads > 1)
+    {
+      const Handle(OSD_ThreadPool)& aThreadPool = OSD_ThreadPool::DefaultPool();
+      OSD_ThreadPool::Launcher aLauncher(*aThreadPool, aNbThreads);
+      aLauncher.Perform(anIntervals.Lower(), anIntervals.Upper(), aComp);
+    }
+    else
+    {
+      for (Standard_Integer anI = anIntervals.Lower(); anI < anIntervals.Upper(); ++anI)
+      {
+        aComp(0, anI);
+      }
+    }
     aComp.OptimalValues(myMaxDistance, myMaxParameter);
 
     myMaxDistance = sqrt(Abs(myMaxDistance));
   }
-  catch (Standard_Failure const&) {
+  catch (Standard_Failure const&)
+  {
     myErrorStatus = 3;
   }
 }
@@ -467,11 +452,11 @@ void GeomLib_CheckCurveOnSurface::Perform(const Handle(Geom2d_Curve)& thePCurve,
 //            (fills theSubIntervals array).
 //            Returns number of subintervals.
 //=======================================================================
-Standard_Integer FillSubIntervals(const Handle(Geom_Curve)& theCurve3d,
-                                  const Handle(Geom2d_Curve)& theCurve2d,
+Standard_Integer FillSubIntervals(const Handle(Adaptor3d_Curve)& theCurve3d,
+                                  const Handle(Adaptor2d_Curve2d)& theCurve2d,
                                   const Standard_Real theFirst,
                                   const Standard_Real theLast,
-                                  Standard_Integer &theNbParticles,
+                                  Standard_Integer& theNbParticles,
                                   TColStd_Array1OfReal* const theSubIntervals)
 {
   const Standard_Integer aMaxKnots = 101;
@@ -484,33 +469,18 @@ Standard_Integer FillSubIntervals(const Handle(Geom_Curve)& theCurve3d,
   Standard_Boolean isTrimmed3D = Standard_False, isTrimmed2D = Standard_False;
 
   //
-  if (theCurve3d->IsKind(STANDARD_TYPE(Geom_TrimmedCurve)))
+  if (theCurve3d->GetType() == GeomAbs_BSplineCurve)
   {
-    aBS3DCurv = Handle(Geom_BSplineCurve)::
-                      DownCast(Handle(Geom_TrimmedCurve)::
-                      DownCast(theCurve3d)->BasisCurve());
-    isTrimmed3D = Standard_True;
+    aBS3DCurv = theCurve3d->BSpline();
   }
-  else
+  if (theCurve2d->GetType() == GeomAbs_BSplineCurve)
   {
-    aBS3DCurv = Handle(Geom_BSplineCurve)::DownCast(theCurve3d);
+    aBS2DCurv = theCurve2d->BSpline();
   }
 
-  if (theCurve2d->IsKind(STANDARD_TYPE(Geom2d_TrimmedCurve)))
-  {
-    aBS2DCurv = Handle(Geom2d_BSplineCurve)::
-                      DownCast(Handle(Geom2d_TrimmedCurve)::
-                      DownCast(theCurve2d)->BasisCurve());
-    isTrimmed2D = Standard_True;
-  }
-  else
-  {
-    aBS2DCurv = Handle(Geom2d_BSplineCurve)::DownCast(theCurve2d);
-  }
+  Handle(TColStd_HArray1OfReal) anArrKnots3D, anArrKnots2D;
 
-  Handle(TColStd_HArray1OfReal) anArrKnots3D,  anArrKnots2D; 
- 
-  if(!aBS3DCurv.IsNull())
+  if (!aBS3DCurv.IsNull())
   {
     if(aBS3DCurv->NbKnots() <= aMaxKnots)
     {
