@@ -27,12 +27,10 @@
 #include <Geom_Line.hxx>
 #include <Geom_Plane.hxx>
 #include <GeomLib.hxx>
-#include <GeomPlate_Aij.hxx>
 #include <GeomPlate_BuildAveragePlane.hxx>
 #include <gp_Ax1.hxx>
 #include <gp_Ax3.hxx>
 #include <gp_Dir.hxx>
-#include <gp_Lin2d.hxx>
 #include <gp_Pln.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Vec.hxx>
