@@ -49,20 +49,16 @@
 #include <IntRes2d_IntersectionPoint.hxx>
 #include <Law_Interpol.hxx>
 #include <LocalAnalysis_SurfaceContinuity.hxx>
-#include <Plate_D1.hxx>
 #include <Plate_D2.hxx>
 #include <Plate_FreeGtoCConstraint.hxx>
 #include <Plate_GtoCConstraint.hxx>
 #include <Plate_PinpointConstraint.hxx>
 #include <Plate_Plate.hxx>
 #include <Precision.hxx>
-#include <ProjLib_CompProjectedCurve.hxx>
 #include <ProjLib_HCompProjectedCurve.hxx>
 #include <Standard_ConstructionError.hxx>
-#include <Standard_RangeError.hxx>
 #include <TColgp_Array1OfPnt2d.hxx>
 #include <TColgp_HArray1OfPnt.hxx>
-#include <TColgp_HArray2OfPnt.hxx>
 #include <TColgp_SequenceOfVec.hxx>
 #include <TColStd_HArray1OfReal.hxx>
 #include <TColStd_SequenceOfInteger.hxx>
