@@ -16,7 +16,6 @@
 
 
 #include <Geom_BezierSurface.hxx>
-#include <Geom_BSplineSurface.hxx>
 #include <Geom_ConicalSurface.hxx>
 #include <Geom_CylindricalSurface.hxx>
 #include <Geom_OffsetSurface.hxx>
@@ -39,9 +38,7 @@
 #include <Message_ProgressScope.hxx>
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_Failure.hxx>
-#include <Standard_OutOfRange.hxx>
 #include <Standard_Stream.hxx>
-#include <TColgp_Array1OfPnt.hxx>
 #include <TColgp_Array2OfPnt.hxx>
 #include <TColStd_Array1OfInteger.hxx>
 #include <TColStd_Array1OfReal.hxx>
@@ -121,9 +118,9 @@ Standard_Integer  GeomTools_SurfaceSet::Index
 //purpose  : 
 //=======================================================================
 
-static void Print(const gp_Pnt P,
-		  Standard_OStream& OS,
-		  const Standard_Boolean compact)
+static void Print(const gp_Pnt&          P,
+                  Standard_OStream&      OS,
+                  const Standard_Boolean compact)
 {
   OS << P.X();
   if (!compact) OS << ",";
@@ -140,9 +137,9 @@ static void Print(const gp_Pnt P,
 //purpose  : 
 //=======================================================================
 
-static void Print(const gp_Dir D,
-		  Standard_OStream& OS,
-		  const Standard_Boolean compact)
+static void Print(const gp_Dir&          D,
+                  Standard_OStream&      OS,
+                  const Standard_Boolean compact)
 {
   OS << D.X();
   if (!compact) OS << ",";
