@@ -13,12 +13,8 @@
 
 
 #include <IFSelect_BasicDumper.hxx>
-#include <IFSelect_Dispatch.hxx>
-#include <IFSelect_GeneralModifier.hxx>
 #include <IFSelect_IntParam.hxx>
-#include <IFSelect_Modifier.hxx>
 #include <IFSelect_SelectAnyList.hxx>
-#include <IFSelect_SelectAnyType.hxx>
 #include <IFSelect_SelectCombine.hxx>
 #include <IFSelect_SelectControl.hxx>
 #include <IFSelect_SelectDeduct.hxx>
