@@ -23,13 +23,11 @@
 #include <IGESData_IGESReaderData.hxx>
 #include <IGESData_IGESWriter.hxx>
 #include <IGESData_LevelListEntity.hxx>
-#include <IGESData_ParamCursor.hxx>
 #include <IGESData_ParamReader.hxx>
 #include <Interface_Check.hxx>
 #include <Interface_CopyTool.hxx>
 #include <Interface_EntityIterator.hxx>
 #include <Interface_ShareTool.hxx>
-#include <Standard_DomainError.hxx>
 
 IGESAppli_ToolLineWidening::IGESAppli_ToolLineWidening ()    {  }
 
