@@ -24,7 +24,6 @@
 #include <IGESData_IGESDumper.hxx>
 #include <IGESData_IGESReaderData.hxx>
 #include <IGESData_IGESWriter.hxx>
-#include <IGESData_ParamCursor.hxx>
 #include <IGESData_ParamReader.hxx>
 #include <IGESGeom_TransformationMatrix.hxx>
 #include <Interface_Check.hxx>
@@ -33,7 +32,6 @@
 #include <Interface_Macros.hxx>
 #include <Interface_ShareTool.hxx>
 #include <Message_Messenger.hxx>
-#include <Standard_DomainError.hxx>
 
 IGESAppli_ToolNode::IGESAppli_ToolNode ()    {  }
 
