@@ -15,9 +15,7 @@
 
 #include <IGESCAFControl.hxx>
 #include <IGESCAFControl_Writer.hxx>
-#include <IGESData_IGESEntity.hxx>
 #include <IGESData_IGESModel.hxx>
-#include <IGESData_NameEntity.hxx>
 #include <IGESGraph_Color.hxx>
 #include <IGESGraph_DefinitionLevel.hxx>
 #include <IGESSolid_Face.hxx>
@@ -28,24 +26,18 @@
 #include <TCollection_AsciiString.hxx>
 #include <TCollection_HAsciiString.hxx>
 #include <TCollection_HExtendedString.hxx>
-#include <TColStd_HSequenceOfExtendedString.hxx>
 #include <TDataStd_Name.hxx>
-#include <TDF_ChildIterator.hxx>
 #include <TDF_Label.hxx>
 #include <TDF_LabelSequence.hxx>
 #include <TDocStd_Document.hxx>
-#include <TopAbs.hxx>
 #include <TopExp_Explorer.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Face.hxx>
 #include <TopoDS_Iterator.hxx>
 #include <TopoDS_Shape.hxx>
-#include <TopTools_SequenceOfShape.hxx>
-#include <Transfer_FinderProcess.hxx>
 #include <Transfer_TransientListBinder.hxx>
 #include <TransferBRep.hxx>
 #include <TransferBRep_ShapeMapper.hxx>
-#include <XCAFDoc_ColorTool.hxx>
 #include <XCAFDoc_DocumentTool.hxx>
 #include <XCAFDoc_LayerTool.hxx>
 #include <XCAFDoc_LengthUnit.hxx>
@@ -102,7 +94,7 @@ namespace
       }
     }
 
-    if (!hasReferredShape && !hasComponents)
+    if (!hasReferredShape && !hasComponents && !thePrevName.IsNull())
     {
       TopoDS_Shape aShape;
       if (!XCAFDoc_ShapeTool::GetShape (theLabel, aShape)) return;
@@ -286,7 +278,7 @@ void IGESCAFControl_Writer::MakeColors (const TopoDS_Shape &S,
   // check if shape has its own style (or inherits from ancestor)
   XCAFPrs_Style style = inherit;
   if ( settings.Contains(S) ) {
-    XCAFPrs_Style own = settings.FindFromKey(S);
+    const XCAFPrs_Style& own = settings.FindFromKey(S);
     if ( own.IsSetColorCurv() ) style.SetColorCurv ( own.GetColorCurv() );
     if ( own.IsSetColorSurf() ) style.SetColorSurf ( own.GetColorSurf() );
     style.SetMaterial (own.Material());
@@ -405,7 +397,7 @@ static void AttachLayer (const Handle(Transfer_FinderProcess) &FP,
   if ( aSh.ShapeType() == TopAbs_COMPOUND ) {
     TopoDS_Iterator aShIt(aSh);
     for ( ; aShIt.More(); aShIt.Next() ) {
-      TopoDS_Shape newSh = aShIt.Value();
+      const TopoDS_Shape& newSh = aShIt.Value();
       Handle(TColStd_HSequenceOfExtendedString) shLayers = new TColStd_HSequenceOfExtendedString;
       if (! LTool->GetLayers( newSh, shLayers) || newSh.ShapeType() == TopAbs_COMPOUND )
 	AttachLayer(FP, LTool, newSh, localIntName);
@@ -421,7 +413,7 @@ static void AttachLayer (const Handle(Transfer_FinderProcess) &FP,
   }
   
   for (Standard_Integer i = 1; i <= shseq.Length(); i++ ) {
-    TopoDS_Shape localShape = shseq.Value(i);
+    const TopoDS_Shape& localShape = shseq.Value(i);
     Handle(IGESData_IGESEntity) Igesent;
     Handle(TransferBRep_ShapeMapper) mapper = TransferBRep::ShapeMapper ( FP, localShape );
     if ( FP->FindTypedTransient ( mapper, STANDARD_TYPE(IGESData_IGESEntity), Igesent ) ) {
