@@ -14,27 +14,20 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-// modif du 31/01/97 : mjm
-// on commence par les SplineCurves.
-// modif du 17/03/97 : mjm
-// SplineSurfaces.
-//%13 pdn 12.02.99: USA60293 avoid applying transformation twice
+#include <IGESConvGeom.hxx>
 
 #include <BSplCLib.hxx>
 #include <BSplSLib.hxx>
 #include <Geom2d_BSplineCurve.hxx>
 #include <Geom_BSplineCurve.hxx>
 #include <Geom_BSplineSurface.hxx>
-#include <GeomConvert_CompCurveToBSplineCurve.hxx>
 #include <gp_GTrsf.hxx>
 #include <gp_Trsf.hxx>
-#include <IGESConvGeom.hxx>
 #include <IGESData_ToolLocation.hxx>
 #include <IGESGeom_SplineCurve.hxx>
 #include <IGESGeom_SplineSurface.hxx>
 #include <PLib.hxx>
 #include <TColgp_HArray1OfPnt.hxx>
-#include <TColgp_HArray2OfPnt.hxx>
 #include <TColStd_Array1OfInteger.hxx>
 #include <TColStd_Array1OfReal.hxx>
 #include <TColStd_HArray1OfReal.hxx>
