@@ -18,10 +18,8 @@
 
 #include <IGESData_DirChecker.hxx>
 #include <IGESData_IGESDumper.hxx>
-#include <IGESData_IGESEntity.hxx>
 #include <IGESData_IGESReaderData.hxx>
 #include <IGESData_IGESWriter.hxx>
-#include <IGESData_ParamCursor.hxx>
 #include <IGESData_ParamReader.hxx>
 #include <IGESDimen_CurveDimension.hxx>
 #include <IGESDimen_GeneralNote.hxx>
@@ -34,8 +32,6 @@
 #include <Interface_EntityIterator.hxx>
 #include <Interface_Macros.hxx>
 #include <Interface_ShareTool.hxx>
-#include <Message_Messenger.hxx>
-#include <Standard_DomainError.hxx>
 
 IGESDimen_ToolCurveDimension::IGESDimen_ToolCurveDimension ()    {  }
 
