@@ -20,19 +20,14 @@
 #include <gp_XY.hxx>
 #include <IGESData_DirChecker.hxx>
 #include <IGESData_Dump.hxx>
-#include <IGESData_HArray1OfIGESEntity.hxx>
 #include <IGESData_IGESDumper.hxx>
-#include <IGESData_IGESEntity.hxx>
 #include <IGESData_IGESReaderData.hxx>
 #include <IGESData_IGESWriter.hxx>
-#include <IGESData_ParamCursor.hxx>
 #include <IGESData_ParamReader.hxx>
-#include <IGESData_ViewKindEntity.hxx>
 #include <IGESDraw_DrawingWithRotation.hxx>
 #include <IGESDraw_HArray1OfViewKindEntity.hxx>
 #include <IGESDraw_PerspectiveView.hxx>
 #include <IGESDraw_ToolDrawingWithRotation.hxx>
-#include <IGESDraw_View.hxx>
 #include <Interface_Check.hxx>
 #include <Interface_CopyTool.hxx>
 #include <Interface_EntityIterator.hxx>
