@@ -13,8 +13,6 @@
 
 
 #include <IGESData_IGESDumper.hxx>
-#include <IGESData_IGESEntity.hxx>
-#include <IGESGeom_Boundary.hxx>
 #include <IGESGeom_BoundedSurface.hxx>
 #include <IGESGeom_BSplineCurve.hxx>
 #include <IGESGeom_BSplineSurface.hxx>
@@ -22,7 +20,6 @@
 #include <IGESGeom_CompositeCurve.hxx>
 #include <IGESGeom_ConicArc.hxx>
 #include <IGESGeom_CopiousData.hxx>
-#include <IGESGeom_CurveOnSurface.hxx>
 #include <IGESGeom_Direction.hxx>
 #include <IGESGeom_Flash.hxx>
 #include <IGESGeom_Line.hxx>
