@@ -18,12 +18,9 @@
 
 #include <IGESData_DirChecker.hxx>
 #include <IGESData_Dump.hxx>
-#include <IGESData_HArray1OfIGESEntity.hxx>
 #include <IGESData_IGESDumper.hxx>
-#include <IGESData_IGESEntity.hxx>
 #include <IGESData_IGESReaderData.hxx>
 #include <IGESData_IGESWriter.hxx>
-#include <IGESData_ParamCursor.hxx>
 #include <IGESData_ParamReader.hxx>
 #include <IGESGeom_CompositeCurve.hxx>
 #include <IGESGeom_ToolCompositeCurve.hxx>
@@ -34,7 +31,6 @@
 #include <Interface_ShareTool.hxx>
 #include <Message_Messenger.hxx>
 #include <Message_Msg.hxx>
-#include <Standard_DomainError.hxx>
 
 // MGE 28/07/98
 IGESGeom_ToolCompositeCurve::IGESGeom_ToolCompositeCurve ()    {  }
