@@ -20,7 +20,6 @@
 #include <IGESData_IGESDumper.hxx>
 #include <IGESData_IGESReaderData.hxx>
 #include <IGESData_IGESWriter.hxx>
-#include <IGESData_ParamCursor.hxx>
 #include <IGESData_ParamReader.hxx>
 #include <IGESGraph_LineFontPredefined.hxx>
 #include <IGESGraph_ToolLineFontPredefined.hxx>
@@ -28,8 +27,6 @@
 #include <Interface_CopyTool.hxx>
 #include <Interface_EntityIterator.hxx>
 #include <Interface_ShareTool.hxx>
-#include <Message_Messenger.hxx>
-#include <Standard_DomainError.hxx>
 
 IGESGraph_ToolLineFontPredefined::IGESGraph_ToolLineFontPredefined ()    {  }
 
