@@ -19,10 +19,8 @@
 #include <IGESData_DirChecker.hxx>
 #include <IGESData_Dump.hxx>
 #include <IGESData_IGESDumper.hxx>
-#include <IGESData_IGESEntity.hxx>
 #include <IGESData_IGESReaderData.hxx>
 #include <IGESData_IGESWriter.hxx>
-#include <IGESData_ParamCursor.hxx>
 #include <IGESData_ParamReader.hxx>
 #include <IGESData_Status.hxx>
 #include <IGESSolid_Face.hxx>
@@ -36,7 +34,6 @@
 #include <Interface_ShareTool.hxx>
 #include <Message_Messenger.hxx>
 #include <Message_Msg.hxx>
-#include <Standard_DomainError.hxx>
 
 // MGE 03/08/98
 //=======================================================================
