@@ -17,46 +17,33 @@
 
 #include <BRep_Builder.hxx>
 #include <BRepLib.hxx>
-#include <BRepTools_Modifier.hxx>
-#include <gp_Trsf.hxx>
 #include <IGESAppli.hxx>
 #include <IGESAppli_Protocol.hxx>
 #include <IGESData_FileProtocol.hxx>
 #include <IGESData_GlobalSection.hxx>
-#include <IGESData_IGESEntity.hxx>
-#include <IGESData_IGESModel.hxx>
 #include <IGESFile_Read.hxx>
 #include <IGESSolid.hxx>
 #include <IGESSolid_Protocol.hxx>
-#include <IGESToBRep.hxx>
 #include <IGESToBRep_Actor.hxx>
 #include <IGESToBRep_CurveAndSurface.hxx>
 #include <IGESToBRep_Reader.hxx>
-#include <Interface_Check.hxx>
 #include <Interface_CheckIterator.hxx>
 #include <Interface_CheckTool.hxx>
-#include <Interface_Macros.hxx>
 #include <Interface_ShareFlags.hxx>
 #include <Interface_Static.hxx>
 #include <Message_Messenger.hxx>
 #include <Message_Msg.hxx>
 #include <Message_ProgressScope.hxx>
 #include <OSD_Timer.hxx>
-#include <ShapeAlgo.hxx>
-#include <ShapeAlgo_AlgoContainer.hxx>
 #include <ShapeExtend_Explorer.hxx>
 #include <ShapeFix_ShapeTolerance.hxx>
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_Failure.hxx>
-#include <TopAbs.hxx>
 #include <TopoDS_Compound.hxx>
 #include <TopoDS_Shape.hxx>
-#include <Transfer_IteratorOfProcessForTransient.hxx>
 #include <Transfer_TransferOutput.hxx>
 #include <Transfer_TransientProcess.hxx>
 #include <TransferBRep.hxx>
-#include <TransferBRep_ShapeBinder.hxx>
-#include <TransferBRep_ShapeListBinder.hxx>
 #include <XSAlgo.hxx>
 #include <XSAlgo_AlgoContainer.hxx>
 
@@ -170,7 +157,7 @@ Standard_Integer IGESToBRep_Reader::LoadFile (const Standard_CString filename)
   Interface_CheckTool cht (model,protocol);
   Interface_CheckIterator anIter = cht.CompleteCheckList();
   for(anIter.Start(); anIter.More(); anIter.Next()) {
-    const Handle(Interface_Check) ach = anIter.Value();
+    const Handle(Interface_Check)& ach = anIter.Value();
     nbWarn += ach->NbWarnings();
     nbFail += ach->NbFails();
   }
@@ -565,7 +552,7 @@ Standard_Boolean  IGESToBRep_Reader::Transfer(const Standard_Integer num,
     shape = XSAlgo::AlgoContainer()->ProcessShape( shape, eps*CAS.GetUnitFactor(), CAS.GetMaxTol(),
                                                    "read.iges.resource.name", 
                                                    "read.iges.sequence", info,
-                                                   aPS.Next() );
+                                                   aPS.Next(), false, TopAbs_EDGE);
     if (aPS.UserBreak())
       return Standard_False;
 
