@@ -64,6 +64,7 @@
 #include <vtkImageWriter.h>
 #include <vtkInteractorStyleTrackballCamera.h>
 #include <vtkJPEGWriter.h>
+#include <vtkMatrix4x4.h>
 #include <vtkPNGWriter.h>
 #include <vtkPNMWriter.h>
 #include <vtkPolyDataMapper.h>
@@ -83,7 +84,6 @@
   #include <Xw_Window.hxx>
   #include <vtkXRenderWindowInteractor.h>
   #include <vtkXOpenGLRenderWindow.h>
-  #include <tk.h>
 #endif
 #include <Standard_WarningsRestore.hxx>
 
@@ -94,9 +94,25 @@
 //================================================================
 // TYPE DEFINITIONS
 //================================================================
+namespace
+{
+  struct VtkPointerHasher
+  {
+    std::size_t operator()(const vtkSmartPointer<vtkActor>& thePointer) const
+    {
+      return std::hash<vtkActor*>{}(thePointer.Get());
+    }
+
+    bool operator()(const vtkSmartPointer<vtkActor>& thePointer1,
+                    const vtkSmartPointer<vtkActor>& thePointer2) const
+    {
+      return thePointer1 == thePointer2;
+    }
+  };
+}
 
 typedef NCollection_DoubleMap<TopoDS_Shape, TCollection_AsciiString> DoubleMapOfShapesAndNames;
-typedef NCollection_DoubleMap<vtkSmartPointer<vtkActor>, TCollection_AsciiString> DoubleMapOfActorsAndNames;
+typedef NCollection_DoubleMap<vtkSmartPointer<vtkActor>, TCollection_AsciiString, VtkPointerHasher> DoubleMapOfActorsAndNames;
 
 typedef IVtkDraw_HighlightAndSelectionPipeline PipelinePtr;
 
@@ -167,6 +183,23 @@ static Handle(PipelinePtr) PipelineByActorName (const TCollection_AsciiString& t
   return PipelineByActor (anActor);
 }
 
+//! Create global presentation attributes.
+static Handle(Prs3d_Drawer) createDefaultDrawer()
+{
+  Handle(Prs3d_Drawer) aGlobalDrawer = new Prs3d_Drawer();
+  aGlobalDrawer->SetupOwnDefaults();
+  aGlobalDrawer->SetTypeOfDeflection (Aspect_TOD_RELATIVE);
+  aGlobalDrawer->SetDeviationCoefficient (0.0001);
+  return aGlobalDrawer;
+}
+
+//! Get global presentation attributes (analog of AIS_InteractiveContext::DefaultDrawer()).
+static const Handle(Prs3d_Drawer)& GetDefaultDrawer()
+{
+  static Handle(Prs3d_Drawer) aGlobalDrawer = createDefaultDrawer();
+  return aGlobalDrawer;
+}
+
 #ifdef _WIN32
 
 static Handle(WNT_Window)& GetWindow()
@@ -295,7 +328,7 @@ void IVtkDraw::ViewerInit (const IVtkWinParams& theParams)
 #else
     Window aWindowId = GetWindow()->XWindow();
     aRenWin->SetWindowId ((void*)aWindowId);
-    Display *aDisplayId = GetDisplayConnection()->GetDisplay();
+    Display* aDisplayId = (Display* )GetDisplayConnection()->GetDisplayAspect();
     aRenWin->SetDisplayId (aDisplayId);
 
     // Setup XWindow
@@ -495,12 +528,106 @@ vtkActor* CreateActor (const Standard_Integer theId,
     return NULL;
   }
 
-  Handle(PipelinePtr) aPL = new PipelinePtr (theShape, theId);
+  Handle(PipelinePtr) aPL = new PipelinePtr (theShape, theId, GetDefaultDrawer());
   GetPipelines()->Bind (theId, aPL);
 
+  aPL->Actor()->GetProperty()->SetInterpolationToPhong();
   return aPL->Actor();
 }
 
+
+//===============================================================================================
+//function : VtkDefaults
+//purpose  :
+//===============================================================================================
+static int VtkDefaults (Draw_Interpretor& theDi,
+                        Standard_Integer  theArgsNb,
+                        const char**      theArgVec)
+{
+  const Handle(Prs3d_Drawer)& aDefParams = GetDefaultDrawer();
+  if (theArgsNb < 2)
+  {
+    if (aDefParams->TypeOfDeflection() == Aspect_TOD_RELATIVE)
+    {
+      theDi << "DeflType:           relative\n"
+            << "DeviationCoeff:     " << aDefParams->DeviationCoefficient() << "\n";
+    }
+    else
+    {
+      theDi << "DeflType:           absolute\n"
+            << "AbsoluteDeflection: " << aDefParams->MaximalChordialDeviation() << "\n";
+    }
+    theDi << "AngularDeflection:  " << (180.0 * aDefParams->DeviationAngle() / M_PI) << "\n";
+    theDi << "AutoTriangulation:  " << (aDefParams->IsAutoTriangulation() ? "on" : "off") << "\n";
+    return 0;
+  }
+
+  for (Standard_Integer anArgIter = 1; anArgIter < theArgsNb; ++anArgIter)
+  {
+    TCollection_AsciiString anArg (theArgVec[anArgIter]);
+    anArg.UpperCase();
+    if (anArg == "-ABSDEFL"
+     || anArg == "-ABSOLUTEDEFLECTION"
+     || anArg == "-DEFL"
+     || anArg == "-DEFLECTION")
+    {
+      if (++anArgIter >= theArgsNb)
+      {
+        theDi << "Syntax error at " << anArg;
+        return 1;
+      }
+      aDefParams->SetTypeOfDeflection         (Aspect_TOD_ABSOLUTE);
+      aDefParams->SetMaximalChordialDeviation (Draw::Atof (theArgVec[anArgIter]));
+    }
+    else if (anArg == "-RELDEFL"
+          || anArg == "-RELATIVEDEFLECTION"
+          || anArg == "-DEVCOEFF"
+          || anArg == "-DEVIATIONCOEFF"
+          || anArg == "-DEVIATIONCOEFFICIENT")
+    {
+      if (++anArgIter >= theArgsNb)
+      {
+        theDi << "Syntax error at " << anArg;
+        return 1;
+      }
+      aDefParams->SetTypeOfDeflection     (Aspect_TOD_RELATIVE);
+      aDefParams->SetDeviationCoefficient (Draw::Atof (theArgVec[anArgIter]));
+    }
+    else if (anArg == "-ANGDEFL"
+          || anArg == "-ANGULARDEFL"
+          || anArg == "-ANGULARDEFLECTION")
+    {
+      if (++anArgIter >= theArgsNb)
+      {
+        theDi << "Syntax error at " << anArg;
+        return 1;
+      }
+      aDefParams->SetDeviationAngle (M_PI * Draw::Atof (theArgVec[anArgIter]) / 180.0);
+    }
+    else if (anArg == "-AUTOTR"
+          || anArg == "-AUTOTRIANG"
+          || anArg == "-AUTOTRIANGULATION")
+    {
+      ++anArgIter;
+      bool toTurnOn = true;
+      if (anArgIter >= theArgsNb
+      || !Draw::ParseOnOff (theArgVec[anArgIter], toTurnOn))
+      {
+        theDi << "Syntax error at '" << anArg << "'";
+        return 1;
+      }
+      aDefParams->SetAutoTriangulation (toTurnOn);
+    }
+    else
+    {
+      theDi << "Syntax error: unknown argument '" << anArg << "'";
+      return 1;
+    }
+  }
+
+  return 0;
+}
+
 //================================================================
 // Function : VtkDisplay
 // Purpose  : 
@@ -699,7 +826,7 @@ static Standard_Integer VtkRemove (Draw_Interpretor& ,
         IVtk_IdType aShapeID = aSrc->GetShape()->GetId();
         GetPicker()->RemoveSelectableObject (aSrc->GetShape());
         GetPipeline (aSrc->GetShape()->GetId())->RemoveFromRenderer (aRenderer);
-        GetPipelines()->UnBind (aShapeID); // Remove a pipepline
+        GetPipelines()->UnBind (aShapeID); // Remove a pipeline
       }
       else
       {
@@ -719,158 +846,159 @@ static Standard_Integer VtkRemove (Draw_Interpretor& ,
 
 //================================================================
 // Function  : VtkSetDisplayMode
-// Purpose   : 
-// Draw args : ivtksetdispmode [name] mode(0,1)
+// Purpose   :
 //================================================================
-static Standard_Integer VtkSetDisplayMode (Draw_Interpretor& ,
+static Standard_Integer VtkSetDisplayMode (Draw_Interpretor& theDI,
                                            Standard_Integer theArgNum,
                                            const char** theArgs)
 {
   if (!GetInteractor()
    || !GetInteractor()->IsEnabled())
   {
-    Message::SendFail() << "Error: call ivtkinit before";
-    return 1;
-  }
-  else if (theArgNum != 2 && theArgNum != 3)
-  {
-    Message::SendFail() << "Syntax error: expects 1 or 2 arguments";
+    theDI << "Error: call ivtkinit before";
     return 1;
   }
 
-  if (theArgNum == 2)
+  Standard_Integer aDispMode = -1;
+  Standard_Integer isFaceBoundaryDraw = -1, isSmoothShading = -1;
+  Graphic3d_TypeOfShadingModel aShadingModel = Graphic3d_TOSM_DEFAULT;
+  NCollection_Sequence< vtkSmartPointer<vtkActor> > anActors;
+  for (Standard_Integer anArgIter = 1; anArgIter < theArgNum; ++anArgIter)
   {
-    // Set disp mode for all objects
-    Standard_Integer aMode =  Draw::Atoi (theArgs[1]); // Get mode
-    DoubleMapOfActorsAndNames::Iterator anIter (GetMapOfActors());
-    while (anIter.More())
+    TCollection_AsciiString anArgCase (theArgs[anArgIter]);
+    anArgCase.LowerCase();
+    if (anArgCase == "-faceboundarydraw"
+     || anArgCase == "-drawfaceboundary"
+     || anArgCase == "-faceboundary")
     {
-      vtkSmartPointer<vtkActor> anActor = anIter.Key1();
-      IVtkTools_ShapeDataSource* aSrc = IVtkTools_ShapeObject::GetShapeSource (anActor);
-      if (aSrc)
+      bool toDraw = Draw::ParseOnOffNoIterator (theArgNum, theArgs, anArgIter);
+      isFaceBoundaryDraw = toDraw ? 1 : 0;
+    }
+    else if (anArgCase == "-smoothshading"
+          || anArgCase == "-smooth")
+    {
+      bool toEnable = Draw::ParseOnOffNoIterator (theArgNum, theArgs, anArgIter);
+      isSmoothShading = toEnable ? 1 : 0;
+    }
+    else if (anArgIter + 1 < theArgNum
+          && (anArgCase == "-shadingmodel"))
+    {
+      TCollection_AsciiString aModelName (theArgs[++anArgIter]);
+      aModelName.LowerCase();
+      if (aModelName == "fragment"
+       || aModelName == "frag"
+       || aModelName == "phong")
       {
-        IVtkOCC_Shape::Handle anOccShape = aSrc->GetShape();
-        if (!anOccShape.IsNull())
+        aShadingModel = Graphic3d_TOSM_FRAGMENT;
+      }
+      else if (aModelName == "vertex"
+            || aModelName == "vert"
+            || aModelName == "gouraud")
+      {
+        aShadingModel = Graphic3d_TOSM_VERTEX;
+      }
+      else if (aModelName == "facet"
+            || aModelName == "flat")
+      {
+        aShadingModel = Graphic3d_TOSM_FACET;
+      }
+      else
+      {
+        theDI << "Syntax error: unknown shading model '" << theArgs[anArgIter] << "'";
+        return 1;
+      }
+    }
+    else if (aDispMode == -1
+          && (anArgCase == "0"
+           || anArgCase == "1"))
+    {
+      aDispMode = Draw::Atoi (theArgs[anArgIter]);
+    }
+    else if (aDispMode == -1
+          && (anArgCase == "-shaded"
+           || anArgCase == "-shading"))
+    {
+      aDispMode = DM_Shading;
+    }
+    else if (aDispMode == -1
+          && anArgCase == "-wireframe")
+    {
+      aDispMode = DM_Wireframe;
+    }
+    else
+    {
+      TCollection_AsciiString aName = theArgs[anArgIter];
+      vtkSmartPointer<vtkActor> anActor;
+      if (!GetMapOfActors().Find2 (aName, anActor))
+      {
+        theDI << "Syntax error: object '" << aName << "' not found";
+        return 1;
+      }
+      anActors.Append (anActor);
+    }
+  }
+  if (aDispMode == -1)
+  {
+    theDI << "Syntax error: wrong number of arguments";
+    return 1;
+  }
+
+  if (anActors.IsEmpty())
+  {
+    // update all objects
+    for (DoubleMapOfActorsAndNames::Iterator anIter (GetMapOfActors()); anIter.More(); anIter.Next())
+    {
+      anActors.Append (anIter.Key1());
+    }
+  }
+
+  for (NCollection_Sequence< vtkSmartPointer<vtkActor> >::Iterator anActorIter (anActors); anActorIter.More(); anActorIter.Next())
+  {
+    vtkSmartPointer<vtkActor> anActor = anActorIter.Value();
+    IVtkTools_ShapeDataSource* aSrc = IVtkTools_ShapeObject::GetShapeSource (anActor);
+    if (aSrc == NULL)
+    {
+      continue;
+    }
+
+    IVtkOCC_Shape::Handle anOccShape = aSrc->GetShape();
+    if (!anOccShape.IsNull())
+    {
+      IVtkTools_DisplayModeFilter* aFilter = GetPipeline ( anOccShape->GetId() )->GetDisplayModeFilter();
+      aFilter->SetDisplayMode ((IVtk_DisplayMode)aDispMode);
+      if (isFaceBoundaryDraw != -1)
+      {
+        // Set Red color for boundary edges
+        vtkLookupTable* aTable = (vtkLookupTable*)anActor->GetMapper()->GetLookupTable();
+        IVtkTools::SetLookupTableColor (aTable, MT_SharedEdge, 1., 0., 0., 1.);
+        aFilter->SetFaceBoundaryDraw (isFaceBoundaryDraw == 1);
+      }
+      if (isSmoothShading != -1)
+      {
+        aFilter->SetSmoothShading (isSmoothShading == 1);
+      }
+      switch (aShadingModel)
+      {
+        case Graphic3d_TOSM_FACET:
         {
-          IVtkTools_DisplayModeFilter* aFilter = GetPipeline ( anOccShape->GetId() )->GetDisplayModeFilter();
-          aFilter->SetDisplayMode((IVtk_DisplayMode)aMode);
-          aFilter->Modified();
-          aFilter->Update();
+          anActor->GetProperty()->SetInterpolationToFlat();
+          break;
         }
-      }
-      anIter.Next();
-    }
-  }
-  // Set disp mode for named object
-  else 
-  {
-    TCollection_AsciiString aName = theArgs[1];
-    vtkSmartPointer<vtkActor> anActor;
-    if (!GetMapOfActors().Find2 (aName, anActor))
-    {
-      Message::SendFail() << "Syntax error: object '" << aName << "' not found";
-      return 1;
-    }
-
-    Standard_Integer aMode = atoi(theArgs[2]);
-    vtkSmartPointer<IVtkTools_ShapeDataSource> aSrc = IVtkTools_ShapeObject::GetShapeSource (anActor);
-    if (aSrc)
-    {
-      IVtkOCC_Shape::Handle anOccShape = aSrc->GetShape();
-      if (!anOccShape.IsNull())
-      {
-        IVtkTools_DisplayModeFilter* aFilter = GetPipeline (anOccShape->GetId())->GetDisplayModeFilter();
-        aFilter->SetDisplayMode ((IVtk_DisplayMode)aMode);
-        aFilter->Modified();
-        aFilter->Update();
-      }
-    }
-  }
-
-  // Redraw window
-  GetInteractor()->Render();
-  return 0;
-}
-
-//================================================================
-// Function  : VtkSetBoundaryDraw
-// Purpose   :
-//================================================================
-static Standard_Integer VtkSetBoundaryDraw (Draw_Interpretor& ,
-                                            Standard_Integer theArgNum,
-                                            const char** theArgs)
-{
-  if (!GetInteractor()
-   || !GetInteractor()->IsEnabled())
-  {
-    Message::SendFail() << "Error: call ivtkinit before";
-    return 1;
-  }
-  else if (theArgNum != 2 && theArgNum != 3)
-  {
-    Message::SendFail() << "Syntax error: expects 1 or 2 arguments";
-    return 1;
-  }
-
-  if (theArgNum == 2)
-  {
-    // Set disp mode for all objects
-    Standard_Boolean toDraw = true;
-    Draw::ParseOnOff (theArgs[1], toDraw);
-    DoubleMapOfActorsAndNames::Iterator anIter(GetMapOfActors());
-    while (anIter.More())
-    {
-      vtkSmartPointer<vtkActor> anActor = anIter.Key1();
-      // Set Red color for boundary edges
-      vtkLookupTable* aTable = (vtkLookupTable*)anActor->GetMapper()->GetLookupTable();
-      IVtkTools::SetLookupTableColor(aTable, MT_SharedEdge, 1., 0., 0., 1.);
-
-      IVtkTools_ShapeDataSource* aSrc = IVtkTools_ShapeObject::GetShapeSource(anActor);
-      if (aSrc)
-      {
-        IVtkOCC_Shape::Handle anOccShape = aSrc->GetShape();
-        if (!anOccShape.IsNull())
+        case Graphic3d_TOSM_VERTEX:
         {
-          IVtkTools_DisplayModeFilter* aFilter = GetPipeline(anOccShape->GetId())->GetDisplayModeFilter();
-          aFilter->SetDisplayMode(DM_Shading);
-          aFilter->SetFaceBoundaryDraw(toDraw != 0);
-          aFilter->Modified();
-          aFilter->Update();
+          anActor->GetProperty()->SetInterpolationToGouraud();
+          break;
         }
+        case Graphic3d_TOSM_FRAGMENT:
+        {
+          anActor->GetProperty()->SetInterpolationToPhong();
+          break;
+        }
+        default: break;
       }
-      anIter.Next();
-    }
-  }
-  else
-  {
-    // Set disp mode for named object
-    TCollection_AsciiString aName = theArgs[1];
-    vtkSmartPointer<vtkActor> anActor;
-    if (!GetMapOfActors().Find2 (aName, anActor))
-    {
-      Message::SendFail() << "Syntax error: object '" << aName << "' not found";
-      return 1;
-    }
 
-    Standard_Boolean toDraw = true;
-    Draw::ParseOnOff (theArgs[2], toDraw);
-
-    // Set Red color for boundary edges
-    vtkLookupTable* aTable = (vtkLookupTable*)anActor->GetMapper()->GetLookupTable();
-    IVtkTools::SetLookupTableColor (aTable, MT_SharedEdge, 1., 0., 0., 1.);
-
-    vtkSmartPointer<IVtkTools_ShapeDataSource> aSrc = IVtkTools_ShapeObject::GetShapeSource (anActor);
-    if (aSrc)
-    {
-      IVtkOCC_Shape::Handle anOccShape = aSrc->GetShape();
-      if (!anOccShape.IsNull())
-      {
-        IVtkTools_DisplayModeFilter* aFilter = GetPipeline (anOccShape->GetId())->GetDisplayModeFilter();
-        aFilter->SetDisplayMode (DM_Shading);
-        aFilter->SetFaceBoundaryDraw (toDraw != 0);
-        aFilter->Modified();
-        aFilter->Update();
-      }
+      aFilter->Modified();
+      aFilter->Update();
     }
   }
 
@@ -1291,6 +1419,123 @@ static Standard_Integer VtkViewProj (Draw_Interpretor& ,
   return 0;
 }
 
+//=================================================================================================
+//function : VtkViewParams
+//purpose  :
+//=================================================================================================
+static int VtkViewParams (Draw_Interpretor& theDI, Standard_Integer theArgsNb, const char** /*theArgVec*/)
+{
+  if (!GetInteractor()
+   || !GetInteractor()->IsEnabled())
+  {
+    Message::SendFail() << "Error: call ivtkinit before";
+    return 1;
+  }
+  else if (theArgsNb != 1)
+  {
+    Message::SendFail() << "Syntax error: wrong number of arguments";
+    return 1;
+  }
+
+  vtkCamera* aCam = GetRenderer()->GetActiveCamera();
+
+  gp_XYZ aViewUp, aViewProj, aViewEye, aViewAt;
+  aCam->GetViewUp (aViewUp.ChangeCoord(1), aViewUp.ChangeCoord(2), aViewUp.ChangeCoord(3));
+  aCam->GetDirectionOfProjection (aViewProj.ChangeCoord(1), aViewProj.ChangeCoord(2), aViewProj.ChangeCoord(3));
+  aViewProj.Reverse();
+  aCam->GetPosition (aViewEye.ChangeCoord(1), aViewEye.ChangeCoord(2), aViewEye.ChangeCoord(3));
+  aCam->GetFocalPoint (aViewAt.ChangeCoord(1), aViewAt.ChangeCoord(2), aViewAt.ChangeCoord(3));
+  const Standard_Real aViewScale = aCam->GetParallelScale();
+  const Standard_Real aViewAspect = GetRenderer()->GetTiledAspectRatio();
+  vtkMatrix4x4* aProjMat = aCam->GetProjectionTransformMatrix (GetRenderer()->GetTiledAspectRatio(), -1, 1);
+  vtkMatrix4x4* aViewMat = aCam->GetViewTransformMatrix();
+  // print all of the available view parameters
+  char aText[4096];
+  Sprintf (aText,
+           "Scale: %g\n"
+           "Aspect:  %g\n"
+           "Proj:  %12g %12g %12g\n"
+           "Up:    %12g %12g %12g\n"
+           "At:    %12g %12g %12g\n"
+           "Eye:   %12g %12g %12g\n"
+           "ViewMat:       %12g %12g %12g %12g\n"
+           "               %12g %12g %12g %12g\n"
+           "               %12g %12g %12g %12g\n"
+           "               %12g %12g %12g %12g\n"
+           "ProjMat:       %12g %12g %12g %12g\n"
+           "               %12g %12g %12g %12g\n"
+           "               %12g %12g %12g %12g\n"
+           "               %12g %12g %12g %12g\n",
+           aViewScale, aViewAspect,
+           aViewProj.X(), aViewProj.Y(), aViewProj.Z(),
+           aViewUp.X(), aViewUp.Y(), aViewUp.Z(),
+           aViewAt.X(), aViewAt.Y(), aViewAt.Z(),
+           aViewEye.X(), aViewEye.Y(), aViewEye.Z(),
+           aViewMat->GetElement (0, 0), aViewMat->GetElement(0, 1), aViewMat->GetElement(0, 2), aViewMat->GetElement(0, 3),
+           aViewMat->GetElement (1, 0), aViewMat->GetElement(1, 1), aViewMat->GetElement(1, 2), aViewMat->GetElement(1, 3),
+           aViewMat->GetElement (2, 0), aViewMat->GetElement(2, 1), aViewMat->GetElement(2, 2), aViewMat->GetElement(2, 3),
+           aViewMat->GetElement (3, 0), aViewMat->GetElement(3, 1), aViewMat->GetElement(3, 2), aViewMat->GetElement(3, 3),
+           aProjMat->GetElement (0, 0), aProjMat->GetElement(0, 1), aProjMat->GetElement(0, 2), aProjMat->GetElement(0, 3),
+           aProjMat->GetElement (1, 0), aProjMat->GetElement(1, 1), aProjMat->GetElement(1, 2), aProjMat->GetElement(1, 3),
+           aProjMat->GetElement (2, 0), aProjMat->GetElement(2, 1), aProjMat->GetElement(2, 2), aProjMat->GetElement(2, 3),
+           aProjMat->GetElement (3, 0), aProjMat->GetElement(3, 1), aProjMat->GetElement(3, 2), aProjMat->GetElement(3, 3));
+  theDI << aText;
+  return 0;
+}
+
+//=================================================================================================
+//function : VtkCamera
+//purpose  :
+//=================================================================================================
+static int VtkCamera (Draw_Interpretor& theDI, Standard_Integer theArgsNb, const char** theArgVec)
+{
+  if (!GetInteractor()
+   || !GetInteractor()->IsEnabled())
+  {
+    Message::SendFail() << "Error: call ivtkinit before";
+    return 1;
+  }
+
+  vtkCamera* aCamera = GetRenderer()->GetActiveCamera();
+
+  if (theArgsNb < 2)
+  {
+    Standard_Real aZNear = 0.0, aZFar = 0.0;
+    aCamera->GetClippingRange (aZNear, aZFar);
+    theDI << "ProjType:   " << (aCamera->GetParallelProjection() ? "orthographic" : "perspective") << "\n";
+    theDI << "FOVy:       " << aCamera->GetViewAngle() << "\n";
+    theDI << "Distance:   " << aCamera->GetDistance() << "\n";
+    theDI << "ZNear:      " << aZNear << "\n";
+    theDI << "ZFar:       " << aZFar << "\n";
+    return 0;
+  }
+
+  for (Standard_Integer anArgIter = 1; anArgIter < theArgsNb; ++anArgIter)
+  {
+    Standard_CString        anArg = theArgVec[anArgIter];
+    TCollection_AsciiString anArgCase(anArg);
+    anArgCase.LowerCase();
+    if (anArgCase == "-ortho"
+     || anArgCase == "-orthographic")
+    {
+      aCamera->SetParallelProjection (true);
+    }
+    else if (anArgCase == "-persp"
+          || anArgCase == "-perspective")
+    {
+      aCamera->SetParallelProjection (false);
+    }
+    else
+    {
+      Message::SendFail() << "Error: unknown argument '" << anArg << "'";
+      return 1;
+    }
+  }
+  GetRenderer()->ResetCamera();
+  GetInteractor()->Render();
+  return 0;
+}
+
 //===================================================================
 // Fubction  : VtkDump
 // Purpose   :
@@ -1509,6 +1754,14 @@ void IVtkDraw::Commands (Draw_Interpretor& theCommands)
               "ivtkclose : Closes the Vtk window.",
     __FILE__, VtkClose, group);
 
+  theCommands.Add("ivtkdefaults",
+               "ivtkdefaults [-absDefl value]"
+       "\n\t\t:              [-devCoeff value]"
+       "\n\t\t:              [-angDefl value]"
+       "\n\t\t:              [-autoTriang {off/on | 0/1}]"
+       "\n\t\t: Sets default VTK meshing parameters."
+    , __FILE__, VtkDefaults, group);
+
   theCommands.Add("ivtkrenderparams",
               "ivtkrenderparams [-depthPeeling NbLayers] [-shadows {on|off}]"
       "\n\t\t: Sets Vtk rendering parameters."
@@ -1538,16 +1791,14 @@ void IVtkDraw::Commands (Draw_Interpretor& theCommands)
     __FILE__, VtkRemove, group);
 
   theCommands.Add("ivtksetdispmode",
-              "ivtksetdispmode [name] mode={0|1}"
-      "\n\t\t: Sets or unsets display mode 'mode' to the object with name 'name' or to all objects.",
+              "ivtksetdispmode [name] mode={0|1} [-faceBoundaryDraw {0|1}] [-smoothShading {0|1}]"
+      "\n\t\t:                                   [-shadingModel {phong|gouraud|flat}]"
+      "\n\t\t: Sets or unsets display mode to the object with the given name or to all objects."
+      "\n\t\t:   -faceBoundaryDraw show/hide boundaries within shading display mode"
+      "\n\t\t:   -smoothShading    enable/disable vertex normals for smooth shading"
+      "\n\t\t:   -shadingModel     sets specified shading model",
     __FILE__, VtkSetDisplayMode, group);
 
-  theCommands.Add("ivtksetboundingdraw",
-              "ivtksetboundingdraw [name] {on|off}"
-      "\n\t\t: Sets or unsets boundaries drawing for shading display mode"
-      "\n\t\t: to the object with name 'name' or to all objects.",
-    __FILE__, VtkSetBoundaryDraw, group);
-
   theCommands.Add("ivtksetselmode",
               "ivtksetselmode [name] mode {on|off}"
       "\n\t\t: Sets or unsets selection mode 'mode' to the object with name 'name'"
@@ -1616,6 +1867,20 @@ void IVtkDraw::Commands (Draw_Interpretor& theCommands)
               "ivtksettransparency name 0..1"
       "\n\t\t: Sets transparency to the object with name 'name'.",
     __FILE__, VtkSetTransparency, group);
+
+  theCommands.Add("ivtkviewparams",
+              "ivtkviewparams: Prints all current view parameters.",
+    __FILE__, VtkViewParams, group);
+
+  theCommands.Add("ivtkcamera",
+              "ivtkcamera [-ortho] [-persp]"
+      "\n\t\t: Manages camera parameters."
+      "\n\t\t: Prints current value when option called without argument."
+      "\n\t\t: Orthographic camera:"
+      "\n\t\t:   -ortho      activate orthographic projection"
+      "\n\t\t: Perspective camera:"
+      "\n\t\t:   -persp      activate perspective  projection",
+    __FILE__, VtkCamera, group);
 }
 
 //================================================================
