@@ -15,54 +15,71 @@
 
 #include <IVtkOCC_ShapeMesher.hxx>
 
-#include <Adaptor3d_IsoCurve.hxx>
 #include <Bnd_Box.hxx>
 #include <BRep_Tool.hxx>
-#include <BRepBndLib.hxx>
-#include <BRepMesh_DiscretFactory.hxx>
-#include <BRepMesh_DiscretRoot.hxx>
 #include <BRepTools.hxx>
-#include <Hatch_Hatcher.hxx>
-#include <GCPnts_QuasiUniformDeflection.hxx>
-#include <GCPnts_TangentialDeflection.hxx>
-#include <Geom_BezierSurface.hxx>
-#include <Geom_BSplineSurface.hxx>
-#include <Geom2dAdaptor_Curve.hxx>
-#include <GeomAdaptor_Curve.hxx>
-#include <gp_Dir2d.hxx>
-#include <gp_Pnt2d.hxx>
 #include <Message.hxx>
 #include <NCollection_Array1.hxx>
 #include <Poly_Polygon3D.hxx>
 #include <Poly_PolygonOnTriangulation.hxx>
 #include <Poly_Triangulation.hxx>
-#include <Precision.hxx>
 #include <Prs3d.hxx>
 #include <Prs3d_Drawer.hxx>
-#include <Prs3d_IsoAspect.hxx>
 #include <Standard_ErrorHandler.hxx>
 #include <StdPrs_Isolines.hxx>
 #include <StdPrs_ToolTriangulatedShape.hxx>
-#include <TColgp_SequenceOfPnt2d.hxx>
-#include <TColStd_Array1OfReal.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
+#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(IVtkOCC_ShapeMesher,IVtk_IShapeMesher)
 
-// Handle implementation
+//================================================================
+// Function : IVtkOCC_ShapeMesher
+// Purpose  :
+//================================================================
+IVtkOCC_ShapeMesher::IVtkOCC_ShapeMesher()
+{
+  //
+}
 
+//================================================================
+// Function : ~IVtkOCC_ShapeMesher
+// Purpose  :
+//================================================================
+IVtkOCC_ShapeMesher::~IVtkOCC_ShapeMesher()
+{
+  //
+}
 
 //================================================================
 // Function : internalBuild
-// Purpose  : 
+// Purpose  :
 //================================================================
 void IVtkOCC_ShapeMesher::internalBuild()
 {
-  // TODO: do we need any protection here so as not to triangualte
-  // the shape twice??? This can be done e.g. by checking if
-  // triangulation exists for TopoDS_Shape..
-  meshShape();
+  const TopoDS_Shape& anOcctShape = GetShapeObj()->GetShape();
+  if (anOcctShape.IsNull())
+  {
+    return;
+  }
+
+  const Handle(Prs3d_Drawer)& anOcctDrawer = GetShapeObj()->Attributes();
+  const Standard_Real aShapeDeflection = StdPrs_ToolTriangulatedShape::GetDeflection (anOcctShape, anOcctDrawer);
+  if (anOcctDrawer->IsAutoTriangulation())
+  {
+    StdPrs_ToolTriangulatedShape::ClearOnOwnDeflectionChange (anOcctShape, anOcctDrawer, true);
+    StdPrs_ToolTriangulatedShape::Tessellate (anOcctShape, anOcctDrawer);
+  }
+  for (TopExp_Explorer aFaceIter (anOcctShape, TopAbs_FACE); aFaceIter.More(); aFaceIter.Next())
+  {
+    const TopoDS_Face& anOcctFace = TopoDS::Face (aFaceIter.Current());
+    TopLoc_Location aLoc;
+    if (const Handle(Poly_Triangulation)& anOcctTriangulation = BRep_Tool::Triangulation (anOcctFace, aLoc))
+    {
+      StdPrs_ToolTriangulatedShape::ComputeNormals (anOcctFace, anOcctTriangulation);
+    }
+  }
 
   // Free vertices and free edges should always be shown.
   // Shared edges are needed in WF representation only.
@@ -71,83 +88,79 @@ void IVtkOCC_ShapeMesher::internalBuild()
   addEdges();
 
   // Build wireframe points and cells (lines for isolines)
-  addWireFrameFaces();
+  for (TopExp_Explorer aFaceIter (anOcctShape, TopAbs_FACE); aFaceIter.More(); aFaceIter.Next())
+  {
+    const TopoDS_Face& anOcctFace = TopoDS::Face (aFaceIter.Current());
+    try
+    {
+      OCC_CATCH_SIGNALS
+      addWFFace (anOcctFace, GetShapeObj()->GetSubShapeId (anOcctFace), aShapeDeflection);
+    }
+    catch (const Standard_Failure& anException)
+    {
+      Message::SendFail (TCollection_AsciiString("Error: addWireFrameFaces() wireframe presentation builder has failed (")
+                       + anException.GetMessageString() + ")");
+    }
+  }
 
   // Build shaded representation (based on Poly_Triangulation)
-  addShadedFaces();
+  for (TopExp_Explorer aFaceIter (anOcctShape, TopAbs_FACE); aFaceIter.More(); aFaceIter.Next())
+  {
+    const TopoDS_Face& anOcctFace = TopoDS::Face (aFaceIter.Current());
+    addShadedFace (anOcctFace, GetShapeObj()->GetSubShapeId (anOcctFace));
+  }
 }
 
 //================================================================
 // Function : GetShapeObj
-// Purpose  : 
+// Purpose  :
 //================================================================
 const IVtkOCC_Shape::Handle IVtkOCC_ShapeMesher::GetShapeObj() const
 {
-  return (IVtkOCC_Shape::Handle::DownCast(myShapeObj));
+  return IVtkOCC_Shape::Handle::DownCast(myShapeObj);
 }
 
 //================================================================
 // Function : GetDeflection
-// Purpose  : Returns absolute deflection used by this algorithm.
+// Purpose  :
 //================================================================
 Standard_Real IVtkOCC_ShapeMesher::GetDeflection() const
 {
-  if (myDeflection < Precision::Confusion()) // if not yet initialized
-  {
-    Handle(Prs3d_Drawer) aDefDrawer = new Prs3d_Drawer();
-    aDefDrawer->SetTypeOfDeflection (Aspect_TOD_RELATIVE);
-    aDefDrawer->SetDeviationCoefficient (GetDeviationCoeff());
-    myDeflection = StdPrs_ToolTriangulatedShape::GetDeflection (GetShapeObj()->GetShape(), aDefDrawer);
-  }
-
-  return myDeflection;
+  const TopoDS_Shape& anOcctShape = GetShapeObj()->GetShape();
+  return !anOcctShape.IsNull()
+        ? StdPrs_ToolTriangulatedShape::GetDeflection (anOcctShape, GetShapeObj()->Attributes())
+        : 0.0;
 }
 
 //================================================================
-// Function : meshShape
-// Purpose  : 
+// Function : GetDeflection
+// Purpose  :
 //================================================================
-void IVtkOCC_ShapeMesher::meshShape()
+Standard_Real IVtkOCC_ShapeMesher::GetDeviationCoeff() const
 {
-  const TopoDS_Shape& anOcctShape = GetShapeObj()->GetShape();
-  if (anOcctShape.IsNull())
+  if (IVtkOCC_Shape::Handle aShape = GetShapeObj())
   {
-    return;
+    return aShape->Attributes()->DeviationCoefficient();
   }
+  return 0.0;
+}
 
-  //Clean triangulation before compute incremental mesh
-  BRepTools::Clean (anOcctShape);
-
-  //Compute triangulation
-  Standard_Real aDeflection = GetDeflection();
-  if (aDeflection < Precision::Confusion())
+//================================================================
+// Function : GetDeviationAngle
+// Purpose  :
+//================================================================
+Standard_Real IVtkOCC_ShapeMesher::GetDeviationAngle() const
+{
+  if (IVtkOCC_Shape::Handle aShape = GetShapeObj())
   {
-    return;
-  }
-
-  try
-  {
-    OCC_CATCH_SIGNALS
-
-    Handle(BRepMesh_DiscretRoot) anAlgo;
-    anAlgo = BRepMesh_DiscretFactory::Get().Discret (anOcctShape,
-                                                     aDeflection,
-                                                     GetDeviationAngle());
-    if (!anAlgo.IsNull())
-    {
-      anAlgo->Perform();
-    }
-  }
-  catch (const Standard_Failure& anException)
-  {
-    Message::SendFail (TCollection_AsciiString("Error: IVtkOCC_ShapeMesher::meshShape() triangulation builder has failed (")
-                     + anException.GetMessageString() + ")");
+    return aShape->Attributes()->DeviationAngle();
   }
+  return 0.0;
 }
 
 //================================================================
 // Function : addFreeVertices
-// Purpose  : 
+// Purpose  :
 //================================================================
 void IVtkOCC_ShapeMesher::addFreeVertices()
 {
@@ -176,7 +189,7 @@ void IVtkOCC_ShapeMesher::addFreeVertices()
 
 //================================================================
 // Function : addEdges
-// Purpose  : 
+// Purpose  :
 //================================================================
 void IVtkOCC_ShapeMesher::addEdges()
 {
@@ -213,54 +226,9 @@ void IVtkOCC_ShapeMesher::addEdges()
   }
 }
 
-//================================================================
-// Function : addWireFrameFaces
-// Purpose  : 
-//================================================================
-void IVtkOCC_ShapeMesher::addWireFrameFaces()
-{
-  // Check the deflection value once for all faces
-  if (GetDeflection() < Precision::Confusion())
-  {
-    return;
-  }
-
-  TopExp_Explorer aFaceIter (GetShapeObj()->GetShape(), TopAbs_FACE);
-  for (; aFaceIter.More(); aFaceIter.Next())
-  {
-    const TopoDS_Face& anOcctFace = TopoDS::Face (aFaceIter.Current());
-    try
-    {
-      OCC_CATCH_SIGNALS
-      addWFFace (anOcctFace, 
-                 GetShapeObj()->GetSubShapeId (anOcctFace));
-    }
-    catch (const Standard_Failure& anException)
-    {
-      Message::SendFail (TCollection_AsciiString("Error: addWireFrameFaces() wireframe presentation builder has failed (")
-                       + anException.GetMessageString() + ")");
-    }
-  }
-}
-
-//================================================================
-// Function : addShadedFaces
-// Purpose  : 
-//================================================================
-void IVtkOCC_ShapeMesher::addShadedFaces()
-{
-  TopExp_Explorer aFaceIter (GetShapeObj()->GetShape(), TopAbs_FACE);
-  for (; aFaceIter.More(); aFaceIter.Next())
-  {
-    const TopoDS_Face& anOcctFace = TopoDS::Face (aFaceIter.Current());
-    addShadedFace (anOcctFace,
-                   GetShapeObj()->GetSubShapeId (anOcctFace));
-  }
-}
-
 //================================================================
 // Function : addVertex
-// Purpose  : 
+// Purpose  :
 //================================================================
 void IVtkOCC_ShapeMesher::addVertex (const TopoDS_Vertex& theVertex,
                                      const IVtk_IdType    theShapeId,
@@ -273,53 +241,14 @@ void IVtkOCC_ShapeMesher::addVertex (const TopoDS_Vertex& theVertex,
 
   gp_Pnt aPnt3d = BRep_Tool::Pnt (theVertex);
 
-  IVtk_PointId anId = 
-    myShapeData->InsertCoordinate (aPnt3d.X(), aPnt3d.Y(), aPnt3d.Z());
+  IVtk_PointId anId = myShapeData->InsertCoordinate (aPnt3d);
   myShapeData->InsertVertex (theShapeId, anId, theMeshType);
 
 }
 
-//================================================================
-// Function : processPolyline
-// Purpose  : 
-//================================================================
-void IVtkOCC_ShapeMesher::processPolyline (Standard_Integer          theNbNodes,
-                                      const TColgp_Array1OfPnt&      thePoints,
-                                      const TColStd_Array1OfInteger& thePointIds,
-                                      const IVtk_IdType              theOcctId,
-                                      bool                           theNoTransform,
-                                      gp_Trsf                        theTransformation,
-                                      const IVtk_MeshType            theMeshType)
-{
-  if (theNbNodes < 2)
-  {
-    return;
-  }
-
-  IVtk_PointIdList aPolyPointIds;
-
-  IVtk_PointId anId;
-  for (Standard_Integer aJ = 0; aJ < theNbNodes; aJ++)
-  {
-    Standard_Integer aPntId = thePointIds (aJ + 1);
-    gp_Pnt point = thePoints (aPntId);
-
-    if (!theNoTransform)
-    {
-      // Apply the transformation to points
-      point.Transform (theTransformation);
-    }
-
-    anId = myShapeData->InsertCoordinate (point.X(), point.Y(), point.Z());
-    aPolyPointIds.Append (anId);
-  }
-
-  myShapeData->InsertLine (theOcctId, &aPolyPointIds, theMeshType);
-}
-
 //================================================================
 // Function : addEdge
-// Purpose  : 
+// Purpose  :
 //================================================================
 void IVtkOCC_ShapeMesher::addEdge (const TopoDS_Edge&  theEdge,
                                    const IVtk_IdType   theShapeId,
@@ -330,80 +259,69 @@ void IVtkOCC_ShapeMesher::addEdge (const TopoDS_Edge&  theEdge,
     return;
   }
 
-  // Two discrete representations of an OCCT edge are possible:
-  // 1. Polygon on trinagulation - holds Ids of points
-  // contained in Poly_Triangulation object
   Handle(Poly_PolygonOnTriangulation) aPolyOnTriangulation;
   Handle(Poly_Triangulation) aTriangulation;
-  TopLoc_Location aLocation;
-  BRep_Tool::PolygonOnTriangulation (theEdge,
-                                     aPolyOnTriangulation,
-                                     aTriangulation,
-                                     aLocation,
-                                     1);
-
-  // 2. 3D polygon - holds 3D points
-  Handle(Poly_Polygon3D) aPoly3d;
-  if (aPolyOnTriangulation.IsNull())
+  TopLoc_Location aLoc;
+  BRep_Tool::PolygonOnTriangulation (theEdge, aPolyOnTriangulation, aTriangulation, aLoc, 1);
+  if (!aPolyOnTriangulation.IsNull()
+    && aPolyOnTriangulation->NbNodes() >= 2)
   {
-    aPoly3d = BRep_Tool::Polygon3D (theEdge, aLocation);
+    // prefer polygon on triangulation when defined
+    const gp_Trsf aTrsf = aLoc.Transformation();
+    const bool hasTransform = !aLoc.IsIdentity();
+
+    IVtk_PointIdList aPolyPointIds;
+    const Standard_Integer aNbNodes = aPolyOnTriangulation->NbNodes();
+    for (Standard_Integer aJ = 0; aJ < aNbNodes; aJ++)
+    {
+      const Standard_Integer aPntId = aPolyOnTriangulation->Node (aJ + 1);
+      gp_Pnt aPoint = aTriangulation->Node (aPntId);
+      gp_Dir aNorm  = aTriangulation->HasNormals() ? aTriangulation->Normal (aPntId) : gp::DZ();
+      if (hasTransform)
+      {
+        aPoint.Transform (aTrsf);
+        aNorm .Transform (aTrsf);
+      }
+
+      IVtk_PointId anId = myShapeData->InsertPoint (aPoint, Graphic3d_Vec3 ((float )aNorm.X(), (float )aNorm.Y(), (float )aNorm.Z()));
+      aPolyPointIds.Append (anId);
+    }
+    myShapeData->InsertLine (theShapeId, &aPolyPointIds, theMeshType);
+    return;
   }
 
-  if (aPoly3d.IsNull() && aPolyOnTriangulation.IsNull())
+  // try polygon 3d
+  Handle(Poly_Polygon3D) aPoly3d = BRep_Tool::Polygon3D (theEdge, aLoc);
+  if (aPoly3d.IsNull()
+   || aPoly3d->NbNodes() < 2)
   {
     return;
   }
 
-  // Handle a non-identity transofmation applied to the edge
-  gp_Trsf anEdgeTransf;
-  bool noTransform = true;
-  if (!aLocation.IsIdentity())
+  const gp_Trsf anEdgeTransf = aLoc.Transformation();
+  const bool     noTransform = aLoc.IsIdentity();
+  IVtk_PointIdList aPolyPointIds;
+  for (Standard_Integer aNodeIter = 1; aNodeIter <= aPoly3d->NbNodes(); ++aNodeIter)
   {
-    noTransform = false;
-    anEdgeTransf = aLocation.Transformation();
-  }
-
-  if (!aPoly3d.IsNull())
-  {
-    Standard_Integer aNbNodes = aPoly3d->NbNodes();
-    const TColgp_Array1OfPnt& aPoints = aPoly3d->Nodes();
-    TColStd_Array1OfInteger aPointIds (1, aNbNodes);
-
-    for (Standard_Integer anI = 1; anI <= aNbNodes; anI++)
+    gp_Pnt aPnt = aPoly3d->Nodes().Value (aNodeIter);
+    if (!noTransform)
     {
-      aPointIds.SetValue (anI, anI);
+      aPnt.Transform (anEdgeTransf);
     }
 
-    processPolyline (aNbNodes,
-                     aPoints,
-                     aPointIds,
-                     theShapeId,
-                     noTransform,
-                     anEdgeTransf,
-                     theMeshType);
-  }
-  else
-  {
-    Standard_Integer aNbNodes = aPolyOnTriangulation->NbNodes();
-    const TColStd_Array1OfInteger& aPointIds = aPolyOnTriangulation->Nodes();
-    const TColgp_Array1OfPnt& aPoints = aTriangulation->Nodes();
-
-    processPolyline (aNbNodes,
-                     aPoints,
-                     aPointIds,
-                     theShapeId,
-                     noTransform,
-                     anEdgeTransf,
-                     theMeshType);
+    const IVtk_PointId anId = myShapeData->InsertCoordinate (aPnt);
+    aPolyPointIds.Append (anId);
   }
+  myShapeData->InsertLine (theShapeId, &aPolyPointIds, theMeshType);
 }
 
 //================================================================
 // Function : addWFFace
-// Purpose  : 
+// Purpose  :
 //================================================================
-void IVtkOCC_ShapeMesher::addWFFace (const TopoDS_Face& theFace,
-                                     const IVtk_IdType  theShapeId)
+void IVtkOCC_ShapeMesher::addWFFace (const TopoDS_Face&  theFace,
+                                     const IVtk_IdType   theShapeId,
+                                     const Standard_Real theDeflection)
 {
   if (theFace.IsNull())
   {
@@ -413,12 +331,6 @@ void IVtkOCC_ShapeMesher::addWFFace (const TopoDS_Face& theFace,
   TopoDS_Face aFaceToMesh = theFace;
   aFaceToMesh.Orientation (TopAbs_FORWARD);
 
-  // The code that builds wireframe representation for a TopoDS_Face
-  // has been adapted from some OCCT 6.5.1 methods:
-  // - Prs3d_WFShape::Add()
-  // - StdPrs_WFDeflectionRestrictedFace::Add()
-  // - StdPrs_DeflectionCurve::Add()
-
   // Add face's edges here but with the face ID
   for (TopExp_Explorer anEdgeIter (aFaceToMesh, TopAbs_EDGE); anEdgeIter.More(); anEdgeIter.Next())
   {
@@ -433,16 +345,8 @@ void IVtkOCC_ShapeMesher::addWFFace (const TopoDS_Face& theFace,
     return;
   }
 
-  const Standard_Real aDeflection = GetDeflection();
-  Handle(Prs3d_Drawer) aDrawer = new Prs3d_Drawer();
-  aDrawer->SetUIsoAspect (new Prs3d_IsoAspect (Quantity_NOC_WHITE, Aspect_TOL_SOLID, 1.0f, myNbIsos[0]));
-  aDrawer->SetVIsoAspect (new Prs3d_IsoAspect (Quantity_NOC_WHITE, Aspect_TOL_SOLID, 1.0f, myNbIsos[1]));
-  aDrawer->SetDeviationAngle (myDevAngle);
-  aDrawer->SetDeviationCoefficient (myDevCoeff);
-  aDrawer->SetMaximalChordialDeviation (aDeflection);
-
   Prs3d_NListOfSequenceOfPnt aPolylines;
-  StdPrs_Isolines::Add (theFace, aDrawer, aDeflection, aPolylines, aPolylines);
+  StdPrs_Isolines::Add (theFace, GetShapeObj()->Attributes(), theDeflection, aPolylines, aPolylines);
   for (Prs3d_NListOfSequenceOfPnt::Iterator aPolyIter (aPolylines); aPolyIter.More(); aPolyIter.Next())
   {
     const Handle(TColgp_HSequenceOfPnt)& aPoints = aPolyIter.Value();
@@ -456,7 +360,7 @@ void IVtkOCC_ShapeMesher::addWFFace (const TopoDS_Face& theFace,
     for (TColgp_HSequenceOfPnt::Iterator aNodeIter (*aPoints); aNodeIter.More(); aNodeIter.Next())
     {
       const gp_Pnt& aPnt = aNodeIter.Value();
-      const IVtk_PointId anId = myShapeData->InsertCoordinate (aPnt.X(), aPnt.Y(), aPnt.Z());
+      const IVtk_PointId anId = myShapeData->InsertCoordinate (aPnt);
       aPolyPointIds.Append (anId);
     }
 
@@ -466,7 +370,7 @@ void IVtkOCC_ShapeMesher::addWFFace (const TopoDS_Face& theFace,
 
 //================================================================
 // Function : addShadedFace
-// Purpose  : 
+// Purpose  :
 //================================================================
 void IVtkOCC_ShapeMesher::addShadedFace (const TopoDS_Face& theFace,
                                          const IVtk_IdType  theShapeId)
@@ -476,54 +380,58 @@ void IVtkOCC_ShapeMesher::addShadedFace (const TopoDS_Face& theFace,
     return;
   }
 
-  // Build triangulation of the face.
   TopLoc_Location aLoc;
-  Handle(Poly_Triangulation) anOcctTriangulation = BRep_Tool::Triangulation (theFace, aLoc);
+  const Handle(Poly_Triangulation)& anOcctTriangulation = BRep_Tool::Triangulation (theFace, aLoc);
   if (anOcctTriangulation.IsNull())
   {
     return;
   }
 
-  gp_Trsf aPntTransform;
-  Standard_Boolean noTransform = Standard_True;
-  if (!aLoc.IsIdentity())
-  {
-    noTransform = Standard_False;
-    aPntTransform = aLoc.Transformation();
-  }
+  // Determinant of transform matrix less then 0 means that mirror transform applied
+  const gp_Trsf aTrsf = aLoc.Transformation();
+  const bool hasTransform = !aLoc.IsIdentity();
+  const bool isMirrored   = aTrsf.VectorialPart().Determinant() < 0;
 
   // Get triangulation points.
-  const TColgp_Array1OfPnt& aPoints = anOcctTriangulation->Nodes();
   Standard_Integer aNbPoints = anOcctTriangulation->NbNodes();
 
   // Keep inserted points id's of triangulation in an array.
   NCollection_Array1<IVtk_PointId> aPointIds (1, aNbPoints);
   IVtk_PointId anId;
-
-  Standard_Integer anI;
-  for (anI = 1; anI <= aNbPoints; anI++)
+  for (Standard_Integer anI = 1; anI <= aNbPoints; anI++)
   {
-    gp_Pnt aPoint = aPoints (anI);
-
-    if (!noTransform)
+    gp_Pnt aPoint = anOcctTriangulation->Node (anI);
+    gp_Dir aNorm  = anOcctTriangulation->HasNormals() ? anOcctTriangulation->Normal (anI) : gp::DZ();
+    if ((theFace.Orientation() == TopAbs_REVERSED) ^ isMirrored)
     {
-      aPoint.Transform (aPntTransform);
+      aNorm.Reverse();
+    }
+    if (hasTransform)
+    {
+      aPoint.Transform (aTrsf);
+      aNorm .Transform (aTrsf);
     }
 
     // Add a point into output shape data and keep its id in the array.
-    anId = myShapeData->InsertCoordinate (aPoint.X(), aPoint.Y(), aPoint.Z());
+    anId = myShapeData->InsertPoint (aPoint, Graphic3d_Vec3 ((float )aNorm.X(), (float )aNorm.Y(), (float )aNorm.Z()));
     aPointIds.SetValue (anI, anId);
   }
 
   // Create triangles on the created triangulation points.
-  const Poly_Array1OfTriangle& aTriangles = anOcctTriangulation->Triangles();
-  Standard_Integer aNbTriangles = anOcctTriangulation->NbTriangles();
+  const Standard_Integer aNbTriangles = anOcctTriangulation->NbTriangles();
   Standard_Integer aN1, aN2, aN3;
-  for (anI = 1; anI <= aNbTriangles; anI++)
+  for (Standard_Integer anI = 1; anI <= aNbTriangles; anI++)
   {
-    aTriangles(anI).Get (aN1, aN2, aN3); // get indexes of triangle's points
+    if (theFace.Orientation() == TopAbs_REVERSED)
+    {
+      anOcctTriangulation->Triangle (anI).Get (aN1, aN3, aN2);
+    }
+    else
+    {
+      anOcctTriangulation->Triangle (anI).Get (aN1, aN2, aN3);
+    }
+
     // Insert new triangle on these points into output shape data.
-    myShapeData->InsertTriangle (
-      theShapeId, aPointIds(aN1), aPointIds(aN2), aPointIds(aN3), MT_ShadedFace);
+    myShapeData->InsertTriangle (theShapeId, aPointIds(aN1), aPointIds(aN2), aPointIds(aN3), MT_ShadedFace);
   }
 }
