@@ -66,6 +66,8 @@ namespace
       case FIT_RGBF:   return Image_Format_RGBF;
       case FIT_RGBAF:  return Image_Format_RGBAF;
       case FIT_FLOAT:  return Image_Format_GrayF;
+      case FIT_INT16:
+      case FIT_UINT16: return Image_Format_Gray16;
       case FIT_BITMAP:
       {
         switch (theColorTypeFI)
@@ -118,6 +120,8 @@ namespace
       case Image_Format_Gray:
       case Image_Format_Alpha:
         return FIT_BITMAP;
+      case Image_Format_Gray16:
+        return FIT_UINT16;
       default:
         return FIT_UNKNOWN;
     }
@@ -131,6 +135,10 @@ namespace
     Image_FreeImageStream (std::istream& theStream)
     : myIStream (&theStream), myOStream (NULL), myInitPos (theStream.tellg()) {}
 
+    //! Construct wrapper over output stream.
+    Image_FreeImageStream (std::ostream& theStream)
+    : myIStream (NULL), myOStream (&theStream), myInitPos (theStream.tellp()) {}
+
     //! Get io object.
     FreeImageIO GetFiIO() const
     {
@@ -139,12 +147,15 @@ namespace
       if (myIStream != NULL)
       {
         anIo.read_proc = readProc;
-        anIo.seek_proc = seekProc;
-        anIo.tell_proc = tellProc;
+        anIo.seek_proc = seekProcIn;
+        anIo.tell_proc = tellProcIn;
       }
       if (myOStream != NULL)
       {
         anIo.write_proc = writeProc;
+        // seek and tell are also used for saving in some formats (.tif for example)
+        anIo.seek_proc = seekProcOut;
+        anIo.tell_proc = tellProcOut;
       }
       return anIo;
     }
@@ -179,7 +190,7 @@ namespace
     }
 
     //! Simulate fseek().
-    static int DLL_CALLCONV seekProc (fi_handle theHandle, long theOffset, int theOrigin)
+    static int DLL_CALLCONV seekProcIn (fi_handle theHandle, long theOffset, int theOrigin)
     {
       Image_FreeImageStream* aThis = (Image_FreeImageStream* )theHandle;
       if (aThis->myIStream == NULL)
@@ -212,13 +223,53 @@ namespace
       return isSeekDone ? 0 : -1;
     }
 
+    static int DLL_CALLCONV seekProcOut (fi_handle theHandle, long theOffset, int theOrigin)
+    {
+      Image_FreeImageStream* aThis = (Image_FreeImageStream* )theHandle;
+      if (aThis->myOStream == NULL)
+      {
+        return -1;
+      }
+
+      bool isSeekDone = false;
+      switch (theOrigin)
+      {
+      case SEEK_SET:
+        if (aThis->myOStream->seekp ((std::streamoff )aThis->myInitPos + theOffset, std::ios::beg))
+        {
+          isSeekDone = true;
+        }
+        break;
+      case SEEK_CUR:
+        if (aThis->myOStream->seekp (theOffset, std::ios::cur))
+        {
+          isSeekDone = true;
+        }
+        break;
+      case SEEK_END:
+        if (aThis->myOStream->seekp (theOffset, std::ios::end))
+        {
+          isSeekDone = true;
+        }
+        break;
+      }
+      return isSeekDone ? 0 : -1;
+    }
+
     //! Simulate ftell().
-    static long DLL_CALLCONV tellProc (fi_handle theHandle)
+    static long DLL_CALLCONV tellProcIn (fi_handle theHandle)
     {
       Image_FreeImageStream* aThis = (Image_FreeImageStream* )theHandle;
       const long aPos = aThis->myIStream != NULL ? (long )(aThis->myIStream->tellg() - aThis->myInitPos) : 0;
       return aPos;
     }
+
+    static long DLL_CALLCONV tellProcOut (fi_handle theHandle)
+    {
+      Image_FreeImageStream* aThis = (Image_FreeImageStream* )theHandle;
+      const long aPos = aThis->myOStream != NULL ? (long )(aThis->myOStream->tellp() - aThis->myInitPos) : 0;
+      return aPos;
+    }
   private:
     std::istream*  myIStream;
     std::ostream*  myOStream;
@@ -234,6 +285,37 @@ namespace
     return aGuid;
   }
 
+  //! Returns GUID of image format from file name
+  static GUID getFileFormatFromName (const TCollection_AsciiString& theFileName)
+  {
+    TCollection_AsciiString aFileNameLower = theFileName;
+    aFileNameLower.LowerCase();
+    GUID aFileFormat = getNullGuid();
+    if (aFileNameLower.EndsWith (".bmp"))
+    {
+      aFileFormat = GUID_ContainerFormatBmp;
+    }
+    else if (aFileNameLower.EndsWith (".png"))
+    {
+      aFileFormat = GUID_ContainerFormatPng;
+    }
+    else if (aFileNameLower.EndsWith (".jpg")
+          || aFileNameLower.EndsWith (".jpeg"))
+    {
+      aFileFormat = GUID_ContainerFormatJpeg;
+    }
+    else if (aFileNameLower.EndsWith (".tiff")
+          || aFileNameLower.EndsWith (".tif"))
+    {
+      aFileFormat = GUID_ContainerFormatTiff;
+    }
+    else if (aFileNameLower.EndsWith (".gif"))
+    {
+      aFileFormat = GUID_ContainerFormatGif;
+    }
+    return aFileFormat;
+  }
+
   //! Sentry over IUnknown pointer.
   template<class T> class Image_ComPtr
   {
@@ -304,6 +386,10 @@ namespace
     {
       return Image_Format_Gray;
     }
+    else if (theFormat == GUID_WICPixelFormat16bppGray)
+    {
+      return Image_Format_Gray16;
+    }
     return Image_Format_UNKNOWN;
   }
 
@@ -318,6 +404,7 @@ namespace
       case Image_Format_BGR:    return GUID_WICPixelFormat24bppBGR;
       case Image_Format_Gray:   return GUID_WICPixelFormat8bppGray;
       case Image_Format_Alpha:  return GUID_WICPixelFormat8bppGray; // GUID_WICPixelFormat8bppAlpha
+      case Image_Format_Gray16: return GUID_WICPixelFormat16bppGray;
       case Image_Format_GrayF:  // GUID_WICPixelFormat32bppGrayFloat
       case Image_Format_AlphaF:
       case Image_Format_RGBAF:  // GUID_WICPixelFormat128bppRGBAFloat
@@ -337,7 +424,11 @@ namespace
 // purpose  :
 // =======================================================================
 Image_AlienPixMap::Image_AlienPixMap()
+#ifdef HAVE_WINCODEC
+: myPalette (NULL)
+#else
 : myLibImage (NULL)
+#endif
 {
   SetTopDown (false);
 }
@@ -496,6 +587,12 @@ void Image_AlienPixMap::Clear()
     FreeImage_Unload (myLibImage);
     myLibImage = NULL;
   }
+#elif defined(HAVE_WINCODEC)
+  if (myPalette != NULL)
+  {
+    myPalette->Release();
+    myPalette = NULL;
+  }
 #elif defined(__EMSCRIPTEN__)
   if (myLibImage != NULL)
   {
@@ -526,7 +623,7 @@ bool Image_AlienPixMap::IsTopDownDefault()
 // =======================================================================
 #ifdef HAVE_FREEIMAGE
 bool Image_AlienPixMap::Load (const Standard_Byte* theData,
-                              Standard_Size theLength,
+                              const Standard_Size theLength,
                               const TCollection_AsciiString& theImagePath)
 {
   Clear();
@@ -696,7 +793,7 @@ bool Image_AlienPixMap::Load (std::istream& theStream,
 
 #elif defined(HAVE_WINCODEC)
 bool Image_AlienPixMap::Load (const Standard_Byte* theData,
-                              Standard_Size theLength,
+                              const Standard_Size theLength,
                               const TCollection_AsciiString& theFileName)
 {
   Clear();
@@ -742,7 +839,7 @@ bool Image_AlienPixMap::Load (const Standard_Byte* theData,
    || aFrameCount < 1
    || aWicDecoder->GetFrame (0, &aWicFrameDecode.ChangePtr()) != S_OK
    || aWicFrameDecode->GetSize (&aFrameSizeX, &aFrameSizeY) != S_OK
-   || aWicFrameDecode->GetPixelFormat (&aWicPixelFormat))
+   || aWicFrameDecode->GetPixelFormat (&aWicPixelFormat) != S_OK)
   {
     Message::SendFail ("Error: cannot get WIC Image Frame");
     return false;
@@ -759,7 +856,6 @@ bool Image_AlienPixMap::Load (const Standard_Byte* theData,
       Message::SendFail ("Error: cannot convert WIC Image Frame to RGB format");
       return false;
     }
-    aWicFrameDecode.Nullify();
   }
 
   if (!Image_PixMap::InitTrash (aPixelFormat, aFrameSizeX, aFrameSizeY))
@@ -768,17 +864,37 @@ bool Image_AlienPixMap::Load (const Standard_Byte* theData,
     return false;
   }
 
+  TCollection_AsciiString aFileNameLower = theFileName;
+  aFileNameLower.LowerCase();
+  if (aFileNameLower.EndsWith (".gif")
+   && (aWicImgFactory->CreatePalette (&myPalette) != S_OK
+    || aWicFrameDecode->CopyPalette (myPalette) != S_OK))
+  {
+    Message::SendFail ("Error: cannot get palette for GIF image");
+    return false;
+  }
+
   IWICBitmapSource* aWicSrc = aWicFrameDecode.get();
   if(!aWicConvertedFrame.IsNull())
   {
     aWicSrc = aWicConvertedFrame.get();
   }
+
+  IWICBitmapFlipRotator* aRotator;
+  bool isTopDown = true;
+  if (aWicImgFactory->CreateBitmapFlipRotator (&aRotator) == S_OK
+   && aRotator->Initialize (aWicSrc, WICBitmapTransformFlipVertical) == S_OK)
+  {
+    isTopDown = false;
+    aWicSrc = aRotator;
+  }
+
   if (aWicSrc->CopyPixels (NULL, (UINT )SizeRowBytes(), (UINT )SizeBytes(), ChangeData()) != S_OK)
   {
     Message::SendFail ("Error: cannot copy pixels from WIC Image");
     return false;
   }
-  SetTopDown (true);
+  SetTopDown (isTopDown);
   return true;
 }
 bool Image_AlienPixMap::Load (std::istream& theStream,
@@ -815,7 +931,7 @@ bool Image_AlienPixMap::Load (std::istream& ,
   return false;
 }
 bool Image_AlienPixMap::Load (const Standard_Byte* theData,
-                              Standard_Size theLength,
+                              const Standard_Size theLength,
                               const TCollection_AsciiString& theImagePath)
 {
   Clear();
@@ -848,7 +964,7 @@ bool Image_AlienPixMap::Load (std::istream& ,
   return false;
 }
 bool Image_AlienPixMap::Load (const Standard_Byte* ,
-                              Standard_Size ,
+                              const Standard_Size ,
                               const TCollection_AsciiString& )
 {
   Clear();
@@ -898,11 +1014,52 @@ bool Image_AlienPixMap::savePPM (const TCollection_AsciiString& theFileName) con
   return true;
 }
 
+// =======================================================================
+// function : convertData
+// purpose  :
+// =======================================================================
+#ifdef HAVE_WINCODEC
+static bool convertData (const Image_AlienPixMap& theSrcPixMapData,
+                         const WICPixelFormatGUID& theFormat,
+                         IWICImagingFactory& theWicImgFactory,
+                         Image_PixMapData& theDstPixMapData)
+{
+  const UINT aSizeRowBytes = (UINT)theSrcPixMapData.SizeRowBytes();
+  const UINT aSizeBytes = (UINT)theSrcPixMapData.SizeBytes();
+
+  Image_ComPtr<IWICBitmap> anSrcImg;
+  Image_ComPtr<IWICFormatConverter> aWicFormatConverter;
+  HRESULT anHResult = theWicImgFactory.CreateBitmapFromMemory ((UINT)theSrcPixMapData.SizeX(), (UINT)theSrcPixMapData.SizeY(),
+                                                               convertToWicFormat (theSrcPixMapData.Format()),
+                                                               aSizeRowBytes, aSizeBytes,
+                                                               (BYTE*)theSrcPixMapData.Data(), &anSrcImg.ChangePtr());
+  if (anHResult != S_OK
+   || theWicImgFactory.CreateFormatConverter (&aWicFormatConverter.ChangePtr()) != S_OK
+   || aWicFormatConverter->Initialize (anSrcImg.get(), theFormat, WICBitmapDitherTypeNone, theSrcPixMapData.GetPalette(), 0.0f, WICBitmapPaletteTypeCustom) != S_OK)
+  {
+    Message::SendFail ("Error: cannot convert WIC Image Frame to required format");
+    return false;
+  }
+
+  theDstPixMapData.Init (Image_PixMap::DefaultAllocator(), 1, theSrcPixMapData.SizeXYZ(), aSizeRowBytes, NULL);
+
+  if (aWicFormatConverter->CopyPixels (NULL, aSizeRowBytes, aSizeBytes, theDstPixMapData.ChangeData()) != S_OK)
+  {
+    Message::SendFail ("Error: cannot copy pixels from WIC Image");
+    return false;
+  }
+
+  return true;
+}
+#endif
+
 // =======================================================================
 // function : Save
 // purpose  :
 // =======================================================================
-bool Image_AlienPixMap::Save (const TCollection_AsciiString& theFileName)
+bool Image_AlienPixMap::Save (Standard_Byte* theBuffer,
+                              const Standard_Size theLength,
+                              const TCollection_AsciiString& theFileName)
 {
 #ifdef HAVE_FREEIMAGE
   if (myLibImage == NULL)
@@ -930,10 +1087,399 @@ bool Image_AlienPixMap::Save (const TCollection_AsciiString& theFileName)
     SetTopDown (false);
   }
 
+  FIBITMAP* anImageToDump = getImageToDump (anImageFormat);
+
+  if (anImageToDump == NULL)
+  {
+    return false;
+  }
+
+  bool isSaved = false;
+  if (theBuffer != NULL)
+  {
+    // a memory buffer wrapped by FreeImage is read only (images can be loaded but not be saved)
+    // so we call FreeImage_OpenMemory() with default arguments and just memcpy in requsted buffer.
+    FIMEMORY* aFiMem = FreeImage_OpenMemory();
+    isSaved = (FreeImage_SaveToMemory (anImageFormat, anImageToDump, aFiMem) != FALSE);
+    BYTE* aData = NULL;
+    DWORD aSize;
+    FreeImage_AcquireMemory (aFiMem, &aData, &aSize);
+    if (aSize > theLength)
+    {
+      Message::SendFail ("Error: memory buffer too small for storing image");
+      return false;
+    }
+    memcpy (theBuffer, aData, aSize);
+    FreeImage_CloseMemory (aFiMem);
+  }
+  else
+  {
+#ifdef _WIN32
+    isSaved = (FreeImage_SaveU (anImageFormat, anImageToDump, aFileNameW.ToWideString ()) != FALSE);
+#else
+    isSaved = (FreeImage_Save (anImageFormat, anImageToDump, theFileName.ToCString ()) != FALSE);
+#endif
+  }
+  if (anImageToDump != myLibImage)
+  {
+    FreeImage_Unload (anImageToDump);
+  }
+  return isSaved;
+
+#elif defined(HAVE_WINCODEC)
+
+  TCollection_AsciiString aFileNameLower = theFileName;
+  aFileNameLower.LowerCase();
+  if (aFileNameLower.EndsWith (".ppm"))
+  {
+    return savePPM (theFileName);
+  }
+
+  GUID aFileFormat = getFileFormatFromName (theFileName);
+  if (aFileFormat == getNullGuid())
+  {
+    Message::SendFail ("Error: unsupported image format");
+    return false;
+  }
+
+  Image_ComPtr<IWICImagingFactory> aWicImgFactory;
+  CoInitializeEx (NULL, COINIT_MULTITHREADED);
+  if (CoCreateInstance (CLSID_WICImagingFactory, NULL, CLSCTX_INPROC_SERVER, IID_PPV_ARGS(&aWicImgFactory.ChangePtr())) != S_OK)
+  {
+    Message::SendFail ("Error: cannot initialize WIC Imaging Factory");
+    return false;
+  }
+
+  WICPixelFormatGUID aWicPixelFormat = convertToWicFormat (myImgFormat);
+  if (aWicPixelFormat == getNullGuid())
+  {
+    Message::SendFail ("Error: unsupported pixel format");
+    return false;
+  }
+
+  Image_PixMapData* aPixMapData = &myData;
+  Image_PixMapData aConvertedData;
+  if (aFileFormat == GUID_ContainerFormatGif)
+  {
+    aWicPixelFormat = GUID_WICPixelFormat8bppIndexed;
+    convertData (*this, aWicPixelFormat, *aWicImgFactory, aConvertedData);
+    aPixMapData = &aConvertedData;
+  }
+
+  Image_ComPtr<IWICStream> aWicStream;
+  Image_ComPtr<IWICBitmapEncoder> aWicEncoder;
+  const TCollection_ExtendedString aFileNameW (theFileName);
+  if (theBuffer != NULL)
+  {
+    if (aWicImgFactory->CreateStream (&aWicStream.ChangePtr()) != S_OK
+     || aWicStream->InitializeFromMemory (theBuffer,(DWORD )theLength) != S_OK)
+    {
+      Message::SendFail ("Error: cannot create WIC Memory Stream");
+      return false;
+    }
+  }
+  else
+  {
+    if (aWicImgFactory->CreateStream (&aWicStream.ChangePtr()) != S_OK
+     || aWicStream->InitializeFromFilename (aFileNameW.ToWideString(), GENERIC_WRITE) != S_OK)
+    {
+      Message::SendFail ("Error: cannot create WIC File Stream");
+      return false;
+    }
+  }
+  if (aWicImgFactory->CreateEncoder (aFileFormat, NULL, &aWicEncoder.ChangePtr()) != S_OK
+   || aWicEncoder->Initialize (aWicStream.get(), WICBitmapEncoderNoCache) != S_OK)
+  {
+    Message::SendFail ("Error: cannot create WIC Encoder");
+    return false;
+  }
+
+  WICPixelFormatGUID aWicPixelFormatRes = aWicPixelFormat;
+  Image_ComPtr<IWICBitmapFrameEncode> aWicFrameEncode;
+  if (aWicEncoder->CreateNewFrame (&aWicFrameEncode.ChangePtr(), NULL) != S_OK
+   || aWicFrameEncode->Initialize (NULL) != S_OK
+   || aWicFrameEncode->SetSize ((UINT )SizeX(), (UINT )SizeY()) != S_OK
+   || aWicFrameEncode->SetPixelFormat (&aWicPixelFormatRes) != S_OK)
+  {
+    Message::SendFail ("Error: cannot create WIC Frame");
+    return false;
+  }
+
+  if (aFileFormat == GUID_ContainerFormatGif
+   && (myPalette == NULL
+    || aWicFrameEncode->SetPalette (myPalette) != S_OK))
+  {
+    Message::SendFail ("Error: cannot set palette");
+    return false;
+  }
+
+  if (aWicPixelFormatRes != aWicPixelFormat)
+  {
+    Message::SendFail ("Error: pixel format is unsupported by image format");
+    return false;
+  }
+
+  if (IsTopDown())
+  {
+    if (aWicFrameEncode->WritePixels ((UINT )SizeY(), (UINT )SizeRowBytes(), (UINT )SizeBytes(), (BYTE* )aPixMapData->Data()) != S_OK)
+    {
+      Message::SendFail ("Error: cannot write pixels to WIC Frame");
+      return false;
+    }
+  }
+  else
+  {
+    for (Standard_Size aRow = 0; aRow < SizeY(); ++aRow)
+    {
+      if (aWicFrameEncode->WritePixels (1, (UINT )SizeRowBytes(), (UINT )SizeRowBytes(), (BYTE* )aPixMapData->Row (aRow)) != S_OK)
+      {
+        Message::SendFail ("Error: cannot write pixels to WIC Frame");
+        return false;
+      }
+    }
+  }
+  if (aWicFrameEncode->Commit() != S_OK
+   || aWicEncoder->Commit() != S_OK)
+  {
+    Message::SendFail ("Error: cannot commit data to WIC Frame");
+    return false;
+  }
+  if (aWicStream->Commit (STGC_DEFAULT) != S_OK)
+  {
+    //Message::Send ("Error: cannot commit data to WIC File Stream", Message_Fail);
+    //return false;
+  }
+  return true;
+#else
+  if (theBuffer != NULL)
+  {
+    Message::SendFail ("Error: no image library available");
+    return false;
+  }
+  const Standard_Integer aLen = theFileName.Length();
+  if ((aLen >= 4) && (theFileName.Value (aLen - 3) == '.')
+      && strcasecmp( theFileName.ToCString() + aLen - 3, "ppm") == 0 )
+  {
+    return savePPM (theFileName);
+  }
+  Message::SendTrace ("Image_PixMap, no image library available! Image saved in PPM format");
+  return savePPM (theFileName);
+#endif
+}
+
+bool Image_AlienPixMap::Save (std::ostream& theStream, const TCollection_AsciiString& theExtension)
+{
+#ifdef HAVE_FREEIMAGE
+  if (myLibImage == NULL)
+  {
+    return false;
+  }
+
+#ifdef _WIN32
+  const TCollection_ExtendedString anExtW (theExtension.ToCString(), Standard_True);
+  FREE_IMAGE_FORMAT anImageFormat = FreeImage_GetFIFFromFilenameU (anExtW.ToWideString());
+#else
+  FREE_IMAGE_FORMAT anImageFormat = FreeImage_GetFIFFromFilename (theExtension.ToCString());
+#endif
+  if (anImageFormat == FIF_UNKNOWN)
+  {
+#ifdef OCCT_DEBUG
+    std::cerr << "Image_PixMap, image format doesn't supported!\n";
+#endif
+    return false;
+  }
+
+  if (IsTopDown())
+  {
+    FreeImage_FlipVertical (myLibImage);
+    SetTopDown (false);
+  }
+
+  FIBITMAP* anImageToDump = getImageToDump (anImageFormat);
+
+  if (anImageToDump == NULL)
+  {
+    return false;
+  }
+
+  bool isSaved = false;
+  Image_FreeImageStream aStream (theStream);
+  FreeImageIO anIO = aStream.GetFiIO();
+
+  isSaved = (FreeImage_SaveToHandle(anImageFormat, anImageToDump, &anIO, &aStream) != FALSE);
+
+  if (anImageToDump != myLibImage)
+  {
+    FreeImage_Unload (anImageToDump);
+  }
+  return isSaved;
+#elif defined(HAVE_WINCODEC)
+  GUID aFileFormat = getFileFormatFromName (theExtension);
+  if (aFileFormat == getNullGuid())
+  {
+    Message::SendFail ("Error: unsupported image format");
+    return false;
+  }
+
+  Image_ComPtr<IWICImagingFactory> aWicImgFactory;
+  CoInitializeEx (NULL, COINIT_MULTITHREADED);
+  if (CoCreateInstance (CLSID_WICImagingFactory, NULL, CLSCTX_INPROC_SERVER, IID_PPV_ARGS(&aWicImgFactory.ChangePtr())) != S_OK)
+  {
+    Message::SendFail ("Error: cannot initialize WIC Imaging Factory");
+    return false;
+  }
+
+  WICPixelFormatGUID aWicPixelFormat = convertToWicFormat (myImgFormat);
+  if (aWicPixelFormat == getNullGuid())
+  {
+    Message::SendFail ("Error: unsupported pixel format");
+    return false;
+  }
+
+  Image_PixMapData* aPixMapData = &myData;
+  Image_PixMapData aConvertedData;
+  if (aFileFormat == GUID_ContainerFormatGif)
+  {
+    aWicPixelFormat = GUID_WICPixelFormat8bppIndexed;
+    convertData (*this, aWicPixelFormat, *aWicImgFactory, aConvertedData);
+    aPixMapData = &aConvertedData;
+  }
+
+  Image_ComPtr<IStream> aStream;
+  Image_ComPtr<IWICBitmapEncoder> aWicEncoder;
+
+  if (CreateStreamOnHGlobal (NULL, Standard_True, &aStream.ChangePtr()) != S_OK)
+  {
+    Message::SendFail ("Error: cannot create Stream on global");
+    return false;
+  }
+
+  if (aWicImgFactory->CreateEncoder (aFileFormat, NULL, &aWicEncoder.ChangePtr()) != S_OK
+   || aWicEncoder->Initialize (aStream.get(), WICBitmapEncoderNoCache) != S_OK)
+  {
+    Message::SendFail ("Error: cannot create WIC Encoder");
+    return false;
+  }
+
+  WICPixelFormatGUID aWicPixelFormatRes = aWicPixelFormat;
+  Image_ComPtr<IWICBitmapFrameEncode> aWicFrameEncode;
+  if (aWicEncoder->CreateNewFrame (&aWicFrameEncode.ChangePtr(), NULL) != S_OK
+   || aWicFrameEncode->Initialize (NULL) != S_OK
+   || aWicFrameEncode->SetSize ((UINT )SizeX(), (UINT )SizeY()) != S_OK
+   || aWicFrameEncode->SetPixelFormat (&aWicPixelFormatRes) != S_OK)
+  {
+    Message::SendFail ("Error: cannot create WIC Frame");
+    return false;
+  }
+
+  if (aFileFormat == GUID_ContainerFormatGif
+   && (myPalette == NULL
+    || aWicFrameEncode->SetPalette (myPalette) != S_OK))
+  {
+    Message::SendFail ("Error: cannot set palette");
+    return false;
+  }
+
+  if (aWicPixelFormatRes != aWicPixelFormat)
+  {
+    Message::SendFail ("Error: pixel format is unsupported by image format");
+    return false;
+  }
+
+  if (IsTopDown())
+  {
+    if (aWicFrameEncode->WritePixels ((UINT )SizeY(), (UINT )SizeRowBytes(), (UINT )SizeBytes(), (BYTE* )aPixMapData->Data()) != S_OK)
+    {
+      Message::SendFail ("Error: cannot write pixels to WIC Frame");
+      return false;
+    }
+  }
+  else
+  {
+    for (Standard_Size aRow = 0; aRow < SizeY(); ++aRow)
+    {
+      if (aWicFrameEncode->WritePixels (1, (UINT )SizeRowBytes(), (UINT )SizeRowBytes(), (BYTE* )aPixMapData->Row (aRow)) != S_OK)
+      {
+        Message::SendFail ("Error: cannot write pixels to WIC Frame");
+        return false;
+      }
+    }
+  }
+  if (aWicFrameEncode->Commit() != S_OK
+   || aWicEncoder->Commit() != S_OK)
+  {
+    Message::SendFail ("Error: cannot commit data to WIC Frame");
+    return false;
+  }
+  if (aStream->Commit (STGC_DEFAULT) != S_OK)
+  {
+    //Message::Send ("Error: cannot commit data to Stream", Message_Fail);
+    //return false;
+  }
+
+  // WIC doesn't have the way to encode image directly in std::ostream
+  // so we use a workaround to transfer data from IStream to std::ostream
+  STATSTG aStat;
+  if (aStream->Stat (&aStat, STATFLAG_NONAME) != S_OK)
+  {
+    Message::SendFail ("Error: cannot get stat from stream");
+    return false;
+  }
+  HGLOBAL aMem;
+  if (GetHGlobalFromStream (aStream.get(), &aMem) != S_OK)
+  {
+    Message::SendFail ("Error: cannot get global from stream");
+    return false;
+  }
+
+  LPVOID aData = GlobalLock (aMem);
+  if (aData == NULL)
+  {
+    Message::SendFail ("Error: cannot lock global");
+    return false;
+  }
+  if (!theStream.write ((const char* )aData, aStat.cbSize.QuadPart))
+  {
+    Message::SendFail ("Error: cannot write data to ostream");
+    return false;
+  }
+  if (GlobalUnlock (aMem) == 0 && GetLastError() != NO_ERROR)
+  {
+    Message::SendFail ("Error: cannot unlock global");
+    return false;
+  }
+  return true;
+#else
+  Message::SendFail ("Error: no image library available");
+  return false;
+#endif
+}
+
+// =======================================================================
+// function : AdjustGamma
+// purpose  :
+// =======================================================================
+bool Image_AlienPixMap::AdjustGamma (const Standard_Real theGammaCorr)
+{
+#ifdef HAVE_FREEIMAGE
+  return FreeImage_AdjustGamma (myLibImage, theGammaCorr) != FALSE;
+#else
+  (void )theGammaCorr;
+  return false;
+#endif
+}
+
+#ifdef HAVE_FREEIMAGE
+// =======================================================================
+// function : GetImageToDump
+// purpose  :
+// =======================================================================
+FIBITMAP* Image_AlienPixMap::getImageToDump (const Standard_Integer theFormat)
+{
+  FIBITMAP* anImageToDump = myLibImage;
   // FreeImage doesn't provide flexible format conversion API
   // so we should perform multiple conversions in some cases!
-  FIBITMAP* anImageToDump = myLibImage;
-  switch (anImageFormat)
+  switch (theFormat)
   {
     case FIF_PNG:
     case FIF_BMP:
@@ -964,7 +1510,7 @@ bool Image_AlienPixMap::Save (const TCollection_AsciiString& theFileName)
         aTmpBitmap = FreeImage_ConvertToType (myLibImage, FIT_BITMAP);
         if (aTmpBitmap == NULL)
         {
-          return false;
+          return NULL;
         }
       }
 
@@ -977,7 +1523,7 @@ bool Image_AlienPixMap::Save (const TCollection_AsciiString& theFileName)
         }
         if (aTmpBitmap24 == NULL)
         {
-          return false;
+          return NULL;
         }
         aTmpBitmap = aTmpBitmap24;
       }
@@ -1022,7 +1568,7 @@ bool Image_AlienPixMap::Save (const TCollection_AsciiString& theFileName)
         anImageToDump = FreeImage_ConvertToType (myLibImage, FIT_BITMAP);
         if (anImageToDump == NULL)
         {
-          return false;
+          return NULL;
         }
       }
 
@@ -1035,169 +1581,13 @@ bool Image_AlienPixMap::Save (const TCollection_AsciiString& theFileName)
         }
         if (aTmpBitmap24 == NULL)
         {
-          return false;
+          return NULL;
         }
         anImageToDump = aTmpBitmap24;
       }
       break;
     }
   }
-
-  if (anImageToDump == NULL)
-  {
-    return false;
-  }
-
-#ifdef _WIN32
-  bool isSaved = (FreeImage_SaveU (anImageFormat, anImageToDump, aFileNameW.ToWideString()) != FALSE);
-#else
-  bool isSaved = (FreeImage_Save  (anImageFormat, anImageToDump, theFileName.ToCString()) != FALSE);
-#endif
-  if (anImageToDump != myLibImage)
-  {
-    FreeImage_Unload (anImageToDump);
-  }
-  return isSaved;
-
-#elif defined(HAVE_WINCODEC)
-
-  TCollection_AsciiString aFileNameLower = theFileName;
-  aFileNameLower.LowerCase();
-  GUID aFileFormat = getNullGuid();
-  if (aFileNameLower.EndsWith (".ppm"))
-  {
-    return savePPM (theFileName);
-  }
-  else if (aFileNameLower.EndsWith (".bmp"))
-  {
-    aFileFormat = GUID_ContainerFormatBmp;
-  }
-  else if (aFileNameLower.EndsWith (".png"))
-  {
-    aFileFormat = GUID_ContainerFormatPng;
-  }
-  else if (aFileNameLower.EndsWith (".jpg")
-        || aFileNameLower.EndsWith (".jpeg"))
-  {
-    aFileFormat = GUID_ContainerFormatJpeg;
-  }
-  else if (aFileNameLower.EndsWith (".tiff"))
-  {
-    aFileFormat = GUID_ContainerFormatTiff;
-  }
-  else if (aFileNameLower.EndsWith (".gif"))
-  {
-    aFileFormat = GUID_ContainerFormatGif;
-  }
-
-  if (aFileFormat == getNullGuid())
-  {
-    Message::SendFail ("Error: unsupported image format");
-    return false;
-  }
-
-  Image_ComPtr<IWICImagingFactory> aWicImgFactory;
-  CoInitializeEx (NULL, COINIT_MULTITHREADED);
-  if (CoCreateInstance (CLSID_WICImagingFactory, NULL, CLSCTX_INPROC_SERVER, IID_PPV_ARGS(&aWicImgFactory.ChangePtr())) != S_OK)
-  {
-    Message::SendFail ("Error: cannot initialize WIC Imaging Factory");
-    return false;
-  }
-
-  Image_ComPtr<IWICStream> aWicFileStream;
-  Image_ComPtr<IWICBitmapEncoder> aWicEncoder;
-  const TCollection_ExtendedString aFileNameW (theFileName);
-  if (aWicImgFactory->CreateStream (&aWicFileStream.ChangePtr()) != S_OK
-   || aWicFileStream->InitializeFromFilename (aFileNameW.ToWideString(), GENERIC_WRITE) != S_OK)
-  {
-    Message::SendFail ("Error: cannot create WIC File Stream");
-    return false;
-  }
-  if (aWicImgFactory->CreateEncoder (aFileFormat, NULL, &aWicEncoder.ChangePtr()) != S_OK
-   || aWicEncoder->Initialize (aWicFileStream.get(), WICBitmapEncoderNoCache) != S_OK)
-  {
-    Message::SendFail ("Error: cannot create WIC Encoder");
-    return false;
-  }
-
-  const WICPixelFormatGUID aWicPixelFormat = convertToWicFormat (myImgFormat);
-  if (aWicPixelFormat == getNullGuid())
-  {
-    Message::SendFail ("Error: unsupported pixel format");
-    return false;
-  }
-
-  WICPixelFormatGUID aWicPixelFormatRes = aWicPixelFormat;
-  Image_ComPtr<IWICBitmapFrameEncode> aWicFrameEncode;
-  if (aWicEncoder->CreateNewFrame (&aWicFrameEncode.ChangePtr(), NULL) != S_OK
-   || aWicFrameEncode->Initialize (NULL) != S_OK
-   || aWicFrameEncode->SetSize ((UINT )SizeX(), (UINT )SizeY()) != S_OK
-   || aWicFrameEncode->SetPixelFormat (&aWicPixelFormatRes) != S_OK)
-  {
-    Message::SendFail ("Error: cannot create WIC Frame");
-    return false;
-  }
-
-  if (aWicPixelFormatRes != aWicPixelFormat)
-  {
-    Message::SendFail ("Error: pixel format is unsupported by image format");
-    return false;
-  }
-
-  if (IsTopDown())
-  {
-    if (aWicFrameEncode->WritePixels ((UINT )SizeY(), (UINT )SizeRowBytes(), (UINT )SizeBytes(), (BYTE* )Data()) != S_OK)
-    {
-      Message::SendFail ("Error: cannot write pixels to WIC Frame");
-      return false;
-    }
-  }
-  else
-  {
-    for (Standard_Size aRow = 0; aRow < SizeY(); ++aRow)
-    {
-      if (aWicFrameEncode->WritePixels (1, (UINT )SizeRowBytes(), (UINT )SizeRowBytes(), (BYTE* )Row (aRow)) != S_OK)
-      {
-        Message::SendFail ("Error: cannot write pixels to WIC Frame");
-        return false;
-      }
-    }
-  }
-
-  if (aWicFrameEncode->Commit() != S_OK
-   || aWicEncoder->Commit() != S_OK)
-  {
-    Message::SendFail ("Error: cannot commit data to WIC Frame");
-    return false;
-  }
-  if (aWicFileStream->Commit (STGC_DEFAULT) != S_OK)
-  {
-    //Message::Send ("Error: cannot commit data to WIC File Stream", Message_Fail);
-    //return false;
-  }
-  return true;
-#else
-  const Standard_Integer aLen = theFileName.Length();
-  if ((aLen >= 4) && (theFileName.Value (aLen - 3) == '.')
-      && strcasecmp( theFileName.ToCString() + aLen - 3, "ppm") == 0 )
-  {
-    return savePPM (theFileName);
-  }
-  Message::SendTrace ("Image_PixMap, no image library available! Image saved in PPM format");
-  return savePPM (theFileName);
-#endif
+  return anImageToDump;
 }
-
-// =======================================================================
-// function : AdjustGamma
-// purpose  :
-// =======================================================================
-bool Image_AlienPixMap::AdjustGamma (const Standard_Real theGammaCorr)
-{
-#ifdef HAVE_FREEIMAGE
-  return FreeImage_AdjustGamma (myLibImage, theGammaCorr) != FALSE;
-#else
-  (void )theGammaCorr;
-  return false;
 #endif
-}
