@@ -499,12 +499,34 @@ void IntPatch_ALineToWLine::MakeWLine(const Handle(IntPatch_ALine)& theALine,
     if(aStep < Epsilon(theLPar))
       break;
 
+    Standard_Boolean isStepReduced = Standard_False;
+    Standard_Real aLPar = theLPar;
+
+    for (Standard_Integer i = aVertexParams.Lower(); i <= aVertexParams.Upper(); i++)
+    {
+      if (hasVertexBeenChecked(i))
+        continue;
+
+      aLPar = aVertexParams(i);
+      if (Abs(aLPar - aParameter) < aPrmTol)
+        continue;
+
+      break;
+    }
+
+    if ((aStep - (aLPar - aParameter) > aPrmTol) &&
+        (Abs(aLPar - aParameter) > aPrmTol))
+    {
+      aStep = Max((aLPar - aParameter) / 5, 1.e-5); 
+      isStepReduced = Standard_True;
+    }
+
     Standard_Integer aNewVertID = 0;
     aLinOn2S = new IntSurf_LineOn2S;
     Standard_Boolean anIsFirstDegenerated = Standard_False,
       anIsLastDegenerated = Standard_False;
     
-    const Standard_Real aStepMin = 0.1*aStep, aStepMax = 10.0*aStep;
+    Standard_Real aStepMin = 0.1 * aStep, aStepMax = 10.0 * aStep;
 
     Standard_Boolean isLast = Standard_False;
     Standard_Real aPrevParam = aParameter;
@@ -657,8 +679,12 @@ void IntPatch_ALineToWLine::MakeWLine(const Handle(IntPatch_ALine)& theALine,
       {
         if (isPointValid)
         {
-          StepComputing(theALine, aPOn2S, theLPar, aParameter, aTgMagn,
-                        aStepMin, aStepMax, myTol3D, aStep);
+          if (!isStepReduced)
+          {
+            StepComputing(theALine, aPOn2S, theLPar, aParameter, aTgMagn,
+                          aStepMin, aStepMax, myTol3D, aStep);
+          }
+
           AddPointIntoLine(aLinOn2S, anArrPeriods, aPOn2S);
           aPrevLPoint = aPOn2S;
         }
@@ -688,7 +714,8 @@ void IntPatch_ALineToWLine::MakeWLine(const Handle(IntPatch_ALine)& theALine,
       }
 
       IntPatch_Point aVtx = theALine->Vertex(aVertexNumber);
-      const Standard_Real aNewVertexParam = aLinOn2S->NbPoints() + 1;
+      Standard_Real aNewVertexParam = aLinOn2S->NbPoints() + 1;
+      Standard_Integer aNbPointsPrev = aLinOn2S->NbPoints();
 
       //ATTENTION!!!
       // IsPoleOrSeam inserts new point in aLinOn2S if aVtx respects
@@ -722,6 +749,7 @@ void IntPatch_ALineToWLine::MakeWLine(const Handle(IntPatch_ALine)& theALine,
 
       aPrePointExist = IsPoleOrSeam(myS1, myS2, aPrefIso, aLinOn2S, aVtx,
                                 anArrPeriods, aTol, aSingularSurfaceID);
+
       if (aPrePointExist == IntPatch_SPntPole ||
           aPrePointExist == IntPatch_SPntPoleSeamU)
       {
@@ -735,6 +763,11 @@ void IntPatch_ALineToWLine::MakeWLine(const Handle(IntPatch_ALine)& theALine,
       const Standard_Real aCurVertParam = aVtx.ParameterOnLine();
       if(aPrePointExist != IntPatch_SPntNone)
       {
+        if (aNbPointsPrev == aLinOn2S->NbPoints())
+        {
+          //Vertex coinsides any point of line and was not added into line
+          aNewVertexParam = aNbPointsPrev;
+        }
         aPrevParam = aParameter = aCurVertParam;
       }
       else
@@ -795,6 +828,38 @@ void IntPatch_ALineToWLine::MakeWLine(const Handle(IntPatch_ALine)& theALine,
 
       if ((aPrePointExist != IntPatch_SPntNone) && (aLinOn2S->NbPoints() > 1))
         break;
+
+      if (isStepReduced)
+      {
+        isStepReduced = Standard_False;
+
+        aStep = (theLPar - aParameter) / (Standard_Real)(myNbPointsInWline - 1);
+        if(aStep < Epsilon(theLPar))
+          break;
+  
+        aLPar = aVertexParams(aNbVert);
+        for (Standard_Integer i = aVertexParams.Lower(); i <= aVertexParams.Upper(); i++)
+        {
+          if (hasVertexBeenChecked(i))
+            continue;
+  
+          aLPar = aVertexParams(i);
+          if (Abs(aLPar - aParameter) < aPrmTol)
+            continue;
+  
+          break;
+        }
+
+        if ((aStep - (aLPar - aParameter) > aPrmTol) &&
+            (Abs(aLPar - aParameter) > aPrmTol))
+        {
+          aStep = Max((aLPar - aParameter) / 5, 1.e-5);
+          isStepReduced = Standard_True;
+        }
+  
+        aStepMin = 0.1 * aStep;
+        aStepMax = 10.0 * aStep;
+      }
     }//for(; !isLast; aParameter += aStep)
 
     if(aLinOn2S->NbPoints() < 2)
