@@ -15,18 +15,12 @@
 // commercial license or contractual agreement.
 
 
-#include <Adaptor3d_HSurface.hxx>
-#include <Bnd_Array1OfBox.hxx>
-#include <Bnd_Box.hxx>
+#include <Adaptor3d_Surface.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Vec.hxx>
 #include <gp_XYZ.hxx>
 #include <IntPatch_HInterTool.hxx>
 #include <IntPatch_Polyhedron.hxx>
-#include <Precision.hxx>
-#include <Standard_ConstructionError.hxx>
-#include <Standard_OutOfRange.hxx>
-#include <TColgp_Array2OfPnt.hxx>
 #include <TColStd_Array2OfReal.hxx>
 
 #include <stdio.h>
@@ -37,7 +31,7 @@
 #define NBMAXUV                     30
 
 //================================================================================
-static Standard_Integer NbPOnU (const Handle(Adaptor3d_HSurface)& S)
+static Standard_Integer NbPOnU (const Handle(Adaptor3d_Surface)& S)
 {
   const Standard_Real u0 = S->FirstUParameter();
   const Standard_Real u1 = S->LastUParameter();
@@ -45,7 +39,7 @@ static Standard_Integer NbPOnU (const Handle(Adaptor3d_HSurface)& S)
   return (nbpu>NBMAXUV? NBMAXUV : nbpu);
 }
 //================================================================================
-static Standard_Integer NbPOnV (const Handle(Adaptor3d_HSurface)& S)
+static Standard_Integer NbPOnV (const Handle(Adaptor3d_Surface)& S)
 {
   const Standard_Real v0 = S->FirstVParameter();
   const Standard_Real v1 = S->LastVParameter();
@@ -69,7 +63,7 @@ void IntPatch_Polyhedron::Destroy()
 //function : IntPatch_Polyhedron
 //purpose  : 
 //=======================================================================
-IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_HSurface)& Surface)
+IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_Surface)& Surface)
      : TheDeflection(Epsilon(100.)),
        nbdeltaU(NbPOnU(Surface)),
        nbdeltaV(NbPOnV(Surface)),
@@ -126,7 +120,7 @@ IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_HSurface)& Surf
 //function : IntPatch_Polyhedron
 //purpose  : 
 //=======================================================================
-IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_HSurface)& Surface,
+IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_Surface)& Surface,
                                           const Standard_Integer nbu,
                                           const Standard_Integer nbv)
 : TheDeflection(Epsilon(100.)),
@@ -188,7 +182,7 @@ IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_HSurface)& Surf
 //=======================================================================
 
 Standard_Real IntPatch_Polyhedron::DeflectionOnTriangle
-  (const Handle(Adaptor3d_HSurface)& Surface,
+  (const Handle(Adaptor3d_Surface)& Surface,
    const Standard_Integer Triang) const 
 {
   Standard_Integer i1,i2,i3;    
@@ -402,12 +396,12 @@ Standard_Integer IntPatch_Polyhedron::TriConnex (const Standard_Integer Triang,
       if (colT==(colP+colP)) {
         colT++;
 	linO=(ligP>ligE)? ligP : ligE; 	//--linO=Max(ligP, ligE);
-	colO=colP+1;;
+	colO=colP+1;
       }
       else {
         colT--;
 	linO=(ligP<ligE)? ligP : ligE; 	//--linO=Min(ligP, ligE);
-	colO=colP-1;;
+	colO=colP-1;
       }
       break;
     case 3:  // Oblique
