@@ -15,14 +15,9 @@
 // commercial license or contractual agreement.
 
 
-#include <Adaptor2d_HCurve2d.hxx>
-#include <IntPatch_Point.hxx>
 #include <IntPatch_RLine.hxx>
 #include <IntSurf_LineOn2S.hxx>
 #include <IntSurf_PntOn2S.hxx>
-#include <Precision.hxx>
-#include <Standard_DomainError.hxx>
-#include <Standard_OutOfRange.hxx>
 #include <Standard_Type.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(IntPatch_RLine,IntPatch_PointLine)
@@ -110,12 +105,12 @@ void IntPatch_RLine::ParamOnS2(Standard_Real& a,Standard_Real& b) const {
 }
 
 
-void IntPatch_RLine::SetArcOnS1(const Handle(Adaptor2d_HCurve2d)& A) { 
+void IntPatch_RLine::SetArcOnS1(const Handle(Adaptor2d_Curve2d)& A) { 
   theArcOnS1 = A;
   onS1=Standard_True;
 }
 
-void IntPatch_RLine::SetArcOnS2(const Handle(Adaptor2d_HCurve2d)& A) { 
+void IntPatch_RLine::SetArcOnS2(const Handle(Adaptor2d_Curve2d)& A) { 
   theArcOnS2 = A;
   onS2=Standard_True;
 }
