@@ -14,10 +14,7 @@
 // commercial license or contractual agreement.
 
 
-#include <Bnd_Box2d.hxx>
-#include <gp_Pnt2d.hxx>
 #include <Intf_Polygon2d.hxx>
-#include <Standard_OutOfRange.hxx>
 
 //=======================================================================
 //function : Closed
