@@ -24,7 +24,6 @@
 #include <Geom2d_Curve.hxx>
 #include <Geom_Circle.hxx>
 #include <Geom_Curve.hxx>
-#include <Geom_CylindricalSurface.hxx>
 #include <Geom_Line.hxx>
 #include <Geom_Plane.hxx>
 #include <Geom_RectangularTrimmedSurface.hxx>
@@ -36,7 +35,6 @@
 #include <LocOpe_BuildShape.hxx>
 #include <LocOpe_GeneratedShape.hxx>
 #include <Precision.hxx>
-#include <Standard_NoSuchObject.hxx>
 #include <Standard_NullObject.hxx>
 #include <StdFail_NotDone.hxx>
 #include <TopExp.hxx>
@@ -49,12 +47,9 @@
 #include <TopoDS_Solid.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeListOfShape.hxx>
 #include <TopTools_DataMapOfShapeListOfShape.hxx>
 #include <TopTools_DataMapOfShapeShape.hxx>
 #include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
-#include <TopTools_MapIteratorOfMapOfShape.hxx>
 #include <TopTools_MapOfShape.hxx>
 
 static Standard_Boolean ToFuse(const TopoDS_Face& ,
@@ -142,7 +137,6 @@ void LocOpe_Generator::Perform(const Handle(LocOpe_GeneratedShape)& G)
   TopTools_DataMapOfShapeListOfShape theFFMap;
   TopTools_MapOfShape toRemove;
   TopTools_MapIteratorOfMapOfShape itm;
-  TopTools_DataMapIteratorOfDataMapOfShapeListOfShape itf;
 
   // recherche des fusions de faces
   for (itm.Initialize(GEdg); itm.More(); itm.Next()) {
@@ -163,7 +157,7 @@ void LocOpe_Generator::Perform(const Handle(LocOpe_GeneratedShape)& G)
       if (ToFuse(fac,facbis)) {
 	// On recherche si une face a deja fusionne avec facbis
 	Standard_Boolean facbisfound = Standard_False;
-	for (itf.Initialize(theFFMap); itf.More(); itf.Next()) {
+	for (TopTools_DataMapIteratorOfDataMapOfShapeListOfShape itf(theFFMap); itf.More(); itf.Next()) {
 	  if (itf.Key().IsSame(fac)) {
 	    continue;
 	  }
@@ -209,8 +203,8 @@ void LocOpe_Generator::Perform(const Handle(LocOpe_GeneratedShape)& G)
   // a fusionner avec une meme face de base
 
 //  TopTools_DataMapIteratorOfDataMapOfShapeListOfShape itf(theFFMap);
-  itf.Initialize(theFFMap);
-  for (; itf.More(); itf.Next()) {
+  for (TopTools_DataMapIteratorOfDataMapOfShapeListOfShape itf(theFFMap); itf.More(); itf.Next())
+  {
     for (itl.Initialize(itf.Value()); itl.More(); itl.Next()) {
       for (exp.Init(itl.Value(),TopAbs_EDGE); exp.More(); exp.Next()) {
 	const TopoDS_Edge& ed = TopoDS::Edge(exp.Current());
@@ -239,7 +233,8 @@ void LocOpe_Generator::Perform(const Handle(LocOpe_GeneratedShape)& G)
   TopTools_DataMapOfShapeShape DontFuse;
   TopAbs_Orientation orient,orface;
 
-  for (itf.Reset(); itf.More(); itf.Next()) {
+  for (TopTools_DataMapIteratorOfDataMapOfShapeListOfShape itf(theFFMap); itf.More(); itf.Next())
+  {
     const TopoDS_Face& fac = TopoDS::Face(itf.Key());
     for (exp.Init(fac,TopAbs_EDGE); exp.More(); exp.Next()) {
       const TopoDS_Edge& edg = TopoDS::Edge(exp.Current());
@@ -450,7 +445,8 @@ void LocOpe_Generator::Perform(const Handle(LocOpe_GeneratedShape)& G)
   TopTools_MapOfShape EdgAdded;
 
   // Fusion des faces, ou reconstruction
-  for (itf.Reset();itf.More(); itf.Next()) {
+  for (TopTools_DataMapIteratorOfDataMapOfShapeListOfShape itf(theFFMap);itf.More(); itf.Next())
+  {
     const TopoDS_Face& fac = TopoDS::Face(itf.Key());
     Standard_Boolean ModFace = Standard_False;
     TopTools_ListOfShape listofedg;
