@@ -30,7 +30,6 @@
 #include <Geom_Surface.hxx>
 #include <Geom_TrimmedCurve.hxx>
 #include <GeomAdaptor_Curve.hxx>
-#include <GeomAdaptor_Surface.hxx>
 #include <GeomFill_Pipe.hxx>
 #include <GeomInt_IntSS.hxx>
 #include <gp.hxx>
@@ -44,13 +43,11 @@
 #include <IntCurveSurface_IntersectionPoint.hxx>
 #include <IntCurveSurface_IntersectionSegment.hxx>
 #include <LocOpe_BuildShape.hxx>
-#include <LocOpe_FindEdges.hxx>
 #include <LocOpe_Spliter.hxx>
 #include <LocOpe_SplitShape.hxx>
 #include <LocOpe_WiresOnShape.hxx>
 #include <Precision.hxx>
 #include <Standard_ConstructionError.hxx>
-#include <Standard_NoSuchObject.hxx>
 #include <Standard_NullObject.hxx>
 #include <StdFail_NotDone.hxx>
 #include <TopExp.hxx>
@@ -61,7 +58,6 @@
 #include <TopoDS_Shape.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeListOfShape.hxx>
 #include <TopTools_DataMapIteratorOfDataMapOfShapeShape.hxx>
 #include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
 
@@ -1405,7 +1401,7 @@ static void MakeFace(TopoDS_Face& F,
 //  for (TopTools_ListIteratorOfListOfShape itl(ledg); 
   TopTools_ListIteratorOfListOfShape itl(ledg) ;
   for ( ; itl.More(); itl.Next()) {
-    TopoDS_Edge& edg = TopoDS::Edge(itl.Value());
+    const TopoDS_Edge& edg = TopoDS::Edge(itl.Value());
     Handle(Geom2d_Curve) C2d = BRep_Tool::CurveOnSurface(edg,F,f,l);
     if (C2d.IsNull()) {
       BRep_Tool::Range(edg,f,l);
@@ -1532,7 +1528,7 @@ static void MakeFace(TopoDS_Face& F,
     GProp_GProps GP;
     BRepGProp::SurfaceProperties(NewFace,GP);
     if (GP.Mass() < 0) {
-      itl.Value().Reverse();
+      itl.ChangeValue().Reverse();
     }
   }
   if (lwires.Extent() == 1) {
@@ -1648,7 +1644,7 @@ static TopoDS_Edge  NewEdge(const TopoDS_Edge& edg,
     Standard_Boolean rev = Standard_False;
     TopoDS_Vertex Vf = V1;
     TopoDS_Vertex Vl = V2;
-    Handle(Geom_Curve) Cimg = i2s.Line(i);
+    const Handle(Geom_Curve)& Cimg = i2s.Line(i);
     Handle(Geom2d_Curve) Cimg2d;
     if (AppS1) {
       Cimg2d = i2s.LineOnS1(i);
