@@ -19,7 +19,6 @@
 #include <BRep_Tool.hxx>
 #include <BRepAdaptor_Surface.hxx>
 #include <BRepClass_FaceExplorer.hxx>
-#include <BRepLib_MakeFace.hxx>
 #include <BRepLib_MakeWire.hxx>
 #include <BRepTools.hxx>
 #include <BRepTools_WireExplorer.hxx>
@@ -31,7 +30,6 @@
 #include <LocOpe.hxx>
 #include <LocOpe_SplitShape.hxx>
 #include <Precision.hxx>
-#include <Standard_ConstructionError.hxx>
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_NoSuchObject.hxx>
 #include <StdFail_NotDone.hxx>
@@ -44,23 +42,15 @@
 #include <TopoDS_Shape.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeListOfShape.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeShape.hxx>
 #include <TopTools_DataMapOfShapeInteger.hxx>
 #include <TopTools_DataMapOfShapeListOfShape.hxx>
 #include <TopTools_DataMapOfShapeShape.hxx>
 #include <TopTools_IndexedMapOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_ListOfShape.hxx>
-#include <TopTools_MapIteratorOfMapOfOrientedShape.hxx>
-#include <TopTools_MapIteratorOfMapOfShape.hxx>
 #include <TopTools_MapOfOrientedShape.hxx>
-#include <TopTools_MapOfShape.hxx>
 #include <ShapeAnalysis_Edge.hxx>
 #include <Geom2dAPI_ProjectPointOnCurve.hxx>
 
-#include <Geom_Surface.hxx>
-
 static Standard_Boolean IsInside(const TopoDS_Face&,
                                  const TopoDS_Wire&,
                                  const TopoDS_Wire&);
@@ -467,7 +457,7 @@ Standard_Boolean LocOpe_SplitShape::Add(const TopTools_ListOfShape& Lwires,
         else
           {
             //we have to choose the direction
-            TopoDS_Edge aStartEdge = wexp.Current();
+            const TopoDS_Edge& aStartEdge = wexp.Current();
             TopTools_ListOfShape Ldirs;
             Ldirs.Append(aStartEdge);
             Ldirs.Append(NextSectionWire);
@@ -525,7 +515,7 @@ Standard_Boolean LocOpe_SplitShape::Add(const TopTools_ListOfShape& Lwires,
     const TopoDS_Wire& aHole = TopoDS::Wire(itl.Value());
     for (itlNewF.Initialize(NewFaces); itlNewF.More(); itlNewF.Next())
     {
-      TopoDS_Face& aNewFace = TopoDS::Face(itlNewF.Value());
+      TopoDS_Face& aNewFace = TopoDS::Face(itlNewF.ChangeValue());
       if (IsInside(aNewFace, aHole))
       {
         BB.Add(aNewFace, aHole);
