@@ -31,13 +31,11 @@
 #include <Geom_RectangularTrimmedSurface.hxx>
 #include <Geom_Surface.hxx>
 #include <Geom_TrimmedCurve.hxx>
-#include <GeomAdaptor_Surface.hxx>
 #include <GeomAPI_ProjectPointOnCurve.hxx>
 #include <GeomProjLib.hxx>
 #include <gp_Pnt2d.hxx>
 #include <gp_Vec.hxx>
 #include <gp_Vec2d.hxx>
-#include <LocOpe.hxx>
 #include <LocOpe_WiresOnShape.hxx>
 #include <Precision.hxx>
 #include <Standard_ConstructionError.hxx>
@@ -53,7 +51,6 @@
 #include <TopoDS_Wire.hxx>
 #include <TopTools_DataMapIteratorOfDataMapOfShapeShape.hxx>
 #include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_ListOfShape.hxx>
 #include <TopTools_MapOfShape.hxx>
 #include <TopTools_DataMapOfShapeReal.hxx>
@@ -64,8 +61,6 @@
 #include <TopTools_SequenceOfShape.hxx>
 #include <BRepBndLib.hxx>
 #include <Bnd_Box.hxx>
-#include <Bnd_SeqOfBox.hxx>
-#include <NCollection_Handle.hxx>
 #include <TColStd_PackedMapOfInteger.hxx>
 #include <Extrema_ExtPS.hxx>
 
@@ -1472,8 +1467,8 @@ void FindInternalIntersections(const TopoDS_Edge& theEdge,
 Standard_Boolean LocOpe_WiresOnShape::Add(const TopTools_SequenceOfShape& theEdges)
 {
   TopTools_SequenceOfShape anEdges;
-  Bnd_SeqOfBox anEdgeBoxes;
   Standard_Integer i = 1, nb = theEdges.Length();
+  NCollection_Array1<Bnd_Box> anEdgeBoxes(1, nb);
   for (; i <= nb; i++)
   {
     const TopoDS_Shape& aCurSplit = theEdges(i);
@@ -1488,7 +1483,7 @@ Standard_Boolean LocOpe_WiresOnShape::Add(const TopTools_SequenceOfShape& theEdg
         continue;
       Standard_Real aTolE = BRep_Tool::Tolerance(TopoDS::Edge(aCurE));
       aBoxE.SetGap(aTolE);
-      anEdgeBoxes.Append(aBoxE);
+      anEdgeBoxes.SetValue(i, aBoxE);
       anEdges.Append(aCurE);
 
     }
