@@ -19,15 +19,13 @@
 #include <OpenGl_DepthPeeling.hxx>
 #include <OpenGl_FrameBuffer.hxx>
 #include <OpenGl_LayerList.hxx>
+#include <OpenGl_RenderFilter.hxx>
 #include <OpenGl_ShaderManager.hxx>
 #include <OpenGl_ShadowMap.hxx>
-#include <OpenGl_Structure.hxx>
 #include <OpenGl_VertexBuffer.hxx>
 #include <OpenGl_View.hxx>
 #include <OpenGl_Workspace.hxx>
 
-#include <Graphic3d_GraphicDriver.hxx>
-
 namespace
 {
   //! Auxiliary class extending sequence iterator with index.
@@ -156,9 +154,8 @@ struct OpenGl_GlobalLayerSettings
 //purpose  : Constructor
 //=======================================================================
 
-OpenGl_LayerList::OpenGl_LayerList (const Standard_Integer theNbPriorities)
+OpenGl_LayerList::OpenGl_LayerList()
 : myBVHBuilder (new BVH_LinearBuilder<Standard_Real, 3> (BVH_Constants_LeafNodeSizeSingle, BVH_Constants_MaxTreeDepth)),
-  myNbPriorities (theNbPriorities),
   myNbStructures (0),
   myImmediateNbStructures (0),
   myModifStateOfRaytraceable (0)
@@ -201,7 +198,7 @@ void OpenGl_LayerList::InsertLayerBefore (const Graphic3d_ZLayerId theNewLayerId
     return;
   }
 
-  Handle(Graphic3d_Layer) aNewLayer = new Graphic3d_Layer (theNewLayerId, myNbPriorities, myBVHBuilder);
+  Handle(Graphic3d_Layer) aNewLayer = new Graphic3d_Layer (theNewLayerId, myBVHBuilder);
   aNewLayer->SetLayerSettings (theSettings);
 
   Handle(Graphic3d_Layer) anOtherLayer;
@@ -239,7 +236,7 @@ void OpenGl_LayerList::InsertLayerAfter (const Graphic3d_ZLayerId theNewLayerId,
     return;
   }
 
-  Handle(Graphic3d_Layer) aNewLayer = new Graphic3d_Layer (theNewLayerId, myNbPriorities, myBVHBuilder);
+  Handle(Graphic3d_Layer) aNewLayer = new Graphic3d_Layer (theNewLayerId, myBVHBuilder);
   aNewLayer->SetLayerSettings (theSettings);
 
   Handle(Graphic3d_Layer) anOtherLayer;
@@ -294,7 +291,7 @@ void OpenGl_LayerList::RemoveLayer (const Graphic3d_ZLayerId theLayerId)
 
 void OpenGl_LayerList::AddStructure (const OpenGl_Structure*  theStruct,
                                      const Graphic3d_ZLayerId theLayerId,
-                                     const Standard_Integer   thePriority,
+                                     const Graphic3d_DisplayPriority thePriority,
                                      Standard_Boolean         isForChangePriority)
 {
   // add structure to associated layer,
@@ -324,7 +321,7 @@ void OpenGl_LayerList::RemoveStructure (const OpenGl_Structure* theStructure)
   const Handle(Graphic3d_Layer)* aLayerPtr = myLayerIds.Seek (aLayerId);
   const Handle(Graphic3d_Layer)& aLayer = aLayerPtr != NULL ? *aLayerPtr : myLayerIds.Find (Graphic3d_ZLayerId_Default);
 
-  Standard_Integer aPriority = -1;
+  Graphic3d_DisplayPriority aPriority = Graphic3d_DisplayPriority_INVALID;
 
   // remove structure from associated list
   // if the structure is not found there,
@@ -396,7 +393,7 @@ void OpenGl_LayerList::ChangeLayer (const OpenGl_Structure*  theStructure,
   const Handle(Graphic3d_Layer)* aLayerPtr = myLayerIds.Seek (theOldLayerId);
   const Handle(Graphic3d_Layer)& aLayer = aLayerPtr != NULL ? *aLayerPtr : myLayerIds.Find (Graphic3d_ZLayerId_Default);
 
-  Standard_Integer aPriority = -1;
+  Graphic3d_DisplayPriority aPriority = Graphic3d_DisplayPriority_INVALID;
 
   // take priority and remove structure from list found by <theOldLayerId>
   // if the structure is not found there, scan through all other layers
@@ -460,13 +457,12 @@ void OpenGl_LayerList::ChangeLayer (const OpenGl_Structure*  theStructure,
 //=======================================================================
 void OpenGl_LayerList::ChangePriority (const OpenGl_Structure*  theStructure,
                                        const Graphic3d_ZLayerId theLayerId,
-                                       const Standard_Integer   theNewPriority)
+                                       const Graphic3d_DisplayPriority theNewPriority)
 {
   const Handle(Graphic3d_Layer)* aLayerPtr = myLayerIds.Seek (theLayerId);
   const Handle(Graphic3d_Layer)& aLayer = aLayerPtr != NULL ? *aLayerPtr : myLayerIds.Find (Graphic3d_ZLayerId_Default);
 
-  Standard_Integer anOldPriority = -1;
-
+  Graphic3d_DisplayPriority anOldPriority = Graphic3d_DisplayPriority_INVALID;
   if (aLayer->Remove (theStructure, anOldPriority, Standard_True))
   {
     --myNbStructures;
@@ -573,11 +569,11 @@ void OpenGl_LayerList::renderLayer (const Handle(OpenGl_Workspace)& theWorkspace
   if (aLayerSettings.ToEnableDepthTest())
   {
     // assuming depth test is enabled by default
-    glDepthFunc (theDefaultSettings.DepthFunc);
+    aCtx->core11fwd->glDepthFunc (theDefaultSettings.DepthFunc);
   }
   else
   {
-    glDepthFunc (GL_ALWAYS);
+    aCtx->core11fwd->glDepthFunc (GL_ALWAYS);
   }
 
   // save environment texture
@@ -592,7 +588,7 @@ void OpenGl_LayerList::renderLayer (const Handle(OpenGl_Workspace)& theWorkspace
 
   // handle depth write
   theWorkspace->UseDepthWrite() = aLayerSettings.ToEnableDepthWrite() && theDefaultSettings.DepthMask == GL_TRUE;
-  glDepthMask (theWorkspace->UseDepthWrite() ? GL_TRUE : GL_FALSE);
+  aCtx->core11fwd->glDepthMask (theWorkspace->UseDepthWrite() ? GL_TRUE : GL_FALSE);
 
   const Standard_Boolean hasLocalCS = !aLayerSettings.OriginTransformation().IsNull();
   const Handle(OpenGl_ShaderManager)& aManager = aCtx->ShaderManager();
@@ -664,9 +660,9 @@ void OpenGl_LayerList::renderLayer (const Handle(OpenGl_Workspace)& theWorkspace
 
   // render priority list
   const Standard_Integer aViewId = theWorkspace->View()->Identification();
-  for (Graphic3d_ArrayOfIndexedMapOfStructure::Iterator aMapIter (theLayer.ArrayOfStructures()); aMapIter.More(); aMapIter.Next())
+  for (Standard_Integer aPriorityIter = Graphic3d_DisplayPriority_Bottom; aPriorityIter <= Graphic3d_DisplayPriority_Topmost; ++aPriorityIter)
   {
-    const Graphic3d_IndexedMapOfStructure& aStructures = aMapIter.Value();
+    const Graphic3d_IndexedMapOfStructure& aStructures = theLayer.Structures ((Graphic3d_DisplayPriority )aPriorityIter);
     for (OpenGl_Structure::StructIterator aStructIter (aStructures); aStructIter.More(); aStructIter.Next())
     {
       const OpenGl_Structure* aStruct = aStructIter.Value();
@@ -863,8 +859,8 @@ void OpenGl_LayerList::Render (const Handle(OpenGl_Workspace)& theWorkspace,
     if (aClearDepthLayer > aClearDepthLayerPrev)
     {
       aClearDepthLayerPrev = aClearDepthLayer;
-      glDepthMask (GL_TRUE);
-      glClear (GL_DEPTH_BUFFER_BIT);
+      aCtx->core11fwd->glDepthMask (GL_TRUE);
+      aCtx->core11fwd->glClear (GL_DEPTH_BUFFER_BIT);
     }
   }
 
@@ -1250,7 +1246,6 @@ void OpenGl_LayerList::DumpJson (Standard_OStream& theOStream, Standard_Integer
     OCCT_DUMP_FIELD_VALUES_DUMPED (theOStream, theDepth, aLayerId.get())
   }
 
-  OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, myNbPriorities)
   OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, myNbStructures)
   OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, myImmediateNbStructures)
   OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, myModifStateOfRaytraceable)
