@@ -15,14 +15,12 @@
 
 #include <OpenGl_SceneGeometry.hxx>
 
-#include <Graphic3d_GraphicDriver.hxx>
 #include <OSD_Parallel.hxx>
 #include <OSD_Timer.hxx>
 #include <Standard_Assert.hxx>
 #include <OpenGl_ArbTexBindless.hxx>
 #include <OpenGl_PrimitiveArray.hxx>
 #include <OpenGl_Structure.hxx>
-#include <OpenGl_TextureBuffer.hxx>
 
 // Use this macro to output BVH profiling info
 // #define RAY_TRACE_PRINT_INFO
@@ -158,12 +156,12 @@ void OpenGl_RaytraceGeometry::Clear()
   BVH_Geometry<Standard_ShortReal, 3>::BVH_Geometry::Clear();
 
   std::vector<OpenGl_RaytraceLight,
-    NCollection_StdAllocator<OpenGl_RaytraceLight> > anEmptySources;
+    NCollection_OccAllocator<OpenGl_RaytraceLight> > anEmptySources;
 
   Sources.swap (anEmptySources);
 
   std::vector<OpenGl_RaytraceMaterial,
-    NCollection_StdAllocator<OpenGl_RaytraceMaterial> > anEmptyMaterials;
+    NCollection_OccAllocator<OpenGl_RaytraceMaterial> > anEmptyMaterials;
 
   Materials.swap (anEmptyMaterials);
 }
@@ -388,7 +386,6 @@ Standard_Boolean OpenGl_RaytraceGeometry::AcquireTextures (const Handle(OpenGl_C
     return Standard_True;
   }
 
-#if !defined(GL_ES_VERSION_2_0)
   Standard_Integer aTexIter = 0;
   for (NCollection_Vector<Handle(OpenGl_Texture)>::Iterator aTexSrcIter (myTextures); aTexSrcIter.More(); aTexSrcIter.Next(), ++aTexIter)
   {
@@ -425,7 +422,6 @@ Standard_Boolean OpenGl_RaytraceGeometry::AcquireTextures (const Handle(OpenGl_C
       return Standard_False;
     }
   }
-#endif
 
   return Standard_True;
 }
@@ -441,7 +437,6 @@ Standard_Boolean OpenGl_RaytraceGeometry::ReleaseTextures (const Handle(OpenGl_C
     return Standard_True;
   }
 
-#if !defined(GL_ES_VERSION_2_0)
   for (size_t aTexIter = 0; aTexIter < myTextureHandles.size(); ++aTexIter)
   {
     theContext->arbTexBindless->glMakeTextureHandleNonResidentARB (myTextureHandles[aTexIter]);
@@ -453,7 +448,6 @@ Standard_Boolean OpenGl_RaytraceGeometry::ReleaseTextures (const Handle(OpenGl_C
       return Standard_False;
     }
   }
-#endif
 
   return Standard_True;
 }
@@ -499,7 +493,6 @@ Standard_Boolean OpenGl_RaytraceGeometry::UpdateTextureHandles (const Handle(Ope
   myTextureHandles.clear();
   myTextureHandles.resize (myTextures.Size());
 
-#if !defined(GL_ES_VERSION_2_0)
   Standard_Integer aTexIter = 0;
   for (NCollection_Vector<Handle(OpenGl_Texture)>::Iterator aTexSrcIter (myTextures); aTexSrcIter.More(); aTexSrcIter.Next(), ++aTexIter)
   {
@@ -524,7 +517,6 @@ Standard_Boolean OpenGl_RaytraceGeometry::UpdateTextureHandles (const Handle(Ope
       return Standard_False;
     }
   }
-#endif
 
   return Standard_True;
 }
