@@ -13,7 +13,7 @@
 
 #include <OpenGl_UniformBuffer.hxx>
 
-#include <OpenGl_Context.hxx>
+#include <OpenGl_GlCore15.hxx>
 #include <Standard_Assert.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(OpenGl_UniformBuffer, OpenGl_Buffer)
