@@ -16,21 +16,13 @@
 #include <OpenGl_Workspace.hxx>
 
 #include <OpenGl_Aspects.hxx>
-#include <OpenGl_Context.hxx>
 #include <OpenGl_Element.hxx>
-#include <OpenGl_FrameBuffer.hxx>
 #include <OpenGl_GlCore15.hxx>
-#include <OpenGl_SceneGeometry.hxx>
-#include <OpenGl_Structure.hxx>
-#include <OpenGl_Sampler.hxx>
+#include <OpenGl_RenderFilter.hxx>
 #include <OpenGl_ShaderManager.hxx>
-#include <OpenGl_Texture.hxx>
 #include <OpenGl_View.hxx>
 #include <OpenGl_Window.hxx>
 
-#include <Graphic3d_TextureParams.hxx>
-#include <Graphic3d_TransformUtils.hxx>
-
 IMPLEMENT_STANDARD_RTTIEXT(OpenGl_Workspace,Standard_Transient)
 
 // =======================================================================
@@ -124,7 +116,6 @@ OpenGl_Workspace::OpenGl_Workspace (OpenGl_View* theView, const Handle(OpenGl_Wi
     myGlContext->core11fwd->glPixelStorei (GL_UNPACK_ALIGNMENT, 1);
 
     // General initialization of the context
-  #if !defined(GL_ES_VERSION_2_0)
     if (myGlContext->core11ffp != NULL)
     {
       // enable two-side lighting by default
@@ -136,15 +127,17 @@ OpenGl_Workspace::OpenGl_Workspace (OpenGl_View* theView, const Handle(OpenGl_Wi
       }
     }
 
-    myGlContext->core11fwd->glHint (GL_LINE_SMOOTH_HINT,    GL_FASTEST);
-    myGlContext->core11fwd->glHint (GL_POLYGON_SMOOTH_HINT, GL_FASTEST);
+    if (myGlContext->GraphicsLibrary() != Aspect_GraphicsLibrary_OpenGLES)
+    {
+      myGlContext->core11fwd->glHint (GL_LINE_SMOOTH_HINT,    GL_FASTEST);
+      myGlContext->core11fwd->glHint (GL_POLYGON_SMOOTH_HINT, GL_FASTEST);
+    }
     if (myGlContext->Vendor() == "microsoft corporation"
     && !myGlContext->IsGlGreaterEqual (1, 2))
     {
       // this software implementation causes too slow rendering into GL_FRONT on modern Windows
       theView->SetImmediateModeDrawToFront (false);
     }
-  #endif
   }
 
   myNoneCulling .Aspect()->SetFaceCulling (Graphic3d_TypeOfBackfacingModel_DoubleSided);
@@ -171,11 +164,9 @@ Standard_Boolean OpenGl_Workspace::Activate()
   {
     if (myGlContext->caps->ffpEnable)
     {
-    #if defined(GL_ES_VERSION_2_0)
-      Message::SendWarning ("Warning: FFP is unsupported by OpenGL ES");
-    #else
-      Message::SendWarning ("Warning: FFP is unsupported by OpenGL Core Profile");
-    #endif
+      Message::SendWarning (myGlContext->GraphicsLibrary() != Aspect_GraphicsLibrary_OpenGLES
+                          ? "Warning: FFP is unsupported by OpenGL ES"
+                          : "Warning: FFP is unsupported by OpenGL Core Profile");
       myGlContext->caps->ffpEnable = false;
     }
   }
@@ -187,12 +178,10 @@ Standard_Boolean OpenGl_Workspace::Activate()
     myGlContext->caps->useZeroToOneDepth = false;
   }
   myView->Camera()->SetZeroToOneDepth (myGlContext->caps->useZeroToOneDepth);
-#if !defined(GL_ES_VERSION_2_0)
   if (myGlContext->arbClipControl)
   {
     myGlContext->Functions()->glClipControl (GL_LOWER_LEFT, myGlContext->caps->useZeroToOneDepth ? GL_ZERO_TO_ONE : GL_NEGATIVE_ONE_TO_ONE);
   }
-#endif
 
   ResetAppliedAspect();
 
@@ -266,27 +255,34 @@ const OpenGl_Aspects* OpenGl_Workspace::SetAspects (const OpenGl_Aspects* theAsp
 // =======================================================================
 const OpenGl_Aspects* OpenGl_Workspace::ApplyAspects (bool theToBindTextures)
 {
-  bool toSuppressBackFaces = myView->BackfacingModel() == Graphic3d_TypeOfBackfacingModel_BackCulled;
-  if (myView->BackfacingModel() == Graphic3d_TypeOfBackfacingModel_Auto)
+  //bool toSuppressBackFaces = myView->BackfacingModel() == Graphic3d_TypeOfBackfacingModel_BackCulled;
+  Graphic3d_TypeOfBackfacingModel aCullFacesMode = myView->BackfacingModel();
+  if (aCullFacesMode == Graphic3d_TypeOfBackfacingModel_Auto)
   {
-    toSuppressBackFaces = myAspectsSet->Aspect()->FaceCulling() == Graphic3d_TypeOfBackfacingModel_BackCulled;
-    if (myAspectsSet->Aspect()->FaceCulling() == Graphic3d_TypeOfBackfacingModel_Auto
-     && myToAllowFaceCulling)
+    aCullFacesMode = myAspectsSet->Aspect()->FaceCulling();
+    if (aCullFacesMode == Graphic3d_TypeOfBackfacingModel_Auto)
     {
-      toSuppressBackFaces = true;
-      if (myAspectsSet->Aspect()->InteriorStyle() == Aspect_IS_HATCH
-       || myAspectsSet->Aspect()->AlphaMode() == Graphic3d_AlphaMode_Blend
-       || myAspectsSet->Aspect()->AlphaMode() == Graphic3d_AlphaMode_Mask
-       || myAspectsSet->Aspect()->AlphaMode() == Graphic3d_AlphaMode_MaskBlend
-       || (myAspectsSet->Aspect()->AlphaMode() == Graphic3d_AlphaMode_BlendAuto
-        && myAspectsSet->Aspect()->FrontMaterial().Transparency() != 0.0f))
+      aCullFacesMode = Graphic3d_TypeOfBackfacingModel_DoubleSided;
+      if (myToAllowFaceCulling)
       {
-        // disable culling in case of translucent shading aspect
-        toSuppressBackFaces = false;
+        if (myAspectsSet->Aspect()->InteriorStyle() == Aspect_IS_HATCH
+         || myAspectsSet->Aspect()->AlphaMode() == Graphic3d_AlphaMode_Blend
+         || myAspectsSet->Aspect()->AlphaMode() == Graphic3d_AlphaMode_Mask
+         || myAspectsSet->Aspect()->AlphaMode() == Graphic3d_AlphaMode_MaskBlend
+         || (myAspectsSet->Aspect()->AlphaMode() == Graphic3d_AlphaMode_BlendAuto
+          && myAspectsSet->Aspect()->FrontMaterial().Transparency() != 0.0f))
+        {
+          // disable culling in case of translucent shading aspect
+          aCullFacesMode = Graphic3d_TypeOfBackfacingModel_DoubleSided;
+        }
+        else
+        {
+          aCullFacesMode = Graphic3d_TypeOfBackfacingModel_BackCulled;
+        }
       }
     }
   }
-  myGlContext->SetCullBackFaces (toSuppressBackFaces);
+  myGlContext->SetFaceCulling (aCullFacesMode);
 
   if (myAspectsSet->Aspect() == myAspectsApplied
    && myHighlightStyle == myAspectFaceAppliedWithHL)
@@ -305,18 +301,14 @@ const OpenGl_Aspects* OpenGl_Workspace::ApplyAspects (bool theToBindTextures)
   if (myAspectsApplied.IsNull()
    || myAspectsApplied->InteriorStyle() != anIntstyle)
   {
-  #if !defined(GL_ES_VERSION_2_0)
     myGlContext->SetPolygonMode (anIntstyle == Aspect_IS_POINT ? GL_POINT : GL_FILL);
     myGlContext->SetPolygonHatchEnabled (anIntstyle == Aspect_IS_HATCH);
-  #endif
   }
 
-#if !defined(GL_ES_VERSION_2_0)
   if (anIntstyle == Aspect_IS_HATCH)
   {
     myGlContext->SetPolygonHatchStyle (myAspectsSet->Aspect()->HatchStyle());
   }
-#endif
 
   // Case of hidden line
   if (anIntstyle == Aspect_IS_HIDDENLINE)
@@ -430,6 +422,14 @@ Standard_Boolean OpenGl_Workspace::BufferDump (const Handle(OpenGl_FrameBuffer)&
 bool OpenGl_Workspace::ShouldRender (const OpenGl_Element* theElement,
                                      const OpenGl_Group*   theGroup)
 {
+  if ((myRenderFilter & OpenGl_RenderFilter_SkipTrsfPersistence) != 0)
+  {
+    if (theGroup->HasPersistence())
+    {
+      return false;
+    }
+  }
+
   // render only non-raytracable elements when RayTracing is enabled
   if ((myRenderFilter & OpenGl_RenderFilter_NonRaytraceableOnly) != 0)
   {
