@@ -15,9 +15,7 @@
 // commercial license or contractual agreement.
 
 
-#include <gp_XYZ.hxx>
 #include <Plate_D1.hxx>
-#include <Plate_FreeGtoCConstraint.hxx>
 #include <Plate_GtoCConstraint.hxx>
 
 Plate_D1::Plate_D1(const gp_XYZ& du, const gp_XYZ& dv)
