@@ -15,10 +15,7 @@
 // commercial license or contractual agreement.
 
 
-#include <gp_XYZ.hxx>
 #include <Plate_D2.hxx>
-#include <Plate_FreeGtoCConstraint.hxx>
-#include <Plate_GtoCConstraint.hxx>
 
 Plate_D2::Plate_D2(const gp_XYZ& duu, const gp_XYZ& duv, const gp_XYZ& dvv)
 :Duu(duu),Duv(duv),Dvv(dvv)
