@@ -15,7 +15,6 @@
 // commercial license or contractual agreement.
 
 
-#include <Adaptor3d_Curve.hxx>
 #include <Adaptor3d_Surface.hxx>
 #include <gp_Pnt2d.hxx>
 #include <math_FunctionSetRoot.hxx>
@@ -23,7 +22,6 @@
 #include <ProjLib_PrjFunc.hxx>
 #include <ProjLib_PrjResolve.hxx>
 #include <Standard_ConstructionError.hxx>
-#include <Standard_DomainError.hxx>
 #include <StdFail_NotDone.hxx>
 
 ProjLib_PrjResolve::ProjLib_PrjResolve(const Adaptor3d_Curve& C,const Adaptor3d_Surface& S,const Standard_Integer Fix)
