@@ -42,12 +42,11 @@
 #include <IntAna2d_AnaIntersection.hxx>
 #include <ProjLib.hxx>
 #include <Prs3d_ShadingAspect.hxx>
-#include <PrsMgr_PresentationManager3d.hxx>
+#include <PrsMgr_PresentationManager.hxx>
 #include <Select3D_SensitiveGroup.hxx>
 #include <Select3D_SensitiveSegment.hxx>
 #include <SelectMgr_Selection.hxx>
 #include <Standard_ProgramError.hxx>
-#include <UnitsAPI.hxx>
 #include <Geom_Line.hxx>
 #include <Geom_Plane.hxx>
 
@@ -623,7 +622,7 @@ Standard_Real PrsDim_AngleDimension::ComputeValue() const
 //function : Compute
 //purpose  : Having three gp_Pnt points compute presentation
 //=======================================================================
-void PrsDim_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*thePM*/,
+void PrsDim_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager)& ,
                                      const Handle(Prs3d_Presentation)& thePresentation,
                                      const Standard_Integer theMode)
 {
@@ -691,8 +690,14 @@ void PrsDim_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)&
 
   aFirstArrowBegin  = aFirstAttach;
   aSecondArrowBegin = aSecondAttach;
-  aFirstArrowEnd    = aFirstAttach.Translated (-aFirstArrowVec);
-  aSecondArrowEnd   = aSecondAttach.Translated (-aSecondArrowVec);
+  aFirstArrowEnd    = aFirstAttach;
+  aSecondArrowEnd   = aSecondAttach;
+
+  if (aDimensionAspect->ArrowAspect()->IsZoomable())
+  {
+    aFirstArrowEnd.Translate (-aFirstArrowVec);
+    aSecondArrowEnd.Translate (-aSecondArrowVec);
+  }
 
   // Group1: stenciling text and the angle dimension arc
   thePresentation->NewGroup();
@@ -1171,7 +1176,7 @@ Standard_Boolean PrsDim_AngleDimension::IsValidPoints (const gp_Pnt& theFirstPoi
 
 //=======================================================================
 //function : isArrowVisible
-//purpose  : compares given and internal arrows types, returns true if the the type should be shown
+//purpose  : compares given and internal arrows types, returns true if the type should be shown
 //=======================================================================
 Standard_Boolean PrsDim_AngleDimension::isArrowVisible(const PrsDim_TypeOfAngleArrowVisibility theArrowType) const
 {
