@@ -20,12 +20,9 @@
 #include <DBRep.hxx>
 #include <DrawTrSurf.hxx>
 #include <AIS_InteractiveContext.hxx>
-#include <ViewerTest.hxx>
-#include <AIS_Shape.hxx>
 #include <TopoDS_Shape.hxx>
 
 #include <BRepBuilderAPI_MakePolygon.hxx>
-#include <TopoDS_Face.hxx>
 #include <BRepBuilderAPI_MakeFace.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Dir.hxx>
@@ -42,10 +39,8 @@
 #include <BRep_Tool.hxx>
 #include <Poly_Triangulation.hxx>
 #include <TopExp.hxx>
-#include <ChFi3d_FilletShape.hxx>
 #include <BRepFilletAPI_MakeFillet.hxx>
 #include <Standard_ErrorHandler.hxx>
-#include <Geom_TrimmedCurve.hxx>
 #include <Geom_BSplineSurface.hxx>
 
 #include <ShapeUpgrade_UnifySameDomain.hxx>
@@ -396,7 +391,7 @@ static Standard_Integer OCC712 (Draw_Interpretor& di, Standard_Integer argc, con
 //  performTriangulation
 //=======================================================================
 
-Standard_Integer performTriangulation (TopoDS_Shape aShape, Draw_Interpretor& di)
+Standard_Integer performTriangulation (const TopoDS_Shape& aShape, Draw_Interpretor& di)
 {
   int failed=0, total=0;
   TopExp_Explorer ExpFace;
@@ -686,7 +681,7 @@ static Standard_Integer OCC825 (Draw_Interpretor& di,Standard_Integer argc, cons
   Handle(Geom_BezierSurface) BezSurf = new Geom_BezierSurface(poles);
   Handle(Geom_BSplineSurface) BSpSurf = GeomConvert::SurfaceToBSplineSurface(BezSurf);
   BRepBuilderAPI_MakeFace faceMaker(BSpSurf, Precision::Confusion());
-  TopoDS_Face face = faceMaker.Face();
+  const TopoDS_Face& face = faceMaker.Face();
 
   gp_Pnt pnt(0, size, 0);
   BRepPrimAPI_MakeHalfSpace *hSpace = new BRepPrimAPI_MakeHalfSpace(face,pnt);
@@ -898,7 +893,7 @@ static Standard_Integer OCC827 (Draw_Interpretor& di,Standard_Integer argc, cons
 //  performBlend
 //=======================================================================
 
-int performBlend (TopoDS_Shape aShape, Standard_Real rad, TopoDS_Shape& bShape, Draw_Interpretor& di)
+int performBlend (const TopoDS_Shape& aShape, Standard_Real rad, TopoDS_Shape& bShape, Draw_Interpretor& di)
 {
   Standard_Integer status = 0;
   TopoDS_Shape newShape;
