@@ -21,8 +21,9 @@
 #include <NCollection_DataMap.hxx>
 #include <OSD_FileSystem.hxx>
 #include <OSD_File.hxx>
+#include <OSD_Parallel.hxx>
 #include <OSD_Path.hxx>
-#include <Poly_Triangulation.hxx>
+#include <OSD_Timer.hxx>
 #include <RWGltf_GltfAccessorLayout.hxx>
 #include <RWGltf_GltfArrayType.hxx>
 #include <RWGltf_GltfMaterialMap.hxx>
@@ -44,6 +45,12 @@
   #include <RWGltf_GltfOStreamWriter.hxx>
 #endif
 
+#ifdef HAVE_DRACO
+  #include <Standard_WarningsDisable.hxx>
+  #include <draco/compression/encode.h>
+  #include <Standard_WarningsRestore.hxx>
+#endif
+
 IMPLEMENT_STANDARD_RTTIEXT(RWGltf_CafWriter, Standard_Transient)
 
 namespace
@@ -84,8 +91,152 @@ namespace
   {
     theStream.write ((const char* )theTri.GetData(), sizeof(theTri));
   }
+
+#ifdef HAVE_DRACO
+  //! Write nodes to Draco mesh
+  static void writeNodesToDracoMesh (draco::Mesh& theMesh,
+                                     const std::vector<Graphic3d_Vec3>& theNodes)
+  {
+    if (theNodes.empty())
+    {
+      return;
+    }
+
+    draco::PointAttribute anAttr;
+    anAttr.Init (draco::GeometryAttribute::POSITION, 3, draco::DT_FLOAT32, false, sizeof(float) * 3);
+    const int anId = theMesh.AddAttribute (anAttr, true, uint32_t(theNodes.size()));
+    draco::PointAttribute* aPtr = theMesh.attribute (anId);
+    draco::PointIndex anIndex(0);
+    for (size_t aNodeInd = 0; aNodeInd < theNodes.size(); ++aNodeInd, ++anIndex)
+    {
+      aPtr->SetAttributeValue (aPtr->mapped_index(anIndex), theNodes[aNodeInd].GetData());
+    }
+  }
+
+  //! Write normals to Draco mesh
+  static void writeNormalsToDracoMesh (draco::Mesh& theMesh,
+                                       const std::vector<Graphic3d_Vec3>& theNormals)
+  {
+    if (theNormals.empty())
+    {
+      return;
+    }
+
+    draco::PointAttribute anAttr;
+    anAttr.Init (draco::GeometryAttribute::NORMAL, 3, draco::DT_FLOAT32, false, sizeof(float) * 3);
+    const int anId = theMesh.AddAttribute (anAttr, true, uint32_t(theNormals.size()));
+    draco::PointAttribute* aPtr = theMesh.attribute (anId);
+    draco::PointIndex anIndex(0);
+    for (size_t aNormInd = 0; aNormInd < theNormals.size(); ++aNormInd, ++anIndex)
+    {
+      aPtr->SetAttributeValue (aPtr->mapped_index(anIndex), theNormals[aNormInd].GetData());
+    }
+  }
+
+  //! Write texture UV coordinates to Draco mesh
+  static void writeTexCoordsToDracoMesh (draco::Mesh& theMesh,
+                                         const std::vector<Graphic3d_Vec2>& theTexCoord)
+  {
+    if (theTexCoord.empty())
+    {
+      return;
+    }
+
+    draco::PointAttribute anAttr;
+    anAttr.Init (draco::GeometryAttribute::TEX_COORD, 2, draco::DT_FLOAT32, false, sizeof(float) * 2);
+    const int anId = theMesh.AddAttribute (anAttr, true, uint32_t(theTexCoord.size()));
+    draco::PointAttribute* aPtr = theMesh.attribute (anId);
+    draco::PointIndex anIndex(0);
+    for (size_t aTexInd = 0; aTexInd < theTexCoord.size(); ++aTexInd, ++anIndex)
+    {
+      aPtr->SetAttributeValue (aPtr->mapped_index(anIndex), theTexCoord[aTexInd].GetData());
+    }
+  }
+
+  //! Write indices to Draco mesh
+  static void writeIndicesToDracoMesh (draco::Mesh& theMesh,
+                                       const std::vector<Poly_Triangle>& theIndices)
+  {
+    draco::Mesh::Face aFace;
+    int anIndex = 0;
+    for (size_t anInd = 0; anInd < theIndices.size(); ++anInd, ++anIndex)
+    {
+      const Poly_Triangle& anElem = theIndices[anInd];
+      aFace[0] = anElem.Value(1);
+      aFace[1] = anElem.Value(2);
+      aFace[2] = anElem.Value(3);
+      theMesh.SetFace (draco::FaceIndex (anIndex), aFace);
+    }
+  }
+#endif
 }
 
+#ifdef HAVE_DRACO
+//! Functor for parallel execution of encoding meshes to Draco buffers.
+class DracoEncodingFunctor
+{
+public:
+
+  DracoEncodingFunctor (const Message_ProgressRange& theProgress,
+                        draco::Encoder& theDracoEncoder,
+                        const std::vector<std::shared_ptr<RWGltf_CafWriter::Mesh>>& theMeshes,
+                        std::vector<std::shared_ptr<draco::EncoderBuffer>>& theEncoderBuffers)
+  : myProgress(theProgress, "Draco compression", Max(1, int(theMeshes.size()))),
+    myDracoEncoder(&theDracoEncoder),
+    myRanges(0, int(theMeshes.size()) - 1),
+    myMeshes(&theMeshes),
+    myEncoderBuffers(&theEncoderBuffers)
+  { 
+    for (int anIndex = 0; anIndex != int(theMeshes.size()); ++anIndex)
+    {
+      myRanges.SetValue(anIndex, myProgress.Next());
+    }
+  }
+
+  void operator () (int theMeshIndex) const
+  {
+    const std::shared_ptr<RWGltf_CafWriter::Mesh>& aCurrentMesh = myMeshes->at(theMeshIndex);
+    if (aCurrentMesh->NodesVec.empty())
+    {
+      return;
+    }
+
+    Message_ProgressScope aScope(myRanges[theMeshIndex], NULL, 1);
+
+    draco::Mesh aMesh;
+    writeNodesToDracoMesh (aMesh, aCurrentMesh->NodesVec);
+
+    if (!aCurrentMesh->NormalsVec.empty())
+    {
+      writeNormalsToDracoMesh (aMesh, aCurrentMesh->NormalsVec);
+    }
+
+    if (!aCurrentMesh->TexCoordsVec.empty())
+    {
+      writeTexCoordsToDracoMesh (aMesh, aCurrentMesh->TexCoordsVec);
+    }
+
+    writeIndicesToDracoMesh (aMesh, aCurrentMesh->IndicesVec);
+
+    std::shared_ptr<draco::EncoderBuffer> anEncoderBuffer = std::make_shared<draco::EncoderBuffer>();
+    draco::Status aStatus = myDracoEncoder->EncodeMeshToBuffer (aMesh, anEncoderBuffer.get());
+    if (aStatus.ok())
+    {
+      myEncoderBuffers->at(theMeshIndex) = anEncoderBuffer;
+    }
+
+    aScope.Next();
+  }
+
+private:
+  Message_ProgressScope   myProgress;
+  draco::Encoder*         myDracoEncoder;
+  NCollection_Array1<Message_ProgressRange>                   myRanges;
+  const std::vector<std::shared_ptr<RWGltf_CafWriter::Mesh>>* myMeshes;
+  std::vector<std::shared_ptr<draco::EncoderBuffer>>*         myEncoderBuffers;
+};
+#endif
+
 //================================================================
 // Function : Constructor
 // Purpose  :
@@ -101,7 +252,8 @@ RWGltf_CafWriter::RWGltf_CafWriter (const TCollection_AsciiString& theFile,
   myToEmbedTexturesInGlb (true),
   myToMergeFaces (false),
   myToSplitIndices16 (false),
-  myBinDataLen64  (0)
+  myBinDataLen64  (0),
+  myToParallel (false)
 {
   myCSTrsf.SetOutputLengthUnit (1.0); // meters
   myCSTrsf.SetOutputCoordinateSystem (RWMesh_CoordinateSystem_glTF);
@@ -150,7 +302,8 @@ Standard_Boolean RWGltf_CafWriter::toSkipFaceMesh (const RWMesh_FaceIterator& th
 void RWGltf_CafWriter::saveNodes (RWGltf_GltfFace& theGltfFace,
                                   std::ostream& theBinFile,
                                   const RWMesh_FaceIterator& theFaceIter,
-                                  Standard_Integer& theAccessorNb) const
+                                  Standard_Integer& theAccessorNb,
+                                  const std::shared_ptr<RWGltf_CafWriter::Mesh>& theMesh) const
 {
   if (theGltfFace.NodePos.Id == RWGltf_GltfAccessor::INVALID_ID)
   {
@@ -161,8 +314,11 @@ void RWGltf_CafWriter::saveNodes (RWGltf_GltfFace& theGltfFace,
   }
   else
   {
-    const int64_t aPos = theGltfFace.NodePos.ByteOffset + myBuffViewPos.ByteOffset + theGltfFace.NodePos.Count * sizeof(Graphic3d_Vec3);
-    Standard_ASSERT_RAISE (aPos == (int64_t )theBinFile.tellp(), "wrong offset");
+    if (theMesh.get() == nullptr)
+    {
+      const int64_t aPos = theGltfFace.NodePos.ByteOffset + myBuffViewPos.ByteOffset + theGltfFace.NodePos.Count * sizeof(Graphic3d_Vec3);
+      Standard_ASSERT_RAISE(aPos == (int64_t)theBinFile.tellp(), "wrong offset");
+    }
   }
   theGltfFace.NodePos.Count += theFaceIter.NbNodes();
 
@@ -172,7 +328,14 @@ void RWGltf_CafWriter::saveNodes (RWGltf_GltfFace& theGltfFace,
     gp_XYZ aNode = theFaceIter.NodeTransformed (aNodeIter).XYZ();
     myCSTrsf.TransformPosition (aNode);
     theGltfFace.NodePos.BndBox.Add (Graphic3d_Vec3d(aNode.X(), aNode.Y(), aNode.Z()));
-    writeVec3 (theBinFile, aNode);
+    if (theMesh.get() != nullptr)
+    {
+      theMesh->NodesVec.push_back(Graphic3d_Vec3(float(aNode.X()), float(aNode.Y()), float(aNode.Z())));
+    }
+    else
+    {
+      writeVec3(theBinFile, aNode);
+    }
   }
 }
 
@@ -183,7 +346,8 @@ void RWGltf_CafWriter::saveNodes (RWGltf_GltfFace& theGltfFace,
 void RWGltf_CafWriter::saveNormals (RWGltf_GltfFace& theGltfFace,
                                     std::ostream& theBinFile,
                                     RWMesh_FaceIterator& theFaceIter,
-                                    Standard_Integer& theAccessorNb) const
+                                    Standard_Integer& theAccessorNb,
+                                    const std::shared_ptr<RWGltf_CafWriter::Mesh>& theMesh) const
 {
   if (!theFaceIter.HasNormals())
   {
@@ -199,8 +363,11 @@ void RWGltf_CafWriter::saveNormals (RWGltf_GltfFace& theGltfFace,
   }
   else
   {
-    const int64_t aPos = theGltfFace.NodeNorm.ByteOffset + myBuffViewNorm.ByteOffset + theGltfFace.NodeNorm.Count * sizeof(Graphic3d_Vec3);
-    Standard_ASSERT_RAISE (aPos == (int64_t )theBinFile.tellp(), "wrong offset");
+    if (theMesh.get() == nullptr)
+    {
+      const int64_t aPos = theGltfFace.NodeNorm.ByteOffset + myBuffViewNorm.ByteOffset + theGltfFace.NodeNorm.Count * sizeof(Graphic3d_Vec3);
+      Standard_ASSERT_RAISE(aPos == (int64_t)theBinFile.tellp(), "wrong offset");
+    }
   }
   theGltfFace.NodeNorm.Count += theFaceIter.NbNodes();
 
@@ -210,7 +377,14 @@ void RWGltf_CafWriter::saveNormals (RWGltf_GltfFace& theGltfFace,
     const gp_Dir aNormal = theFaceIter.NormalTransformed (aNodeIter);
     Graphic3d_Vec3 aVecNormal ((float )aNormal.X(), (float )aNormal.Y(), (float )aNormal.Z());
     myCSTrsf.TransformNormal (aVecNormal);
-    writeVec3 (theBinFile, aVecNormal);
+    if (theMesh.get() != nullptr)
+    {
+      theMesh->NormalsVec.push_back(aVecNormal);
+    }
+    else
+    {
+      writeVec3(theBinFile, aVecNormal);
+    }
   }
 }
 
@@ -221,7 +395,8 @@ void RWGltf_CafWriter::saveNormals (RWGltf_GltfFace& theGltfFace,
 void RWGltf_CafWriter::saveTextCoords (RWGltf_GltfFace& theGltfFace,
                                        std::ostream& theBinFile,
                                        const RWMesh_FaceIterator& theFaceIter,
-                                       Standard_Integer& theAccessorNb) const
+                                       Standard_Integer& theAccessorNb,
+                                       const std::shared_ptr<RWGltf_CafWriter::Mesh>& theMesh) const
 {
   if (!theFaceIter.HasTexCoords())
   {
@@ -253,8 +428,11 @@ void RWGltf_CafWriter::saveTextCoords (RWGltf_GltfFace& theGltfFace,
   }
   else
   {
-    const int64_t aPos = theGltfFace.NodeUV.ByteOffset + myBuffViewTextCoord.ByteOffset + theGltfFace.NodeUV.Count * sizeof(Graphic3d_Vec2);
-    Standard_ASSERT_RAISE (aPos == (int64_t )theBinFile.tellp(), "wrong offset");
+    if (theMesh.get() == nullptr)
+    {
+      const int64_t aPos = theGltfFace.NodeUV.ByteOffset + myBuffViewTextCoord.ByteOffset + theGltfFace.NodeUV.Count * sizeof(Graphic3d_Vec2);
+      Standard_ASSERT_RAISE(aPos == (int64_t)theBinFile.tellp(), "wrong offset");
+    }
   }
   theGltfFace.NodeUV.Count += theFaceIter.NbNodes();
 
@@ -263,7 +441,14 @@ void RWGltf_CafWriter::saveTextCoords (RWGltf_GltfFace& theGltfFace,
   {
     gp_Pnt2d aTexCoord = theFaceIter.NodeTexCoord (aNodeIter);
     aTexCoord.SetY (1.0 - aTexCoord.Y());
-    writeVec2 (theBinFile, aTexCoord.XY());
+    if (theMesh.get() != nullptr)
+    {
+      theMesh->TexCoordsVec.push_back(Graphic3d_Vec2((float)aTexCoord.X(), (float)aTexCoord.Y()));
+    }
+    else
+    {
+      writeVec2(theBinFile, aTexCoord.XY());
+    }
   }
 }
 
@@ -274,7 +459,8 @@ void RWGltf_CafWriter::saveTextCoords (RWGltf_GltfFace& theGltfFace,
 void RWGltf_CafWriter::saveIndices (RWGltf_GltfFace& theGltfFace,
                                     std::ostream& theBinFile,
                                     const RWMesh_FaceIterator& theFaceIter,
-                                    Standard_Integer& theAccessorNb)
+                                    Standard_Integer& theAccessorNb,
+                                    const std::shared_ptr<RWGltf_CafWriter::Mesh>& theMesh)
 {
   if (theGltfFace.Indices.Id == RWGltf_GltfAccessor::INVALID_ID)
   {
@@ -287,11 +473,14 @@ void RWGltf_CafWriter::saveIndices (RWGltf_GltfFace& theGltfFace,
   }
   else
   {
-    const int64_t aRefPos = (int64_t )theBinFile.tellp();
-    const int64_t aPos = theGltfFace.Indices.ByteOffset
-                       + myBuffViewInd.ByteOffset
-                       + theGltfFace.Indices.Count * (theGltfFace.Indices.ComponentType == RWGltf_GltfAccessorCompType_UInt32 ? sizeof(uint32_t) : sizeof(uint16_t));
-    Standard_ASSERT_RAISE (aPos == aRefPos, "wrong offset");
+    if (theMesh.get() == nullptr)
+    {
+      const int64_t aRefPos = (int64_t )theBinFile.tellp();
+      const int64_t aPos = theGltfFace.Indices.ByteOffset
+                         + myBuffViewInd.ByteOffset
+                         + theGltfFace.Indices.Count * (theGltfFace.Indices.ComponentType == RWGltf_GltfAccessorCompType_UInt32 ? sizeof(uint32_t) : sizeof(uint16_t));
+      Standard_ASSERT_RAISE (aPos == aRefPos, "wrong offset");
+    }
   }
 
   const Standard_Integer aNodeFirst = theGltfFace.NbIndexedNodes - theFaceIter.ElemLower();
@@ -306,13 +495,20 @@ void RWGltf_CafWriter::saveIndices (RWGltf_GltfFace& theGltfFace,
     aTri(1) += aNodeFirst;
     aTri(2) += aNodeFirst;
     aTri(3) += aNodeFirst;
-    if (theGltfFace.Indices.ComponentType == RWGltf_GltfAccessorCompType_UInt16)
+    if (theMesh.get() != nullptr)
     {
-      writeTriangle16 (theBinFile, NCollection_Vec3<uint16_t>((uint16_t)aTri(1), (uint16_t)aTri(2), (uint16_t)aTri(3)));
+      theMesh->IndicesVec.push_back(aTri);
     }
     else
     {
-      writeTriangle32 (theBinFile, Graphic3d_Vec3i (aTri(1), aTri(2), aTri(3)));
+      if (theGltfFace.Indices.ComponentType == RWGltf_GltfAccessorCompType_UInt16)
+      {
+        writeTriangle16(theBinFile, NCollection_Vec3<uint16_t>((uint16_t)aTri(1), (uint16_t)aTri(2), (uint16_t)aTri(3)));
+      }
+      else
+      {
+        writeTriangle32(theBinFile, Graphic3d_Vec3i(aTri(1), aTri(2), aTri(3)));
+      }
     }
   }
 }
@@ -373,6 +569,14 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
                                      const TColStd_MapOfAsciiString* theLabelFilter,
                                      const Message_ProgressRange& theProgress)
 {
+#ifndef HAVE_DRACO
+  if (myDracoParameters.DracoCompression)
+  {
+    Message::SendFail ("Error: cannot use Draco compression, Draco library missing.");
+    return false;
+  }
+#endif
+
   myBuffViewPos.Id               = RWGltf_GltfAccessor::INVALID_ID;
   myBuffViewPos.ByteOffset       = 0;
   myBuffViewPos.ByteLength       = 0;
@@ -396,11 +600,15 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
   myBuffViewInd.ByteLength       = 0;
   myBuffViewInd.Target           = RWGltf_GltfBufferViewTarget_ELEMENT_ARRAY_BUFFER;
 
+  myBuffViewsDraco.clear();
+
   myBinDataMap.Clear();
   myBinDataLen64 = 0;
 
+  Message_ProgressScope aScope(theProgress, "Write binary data", myDracoParameters.DracoCompression ? 2 : 1);
+
   const Handle(OSD_FileSystem)& aFileSystem = OSD_FileSystem::DefaultFileSystem();
-  opencascade::std::shared_ptr<std::ostream> aBinFile = aFileSystem->OpenOStream (myBinFileNameFull, std::ios::out | std::ios::binary);
+  std::shared_ptr<std::ostream> aBinFile = aFileSystem->OpenOStream (myBinFileNameFull, std::ios::out | std::ios::binary);
   if (aBinFile.get() == NULL
    || !aBinFile->good())
   {
@@ -408,7 +616,7 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
     return false;
   }
 
-  Message_ProgressScope aPSentryBin (theProgress, "Binary data", 4);
+  Message_ProgressScope aPSentryBin (aScope.Next(), "Binary data", 4);
   const RWGltf_GltfArrayType anArrTypes[4] =
   {
     RWGltf_GltfArrayType_Position,
@@ -418,7 +626,7 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
   };
 
   // dispatch faces
-  NCollection_DataMap<XCAFPrs_Style, Handle(RWGltf_GltfFace), XCAFPrs_Style> aMergedFaces;
+  NCollection_DataMap<XCAFPrs_Style, Handle(RWGltf_GltfFace)> aMergedFaces;
   for (XCAFPrs_DocumentExplorer aDocExplorer (theDocument, theRootLabels, XCAFPrs_DocumentExplorerFlags_OnlyLeafNodes);
        aDocExplorer.More() && aPSentryBin.More(); aDocExplorer.Next())
   {
@@ -508,6 +716,7 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
     }
   }
 
+  std::vector<std::shared_ptr<RWGltf_CafWriter::Mesh>> aMeshes;
   Standard_Integer aNbAccessors = 0;
   NCollection_Map<Handle(RWGltf_GltfFaceList)> aWrittenFaces;
   NCollection_DataMap<TopoDS_Shape, Handle(RWGltf_GltfFace), TopTools_ShapeMapHasher> aWrittenPrimData;
@@ -526,6 +735,9 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
     aBuffView->ByteOffset = aBinFile->tellp();
     aWrittenFaces.Clear (false);
     aWrittenPrimData.Clear (false);
+#ifdef HAVE_DRACO
+    size_t aMeshIndex = 0;
+#endif
     for (ShapeToGltfFaceMap::Iterator aBinDataIter (myBinDataMap); aBinDataIter.More() && aPSentryBin.More(); aBinDataIter.Next())
     {
       const Handle(RWGltf_GltfFaceList)& aGltfFaceList = aBinDataIter.Value();
@@ -533,6 +745,23 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
       {
         continue;
       }
+      
+      std::shared_ptr<RWGltf_CafWriter::Mesh> aMeshPtr;
+#ifdef HAVE_DRACO
+      ++aMeshIndex;
+      if (myDracoParameters.DracoCompression)
+      {
+        if (aMeshIndex <= aMeshes.size())
+        {
+          aMeshPtr = aMeshes.at(aMeshIndex - 1);
+        }
+        else
+        {
+          aMeshes.push_back(std::make_shared<RWGltf_CafWriter::Mesh>(RWGltf_CafWriter::Mesh()));
+          aMeshPtr = aMeshes.back();
+        }
+      }
+#endif
 
       for (RWGltf_GltfFaceList::Iterator aGltfFaceIter (*aGltfFaceList); aGltfFaceIter.More() && aPSentryBin.More(); aGltfFaceIter.Next())
       {
@@ -579,22 +808,22 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
             case RWGltf_GltfArrayType_Position:
             {
               aGltfFace->NbIndexedNodes = 0; // reset to zero before RWGltf_GltfArrayType_Indices step
-              saveNodes (*aGltfFace, *aBinFile, aFaceIter, aNbAccessors);
+              saveNodes (*aGltfFace, *aBinFile, aFaceIter, aNbAccessors, aMeshPtr);
               break;
             }
             case RWGltf_GltfArrayType_Normal:
             {
-              saveNormals (*aGltfFace, *aBinFile, aFaceIter, aNbAccessors);
+              saveNormals (*aGltfFace, *aBinFile, aFaceIter, aNbAccessors, aMeshPtr);
               break;
             }
             case RWGltf_GltfArrayType_TCoord0:
             {
-              saveTextCoords (*aGltfFace, *aBinFile, aFaceIter, aNbAccessors);
+              saveTextCoords (*aGltfFace, *aBinFile, aFaceIter, aNbAccessors, aMeshPtr);
               break;
             }
             case RWGltf_GltfArrayType_Indices:
             {
-              saveIndices (*aGltfFace, *aBinFile, aFaceIter, aNbAccessors);
+              saveIndices (*aGltfFace, *aBinFile, aFaceIter, aNbAccessors, aMeshPtr);
               break;
             }
             default:
@@ -611,16 +840,22 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
         }
 
         // add alignment by 4 bytes (might happen on RWGltf_GltfAccessorCompType_UInt16 indices)
-        int64_t aContentLen64 = (int64_t)aBinFile->tellp();
-        while (aContentLen64 % 4 != 0)
+        if (!myDracoParameters.DracoCompression)
         {
-          aBinFile->write (" ", 1);
-          ++aContentLen64;
+          int64_t aContentLen64 = (int64_t)aBinFile->tellp();
+          while (aContentLen64 % 4 != 0)
+          {
+            aBinFile->write(" ", 1);
+            ++aContentLen64;
+          }
         }
       }
     }
 
-    aBuffView->ByteLength = (int64_t )aBinFile->tellp() - aBuffView->ByteOffset;
+    if (!myDracoParameters.DracoCompression)
+    {
+      aBuffView->ByteLength = (int64_t)aBinFile->tellp() - aBuffView->ByteOffset;
+    }
     if (!aPSentryBin.More())
     {
       return false;
@@ -629,6 +864,56 @@ bool RWGltf_CafWriter::writeBinData (const Handle(TDocStd_Document)& theDocument
     aPSentryBin.Next();
   }
 
+  if (myDracoParameters.DracoCompression)
+  {
+#ifdef HAVE_DRACO
+    OSD_Timer aDracoTimer;
+    aDracoTimer.Start();
+    draco::Encoder aDracoEncoder;
+    aDracoEncoder.SetAttributeQuantization (draco::GeometryAttribute::POSITION,  myDracoParameters.QuantizePositionBits);
+    aDracoEncoder.SetAttributeQuantization (draco::GeometryAttribute::NORMAL,    myDracoParameters.QuantizeNormalBits);
+    aDracoEncoder.SetAttributeQuantization (draco::GeometryAttribute::TEX_COORD, myDracoParameters.QuantizeTexcoordBits);
+    aDracoEncoder.SetAttributeQuantization (draco::GeometryAttribute::COLOR,     myDracoParameters.QuantizeColorBits);
+    aDracoEncoder.SetAttributeQuantization (draco::GeometryAttribute::GENERIC,   myDracoParameters.QuantizeGenericBits);
+    aDracoEncoder.SetSpeedOptions (myDracoParameters.CompressionLevel, myDracoParameters.CompressionLevel);
+
+    std::vector<std::shared_ptr<draco::EncoderBuffer>> anEncoderBuffers(aMeshes.size());
+    DracoEncodingFunctor aFunctor (aScope.Next(), aDracoEncoder, aMeshes, anEncoderBuffers);
+    OSD_Parallel::For (0, int(aMeshes.size()), aFunctor, !myToParallel);
+
+    for (size_t aBuffInd = 0; aBuffInd != anEncoderBuffers.size(); ++aBuffInd)
+    {
+      if (anEncoderBuffers.at(aBuffInd).get() == nullptr)
+      {
+        Message::SendFail(TCollection_AsciiString("Error: mesh not encoded in draco buffer."));
+        return false;
+      }
+      RWGltf_GltfBufferView aBuffViewDraco;
+      aBuffViewDraco.Id = (int)aBuffInd;
+      aBuffViewDraco.ByteOffset = aBinFile->tellp();
+      const draco::EncoderBuffer& anEncoderBuff = *anEncoderBuffers.at(aBuffInd);
+      aBinFile->write(anEncoderBuff.data(), std::streamsize(anEncoderBuff.size()));
+      if (!aBinFile->good())
+      {
+        Message::SendFail (TCollection_AsciiString("File '") + myBinFileNameFull + "' cannot be written");
+        return false;
+      }
+
+      int64_t aLength = (int64_t)aBinFile->tellp();
+      while (aLength % 4 != 0)
+      {
+        aBinFile->write(" ", 1);
+        ++aLength;
+      }
+
+      aBuffViewDraco.ByteLength = aLength - aBuffViewDraco.ByteOffset;
+      myBuffViewsDraco.push_back (aBuffViewDraco);
+    }
+    aDracoTimer.Stop();
+    Message::SendInfo (TCollection_AsciiString("Draco compression time: ") + aDracoTimer.ElapsedTime() + " s");
+#endif
+  }
+
   if (myIsBinary
    && myToEmbedTexturesInGlb)
   {
@@ -707,7 +992,7 @@ bool RWGltf_CafWriter::writeJson (const Handle(TDocStd_Document)&  theDocument,
 
   const TCollection_AsciiString aFileNameGltf = myFile;
   const Handle(OSD_FileSystem)& aFileSystem = OSD_FileSystem::DefaultFileSystem();
-  opencascade::std::shared_ptr<std::ostream> aGltfContentFile = aFileSystem->OpenOStream (aFileNameGltf, std::ios::out | std::ios::binary);
+  std::shared_ptr<std::ostream> aGltfContentFile = aFileSystem->OpenOStream (aFileNameGltf, std::ios::out | std::ios::binary);
   if (aGltfContentFile.get() == NULL
    || !aGltfContentFile->good())
   {
@@ -827,7 +1112,7 @@ bool RWGltf_CafWriter::writeJson (const Handle(TDocStd_Document)&  theDocument,
   if (aFullLen64 < std::numeric_limits<uint32_t>::max())
   {
     {
-      opencascade::std::shared_ptr<std::istream> aBinFile = aFileSystem->OpenIStream (myBinFileNameFull, std::ios::in | std::ios::binary);
+      std::shared_ptr<std::istream> aBinFile = aFileSystem->OpenIStream (myBinFileNameFull, std::ios::in | std::ios::binary);
       if (aBinFile.get() == NULL || !aBinFile->good())
       {
         Message::SendFail (TCollection_AsciiString ("File '") + myBinFileNameFull + "' cannot be opened");
@@ -1020,10 +1305,13 @@ void RWGltf_CafWriter::writePositions (const RWGltf_GltfFace& theGltfFace)
   }
 
   myWriter->StartObject();
-  myWriter->Key    ("bufferView");
-  myWriter->Int    (myBuffViewPos.Id);
-  myWriter->Key    ("byteOffset");
-  myWriter->Int64  (theGltfFace.NodePos.ByteOffset);
+  if (!myDracoParameters.DracoCompression)
+  {
+    myWriter->Key    ("bufferView");
+    myWriter->Int    (myBuffViewPos.Id);
+    myWriter->Key    ("byteOffset");
+    myWriter->Int64  (theGltfFace.NodePos.ByteOffset);
+  }
   myWriter->Key    ("componentType");
   myWriter->Int    (theGltfFace.NodePos.ComponentType);
   myWriter->Key    ("count");
@@ -1068,10 +1356,13 @@ void RWGltf_CafWriter::writeNormals (const RWGltf_GltfFace& theGltfFace)
   }
 
   myWriter->StartObject();
-  myWriter->Key    ("bufferView");
-  myWriter->Int    (myBuffViewNorm.Id);
-  myWriter->Key    ("byteOffset");
-  myWriter->Int64  (theGltfFace.NodeNorm.ByteOffset);
+  if (!myDracoParameters.DracoCompression)
+  {
+    myWriter->Key    ("bufferView");
+    myWriter->Int    (myBuffViewNorm.Id);
+    myWriter->Key    ("byteOffset");
+    myWriter->Int64  (theGltfFace.NodeNorm.ByteOffset);
+  }
   myWriter->Key    ("componentType");
   myWriter->Int    (theGltfFace.NodeNorm.ComponentType);
   myWriter->Key    ("count");
@@ -1116,10 +1407,13 @@ void RWGltf_CafWriter::writeTextCoords (const RWGltf_GltfFace& theGltfFace)
   }
 
   myWriter->StartObject();
-  myWriter->Key    ("bufferView");
-  myWriter->Int    (myBuffViewTextCoord.Id);
-  myWriter->Key    ("byteOffset");
-  myWriter->Int64  (theGltfFace.NodeUV.ByteOffset);
+  if (!myDracoParameters.DracoCompression)
+  {
+    myWriter->Key    ("bufferView");
+    myWriter->Int    (myBuffViewTextCoord.Id);
+    myWriter->Key    ("byteOffset");
+    myWriter->Int64  (theGltfFace.NodeUV.ByteOffset);
+  }
   myWriter->Key    ("componentType");
   myWriter->Int    (theGltfFace.NodeUV.ComponentType);
   myWriter->Key    ("count");
@@ -1164,10 +1458,13 @@ void RWGltf_CafWriter::writeIndices (const RWGltf_GltfFace& theGltfFace)
   }
 
   myWriter->StartObject();
-  myWriter->Key    ("bufferView");
-  myWriter->Int    (myBuffViewInd.Id);
-  myWriter->Key    ("byteOffset");
-  myWriter->Int64  (theGltfFace.Indices.ByteOffset);
+  if (!myDracoParameters.DracoCompression)
+  {
+    myWriter->Key("bufferView");
+    myWriter->Int(myBuffViewInd.Id);
+    myWriter->Key("byteOffset");
+    myWriter->Int64(theGltfFace.Indices.ByteOffset);
+  }
   myWriter->Key    ("componentType");
   myWriter->Int    (theGltfFace.Indices.ComponentType);
   myWriter->Key    ("count");
@@ -1309,6 +1606,24 @@ void RWGltf_CafWriter::writeBufferViews (const Standard_Integer theBinDataBuffer
     myWriter->Int    (myBuffViewInd.Target);
     myWriter->EndObject();
   }
+  if (myDracoParameters.DracoCompression)
+  {
+    for (size_t aBufInd = 0; aBufInd != myBuffViewsDraco.size(); ++aBufInd)
+    {
+      if (myBuffViewsDraco[aBufInd].Id != RWGltf_GltfAccessor::INVALID_ID)
+      {
+        aBuffViewId++;
+        myWriter->StartObject();
+        myWriter->Key("buffer");
+        myWriter->Int(theBinDataBufferId);
+        myWriter->Key("byteLength");
+        myWriter->Int64(myBuffViewsDraco[aBufInd].ByteLength);
+        myWriter->Key("byteOffset");
+        myWriter->Int64(myBuffViewsDraco[aBufInd].ByteOffset);
+        myWriter->EndObject();
+      }
+    }
+  }
 
   myMaterialMap->FlushGlbBufferViews (myWriter.get(), theBinDataBufferId, aBuffViewId);
 
@@ -1352,7 +1667,28 @@ void RWGltf_CafWriter::writeBuffers()
 // =======================================================================
 void RWGltf_CafWriter::writeExtensions()
 {
+#ifdef HAVE_RAPIDJSON
   Standard_ProgramError_Raise_if (myWriter.get() == NULL, "Internal error: RWGltf_CafWriter::writeExtensions()");
+
+  if (myDracoParameters.DracoCompression)
+  {
+    myWriter->Key(RWGltf_GltfRootElementName(RWGltf_GltfRootElement_ExtensionsUsed));
+
+    myWriter->StartArray();
+    {
+      myWriter->Key("KHR_draco_mesh_compression");
+    }
+    myWriter->EndArray();
+
+    myWriter->Key(RWGltf_GltfRootElementName(RWGltf_GltfRootElement_ExtensionsRequired));
+
+    myWriter->StartArray();
+    {
+      myWriter->Key("KHR_draco_mesh_compression");
+    }
+    myWriter->EndArray();
+  }
+#endif
 }
 
 // =======================================================================
@@ -1425,6 +1761,7 @@ void RWGltf_CafWriter::writeMaterials (const RWGltf_GltfSceneNodeMap& theSceneNo
 // =======================================================================
 void RWGltf_CafWriter::writePrimArray (const RWGltf_GltfFace& theGltfFace,
                                        const TCollection_AsciiString& theName,
+                                       const int theDracoBufInd,
                                        bool& theToStartPrims)
 {
 #ifdef HAVE_RAPIDJSON
@@ -1471,12 +1808,48 @@ void RWGltf_CafWriter::writePrimArray (const RWGltf_GltfFace& theGltfFace,
     }
     myWriter->Key ("mode");
     myWriter->Int (RWGltf_GltfPrimitiveMode_Triangles);
+
+    if (myDracoParameters.DracoCompression)
+    {
+      myWriter->Key("extensions");
+      myWriter->StartObject();
+      {
+        myWriter->Key("KHR_draco_mesh_compression");
+        myWriter->StartObject();
+        myWriter->Key("bufferView");
+        myWriter->Int(myBuffViewsDraco[theDracoBufInd].Id);
+        myWriter->Key("attributes");
+        myWriter->StartObject();
+        {
+          int anAttrInd = 0;
+          if (theGltfFace.NodePos.Id != RWGltf_GltfAccessor::INVALID_ID)
+          {
+            myWriter->Key("POSITION");
+            myWriter->Int(anAttrInd++);
+          }
+          if (theGltfFace.NodeNorm.Id != RWGltf_GltfAccessor::INVALID_ID)
+          {
+            myWriter->Key("NORMAL");
+            myWriter->Int(anAttrInd++);
+          }
+          if (theGltfFace.NodeUV.Id != RWGltf_GltfAccessor::INVALID_ID)
+          {
+            myWriter->Key("TEXCOORD_0");
+            myWriter->Int(anAttrInd++);
+          }
+        }
+        myWriter->EndObject();
+        myWriter->EndObject();
+      }
+      myWriter->EndObject();
+    }
   }
   myWriter->EndObject();
 #else
   (void )theGltfFace;
   (void )theName;
   (void )theToStartPrims;
+  (void )theDracoBufInd;
 #endif
 }
 
@@ -1492,6 +1865,8 @@ void RWGltf_CafWriter::writeMeshes (const RWGltf_GltfSceneNodeMap& theSceneNodeM
   myWriter->Key (RWGltf_GltfRootElementName (RWGltf_GltfRootElement_Meshes));
   myWriter->StartArray();
 
+  int aDracoBufInd = 0;
+  NCollection_IndexedDataMap<int, int> aDracoBufIndMap;
   NCollection_Map<Handle(RWGltf_GltfFaceList)> aWrittenFaces;
   for (RWGltf_GltfSceneNodeMap::Iterator aSceneNodeIter (theSceneNodeMap); aSceneNodeIter.More(); aSceneNodeIter.Next())
   {
@@ -1522,7 +1897,23 @@ void RWGltf_CafWriter::writeMeshes (const RWGltf_GltfSceneNodeMap& theSceneNodeM
       for (RWGltf_GltfFaceList::Iterator aFaceGroupIter (*aGltfFaceList); aFaceGroupIter.More(); aFaceGroupIter.Next())
       {
         const Handle(RWGltf_GltfFace)& aGltfFace = aFaceGroupIter.Value();
-        writePrimArray (*aGltfFace, aNodeName, toStartPrims);
+        const int aPrevSize = aDracoBufIndMap.Size();
+        const int aTempDracoBufInd = aDracoBufInd;
+        if (myDracoParameters.DracoCompression
+        && !aDracoBufIndMap.FindFromKey (aGltfFace->NodePos.Id, aDracoBufInd))
+        {
+          aDracoBufIndMap.Add (aGltfFace->NodePos.Id, aDracoBufInd);
+        }
+
+        writePrimArray (*aGltfFace, aNodeName, aDracoBufInd, toStartPrims);
+        if (aTempDracoBufInd != aDracoBufInd)
+        {
+          aDracoBufInd = aTempDracoBufInd;
+        }
+        if (!myDracoParameters.DracoCompression || aDracoBufIndMap.Size() > aPrevSize)
+        {
+          ++aDracoBufInd;
+        }
       }
     }
     else
@@ -1542,7 +1933,23 @@ void RWGltf_CafWriter::writeMeshes (const RWGltf_GltfSceneNodeMap& theSceneNodeM
         }
 
         const Handle(RWGltf_GltfFace)& aGltfFace = aGltfFaceList->First();
-        writePrimArray (*aGltfFace, aNodeName, toStartPrims);
+        const int aPrevSize = aDracoBufIndMap.Size();
+        const int aTempDracoBufInd = aDracoBufInd;
+        if (myDracoParameters.DracoCompression
+        && !aDracoBufIndMap.FindFromKey(aGltfFace->NodePos.Id, aDracoBufInd))
+        {
+          aDracoBufIndMap.Add(aGltfFace->NodePos.Id, aDracoBufInd);
+        }
+
+        writePrimArray (*aGltfFace, aNodeName, aDracoBufInd, toStartPrims);
+        if (aTempDracoBufInd != aDracoBufInd)
+        {
+          aDracoBufInd = aTempDracoBufInd;
+        }
+        if (!myDracoParameters.DracoCompression || aDracoBufIndMap.Size() > aPrevSize)
+        {
+          ++aDracoBufInd;
+        }
       }
     }
 
