@@ -18,7 +18,6 @@
 
 #include <Message.hxx>
 #include <Message_Messenger.hxx>
-#include <Message_ProgressScope.hxx>
 #include <BRep_Builder.hxx>
 #include <OSD_Path.hxx>
 #include <OSD_Timer.hxx>
@@ -99,6 +98,20 @@ TopoDS_Shape RWMesh_CafReader::SingleShape() const
 Standard_Boolean RWMesh_CafReader::perform (const TCollection_AsciiString& theFile,
                                             const Message_ProgressRange& theProgress,
                                             const Standard_Boolean theToProbe)
+{
+  std::ifstream aStream;
+  OSD_OpenStream(aStream, theFile, std::ios_base::in | std::ios_base::binary);
+  return perform(aStream, theFile, theProgress, theToProbe);
+}
+
+// =======================================================================
+// function : perform
+// purpose  :
+// =======================================================================
+Standard_Boolean RWMesh_CafReader::perform (std::istream& theStream,
+                                            const TCollection_AsciiString& theFile,
+                                            const Message_ProgressRange& theProgress,
+                                            const Standard_Boolean theToProbe)
 {
   Standard_Integer aNewRootsLower = 1;
   if (!myXdeDoc.IsNull())
@@ -110,7 +123,7 @@ Standard_Boolean RWMesh_CafReader::perform (const TCollection_AsciiString& theFi
 
   OSD_Timer aLoadingTimer;
   aLoadingTimer.Start();
-  const Standard_Boolean isDone = performMesh (theFile, theProgress, theToProbe);
+  const Standard_Boolean isDone = performMesh (theStream, theFile, theProgress, theToProbe);
   if (theToProbe || theProgress.UserBreak())
   {
     return isDone;
@@ -126,7 +139,7 @@ Standard_Boolean RWMesh_CafReader::perform (const TCollection_AsciiString& theFi
   }
 
   TopLoc_Location aDummyLoc;
-  Standard_Integer aNbNodes = 0, aNbElems = 0, aNbFaces = 0;
+  Standard_Integer aNbNodes = 0, aNbElems = 0;
   for (TopTools_SequenceOfShape::Iterator aRootIter (myRootShapes); aRootIter.More(); aRootIter.Next())
   {
     for (TopExp_Explorer aFaceIter (aRootIter.Value(), TopAbs_FACE); aFaceIter.More(); aFaceIter.Next())
@@ -134,7 +147,6 @@ Standard_Boolean RWMesh_CafReader::perform (const TCollection_AsciiString& theFi
       const TopoDS_Face& aFace = TopoDS::Face (aFaceIter.Current());
       if (const Handle(Poly_Triangulation)& aPolyTri = BRep_Tool::Triangulation (aFace, aDummyLoc))
       {
-        ++aNbFaces;
         aNbNodes += aPolyTri->NbNodes();
         aNbElems += aPolyTri->NbTriangles();
       }
