@@ -15,15 +15,12 @@
 #include <Interface_Check.hxx>
 #include <Interface_EntityIterator.hxx>
 #include <RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface.hxx>
-#include <StepData_Logical.hxx>
 #include <StepData_StepReaderData.hxx>
 #include <StepData_StepWriter.hxx>
-#include <StepGeom_BezierSurface.hxx>
 #include <StepGeom_BezierSurfaceAndRationalBSplineSurface.hxx>
 #include <StepGeom_BSplineSurfaceForm.hxx>
 #include <StepGeom_CartesianPoint.hxx>
 #include <StepGeom_HArray2OfCartesianPoint.hxx>
-#include <StepGeom_RationalBSplineSurface.hxx>
 #include <TColStd_HArray2OfReal.hxx>
 
 // --- Enum : BSplineSurfaceForm ---
