@@ -15,15 +15,9 @@
 #include <Interface_Check.hxx>
 #include <Interface_EntityIterator.hxx>
 #include <RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve.hxx>
-#include <StepData_Logical.hxx>
 #include <StepData_StepReaderData.hxx>
 #include <StepData_StepWriter.hxx>
-#include <StepGeom_BSplineCurveForm.hxx>
-#include <StepGeom_CartesianPoint.hxx>
-#include <StepGeom_HArray1OfCartesianPoint.hxx>
-#include <StepGeom_QuasiUniformCurve.hxx>
 #include <StepGeom_QuasiUniformCurveAndRationalBSplineCurve.hxx>
-#include <StepGeom_RationalBSplineCurve.hxx>
 #include <TColStd_HArray1OfReal.hxx>
 
 // --- Enum : BSplineCurveForm ---
