@@ -15,12 +15,8 @@
 #include <Interface_Check.hxx>
 #include <Interface_EntityIterator.hxx>
 #include <RWStepGeom_RWUniformCurveAndRationalBSplineCurve.hxx>
-#include <StepData_Logical.hxx>
 #include <StepData_StepReaderData.hxx>
 #include <StepData_StepWriter.hxx>
-#include <StepGeom_BSplineCurveForm.hxx>
-#include <StepGeom_CartesianPoint.hxx>
-#include <StepGeom_HArray1OfCartesianPoint.hxx>
 #include <StepGeom_RationalBSplineCurve.hxx>
 #include <StepGeom_UniformCurve.hxx>
 #include <StepGeom_UniformCurveAndRationalBSplineCurve.hxx>
