@@ -14,9 +14,7 @@
 // commercial license or contractual agreement.
 
 
-#include <Standard_Type.hxx>
 #include <STEPCAFControl_ExternFile.hxx>
-#include <TCollection_HAsciiString.hxx>
 #include <TDF_Label.hxx>
 #include <XSControl_WorkSession.hxx>
 
