@@ -21,44 +21,32 @@
 #include <Interface_Macros.hxx>
 #include <Interface_Static.hxx>
 #include <Message.hxx>
-#include <Message_Messenger.hxx>
 #include <StepBasic_DerivedUnit.hxx>
 #include <StepBasic_DerivedUnitElement.hxx>
 #include <StepBasic_HArray1OfDerivedUnitElement.hxx>
 #include <StepBasic_MeasureValueMember.hxx>
-#include <StepBasic_MeasureWithUnit.hxx>
 #include <StepBasic_ProductDefinition.hxx>
-#include <StepBasic_SiUnitAndAreaUnit.hxx>
 #include <StepBasic_SiUnitAndLengthUnit.hxx>
-#include <StepBasic_Unit.hxx>
-#include <STEPConstruct.hxx>
 #include <STEPConstruct_UnitContext.hxx>
 #include <STEPConstruct_ValidationProps.hxx>
+#include <StepData_Factors.hxx>
 #include <StepData_StepModel.hxx>
 #include <StepGeom_CartesianPoint.hxx>
 #include <StepGeom_GeometricRepresentationContextAndGlobalUnitAssignedContext.hxx>
 #include <StepGeom_GeometricRepresentationItem.hxx>
 #include <StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx.hxx>
-#include <StepRepr_CharacterizedDefinition.hxx>
 #include <StepRepr_GlobalUnitAssignedContext.hxx>
-#include <StepRepr_HArray1OfRepresentationItem.hxx>
 #include <StepRepr_MeasureRepresentationItem.hxx>
 #include <StepRepr_NextAssemblyUsageOccurrence.hxx>
 #include <StepRepr_ProductDefinitionShape.hxx>
 #include <StepRepr_PropertyDefinition.hxx>
-#include <StepRepr_PropertyDefinitionRepresentation.hxx>
 #include <StepRepr_RepresentationContext.hxx>
 #include <StepRepr_RepresentationItem.hxx>
-#include <StepRepr_RepresentationRelationship.hxx>
 #include <StepRepr_ShapeAspect.hxx>
 #include <StepRepr_ShapeRepresentationRelationship.hxx>
-#include <StepShape_ContextDependentShapeRepresentation.hxx>
 #include <StepShape_ShapeDefinitionRepresentation.hxx>
 #include <StepShape_ShapeRepresentation.hxx>
 #include <TCollection_HAsciiString.hxx>
-#include <TopLoc_Location.hxx>
-#include <TopoDS_Iterator.hxx>
-#include <TopoDS_Shape.hxx>
 #include <Transfer_Binder.hxx>
 #include <Transfer_SimpleBinderOfTransient.hxx>
 #include <TransferBRep.hxx>
@@ -358,9 +346,11 @@ Standard_Boolean STEPConstruct_ValidationProps::AddProp (const StepRepr_Characte
   // record SDR in order to have it written to the file
   Model()->AddWithRefs ( PrDR );
 
+  Handle(StepData_StepModel) aStepModel = Handle(StepData_StepModel)::DownCast(Model());
+
   // for AP203, add subschema name
-  if ( Interface_Static::IVal("write.step.schema") ==3 ) {
-    APIHeaderSection_MakeHeader mkHdr ( Handle(StepData_StepModel)::DownCast ( Model() ) );
+  if ( aStepModel->InternalParameters.WriteSchema ==3 ) {
+    APIHeaderSection_MakeHeader mkHdr ( aStepModel );
     Handle(TCollection_HAsciiString) subSchema = 
       new TCollection_HAsciiString ( "GEOMETRIC_VALIDATION_PROPERTIES_MIM" );
     mkHdr.AddSchemaIdentifier ( subSchema );
@@ -636,7 +626,9 @@ TopoDS_Shape STEPConstruct_ValidationProps::GetPropShape (const Handle(StepRepr_
 //=======================================================================
 
 Standard_Boolean STEPConstruct_ValidationProps::GetPropReal (const Handle(StepRepr_RepresentationItem) &item,
-							     Standard_Real &Val, Standard_Boolean &isArea) const
+                                                             Standard_Real &Val,
+                                                             Standard_Boolean &isArea,
+                                                             const StepData_Factors& theLocalFactors) const
 {
   // decode volume & area
   if ( ! item->IsKind(STANDARD_TYPE(StepRepr_MeasureRepresentationItem)) ) 
@@ -657,7 +649,7 @@ Standard_Boolean STEPConstruct_ValidationProps::GetPropReal (const Handle(StepRe
       Standard_Real exp = DUE->Exponent();
       Handle(StepBasic_NamedUnit) NU = DUE->Unit();
       STEPConstruct_UnitContext unit;
-      unit.ComputeFactors(NU);
+      unit.ComputeFactors(NU, theLocalFactors);
       if(unit.LengthDone()) {
 	Standard_Real lengthFactor = unit.LengthFactor();
 	scale *= pow(lengthFactor,exp);
@@ -668,7 +660,7 @@ Standard_Boolean STEPConstruct_ValidationProps::GetPropReal (const Handle(StepRe
     Handle(StepBasic_NamedUnit) NU = Unit.NamedUnit();
     if(!NU.IsNull()) {
       STEPConstruct_UnitContext unit;
-      unit.ComputeFactors(NU);
+      unit.ComputeFactors(NU, theLocalFactors);
       if(unit.AreaDone())
 	scale =  unit.AreaFactor();
       if(unit.VolumeDone())
@@ -695,8 +687,9 @@ Standard_Boolean STEPConstruct_ValidationProps::GetPropReal (const Handle(StepRe
 //=======================================================================
 
 Standard_Boolean STEPConstruct_ValidationProps::GetPropPnt (const Handle(StepRepr_RepresentationItem) &item,
-							    const Handle(StepRepr_RepresentationContext) &Context,
-							    gp_Pnt &Pnt) const
+                                                            const Handle(StepRepr_RepresentationContext) &Context,
+                                                            gp_Pnt &Pnt,
+                                                            const StepData_Factors& theLocalFactors) const
 {
   // centroid
   if ( ! item->IsKind(STANDARD_TYPE(StepGeom_CartesianPoint)) ) 
@@ -726,7 +719,7 @@ Standard_Boolean STEPConstruct_ValidationProps::GetPropPnt (const Handle(StepRep
     }
     if ( ! theGUAC.IsNull() ) {
       STEPConstruct_UnitContext UnitTool;
-      UnitTool.ComputeFactors(theGUAC);
+      UnitTool.ComputeFactors(theGUAC, theLocalFactors);
       gp_Pnt zero(0,0,0);
       pos.Scale ( zero, UnitTool.LengthFactor() );
     }
