@@ -24,21 +24,13 @@
 #include <Draw_ProgressIndicator.hxx>
 #include <gp_Pnt2d.hxx>
 #include <gp_XYZ.hxx>
-#include <Message_ListIteratorOfListOfMsg.hxx>
-#include <Message_Msg.hxx>
 #include <Precision.hxx>
 #include <ShapeAnalysis_Edge.hxx>
 #include <ShapeAnalysis_FreeBounds.hxx>
-#include <ShapeAnalysis_Wire.hxx>
 #include <ShapeAnalysis_WireOrder.hxx>
-#include <ShapeAnalysis_WireVertex.hxx>
 #include <ShapeBuild_ReShape.hxx>
-#include <ShapeExtend_DataMapIteratorOfDataMapOfShapeListOfMsg.hxx>
-#include <ShapeExtend_DataMapOfShapeListOfMsg.hxx>
 #include <ShapeExtend_MsgRegistrator.hxx>
-#include <ShapeExtend_WireData.hxx>
 #include <ShapeFix.hxx>
-#include <ShapeFix_Face.hxx>
 #include <ShapeFix_FixSmallFace.hxx>
 #include <ShapeFix_Shape.hxx>
 #include <ShapeFix_ShapeTolerance.hxx>
@@ -48,7 +40,6 @@
 #include <SWDRAW.hxx>
 #include <SWDRAW_ShapeFix.hxx>
 #include <TCollection_AsciiString.hxx>
-#include <TColStd_DataMapIteratorOfDataMapOfAsciiStringInteger.hxx>
 #include <TColStd_DataMapOfAsciiStringInteger.hxx>
 #include <TopAbs_State.hxx>
 #include <TopExp.hxx>
@@ -68,7 +59,6 @@
 #include <strings.h>
 #endif
 #include <stdio.h>
-#include <ShapeExtend_WireData.hxx>
 
 //=======================================================================
 //function : edgesameparam
@@ -372,10 +362,9 @@ static Standard_Integer reface (Draw_Interpretor& di, Standard_Integer argc, con
   TopoDS_Face  face;
   ShapeBuild_ReShape resh;
 
-  Standard_Integer nbf = 0, nbfc = 0;
+  Standard_Integer nbfc = 0;
   for (TopExp_Explorer EF (Shape,TopAbs_FACE); EF.More(); EF.Next()) {
     TopoDS_Face F = TopoDS::Face (EF.Current());    face = F;
-    nbf ++;
     Standard_Boolean newface = Standard_False;
 //    on va voir si ShapeTool_Face trouve qqchose a redire
 //:sw    ShapeTool_Wire STW;
@@ -813,7 +802,7 @@ static Standard_Integer connectedges(Draw_Interpretor& di, Standard_Integer n, c
         Standard_Integer ind = aMapEdges.FindIndex(aExp1.Current());
         di<<ind<<" ";
       }
-       else
+      else
       {
         TopoDS_Vertex aV1, aV2;
         TopExp::Vertices(TopoDS::Edge(aExp1.Current()), aV1,aV2);
