@@ -24,7 +24,6 @@
 #include <BRepBuilderAPI_Transform.hxx>
 #include <BRepTest_Objects.hxx>
 #include <BRepTools.hxx>
-#include <BRepTools_ReShape.hxx>
 #include <DBRep.hxx>
 #include <Draw.hxx>
 #include <Draw_Interpretor.hxx>
@@ -33,7 +32,6 @@
 #include <Geom2d_OffsetCurve.hxx>
 #include <Geom_Curve.hxx>
 #include <Geom_OffsetCurve.hxx>
-#include <Geom_Plane.hxx>
 #include <Geom_RectangularTrimmedSurface.hxx>
 #include <Geom_Surface.hxx>
 #include <Message.hxx>
@@ -43,7 +41,6 @@
 #include <ShapeExtend_CompositeSurface.hxx>
 #include <ShapeFix.hxx>
 #include <ShapeFix_ComposeShell.hxx>
-#include <ShapeUpgrade.hxx>
 #include <ShapeUpgrade_RemoveInternalWires.hxx>
 #include <ShapeUpgrade_RemoveLocations.hxx>
 #include <ShapeUpgrade_ShapeConvertToBezier.hxx>
@@ -61,18 +58,11 @@
 #include <TColGeom2d_HArray1OfCurve.hxx>
 #include <TColGeom_HArray1OfCurve.hxx>
 #include <TColGeom_HArray2OfSurface.hxx>
-#include <TColStd_Array1OfReal.hxx>
 #include <TColStd_HArray1OfReal.hxx>
 #include <TColStd_HSequenceOfReal.hxx>
-#include <TopExp_Explorer.hxx>
 #include <TopoDS.hxx>
-#include <TopoDS_Compound.hxx>
-#include <TopoDS_Edge.hxx>
 #include <TopoDS_Face.hxx>
-#include <TopoDS_Iterator.hxx>
 #include <TopoDS_Shape.hxx>
-#include <TopoDS_Shell.hxx>
-#include <TopoDS_Wire.hxx>
 
 #include <stdio.h> 
 //#include <SWDRAW_ShapeUpgrade.hxx>
@@ -1190,6 +1180,52 @@ static Standard_Integer splitarea (Draw_Interpretor& di,
   return 0;
 }
 
+static Standard_Integer splitbynumber (Draw_Interpretor& di, 
+                                       Standard_Integer argc, 
+                                       const char** argv)
+{
+  if (argc < 4) {
+    di << "bad number of arguments\n";
+    return 1;
+  }
+  
+  TopoDS_Shape inputShape=DBRep::Get(argv[2], TopAbs_FACE);
+  if (inputShape.IsNull()) {
+    di << "Unknown face\n";
+    return 1;
+  }
+  
+  Standard_Integer aNbParts, aNumber1 = 0, aNumber2 = 0;
+  aNbParts = aNumber1 = Draw::Atoi (argv[3]);
+  if (argc > 4)
+    aNumber2 = Draw::Atoi (argv[4]);
+  
+  if (argc == 4 && aNbParts <= 0)
+  {
+    di << "Incorrect number of parts\n";
+    return 1;
+  }
+  if (argc == 5 &&
+      (aNumber1 <= 0 || aNumber2 <= 0))
+  {
+    di << "Incorrect numbers in U or V\n";
+    return 1;
+  }
+    
+  ShapeUpgrade_ShapeDivideArea tool (inputShape);
+  tool.SetSplittingByNumber (Standard_True);
+  if (argc == 4)
+    tool.NbParts() = aNbParts;
+  else
+    tool.SetNumbersUVSplits (aNumber1, aNumber2);
+  tool.Perform();
+  TopoDS_Shape res = tool.Result();
+  
+  ShapeFix::SameParameter ( res, Standard_False );
+  DBRep::Set ( argv[1], res );
+  return 0;
+}
+
 static Standard_Integer removeinternalwires (Draw_Interpretor& di, 
                                              Standard_Integer argc, 
                                              const char** argv)
@@ -1624,6 +1660,8 @@ static Standard_Integer reshape(Draw_Interpretor& /*theDI*/,
 		   __FILE__,splitclosed,g);
   theCommands.Add ("DT_SplitByArea","result shape maxarea [preci]",
 		   __FILE__,splitarea,g);
+  theCommands.Add ("DT_SplitByNumber","result face number [number2]",
+                   __FILE__,splitbynumber,g);
   
   theCommands.Add ("RemoveIntWires","result minarea wholeshape [faces or wires] [moderemoveface ]",
                    __FILE__,removeinternalwires,g);
