@@ -16,8 +16,6 @@
 
 #include <Select3D_SensitiveTriangle.hxx>
 
-#include <Precision.hxx>
-#include <Bnd_Box.hxx>
 #include <TopLoc_Location.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(Select3D_SensitiveTriangle,Select3D_SensitiveEntity)
@@ -50,17 +48,17 @@ Standard_Boolean Select3D_SensitiveTriangle::Matches (SelectBasics_SelectingVolu
 {
   if (!theMgr.IsOverlapAllowed())
   {
-    if (theMgr.GetActiveSelectionType() == SelectBasics_SelectingVolumeManager::Polyline)
+    if (theMgr.GetActiveSelectionType() == SelectMgr_SelectionType_Polyline)
     {
       SelectBasics_PickResult aDummy;
-      return theMgr.Overlaps (myPoints[0], myPoints[1], myPoints[2], mySensType, aDummy);
+      return theMgr.OverlapsTriangle (myPoints[0], myPoints[1], myPoints[2], mySensType, aDummy);
     }
-    return theMgr.Overlaps (myPoints[0])
-        && theMgr.Overlaps (myPoints[1])
-        && theMgr.Overlaps (myPoints[2]);
+    return theMgr.OverlapsPoint (myPoints[0])
+        && theMgr.OverlapsPoint (myPoints[1])
+        && theMgr.OverlapsPoint (myPoints[2]);
   }
 
-  if (!theMgr.Overlaps (myPoints[0], myPoints[1], myPoints[2], mySensType, thePickResult))
+  if (!theMgr.OverlapsTriangle (myPoints[0], myPoints[1], myPoints[2], mySensType, thePickResult))
   {
     return Standard_False;
   }
