@@ -16,22 +16,17 @@
 #include <BRep_Tool.hxx>
 #include <BRepLib.hxx>
 #include <BRepTools.hxx>
-#include <ElCLib.hxx>
-#include <Geom2d_Curve.hxx>
 #include <Geom_BezierSurface.hxx>
 #include <Geom_BSplineSurface.hxx>
 #include <Geom_Curve.hxx>
 #include <Geom_ElementarySurface.hxx>
-#include <Geom_Line.hxx>
 #include <Geom_Surface.hxx>
 #include <Geom_TrimmedCurve.hxx>
 #include <GeomAdaptor_Curve.hxx>
 #include <GeomAdaptor_Surface.hxx>
 #include <GeomLib.hxx>
-#include <gp_Dir.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Vec.hxx>
-#include <Poly_Polygon3D.hxx>
 #include <Precision.hxx>
 #include <ShapeAnalysis_CheckSmallFace.hxx>
 #include <ShapeAnalysis_Curve.hxx>
@@ -42,7 +37,6 @@
 #include <Standard_ErrorHandler.hxx>
 #include <TColgp_Array1OfPnt.hxx>
 #include <TColgp_Array2OfPnt.hxx>
-#include <TColgp_SequenceOfXYZ.hxx>
 #include <TColStd_Array1OfReal.hxx>
 #include <TColStd_Array2OfReal.hxx>
 #include <TColStd_ListOfReal.hxx>
@@ -54,7 +48,6 @@
 #include <TopoDS_Edge.hxx>
 #include <TopoDS_Face.hxx>
 #include <TopoDS_Iterator.hxx>
-#include <TopoDS_Shell.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
 #include <TopTools_Array1OfShape.hxx>
