@@ -41,9 +41,6 @@
 #include <Geom2dAdaptor.hxx>
 #include <Geom2dAPI_Interpolate.hxx>
 #include <Geom_BezierSurface.hxx>
-#include <Geom_BoundedCurve.hxx>
-#include <Geom_BSplineCurve.hxx>
-#include <Geom_BSplineSurface.hxx>
 #include <Geom_Curve.hxx>
 #include <Geom_OffsetSurface.hxx>
 #include <Geom_Plane.hxx>
@@ -61,8 +58,6 @@
 #include <ElCLib.hxx>
 #include <NCollection_Sequence.hxx>
 #include <Precision.hxx>
-#include <ProjLib_CompProjectedCurve.hxx>
-#include <ProjLib_HCompProjectedCurve.hxx>
 #include <ProjLib_ProjectedCurve.hxx>
 #include <ShapeAnalysis.hxx>
 #include <ShapeAnalysis_Curve.hxx>
@@ -1518,7 +1513,7 @@ Handle(Geom2d_Curve) ShapeConstruct_ProjectCurveOnSurface::ApproximatePCurve(con
     }
     
     GeomAPI_PointsToBSpline appr(points3d, params->Array1(), 1, 10, GeomAbs_C1, theTolerance2d);
-    Handle(Geom_BSplineCurve) crv3d = appr.Curve();
+    const Handle(Geom_BSplineCurve)& crv3d = appr.Curve();
     Standard_Integer NbPoles = crv3d->NbPoles();
     TColgp_Array1OfPnt poles3d (1, NbPoles);
     TColgp_Array1OfPnt2d poles2d (1, NbPoles);
