@@ -15,35 +15,23 @@
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
 #include <BRepLib.hxx>
-#include <BRepTools.hxx>
 #include <ElCLib.hxx>
 #include <Geom2d_Curve.hxx>
-#include <Geom_BezierSurface.hxx>
-#include <Geom_BSplineSurface.hxx>
 #include <Geom_Curve.hxx>
-#include <Geom_ElementarySurface.hxx>
 #include <Geom_Line.hxx>
-#include <Geom_Surface.hxx>
-#include <Geom_TrimmedCurve.hxx>
 #include <GeomAdaptor_Curve.hxx>
-#include <GeomAdaptor_Surface.hxx>
 #include <GeomLib.hxx>
 #include <gp_Dir.hxx>
 #include <gp_Vec.hxx>
 #include <Message_Msg.hxx>
-#include <Poly_Polygon3D.hxx>
 #include <Precision.hxx>
 #include <ShapeAnalysis_Curve.hxx>
-#include <ShapeAnalysis_DataMapOfShapeListOfReal.hxx>
 #include <ShapeBuild_ReShape.hxx>
 #include <ShapeFix_Edge.hxx>
-#include <ShapeFix_Face.hxx>
 #include <ShapeFix_FixSmallFace.hxx>
 #include <ShapeFix_Shape.hxx>
 #include <ShapeFix_Wire.hxx>
 #include <Standard_Type.hxx>
-#include <TColgp_Array1OfPnt.hxx>
-#include <TColgp_Array2OfPnt.hxx>
 #include <TColgp_SequenceOfXYZ.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
@@ -57,7 +45,6 @@
 #include <TopoDS_Shell.hxx>
 #include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_Array1OfShape.hxx>
 #include <TopTools_DataMapOfShapeListOfShape.hxx>
 
 IMPLEMENT_STANDARD_RTTIEXT(ShapeFix_FixSmallFace,ShapeFix_Root)
