@@ -12,8 +12,6 @@
 // commercial license or contractual agreement.
 
 
-#include <Standard_Type.hxx>
-#include <StepGeom_Axis2Placement.hxx>
 #include <StepGeom_Conic.hxx>
 #include <TCollection_HAsciiString.hxx>
 
