@@ -12,8 +12,6 @@
 // commercial license or contractual agreement.
 
 
-#include <Standard_Type.hxx>
-#include <StepShape_CsgSelect.hxx>
 #include <StepShape_CsgSolid.hxx>
 #include <TCollection_HAsciiString.hxx>
 
