@@ -25,7 +25,6 @@
 #include <BRepBuilderAPI_MakeFace.hxx>
 #include <BRepBuilderAPI_MakeVertex.hxx>
 #include <BRepLib.hxx>
-#include <Geom_BoundedSurface.hxx>
 #include <Geom_CartesianPoint.hxx>
 #include <Geom_Curve.hxx>
 #include <Geom_RectangularTrimmedSurface.hxx>
@@ -39,7 +38,8 @@
 #include <Standard_Failure.hxx>
 #include <StdFail_NotDone.hxx>
 #include <STEPControl_ActorRead.hxx>
-#include <StepGeom_CartesianPoint.hxx>
+#include <StepData_Factors.hxx>
+#include <StepData_StepModel.hxx>
 #include <StepGeom_CompositeCurve.hxx>
 #include <StepGeom_Curve.hxx>
 #include <StepGeom_CurveBoundedSurface.hxx>
@@ -49,7 +49,6 @@
 #include <StepGeom_SurfacePatch.hxx>
 #include <StepShape_BrepWithVoids.hxx>
 #include <StepShape_ClosedShell.hxx>
-#include <StepShape_ConnectedEdgeSet.hxx>
 #include <StepShape_EdgeBasedWireframeModel.hxx>
 #include <StepShape_FaceBasedSurfaceModel.hxx>
 #include <StepShape_FaceSurface.hxx>
@@ -64,11 +63,13 @@
 #include <StepShape_ManifoldSolidBrep.hxx>
 #include <StepShape_OpenShell.hxx>
 #include <StepShape_OrientedClosedShell.hxx>
-#include <StepShape_Shell.hxx>
 #include <StepShape_ShellBasedSurfaceModel.hxx>
+#include <StepVisual_TessellatedFace.hxx>
+#include <StepVisual_TessellatedShell.hxx>
+#include <StepVisual_TessellatedSolid.hxx>
+#include <StepVisual_TessellatedSurfaceSet.hxx>
 #include <StepToGeom.hxx>
 #include <StepToTopoDS_Builder.hxx>
-#include <StepToTopoDS_DataMapOfTRI.hxx>
 #include <StepToTopoDS_NMTool.hxx>
 #include <StepToTopoDS_Tool.hxx>
 #include <StepToTopoDS_TranslateCompositeCurve.hxx>
@@ -76,6 +77,7 @@
 #include <StepToTopoDS_TranslateEdge.hxx>
 #include <StepToTopoDS_TranslateFace.hxx>
 #include <StepToTopoDS_TranslateShell.hxx>
+#include <StepToTopoDS_TranslateSolid.hxx>
 #include <TopExp_Explorer.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Compound.hxx>
@@ -89,10 +91,11 @@
 #include <TransferBRep.hxx>
 
 #include <stdio.h>
-static void ResetPreci (const TopoDS_Shape& S, Standard_Real maxtol)
+static void ResetPreci (Handle(StepData_StepModel)& theStepModel,
+                        const TopoDS_Shape& S, Standard_Real maxtol)
 {
   //:S4136
-  Standard_Integer modetol = Interface_Static::IVal("read.maxprecision.mode");
+  Standard_Integer modetol = theStepModel->InternalParameters.ReadMaxPrecisionMode;
   if (modetol) {
     ShapeFix_ShapeTolerance STU;
     STU.LimitTolerance (S,Precision::Confusion(),maxtol);
@@ -100,10 +103,9 @@ static void ResetPreci (const TopoDS_Shape& S, Standard_Real maxtol)
 }
 
 // ============================================================================
-// Method  : StepToTopoDS_Builder::StepToTopoDS_Builder
+// Method  : StepToTopoDS_Builder
 // Purpose : Empty constructor
 // ============================================================================
-
 StepToTopoDS_Builder::StepToTopoDS_Builder()
 : myError(StepToTopoDS_BuilderOther)
 {
@@ -114,289 +116,260 @@ StepToTopoDS_Builder::StepToTopoDS_Builder()
 // Method  : Init
 // Purpose : Init with a ManifoldSolidBrep
 // ============================================================================
-
-void StepToTopoDS_Builder::Init
-(const Handle(StepShape_ManifoldSolidBrep)& aManifoldSolid,
- const Handle(Transfer_TransientProcess)& TP,
- const Message_ProgressRange& theProgress)
+void StepToTopoDS_Builder::Init(const Handle(StepShape_ManifoldSolidBrep)& theManifoldSolid,
+                                const Handle(Transfer_TransientProcess)& theTP,
+                                const StepData_Factors& theLocalFactors,
+                                const Message_ProgressRange& theProgress)
 {
-  Message_Messenger::StreamBuffer sout = TP->Messenger()->SendInfo();
+  Message_Messenger::StreamBuffer sout = theTP->Messenger()->SendInfo();
+  Handle(StepData_StepModel) aStepModel = Handle(StepData_StepModel)::DownCast(theTP->Model());
   // Initialisation of the Tool
 
-  StepToTopoDS_Tool         myTool;
+  StepToTopoDS_Tool         aTool;
   StepToTopoDS_DataMapOfTRI aMap;
 
-  myTool.Init(aMap, TP);
+  aTool.Init(aMap, theTP);
 
   // Start Mapping
-
-  Handle(StepShape_ConnectedFaceSet) aShell;
-  aShell = aManifoldSolid->Outer();
+  const Handle(StepShape_ConnectedFaceSet) aShell = theManifoldSolid->Outer();
 
   StepToTopoDS_TranslateShell myTranShell;
   myTranShell.SetPrecision(Precision());
   myTranShell.SetMaxTol(MaxTol());
-  // Non-manifold topology is not referenced by ManifoldSolidBrep (ssv; 14.11.2010)
+
   StepToTopoDS_NMTool dummyNMTool;
-  myTranShell.Init(aShell, myTool, dummyNMTool, theProgress);
-
-  if (myTranShell.IsDone()) {
-    TopoDS_Shape Sh = myTranShell.Value();
-    Sh.Closed(Standard_True);
-    //BRepLib::SameParameter(Sh);
-    TopoDS_Solid S;
-    BRep_Builder B;
-    B.MakeSolid(S);
-    B.Add(S,Sh);
-    myResult = S;
-    myError  = StepToTopoDS_BuilderDone;
-    done     = Standard_True;
-
-    // Get Statistics :
-
-    if ( TP->TraceLevel() > 2 )
-    {
-      sout << "Geometric Statistics : " << std::endl;
-      sout << "   Surface Continuity : - C0 : " << myTool.C0Surf() << std::endl;
-      sout << "                        - C1 : " << myTool.C1Surf() << std::endl;
-      sout << "                        - C2 : " << myTool.C2Surf() << std::endl;
-      sout << "   Curve Continuity :   - C0 : " << myTool.C0Cur3() << std::endl;
-      sout << "                        - C1 : " << myTool.C1Cur3() << std::endl;
-      sout << "                        - C2 : " << myTool.C2Cur3() << std::endl;
-      sout << "   PCurve Continuity :  - C0 : " << myTool.C0Cur2() << std::endl;
-      sout << "                        - C1 : " << myTool.C1Cur2() << std::endl;
-      sout << "                        - C2 : " << myTool.C2Cur2() << std::endl;
-    }
-
-//:S4136    ShapeFix::SameParameter (S,Standard_False);
-    ResetPreci (S, MaxTol());
+  myTranShell.Init(aShell, aTool, dummyNMTool, theLocalFactors, theProgress);
+  if (!myTranShell.IsDone())
+  {
+    theTP->AddWarning(aShell, " OuterShell from ManifoldSolidBrep not mapped to TopoDS");
+    myError = StepToTopoDS_BuilderOther;
+    done = Standard_False;
+    return;
   }
-  else {
-    TP->AddWarning(aShell," OuterShell from ManifoldSolidBrep not mapped to TopoDS");
-    myError  = StepToTopoDS_BuilderOther;
-    done     = Standard_False;
+  TopoDS_Shape aShape = myTranShell.Value();
+  aShape.Closed(Standard_True);
+  TopoDS_Solid aSolid;
+  BRep_Builder aBuilder;
+  aBuilder.MakeSolid(aSolid);
+  aBuilder.Add(aSolid, aShape);
+  myResult = aSolid;
+  myError  = StepToTopoDS_BuilderDone;
+  done     = Standard_True;
+
+  // Get Statistics :
+  if (theTP->TraceLevel() > 2)
+  {
+    sout << "Geometric Statistics : " << std::endl;
+    sout << "   Surface Continuity : - C0 : " << aTool.C0Surf() << std::endl;
+    sout << "                        - C1 : " << aTool.C1Surf() << std::endl;
+    sout << "                        - C2 : " << aTool.C2Surf() << std::endl;
+    sout << "   Curve Continuity :   - C0 : " << aTool.C0Cur3() << std::endl;
+    sout << "                        - C1 : " << aTool.C1Cur3() << std::endl;
+    sout << "                        - C2 : " << aTool.C2Cur3() << std::endl;
+    sout << "   PCurve Continuity :  - C0 : " << aTool.C0Cur2() << std::endl;
+    sout << "                        - C1 : " << aTool.C1Cur2() << std::endl;
+    sout << "                        - C2 : " << aTool.C2Cur2() << std::endl;
   }
+
+  ResetPreci (aStepModel, aSolid, MaxTol());
 }
 
 // ============================================================================
 // Method  : Init
 // Purpose : Init with a BrepWithVoids
 // ============================================================================
-
-void StepToTopoDS_Builder::Init
-(const Handle(StepShape_BrepWithVoids)& aBRepWithVoids,
- const Handle(Transfer_TransientProcess)& TP,
- const Message_ProgressRange& theProgress)
+void StepToTopoDS_Builder::Init(const Handle(StepShape_BrepWithVoids)& theBRepWithVoids,
+                                const Handle(Transfer_TransientProcess)& theTP,
+                                const StepData_Factors& theLocalFactors,
+                                const Message_ProgressRange& theProgress)
 {
-  Message_Messenger::StreamBuffer sout = TP->Messenger()->SendInfo();
+  Message_Messenger::StreamBuffer sout = theTP->Messenger()->SendInfo();
  // Initialisation of the Tool
-  StepToTopoDS_Tool         myTool;
+  StepToTopoDS_Tool         aTool;
   StepToTopoDS_DataMapOfTRI aMap;
 
-  myTool.Init(aMap, TP);
+  aTool.Init(aMap, theTP);
 
   // Start Mapping
-
-  Standard_Integer Nb = aBRepWithVoids->NbVoids();
-  Handle(StepShape_ClosedShell) aCShell;
-  TopoDS_Solid S;
-  TopoDS_Shape Sh;
-  BRep_Builder B;
-  B.MakeSolid(S);
+  TopoDS_Solid aSolid;
+  BRep_Builder aBuilder;
+  aBuilder.MakeSolid(aSolid);
   
-  Message_ProgressScope PS (theProgress, "Shell", Nb+1);
+  Message_ProgressScope aPS (theProgress, "Shell", theBRepWithVoids->NbVoids() + 1);
 
-  StepToTopoDS_TranslateShell myTranShell;
+  StepToTopoDS_TranslateShell aTranShell;
 
-  myTranShell.SetPrecision(Precision());//gka
-  myTranShell.SetMaxTol(MaxTol());
+  aTranShell.SetPrecision(Precision());//gka
+  aTranShell.SetMaxTol(MaxTol());
   // OuterBound
 
-  aCShell = Handle(StepShape_ClosedShell)::DownCast(aBRepWithVoids->Outer());
+  Handle(StepShape_ClosedShell) aCShell = Handle(StepShape_ClosedShell)::DownCast(theBRepWithVoids->Outer());
   // Non-manifold topology is not referenced by BrepWithVoids (ssv; 14.11.2010)
-  StepToTopoDS_NMTool dummyNMTool;
-  myTranShell.Init(aCShell, myTool, dummyNMTool, PS.Next());
-
-  if (myTranShell.IsDone()) {
-    Sh = myTranShell.Value();
-    Sh.Closed(Standard_True);
-    //BRepLib::SameParameter(Sh);
-    B.MakeSolid(S);
-    B.Add(S,Sh);
-    myResult = S;
-    myError  = StepToTopoDS_BuilderDone;
-    done     = Standard_True;
-  }
-  else {
-    TP->AddWarning(aCShell," OuterShell from BrepWithVoids not mapped to TopoDS");
-    myError  = StepToTopoDS_BuilderOther;
-    done     = Standard_False;
+  StepToTopoDS_NMTool aDummyNMTool;
+  aTranShell.Init(aCShell, aTool, aDummyNMTool, theLocalFactors, aPS.Next());
+  if (!aTranShell.IsDone())
+  {
+    theTP->AddWarning( aCShell, " OuterShell from BrepWithVoids not mapped to TopoDS" );
+    myError = StepToTopoDS_BuilderOther;
+    done = Standard_False;
     return;
   }
+  TopoDS_Shape aShape = aTranShell.Value();
+  aShape.Closed(Standard_True);
+  aBuilder.MakeSolid(aSolid);
+  aBuilder.Add(aSolid, aShape);
+  myResult = aSolid;
+  myError  = StepToTopoDS_BuilderDone;
+  done     = Standard_True;
 
   // Voids
-
-  for (Standard_Integer i=1; i<=Nb && PS.More(); i++) {
-
-    aCShell = aBRepWithVoids->VoidsValue(i);
-    myTranShell.Init(aCShell, myTool, dummyNMTool, PS.Next());
-    if (myTranShell.IsDone()) {
-      Sh = myTranShell.Value();
-      Sh.Closed(Standard_True);
+  for (StepShape_HArray1OfOrientedClosedShell::Iterator anIt(theBRepWithVoids->Voids()->Array1());
+       anIt.More() && aPS.More(); anIt.Next())
+  {
+    Handle(StepShape_OrientedClosedShell) anOCShell = anIt.Value();
+    aTranShell.Init(anOCShell, aTool, aDummyNMTool, theLocalFactors, aPS.Next());
+    if (aTranShell.IsDone())
+    {
+      aShape = aTranShell.Value();
+      aShape.Closed(Standard_True);
 
       //:e0 abv 25 Mar 98: void should be an OrientedShell 
-      Handle(StepShape_OrientedClosedShell) aOCShell = aBRepWithVoids->VoidsValue(i);
-      if ( ! aOCShell.IsNull() && ! aOCShell->Orientation() ) Sh.Reverse();
-      
-      //BRepLib::SameParameter(Sh);
-      B.Add(S,Sh);
+      if (!anOCShell.IsNull() && ! anOCShell->Orientation())
+        aShape.Reverse();
+
+      aBuilder.Add(aSolid, aShape);
     }
-    else {
-      TP->AddWarning
-	(aCShell," A Void from BrepWithVoids not mapped to TopoDS");
+    else
+    {
+      theTP->AddWarning (anOCShell, " A Void from BrepWithVoids not mapped to TopoDS");
     }
   }
-  myResult = S;
-
+  myResult = aSolid;
 
   // Get Statistics :
-  
-  if ( TP->TraceLevel() > 2 )
+  if (theTP->TraceLevel() > 2)
   {
     sout << "Geometric Statistics : " << std::endl;
-    sout << "   Surface Continuity : - C0 : " << myTool.C0Surf() << std::endl;
-    sout << "                        - C1 : " << myTool.C1Surf() << std::endl;
-    sout << "                        - C2 : " << myTool.C2Surf() << std::endl;
-    sout << "   Curve Continuity :   - C0 : " << myTool.C0Cur3() << std::endl;
-    sout << "                        - C1 : " << myTool.C1Cur3() << std::endl;
-    sout << "                        - C2 : " << myTool.C2Cur3() << std::endl;
-    sout << "   PCurve Continuity :  - C0 : " << myTool.C0Cur2() << std::endl;
-    sout << "                        - C1 : " << myTool.C1Cur2() << std::endl;
-    sout << "                        - C2 : " << myTool.C2Cur2() << std::endl;
+    sout << "   Surface Continuity : - C0 : " << aTool.C0Surf() << std::endl;
+    sout << "                        - C1 : " << aTool.C1Surf() << std::endl;
+    sout << "                        - C2 : " << aTool.C2Surf() << std::endl;
+    sout << "   Curve Continuity :   - C0 : " << aTool.C0Cur3() << std::endl;
+    sout << "                        - C1 : " << aTool.C1Cur3() << std::endl;
+    sout << "                        - C2 : " << aTool.C2Cur3() << std::endl;
+    sout << "   PCurve Continuity :  - C0 : " << aTool.C0Cur2() << std::endl;
+    sout << "                        - C1 : " << aTool.C1Cur2() << std::endl;
+    sout << "                        - C2 : " << aTool.C2Cur2() << std::endl;
   }
 
 //:S4136  ShapeFix::SameParameter (S,Standard_False);
-  ResetPreci (S, MaxTol());
+  Handle(StepData_StepModel) aStepModel = Handle(StepData_StepModel)::DownCast(theTP->Model());
+  ResetPreci (aStepModel, aSolid, MaxTol());
 }
 
 // ============================================================================
 // Method  : Init
 // Purpose : Init with a FacetedBrep
 // ============================================================================
-
-void StepToTopoDS_Builder::Init(const Handle(StepShape_FacetedBrep)& aFB,
-                                const Handle(Transfer_TransientProcess)& TP,
+void StepToTopoDS_Builder::Init(const Handle(StepShape_FacetedBrep)& theFB,
+                                const Handle(Transfer_TransientProcess)& theTP,
+                                const StepData_Factors& theLocalFactors,
                                 const Message_ProgressRange& theProgress)
 {
   // Initialisation of the Tool
-
-  StepToTopoDS_Tool         myTool;
+  StepToTopoDS_Tool         aTool;
   StepToTopoDS_DataMapOfTRI aMap;
 
-  myTool.Init(aMap, TP);
+  aTool.Init(aMap, theTP);
 
   // Start Mapping
+  const Handle(StepShape_ClosedShell) aCShell = Handle(StepShape_ClosedShell)::DownCast(theFB->Outer());
 
-  Handle(StepShape_ClosedShell) aCShell;
-  aCShell = Handle(StepShape_ClosedShell)::DownCast(aFB->Outer());
-  TopoDS_Shape Sh;
-
-  StepToTopoDS_TranslateShell myTranShell; 
-  myTranShell.SetPrecision(Precision()); //gka
-  myTranShell.SetMaxTol(MaxTol());  
+  StepToTopoDS_TranslateShell aTranShell; 
+  aTranShell.SetPrecision(Precision()); //gka
+  aTranShell.SetMaxTol(MaxTol());  
   // Non-manifold topology is not referenced by FacetedBrep (ss; 14.11.2010)
-  StepToTopoDS_NMTool dummyNMTool;
-  myTranShell.Init(aCShell, myTool, dummyNMTool, theProgress);
-
-  if (myTranShell.IsDone()) {
-    Sh = myTranShell.Value();
-    Sh.Closed(Standard_True);
-    //BRepLib::SameParameter(Sh);
-    myTool.ClearEdgeMap();
-    myTool.ClearVertexMap();
-    TopoDS_Solid S;
-    BRep_Builder B;
-    B.MakeSolid(S);
-    B.Add(S,Sh);
-    myResult = S;
-    myError  = StepToTopoDS_BuilderDone;
-    done     = Standard_True;
-  }
-  else {
-    TP->AddWarning
-      (aCShell," OuterShell from FacetedBrep not mapped to TopoDS");
-    myError  = StepToTopoDS_BuilderOther;
-    done     = Standard_True;
+  StepToTopoDS_NMTool aDummyNMTool;
+  aTranShell.Init(aCShell, aTool, aDummyNMTool, theLocalFactors, theProgress);
+  if (!aTranShell.IsDone()) 
+  {
+    theTP->AddWarning(aCShell, " OuterShell from FacetedBrep not mapped to TopoDS");
+    myError = StepToTopoDS_BuilderOther;
+    done = Standard_False;
+    return;
   }
+  TopoDS_Shape aShape = aTranShell.Value();
+  aShape.Closed(Standard_True);
+  aTool.ClearEdgeMap();
+  aTool.ClearVertexMap();
+  TopoDS_Solid aSolid;
+  BRep_Builder aBuilder;
+  aBuilder.MakeSolid(aSolid);
+  aBuilder.Add(aSolid, aShape);
+  myResult = aSolid;
+  myError  = StepToTopoDS_BuilderDone;
+  done     = Standard_True;
 }
 
 // ============================================================================
 // Method  : Init
 // Purpose : Init with a FacetedBrepAndBrepWithVoids
 // ============================================================================
-
-void StepToTopoDS_Builder::Init
-(const Handle(StepShape_FacetedBrepAndBrepWithVoids)& aFBABWV,
- const Handle(Transfer_TransientProcess)& TP,
- const Message_ProgressRange& theProgress)
-{
+void StepToTopoDS_Builder::Init(const Handle(StepShape_FacetedBrepAndBrepWithVoids)& theFBABWV,
+                                const Handle(Transfer_TransientProcess)& theTP,
+                                const StepData_Factors& theLocalFactors,
+                                const Message_ProgressRange& theProgress){
   // Initialisation of the Tool
-
-  StepToTopoDS_Tool         myTool;
+  StepToTopoDS_Tool         aTool;
   StepToTopoDS_DataMapOfTRI aMap;
 
-  myTool.Init(aMap, TP);
+  aTool.Init(aMap, theTP);
 
   // Start Mapping
-
-  Handle(StepShape_ClosedShell) aCShell;
-  aCShell = Handle(StepShape_ClosedShell)::DownCast(aFBABWV->Outer());
-  TopoDS_Shape Sh;
+  Handle(StepShape_ClosedShell) aCShell = Handle(StepShape_ClosedShell)::DownCast(theFBABWV->Outer());
 
   Message_ProgressScope aPSRoot(theProgress, NULL, 2);
 
-  StepToTopoDS_TranslateShell myTranShell;
-  myTranShell.SetPrecision(Precision()); //gka
-  myTranShell.SetMaxTol(MaxTol());
+  StepToTopoDS_TranslateShell aTranShell;
+  aTranShell.SetPrecision(Precision()); //gka
+  aTranShell.SetMaxTol(MaxTol());
   // Non-manifold topology is not referenced by FacetedBrepAndBrepWithVoids (ss; 14.11.2010)
-  StepToTopoDS_NMTool dummyNMTool;
-  myTranShell.Init(aCShell, myTool, dummyNMTool, aPSRoot.Next());
-
-  if (myTranShell.IsDone()) {
-    Sh = myTranShell.Value();
-    Sh.Closed(Standard_True);
-    //BRepLib::SameParameter(Sh);
-    TopoDS_Solid S;
-    BRep_Builder B;
-    B.MakeSolid(S);
-    B.Add(S,Sh);
-    Standard_Integer Nb, i;
-    Nb = aFBABWV->NbVoids();
-    Message_ProgressScope aPS (aPSRoot.Next(), NULL, Nb);
-    for ( i=1; i<=Nb && aPS.More(); i++) {
-      aCShell = aFBABWV->VoidsValue(i);
-      myTranShell.Init(aCShell, myTool, dummyNMTool, aPS.Next());
-      if (myTranShell.IsDone()) {
-        Sh = myTranShell.Value();
-        Sh.Closed(Standard_True);
-        //BRepLib::SameParameter(Sh);
-        B.Add(S, Sh);
-      }
-      else {
-	TP->AddWarning
-	  (aCShell," A Void from FacetedBrepAndBrepWithVoids not mapped to TopoDS");
-      }
-    }
-    myResult = S;
-    myError  = StepToTopoDS_BuilderDone;
-    done     = Standard_True;
-  }
-  else {
-    TP->AddWarning
-      (aCShell," OuterShell from FacetedBrepAndBrepWithVoids not mapped to TopoDS");
-    done    = Standard_False;
+  StepToTopoDS_NMTool aDummyNMTool;
+  aTranShell.Init(aCShell, aTool, aDummyNMTool, theLocalFactors, aPSRoot.Next());
+  if (!aTranShell.IsDone()) 
+  {
+    theTP->AddWarning
+      (aCShell, " OuterShell from FacetedBrepAndBrepWithVoids not mapped to TopoDS");
+    done = Standard_False;
     myError = StepToTopoDS_BuilderOther;
+    return;
   }
+  TopoDS_Shape aShape = aTranShell.Value();
+  aShape.Closed(Standard_True);
+  TopoDS_Solid aSolid;
+  BRep_Builder aBuilder;
+  aBuilder.MakeSolid(aSolid);
+  aBuilder.Add(aSolid, aShape);
+  Message_ProgressScope aPS (aPSRoot.Next(), NULL, theFBABWV->NbVoids());
+  for (StepShape_HArray1OfOrientedClosedShell::Iterator anIt(theFBABWV->Voids()->Array1());
+       anIt.More() && aPS.More(); anIt.Next())
+  {
+    Handle(StepShape_OrientedClosedShell) anOCShell = anIt.Value();
+    aTranShell.Init(anOCShell, aTool, aDummyNMTool, theLocalFactors, aPS.Next());
+    if (aTranShell.IsDone()) 
+    {
+      aShape = aTranShell.Value();
+      aShape.Closed(Standard_True);
+      aBuilder.Add(aSolid, aShape);
+    }
+    else 
+    {
+      theTP->AddWarning
+        (anOCShell, " A Void from FacetedBrepAndBrepWithVoids not mapped to TopoDS");
+    }
+  }
+  myResult = aSolid;
+  myError  = StepToTopoDS_BuilderDone;
+  done     = Standard_True;
 }
 
 // ============================================================================
@@ -408,6 +381,7 @@ void StepToTopoDS_Builder::Init
 (const Handle(StepShape_ShellBasedSurfaceModel)& aSBSM,
  const Handle(Transfer_TransientProcess)& TP,
  StepToTopoDS_NMTool& NMTool,
+ const StepData_Factors& theLocalFactors,
  const Message_ProgressRange& theProgress)
 {
   Message_Messenger::StreamBuffer sout = TP->Messenger()->SendInfo();
@@ -443,7 +417,7 @@ void StepToTopoDS_Builder::Init
     aOpenShell = aShell.OpenShell();
     aClosedShell = aShell.ClosedShell();
     if (!aOpenShell.IsNull()) {
-      myTranShell.Init(aOpenShell, myTool, NMTool, aRange);
+      myTranShell.Init(aOpenShell, myTool, NMTool, theLocalFactors, aRange);
       if (myTranShell.IsDone()) {
         Shl = TopoDS::Shell(myTranShell.Value());
         Shl.Closed(Standard_False);
@@ -455,7 +429,7 @@ void StepToTopoDS_Builder::Init
       }
     }
     else if (!aClosedShell.IsNull()) {
-      myTranShell.Init(aClosedShell, myTool, NMTool, aRange);
+      myTranShell.Init(aClosedShell, myTool, NMTool, theLocalFactors, aRange);
       if (myTranShell.IsDone()) {
         Shl = TopoDS::Shell(myTranShell.Value());
         Shl.Closed(Standard_True);
@@ -491,8 +465,9 @@ void StepToTopoDS_Builder::Init
   }
 
 //:S4136  ShapeFix::SameParameter (S,Standard_False);
-  ResetPreci (S, MaxTol());
-  ResetPreci (Shl, MaxTol()); //skl
+  Handle(StepData_StepModel) aStepModel = Handle(StepData_StepModel)::DownCast(TP->Model());
+  ResetPreci (aStepModel, S, MaxTol());
+  ResetPreci (aStepModel, Shl, MaxTol()); //skl
 }
 
 // ============================================================================
@@ -501,7 +476,8 @@ void StepToTopoDS_Builder::Init
 // ============================================================================
 
 void StepToTopoDS_Builder::Init (const Handle(StepShape_EdgeBasedWireframeModel)& aEBWM,
-                                 const Handle(Transfer_TransientProcess)& TP)
+                                 const Handle(Transfer_TransientProcess)& TP,
+                                 const StepData_Factors& theLocalFactors)
 {
   myResult.Nullify();
   
@@ -535,7 +511,7 @@ void StepToTopoDS_Builder::Init (const Handle(StepShape_EdgeBasedWireframeModel)
     }
     TopoDS_Wire W;
     for ( Standard_Integer j=1; j <= edges->Length(); j++ ) {
-      myTranEdge.Init (edges->Value(j), myTool, dummyNMTool);
+      myTranEdge.Init (edges->Value(j), myTool, dummyNMTool, theLocalFactors);
       if ( ! myTranEdge.IsDone() ) continue;
       TopoDS_Edge E = TopoDS::Edge(myTranEdge.Value());
       if (E.IsNull()) continue;  // NULL, on saute
@@ -552,7 +528,8 @@ void StepToTopoDS_Builder::Init (const Handle(StepShape_EdgeBasedWireframeModel)
   myError  = ( myResult.IsNull() ? StepToTopoDS_BuilderDone : StepToTopoDS_BuilderOther );
   done     = ! myResult.IsNull();
 
-  ResetPreci (myResult, MaxTol());
+  Handle(StepData_StepModel) aStepModel = Handle(StepData_StepModel)::DownCast(TP->Model());
+  ResetPreci (aStepModel, myResult, MaxTol());
 }
 
 // ============================================================================
@@ -561,7 +538,8 @@ void StepToTopoDS_Builder::Init (const Handle(StepShape_EdgeBasedWireframeModel)
 // ============================================================================
 
 void StepToTopoDS_Builder::Init (const Handle(StepShape_FaceBasedSurfaceModel)& aFBSM,
-                                 const Handle(Transfer_TransientProcess)& TP)
+                                 const Handle(Transfer_TransientProcess)& TP,
+                                 const StepData_Factors& theLocalFactors)
 {
   myResult.Nullify();
   
@@ -597,7 +575,7 @@ void StepToTopoDS_Builder::Init (const Handle(StepShape_FaceBasedSurfaceModel)&
     TopoDS_Shell S;
     for ( Standard_Integer j=1; j <= faces->Length(); j++ ) {
       Handle(StepShape_FaceSurface) fs = Handle(StepShape_FaceSurface)::DownCast ( faces->Value(j) );
-      myTranFace.Init(fs, myTool, dummyNMTool);
+      myTranFace.Init(fs, myTool, dummyNMTool, theLocalFactors);
       if ( ! myTranFace.IsDone() ) continue;
       TopoDS_Face F = TopoDS::Face(myTranFace.Value());
       if (F.IsNull()) continue;  // NULL, on saute
@@ -614,7 +592,8 @@ void StepToTopoDS_Builder::Init (const Handle(StepShape_FaceBasedSurfaceModel)&
   myError  = ( myResult.IsNull() ? StepToTopoDS_BuilderDone : StepToTopoDS_BuilderOther );
   done     = ! myResult.IsNull();
 
-  ResetPreci (myResult, MaxTol());
+  Handle(StepData_StepModel) aStepModel = Handle(StepData_StepModel)::DownCast(TP->Model());
+  ResetPreci (aStepModel, myResult, MaxTol());
 }
 
 
@@ -626,11 +605,12 @@ void StepToTopoDS_Builder::Init (const Handle(StepShape_FaceBasedSurfaceModel)&
 //:i6 abv 17 Sep 98: ProSTEP TR9 r0601-ct.stp: to be able read GS: GeometricCurveSet -> GeometricSet
 
 static TopoDS_Face TranslateBoundedSurf (const Handle(StepGeom_Surface) &surf,
-                                         const Standard_Real TolDegen)
+                                         const Standard_Real TolDegen,
+                                         const StepData_Factors& theLocalFactors)
 {
   TopoDS_Face res;
 
-  Handle(Geom_Surface) theSurf = StepToGeom::MakeSurface (surf);
+  Handle(Geom_Surface) theSurf = StepToGeom::MakeSurface (surf, theLocalFactors);
   if (theSurf.IsNull() || //:i6: protection
       !theSurf->IsKind(STANDARD_TYPE(Geom_BoundedSurface))) return res;
 
@@ -656,6 +636,7 @@ static TopoDS_Face TranslateBoundedSurf (const Handle(StepGeom_Surface) &surf,
 void StepToTopoDS_Builder::Init
 (const Handle(StepShape_GeometricSet)& GCS,
  const Handle(Transfer_TransientProcess)& TP,
+ const StepData_Factors& theLocalFactors,
  const Handle(Transfer_ActorOfTransientProcess)& RA,
  const Standard_Boolean isManifold,
  const Message_ProgressRange& theProgress)
@@ -674,7 +655,7 @@ void StepToTopoDS_Builder::Init
   {
     Message_ProgressRange aRange = aPS.Next();
     StepShape_GeometricSetSelect aGSS = GCS->ElementsValue(i);
-    Handle(Standard_Transient) ent = aGSS.Value();
+    const Handle(Standard_Transient)& ent = aGSS.Value();
 
     TopoDS_Shape res = TransferBRep::ShapeResult ( TP, ent );
     if ( ! res.IsNull() ) { // already translated
@@ -698,7 +679,7 @@ void StepToTopoDS_Builder::Init
         StepToTopoDS_TranslateCompositeCurve TrCC;
         TrCC.SetPrecision(preci);
         TrCC.SetMaxTol(maxtol);
-        TrCC.Init(CC, TP);
+        TrCC.Init(CC, TP, theLocalFactors);
         if (TrCC.IsDone())
         {
           if (TrCC.IsInfiniteSegment())
@@ -719,7 +700,7 @@ void StepToTopoDS_Builder::Init
         Handle(Geom_Curve) aGeomCrv;
         try {
           OCC_CATCH_SIGNALS
-            aGeomCrv = StepToGeom::MakeCurve(aCrv);
+            aGeomCrv = StepToGeom::MakeCurve(aCrv, theLocalFactors);
         }
         catch (Standard_Failure const& anException) {
           Message_Messenger::StreamBuffer sout = TP->Messenger()->SendInfo();
@@ -735,7 +716,7 @@ void StepToTopoDS_Builder::Init
     // try point
     else if ( ent->IsKind(STANDARD_TYPE(StepGeom_CartesianPoint)) ) {
       Handle(StepGeom_CartesianPoint) aPnt = Handle(StepGeom_CartesianPoint)::DownCast ( ent );
-      Handle(Geom_CartesianPoint) thePnt = StepToGeom::MakeCartesianPoint (aPnt);
+      Handle(Geom_CartesianPoint) thePnt = StepToGeom::MakeCartesianPoint (aPnt, theLocalFactors);
       if (! thePnt.IsNull()) {
         BRepBuilderAPI_MakeVertex myMkVtx(thePnt->Pnt());
         if ( myMkVtx.IsDone() ) res = myMkVtx.Vertex();
@@ -754,7 +735,7 @@ void StepToTopoDS_Builder::Init
         TrCBS.SetPrecision(preci);
         TrCBS.SetMaxTol(maxtol);
 
-        TrCBS.Init(CBS, TP);
+        TrCBS.Init(CBS, TP, theLocalFactors);
         if (TrCBS.IsDone()) res = TrCBS.Value();
       }
       // try RectangularCompositeSurface
@@ -768,13 +749,13 @@ void StepToTopoDS_Builder::Init
         for (Standard_Integer ii = 1; ii <= nbi; ii++)
           for (Standard_Integer j = 1; j <= nbj; j++) {
             Handle(StepGeom_SurfacePatch) patch = RCS->SegmentsValue(ii, j);
-            TopoDS_Face f = TranslateBoundedSurf(patch->ParentSurface(), preci);
+            TopoDS_Face f = TranslateBoundedSurf(patch->ParentSurface(), preci, theLocalFactors);
             if (!f.IsNull()) B.Add(C, f);
           }
         res = C;
       }
       // try other surfs
-      else res = TranslateBoundedSurf(aSurf, preci);
+      else res = TranslateBoundedSurf(aSurf, preci, theLocalFactors);
     }
     else if ( ent->IsKind(STANDARD_TYPE(StepGeom_GeometricRepresentationItem)) )
     {
@@ -785,7 +766,7 @@ void StepToTopoDS_Builder::Init
         Handle(STEPControl_ActorRead) anActor = Handle(STEPControl_ActorRead)::DownCast(RA);
         Handle(Transfer_Binder) binder;
         if( !anActor.IsNull())
-          binder = anActor->TransferShape(GRI, TP, isManifold, Standard_False, aRange);
+          binder = anActor->TransferShape(GRI, TP, theLocalFactors, isManifold, Standard_False, aRange);
         if (!binder.IsNull())
         {
           res = TransferBRep::ShapeResult(binder);
@@ -805,6 +786,144 @@ void StepToTopoDS_Builder::Init
 }
 // ***end DTH Apr/6 
 
+// ============================================================================
+// Method  : Init
+// Purpose : Builds a TopoDS_Solid from StepVisual_TessellatedSolid
+// ============================================================================
+void StepToTopoDS_Builder::Init(const Handle(StepVisual_TessellatedSolid)& theTSo,
+                                const Handle(Transfer_TransientProcess)& theTP,
+                                const Standard_Boolean theReadTessellatedWhenNoBRepOnly,
+                                Standard_Boolean& theHasGeom,
+                                const StepData_Factors& theLocalFactors,
+                                const Message_ProgressRange& theProgress)
+{
+  StepToTopoDS_TranslateSolid aTranSolid;
+  aTranSolid.SetPrecision(Precision());
+  aTranSolid.SetMaxTol(MaxTol());
+
+  StepToTopoDS_Tool aTool;
+  StepToTopoDS_DataMapOfTRI aMap;
+  aTool.Init(aMap, theTP);
+
+  StepToTopoDS_NMTool aDummyNMTool;
+  aTranSolid.Init(theTSo, theTP, aTool, aDummyNMTool, theReadTessellatedWhenNoBRepOnly,
+                  theHasGeom, theLocalFactors, theProgress);
+
+  if (!aTranSolid.IsDone())
+  {
+    theTP->AddWarning(theTSo, " TessellatedSolid not mapped to TopoDS");
+    myError = StepToTopoDS_BuilderOther;
+    done = Standard_False;
+    return;
+  }
+  TopoDS_Shape aS = aTranSolid.Value();
+  myResult = TopoDS::Solid(aS);
+  myError = StepToTopoDS_BuilderDone;
+  done = Standard_True;
+}
+
+// ============================================================================
+// Method  : Init
+// Purpose : Builds a TopoDS_Shell from StepVisual_TessellatedShell
+// ============================================================================
+void StepToTopoDS_Builder::Init(const Handle(StepVisual_TessellatedShell)& theTSh,
+                                const Handle(Transfer_TransientProcess)& theTP,
+                                const Standard_Boolean theReadTessellatedWhenNoBRepOnly,
+                                Standard_Boolean& theHasGeom,
+                                const StepData_Factors& theLocalFactors,
+                                const Message_ProgressRange& theProgress)
+{
+  StepToTopoDS_TranslateShell aTranShell;
+  aTranShell.SetPrecision(Precision());
+  aTranShell.SetMaxTol(MaxTol());
+
+  StepToTopoDS_Tool aTool;
+  StepToTopoDS_DataMapOfTRI aMap;
+  aTool.Init(aMap, theTP);
+
+  StepToTopoDS_NMTool aDummyNMTool;
+  aTranShell.Init(theTSh, aTool, aDummyNMTool, theReadTessellatedWhenNoBRepOnly,
+                  theHasGeom, theLocalFactors, theProgress);
+
+  if (!aTranShell.IsDone()) 
+  {
+    theTP->AddWarning(theTSh, " TessellatedShell not mapped to TopoDS");
+    myError = StepToTopoDS_BuilderOther;
+    done = Standard_False;
+    return;
+  }
+  TopoDS_Shape aS = aTranShell.Value();
+  myResult = TopoDS::Shell(aS);
+  myError = StepToTopoDS_BuilderDone;
+  done = Standard_True;
+}
+
+// ============================================================================
+// Method  : Init
+// Purpose : Builds a TopoDS_Face from StepVisual_TessellatedFace
+// ============================================================================
+void StepToTopoDS_Builder::Init(const Handle(StepVisual_TessellatedFace)& theTF,
+                                const Handle(Transfer_TransientProcess)& theTP,
+                                const Standard_Boolean theReadTessellatedWhenNoBRepOnly,
+                                Standard_Boolean& theHasGeom,
+                                const StepData_Factors& theLocalFactors)
+{
+  StepToTopoDS_TranslateFace aTranFace;
+  aTranFace.SetPrecision(Precision());
+  aTranFace.SetMaxTol(MaxTol());
+
+  StepToTopoDS_Tool aTool;
+  StepToTopoDS_DataMapOfTRI aMap;
+  aTool.Init(aMap, theTP);
+
+  StepToTopoDS_NMTool aDummyNMTool;
+  aTranFace.Init(theTF, aTool, aDummyNMTool, theReadTessellatedWhenNoBRepOnly, theHasGeom, theLocalFactors);
+  if (!aTranFace.IsDone()) 
+  {
+    theTP->AddWarning(theTF, " TessellatedFace not mapped to TopoDS");
+    myError = StepToTopoDS_BuilderOther;
+    done = Standard_False;
+    return;
+  }
+  TopoDS_Shape aS = aTranFace.Value();
+  myResult = TopoDS::Face(aS);
+  myError = StepToTopoDS_BuilderDone;
+  done = Standard_True;
+}
+
+// ============================================================================
+// Method  : Init
+// Purpose : Builds a TopoDS_Face from StepVisual_TessellatedSurfaceSet
+// ============================================================================
+void StepToTopoDS_Builder::Init(const Handle(StepVisual_TessellatedSurfaceSet)& theTSS,
+                                const Handle(Transfer_TransientProcess)& theTP,
+                                const StepData_Factors& theLocalFactors,
+                                Standard_Boolean& theHasGeom)
+{
+  StepToTopoDS_TranslateFace aTranFace;
+  aTranFace.SetPrecision(Precision());
+  aTranFace.SetMaxTol(MaxTol());
+
+  StepToTopoDS_Tool aTool;
+  StepToTopoDS_DataMapOfTRI aMap;
+  aTool.Init(aMap, theTP);
+
+  StepToTopoDS_NMTool aDummyNMTool;
+  aTranFace.Init(theTSS, aTool, aDummyNMTool, theLocalFactors);
+  theHasGeom = Standard_False;
+
+  if ( !aTranFace.IsDone() )
+  {
+    theTP->AddWarning(theTSS, " TessellatedSurfaceSet not mapped to TopoDS");
+    myError = StepToTopoDS_BuilderOther;
+    done = Standard_False;
+    return;
+  }
+  TopoDS_Shape aS = aTranFace.Value();
+  myResult = TopoDS::Face(aS);
+  myError = StepToTopoDS_BuilderDone;
+  done = Standard_True;
+}
 
 // ============================================================================
 // Method  : Value
