@@ -14,10 +14,7 @@
 #include <StlAPI_Writer.hxx>
 
 #include <Bnd_Box.hxx>
-#include <BRepBndLib.hxx>
 #include <Message.hxx>
-#include <Message_Messenger.hxx>
-#include <OSD_Path.hxx>
 #include <OSD_OpenFile.hxx>
 #include <RWStl.hxx>
 #include <BRep_Tool.hxx>
@@ -83,23 +80,20 @@ Standard_Boolean StlAPI_Writer::Write (const TopoDS_Shape&    theShape,
       continue;
     }
 
-    const TColgp_Array1OfPnt& aNodes = aTriangulation->Nodes();
-    const Poly_Array1OfTriangle& aTriangles = aTriangulation->Triangles();
-
     // copy nodes
     gp_Trsf aTrsf = aLoc.Transformation();
-    for (Standard_Integer aNodeIter = aNodes.Lower(); aNodeIter <= aNodes.Upper(); ++aNodeIter)
+    for (Standard_Integer aNodeIter = 1; aNodeIter <= aTriangulation->NbNodes(); ++aNodeIter)
     {
-      gp_Pnt aPnt = aNodes (aNodeIter);
+      gp_Pnt aPnt = aTriangulation->Node (aNodeIter);
       aPnt.Transform (aTrsf);
-      aMesh->ChangeNode (aNodeIter + aNodeOffset) = aPnt;
+      aMesh->SetNode (aNodeIter + aNodeOffset, aPnt);
     }
 
     // copy triangles
     const TopAbs_Orientation anOrientation = anExpSF.Current().Orientation();
-    for (Standard_Integer aTriIter = aTriangles.Lower(); aTriIter <= aTriangles.Upper(); ++aTriIter)
+    for (Standard_Integer aTriIter = 1; aTriIter <= aTriangulation->NbTriangles(); ++aTriIter)
     {
-      Poly_Triangle aTri = aTriangles (aTriIter);
+      Poly_Triangle aTri = aTriangulation->Triangle (aTriIter);
 
       Standard_Integer anId[3];
       aTri.Get (anId[0], anId[1], anId[2]);
@@ -117,11 +111,11 @@ Standard_Boolean StlAPI_Writer::Write (const TopoDS_Shape&    theShape,
       anId[2] += aNodeOffset;
 
       aTri.Set (anId[0], anId[1], anId[2]);
-      aMesh->ChangeTriangle (aTriIter + aTriangleOffet) =  aTri;
+      aMesh->SetTriangle (aTriIter + aTriangleOffet, aTri);
     }
 
-    aNodeOffset += aNodes.Size();
-    aTriangleOffet += aTriangles.Size();
+    aNodeOffset += aTriangulation->NbNodes();
+    aTriangleOffet += aTriangulation->NbTriangles();
   }
 
   OSD_Path aPath (theFileName);
