@@ -15,10 +15,7 @@
 
 #include <Standard_NegativeValue.hxx>
 #include <Standard_NullObject.hxx>
-#include <Standard_NumericError.hxx>
-#include <Standard_OutOfRange.hxx>
 #include <Standard_Type.hxx>
-#include <TCollection_AsciiString.hxx>
 #include <TCollection_HAsciiString.hxx>
 #include <TCollection_HExtendedString.hxx>
 
