@@ -18,11 +18,8 @@
 //Version	Date		Purpose
 //		0.0	May 26 1997	Creation
 
-#include <Standard_GUID.hxx>
-#include <TDF_Attribute.hxx>
 #include <TDF_IDFilter.hxx>
 #include <TDF_IDList.hxx>
-#include <TDF_ListIteratorOfIDList.hxx>
 #include <TDF_MapIteratorOfIDMap.hxx>
 
 // To avoid too much resizing actions, et 23 est un nombre premier.
