@@ -16,9 +16,6 @@
 #include <TDataStd_DeltaOnModificationOfIntPackedMap.hxx>
 
 #include <Standard_Type.hxx>
-#include <TColStd_HPackedMapOfInteger.hxx>
-#include <TColStd_MapIteratorOfPackedMapOfInteger.hxx>
-#include <TColStd_PackedMapOfInteger.hxx>
 #include <TDataStd_IntPackedMap.hxx>
 #include <TDF_DeltaOnModification.hxx>
 #include <TDF_Label.hxx>
