@@ -344,12 +344,17 @@ void TDataStd_RealArray::DumpJson (Standard_OStream& theOStream, Standard_Intege
 
   OCCT_DUMP_BASE_CLASS (theOStream, theDepth, TDF_Attribute)
 
-  for (TColStd_Array1OfReal::Iterator aValueIt (myValue->Array1()); aValueIt.More(); aValueIt.Next())
+  if (!myValue.IsNull())
   {
-    const Standard_Real& aValue = aValueIt.Value();
-    OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, aValue)
+    OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, myValue->Lower())
+    OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, myValue->Upper())
+
+    for (TColStd_Array1OfReal::Iterator aValueIt (myValue->Array1()); aValueIt.More(); aValueIt.Next())
+    {
+      const Standard_Real& aValue = aValueIt.Value();
+      OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, aValue)
+    }
   }
 
   OCCT_DUMP_FIELD_VALUE_NUMERICAL (theOStream, myIsDelta)
-  OCCT_DUMP_FIELD_VALUE_GUID (theOStream, myID)
 }
