@@ -18,10 +18,8 @@
 #include <TObj_Application.hxx>
 
 #include <Standard_SStream.hxx>
-#include <Standard_ErrorHandler.hxx>
 #include <Standard_Dump.hxx>
 #include <TCollection_ExtendedString.hxx>
-#include <TColStd_SequenceOfExtendedString.hxx>
 #include <Message_Msg.hxx>
 #include <Message_MsgFile.hxx>
 #include <Resource_Manager.hxx>
