@@ -15,21 +15,14 @@
 // commercial license or contractual agreement.
 
 
-#include <gp_Pnt.hxx>
-#include <TopoDS_Face.hxx>
-#include <TopoDS_Shape.hxx>
 #include <TopOpeBRep_FacesFiller.hxx>
 #include <TopOpeBRep_FacesIntersector.hxx>
 #include <TopOpeBRep_FFDumper.hxx>
 #include <TopOpeBRep_LineInter.hxx>
-#include <TopOpeBRep_PointClassifier.hxx>
 #include <TopOpeBRep_VPointInter.hxx>
 #include <TopOpeBRep_VPointInterClassifier.hxx>
 #include <TopOpeBRep_VPointInterIterator.hxx>
-#include <TopOpeBRepDS_DataStructure.hxx>
-#include <TopOpeBRepDS_HDataStructure.hxx>
 #include <TopOpeBRepDS_Interference.hxx>
-#include <TopOpeBRepDS_Point.hxx>
 #include <TopOpeBRepDS_Transition.hxx>
 
 #ifdef DRAW
@@ -38,29 +31,20 @@
 
 #include <Standard_DomainError.hxx>
 #include <Geom_Surface.hxx>
-#include <Geom_Curve.hxx>
-#include <Geom2d_Curve.hxx>
 #include <Precision.hxx>
 #include <TopoDS.hxx>
 #include <TopExp.hxx>
-#include <BRep_Tool.hxx>
 #include <gp_Vec.hxx>
 
 #include <TopOpeBRepTool_EXPORT.hxx>
 #include <TopOpeBRepTool_SC.hxx>
-#include <TopOpeBRepTool_TOOL.hxx>
 #include <TopOpeBRepTool_ShapeTool.hxx>
 #include <TopOpeBRepTool_makeTransition.hxx>
 
-#include <TopOpeBRepDS_define.hxx>
-#include <TopOpeBRepDS_EXPORT.hxx>
 #include <TopOpeBRepDS_ProcessInterferencesTool.hxx>
-#include <TopOpeBRepDS_Config.hxx>
-#include <TopOpeBRepDS_Curve.hxx>
 #include <TopOpeBRepDS_PointIterator.hxx>
 #include <TopOpeBRepDS_Dumper.hxx>
 
-#include <TopOpeBRep_define.hxx>
 #include <TopOpeBRep_FFTransitionTool.hxx>
 #include <TopOpeBRep_PointGeomTool.hxx>
 #include <TopOpeBRep.hxx>
@@ -367,7 +351,7 @@ static Standard_Boolean FUN_LineRestF
 
 //-----------------------------------------------------------------------
 Standard_EXPORT Standard_Boolean FUN_newtransEdge
-(const Handle(TopOpeBRepDS_HDataStructure) HDS,
+(const Handle(TopOpeBRepDS_HDataStructure)& HDS,
  const TopOpeBRep_FacesFiller& FF,
  const TopOpeBRep_LineInter& L,
  const Standard_Boolean& Lonrest,
@@ -379,7 +363,7 @@ Standard_EXPORT Standard_Boolean FUN_newtransEdge
 {
   T.Before(TopAbs_UNKNOWN); T.After(TopAbs_UNKNOWN);
   const TopoDS_Face& OOface = FF.Face(OOShapeIndex);
-  TopoDS_Face FIE = OOface;
+  const TopoDS_Face& FIE = OOface;
   {
     TopAbs_Orientation oFIE = FIE.Orientation();
     if (oFIE == TopAbs_INTERNAL || oFIE == TopAbs_EXTERNAL) {
@@ -470,7 +454,7 @@ Standard_EXPORT Standard_Boolean FUN_newtransEdge
 } // FUN_newtransEdge
 
 //-----------------------------------------------------------------------
-static void FUN_ScanInterfList(const TopOpeBRepDS_Point& PDS, const Handle(TopOpeBRepDS_HDataStructure) HDS,
+static void FUN_ScanInterfList(const TopOpeBRepDS_Point& PDS, const Handle(TopOpeBRepDS_HDataStructure)& HDS,
 			       const TopOpeBRepDS_ListOfInterference& loI, TopOpeBRepDS_ListOfInterference& loIfound)
 //-----------------------------------------------------------------------
 {
@@ -528,7 +512,7 @@ static Standard_Boolean FUN_sameGsameS(const TopOpeBRepDS_ListOfInterference& lo
   //  geometry <G>, and support <S>
   TopOpeBRepDS_PointIterator PI(loI);   
   for (; PI.More(); PI.Next()) {
-    Handle(TopOpeBRepDS_Interference) EPI = PI.Value();    
+    const Handle(TopOpeBRepDS_Interference)& EPI = PI.Value();
     Standard_Integer GEPI = EPI->Geometry(); Standard_Integer SEPI = EPI->Support();      
     if (GEPI == G && SEPI == S) loIfound.Append(EPI);
   }
@@ -1030,7 +1014,7 @@ void TopOpeBRep_FacesFiller::ProcessVPonR
     // alors qu'il est dessus)
     
     TopOpeBRepDS_Transition tOOedge;
-    // distinguish wether OOedge is the edge on which geometric line lies.
+    // distinguish whether OOedge is the edge on which geometric line lies.
     // OOedge == edge(line) ==> tOOedge = f(orientation of <edge> in <Face> FORWARD)
     // OOedge != edge(line) ==> tOOedge = f(orientation of <Face>)    
     Standard_Real OOpar1,OOpar2; Standard_Boolean isonper; FDS_LOIinfsup((*myDS),OOedge,OOparedge,PVKind,PVIndex,
