@@ -15,47 +15,24 @@
 // commercial license or contractual agreement.
 
 
-#include <Bnd_Box.hxx>
-#include <BRep_Builder.hxx>
-#include <BRep_Tool.hxx>
 #include <BRepAdaptor_Curve.hxx>
 #include <BRepAdaptor_Surface.hxx>
-#include <Geom2d_Curve.hxx>
 #include <Geom_Curve.hxx>
 #include <gp_Pnt.hxx>
-#include <Standard_NoSuchObject.hxx>
 #include <Standard_ProgramError.hxx>
 #include <TColgp_Array1OfPnt.hxx>
-#include <TCollection_AsciiString.hxx>
 #include <TopExp.hxx>
 #include <TopoDS.hxx>
-#include <TopoDS_Compound.hxx>
 #include <TopoDS_Edge.hxx>
 #include <TopoDS_Face.hxx>
 #include <TopoDS_Shape.hxx>
-#include <TopoDS_Vertex.hxx>
-#include <TopOpeBRepBuild_Builder.hxx>
 #include <TopOpeBRepBuild_define.hxx>
-#include <TopOpeBRepBuild_EdgeBuilder.hxx>
-#include <TopOpeBRepBuild_FaceBuilder.hxx>
 #include <TopOpeBRepBuild_GTopo.hxx>
-#include <TopOpeBRepBuild_HBuilder.hxx>
-#include <TopOpeBRepBuild_PaveSet.hxx>
-#include <TopOpeBRepBuild_ShapeSet.hxx>
-#include <TopOpeBRepBuild_ShellFaceSet.hxx>
-#include <TopOpeBRepBuild_SolidBuilder.hxx>
-#include <TopOpeBRepBuild_WireEdgeSet.hxx>
-#include <TopOpeBRepDS_BuildTool.hxx>
-#include <TopOpeBRepDS_CurveIterator.hxx>
 #include <TopOpeBRepDS_DataMapIteratorOfDataMapOfShapeListOfShapeOn1State.hxx>
 #include <TopOpeBRepDS_HDataStructure.hxx>
-#include <TopOpeBRepDS_ListOfShapeOn1State.hxx>
-#include <TopOpeBRepDS_PointIterator.hxx>
-#include <TopOpeBRepDS_SurfaceIterator.hxx>
 #include <TopOpeBRepTool_2d.hxx>
 #include <TopOpeBRepTool_FuseEdges.hxx>
 #include <TopOpeBRepTool_ShapeExplorer.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfIntegerListOfShape.hxx>
 
 //#include <BRepAdaptor_Curve2d.hxx>
 #ifdef OCCT_DEBUG
@@ -281,7 +258,7 @@ void TopOpeBRepBuild_Builder::End()
 //    TopAbs_State state = myState1;
     TopTools_ListOfShape& ls = ChangeMerged(myShape1,myState1);
     for (TopTools_ListIteratorOfListOfShape itls(ls);itls.More();itls.Next()) {
-      TopoDS_Shape& SFE = itls.Value();
+      TopoDS_Shape& SFE = itls.ChangeValue();
       TopOpeBRepTool_FuseEdges FE(SFE);
 
       // avoid fusing old edges
