@@ -19,15 +19,12 @@
 static TCollection_AsciiString PRODINS("dins ");
 #endif
 
-#include <BRep_Tool.hxx>
 #include <BRepAdaptor_Curve.hxx>
 #include <BRepAdaptor_Surface.hxx>
-#include <Geom2d_Curve.hxx>
 #include <Geom2d_Line.hxx>
 #include <Geom_Curve.hxx>
 #include <Geom_Surface.hxx>
 #include <GeomAbs_CurveType.hxx>
-#include <GeomAbs_SurfaceType.hxx>
 #include <GeomAPI_ProjectPointOnSurf.hxx>
 #include <gp_Dir2d.hxx>
 #include <gp_Pnt2d.hxx>
@@ -36,7 +33,6 @@ static TCollection_AsciiString PRODINS("dins ");
 #include <Precision.hxx>
 #include <Standard_ProgramError.hxx>
 #include <TCollection_AsciiString.hxx>
-#include <TopAbs.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Edge.hxx>
 #include <TopoDS_Face.hxx>
@@ -44,7 +40,6 @@ static TCollection_AsciiString PRODINS("dins ");
 #include <TopOpeBRepBuild_define.hxx>
 #include <TopOpeBRepBuild_WireEdgeSet.hxx>
 #include <TopOpeBRepTool_2d.hxx>
-#include <TopOpeBRepTool_CurveTool.hxx>
 
 #ifdef OCCT_DEBUG
 extern Standard_Boolean TopOpeBRep_GettraceSHA(const Standard_Integer i);
@@ -226,10 +221,13 @@ const TopTools_ListOfShape & TopOpeBRepBuild_WireEdgeSet::MakeNeighboursList(con
     // edge list made of connected shapes to Earg through Varg
 
     myCurrentShapeNeighbours.Clear();
-    
+#ifdef DRAW
     Standard_Integer iapp = 0;
+#endif
     for (TopTools_ListIteratorOfListOfShape it(l); it.More(); it.Next()) {
+#ifdef DRAW
       iapp++;
+#endif
       const TopoDS_Shape& curn = it.Value(); // current neighbour
       Standard_Boolean k = VertexConnectsEdgesClosing(V,E,curn);
       if (k) {
@@ -277,10 +275,13 @@ const TopTools_ListOfShape & TopOpeBRepBuild_WireEdgeSet::MakeNeighboursList(con
       if (Eori == TopAbs_REVERSED) d1E.Reverse();
 
       TopTools_ListIteratorOfListOfShape lclo(myCurrentShapeNeighbours);
+#ifdef DRAW
       Standard_Integer rang = 0;
+#endif
       while (lclo.More()) {
+#ifdef DRAW
 	rang++;
-
+#endif
 	if ( ! IsClosed(lclo.Value()) ) {
 	  lclo.Next();
 	  continue;
