@@ -15,44 +15,19 @@
 // commercial license or contractual agreement.
 
 
-#include <BRep_Builder.hxx>
-#include <BRep_Tool.hxx>
 #include <BRepTools.hxx>
-#include <Geom2d_Curve.hxx>
 #include <Geom_RectangularTrimmedSurface.hxx>
 #include <Geom_Surface.hxx>
-#include <GeomAbs_SurfaceType.hxx>
-#include <GeomAdaptor_Surface.hxx>
-#include <gp_Pnt.hxx>
-#include <Standard_NoSuchObject.hxx>
 #include <Standard_ProgramError.hxx>
-#include <TCollection_AsciiString.hxx>
 #include <TopExp.hxx>
 #include <TopoDS.hxx>
-#include <TopoDS_Compound.hxx>
-#include <TopoDS_Edge.hxx>
-#include <TopoDS_Face.hxx>
 #include <TopoDS_Shape.hxx>
-#include <TopoDS_Vertex.hxx>
-#include <TopoDS_Wire.hxx>
-#include <TopOpeBRepBuild_Builder.hxx>
 #include <TopOpeBRepBuild_define.hxx>
-#include <TopOpeBRepBuild_EdgeBuilder.hxx>
 #include <TopOpeBRepBuild_FaceBuilder.hxx>
-#include <TopOpeBRepBuild_GTopo.hxx>
-#include <TopOpeBRepBuild_HBuilder.hxx>
-#include <TopOpeBRepBuild_PaveSet.hxx>
-#include <TopOpeBRepBuild_ShapeSet.hxx>
-#include <TopOpeBRepBuild_ShellFaceSet.hxx>
-#include <TopOpeBRepBuild_SolidBuilder.hxx>
 #include <TopOpeBRepBuild_WireEdgeSet.hxx>
-#include <TopOpeBRepDS.hxx>
 #include <TopOpeBRepDS_BuildTool.hxx>
-#include <TopOpeBRepDS_CurveIterator.hxx>
 #include <TopOpeBRepDS_EXPORT.hxx>
 #include <TopOpeBRepDS_HDataStructure.hxx>
-#include <TopOpeBRepDS_PointIterator.hxx>
-#include <TopOpeBRepDS_SurfaceIterator.hxx>
 #include <TopOpeBRepTool.hxx>
 #include <TopOpeBRepTool_2d.hxx>
 #include <TopOpeBRepTool_EXPORT.hxx>
@@ -162,9 +137,9 @@ void TopOpeBRepBuild_Builder::GWESMakeFaces
 	  Standard_Integer rankVsameG = BDS.AncestorRank(VsameG);
           Standard_Boolean otherRef = (rankVsameG != 0 && rankV != 1);
 
-	  if (otherRef)
+    if (otherRef)
 	    BDS.FillShapesSameDomain(VsameG,V);
-          else
+    else
 	    BDS.FillShapesSameDomain(V,VsameG);
 
 	  hsdm = myDataStructure->HasSameDomain(V);  
@@ -380,8 +355,6 @@ void TopOpeBRepBuild_Builder::GFABUMakeFaces(const TopoDS_Shape& FF,TopOpeBRepBu
       for (; FABU.MoreWire(); FABU.NextWire())
 	{
 	  Standard_Integer ne = 0;
-	  Standard_Integer neFORWARD  = 0;
-	  Standard_Integer neREVERSED = 0;
 	  Standard_Integer neINTERNAL = 0;
 	  Standard_Integer neEXTERNAL = 0;
 
@@ -412,8 +385,6 @@ void TopOpeBRepBuild_Builder::GFABUMakeFaces(const TopoDS_Shape& FF,TopOpeBRepBu
 		  TopAbs_Orientation oE = newEdge.Orientation();
 		  if      (oE == TopAbs_INTERNAL) neINTERNAL++;
 		  else if (oE == TopAbs_EXTERNAL) neEXTERNAL++;
-		  else if (oE == TopAbs_FORWARD)  neFORWARD++;
-		  else if (oE == TopAbs_REVERSED) neREVERSED++;
 	  
 		  Standard_Boolean hasPC = FC2D_HasCurveOnSurface(newEdge,newFace);                                     // jyl980402+
 		  if (!hasPC)                                                                                           // jyl980402+
@@ -505,8 +476,8 @@ void TopOpeBRepBuild_Builder::GFABUMakeFaces(const TopoDS_Shape& FF,TopOpeBRepBu
 			      if(chkORI == 1)
 				{
 				  TopAbs_Orientation ori = FUN_ReOrientIntExtEdge(E2,O2,E1);
-				  if(ori == TopAbs_FORWARD) { E1.Orientation(TopAbs_FORWARD); neFORWARD++; }
-				  if(ori == TopAbs_REVERSED){ E1.Orientation(TopAbs_REVERSED); neREVERSED++; }
+				  if(ori == TopAbs_FORWARD) { E1.Orientation(TopAbs_FORWARD); }
+				  if(ori == TopAbs_REVERSED){ E1.Orientation(TopAbs_REVERSED); }
 				  if(ori == TopAbs_REVERSED || ori == TopAbs_FORWARD)
 				    {
 				      if(O1 == TopAbs_INTERNAL) neINTERNAL--;
@@ -516,8 +487,8 @@ void TopOpeBRepBuild_Builder::GFABUMakeFaces(const TopoDS_Shape& FF,TopOpeBRepBu
 			      if(chkORI == 2)
 				{
 				  TopAbs_Orientation ori = FUN_ReOrientIntExtEdge(E1,O1,E2);
-				  if(ori == TopAbs_FORWARD) { E2.Orientation(TopAbs_FORWARD); neFORWARD++; }
-				  if(ori == TopAbs_REVERSED){ E2.Orientation(TopAbs_REVERSED); neREVERSED++; }
+				  if(ori == TopAbs_FORWARD) { E2.Orientation(TopAbs_FORWARD); }
+				  if(ori == TopAbs_REVERSED){ E2.Orientation(TopAbs_REVERSED); }
 				  if(ori == TopAbs_REVERSED || ori == TopAbs_FORWARD)
 				    {
 				      if(O2 == TopAbs_INTERNAL) neINTERNAL--;
