@@ -17,18 +17,12 @@
 
 #include <Standard_NullObject.hxx>
 #include <TopoDS_Builder.hxx>
-#include <TopoDS_Compound.hxx>
-#include <TopoDS_CompSolid.hxx>
 #include <TopoDS_FrozenShape.hxx>
 #include <TopoDS_ListIteratorOfListOfShape.hxx>
 #include <TopoDS_Shape.hxx>
-#include <TopoDS_Shell.hxx>
-#include <TopoDS_Solid.hxx>
-#include <TopoDS_TCompound.hxx>
 #include <TopoDS_TShape.hxx>
 #include <TopoDS_TWire.hxx>
 #include <TopoDS_UnCompatibleShapes.hxx>
-#include <TopoDS_Wire.hxx>
 
 //=======================================================================
 //function : MakeShape
