@@ -15,12 +15,8 @@
 
 #include <OSD_Environment.hxx>
 #include <Resource_Manager.hxx>
-#include <Standard_NoSuchObject.hxx>
 #include <TCollection_AsciiString.hxx>
 #include <Units.hxx>
-#include <Units_Dimensions.hxx>
-#include <Units_Quantity.hxx>
-#include <Units_Unit.hxx>
 #include <Units_UnitsSystem.hxx>
 #include <UnitsAPI.hxx>
 
