@@ -15,11 +15,7 @@
 
 #include <V3d_Trihedron.hxx>
 
-#include <gp_Ax3.hxx>
 #include <Graphic3d_ArrayOfPolylines.hxx>
-#include <Graphic3d_ArrayOfSegments.hxx>
-#include <Graphic3d_ArrayOfTriangles.hxx>
-#include <Graphic3d_Camera.hxx>
 #include <Graphic3d_TransformPers.hxx>
 #include <Prs3d.hxx>
 #include <Prs3d_Arrow.hxx>
@@ -255,7 +251,7 @@ void V3d_Trihedron::Display (const V3d_View& theView)
     myStructure = new TrihedronStructure (theView.Viewer()->StructureManager(), this);
     myStructure->SetTransformPersistence (myTransformPers);
     myStructure->SetZLayer (Graphic3d_ZLayerId_Topmost);
-    myStructure->SetDisplayPriority (9);
+    myStructure->SetDisplayPriority (Graphic3d_DisplayPriority_Highlight);
     myStructure->SetInfiniteState (Standard_True);
     myStructure->CStructure()->ViewAffinity = new Graphic3d_ViewAffinity();
     myStructure->CStructure()->ViewAffinity->SetVisible (Standard_False);
