@@ -14,41 +14,28 @@
 #include <VrmlConverter_Drawer.hxx>
 #include <VrmlConverter_ShadedShape.hxx>
 #include <Vrml_Normal.hxx>
-#include <TopoDS_Shape.hxx>
-#include <TopoDS_Face.hxx>
 #include <TopoDS.hxx>
-#include <TopAbs.hxx>
 #include <Poly_Connect.hxx>
 #include <TColgp_Array1OfDir.hxx>
 #include <TColgp_HArray1OfVec.hxx>
-#include <Poly_Triangle.hxx>
-#include <Poly_Triangulation.hxx>
 #include <BRepTools.hxx>
 #include <BRep_Tool.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Vec.hxx>
 #include <TopExp_Explorer.hxx>
 #include <TopLoc_Location.hxx>
-#include <TColgp_Array1OfPnt.hxx>
 #include <Poly_Array1OfTriangle.hxx>
 #include <Vrml_IndexedFaceSet.hxx>
 #include <Vrml_Coordinate3.hxx>
-#include <BRepBndLib.hxx>
-#include <Bnd_Box.hxx>
 #include <math.hxx>
 #include <TColStd_HArray1OfInteger.hxx>
 #include <Geom_Surface.hxx>
-#include <CSLib_DerivativeStatus.hxx>
-#include <CSLib_NormalStatus.hxx>
 #include <CSLib.hxx>
 #include <BRepAdaptor_Surface.hxx>
-#include <TColgp_Array1OfPnt2d.hxx>
 #include <Precision.hxx>
 #include <Vrml_Material.hxx>
 #include <VrmlConverter_ShadingAspect.hxx>
 #include <Vrml_ShapeHints.hxx>
-#include <Vrml_MaterialBindingAndNormalBinding.hxx>
-#include <Vrml_NormalBinding.hxx>
 #include <Vrml_Separator.hxx>
 #include <Vrml_NormalBinding.hxx>
 
