@@ -17,7 +17,6 @@
 #include <TDF_ChildIterator.hxx>
 #include <XCAFDoc.hxx>
 #include <TDataStd_TreeNode.hxx>
-#include <Precision.hxx>
 #include <TColgp_HArray1OfPnt.hxx>
 #include <TDataStd_Integer.hxx>
 #include <TDataStd_IntegerArray.hxx>
@@ -25,7 +24,6 @@
 #include <TDataStd_Real.hxx>
 #include <TDataStd_RealArray.hxx>
 #include <TNaming_Builder.hxx>
-#include <TNaming_NamedShape.hxx>
 #include <TColStd_HArray1OfReal.hxx>
 #include <TopoDS.hxx>
 #include <XCAFDimTolObjects_DimensionObject.hxx>
@@ -35,7 +33,8 @@
 IMPLEMENT_DERIVED_ATTRIBUTE(XCAFDoc_Dimension,TDataStd_GenericEmpty)
 enum ChildLab
 {
-  ChildLab_Type = 1,
+  ChildLab_Begin = 1,
+  ChildLab_Type = ChildLab_Begin,
   ChildLab_Value,
   ChildLab_Qualifier,
   ChildLab_Class,
@@ -51,7 +50,9 @@ enum ChildLab
   ChildLab_PntText,
   ChildLab_Presentation,
   ChildLab_Descriptions,
-  ChildLab_DescriptionNames
+  ChildLab_DescriptionNames,
+  ChildLab_AngularQualifier,
+  ChildLab_End
 };
 
 //=======================================================================
@@ -105,10 +106,9 @@ void XCAFDoc_Dimension::SetObject (const Handle(XCAFDimTolObjects_DimensionObjec
     TDataStd_Name::Set(Label(), str);
   }
 
-  TDF_ChildIterator anIter(Label());
-  for(;anIter.More(); anIter.Next())
+  for (int aChild = ChildLab_Begin; aChild < ChildLab_End; aChild++)
   {
-    anIter.Value().ForgetAllAttributes();
+    Label().FindChild(aChild).ForgetAllAttributes();
   }
   Handle(TDataStd_Integer) aType = TDataStd_Integer::Set(Label().FindChild(ChildLab_Type), theObject->GetType());
 
@@ -121,6 +121,8 @@ void XCAFDoc_Dimension::SetObject (const Handle(XCAFDimTolObjects_DimensionObjec
   }
 
   Handle(TDataStd_Integer) aQualifier = TDataStd_Integer::Set(Label().FindChild(ChildLab_Qualifier), theObject->GetQualifier());
+
+  Handle(TDataStd_Integer) anAngularQualifier = TDataStd_Integer::Set(Label().FindChild(ChildLab_AngularQualifier), theObject->GetAngularQualifier());
  
   Standard_Boolean aH;
   XCAFDimTolObjects_DimensionFormVariance aF;
@@ -314,6 +316,12 @@ Handle(XCAFDimTolObjects_DimensionObject) XCAFDoc_Dimension::GetObject()  const
   {
     anObj->SetQualifier((XCAFDimTolObjects_DimensionQualifier)aQualifier->Get());
   }
+
+  Handle(TDataStd_Integer) anAngularQualifier;
+  if (Label().FindChild(ChildLab_AngularQualifier).FindAttribute(TDataStd_Integer::GetID(), anAngularQualifier))
+  {
+    anObj->SetAngularQualifier((XCAFDimTolObjects_AngularQualifier)anAngularQualifier->Get());
+  }
  
   Handle(TDataStd_IntegerArray) aClass;
   if(Label().FindChild(ChildLab_Class).FindAttribute(TDataStd_IntegerArray::GetID(), aClass) 
