@@ -24,7 +24,6 @@
 #include <OSD_File.hxx>
 #include <TCollection_AsciiString.hxx>
 #include <TDF_Label.hxx>
-#include <TDF_LabelSequence.hxx>
 #include <TDF_Tool.hxx>
 #include <TDataStd_Name.hxx>
 #include <TDocStd_Document.hxx>
@@ -100,6 +99,7 @@ static const char* faceCullToString (Graphic3d_TypeOfBackfacingModel theMode)
   {
     case Graphic3d_TypeOfBackfacingModel_Auto:        return "Auto";
     case Graphic3d_TypeOfBackfacingModel_BackCulled:  return "BackCulled";
+    case Graphic3d_TypeOfBackfacingModel_FrontCulled: return "FrontCulled";
     case Graphic3d_TypeOfBackfacingModel_DoubleSided: return "DoubleSided";
   }
   return "";
@@ -1162,6 +1162,12 @@ static Standard_Integer XAddVisMaterial (Draw_Interpretor& , Standard_Integer th
       {
         aMode = Graphic3d_TypeOfBackfacingModel_BackCulled;
       }
+      else if (aCullStr == "frontculled"
+            || aCullStr == "frontcull"
+            || aCullStr == "front")
+      {
+        aMode = Graphic3d_TypeOfBackfacingModel_FrontCulled;
+      }
       else if (aCullStr == "doublesided")
       {
         aMode = Graphic3d_TypeOfBackfacingModel_DoubleSided;
