@@ -18,21 +18,15 @@
 #include <BRepLib.hxx>
 #include <IFSelect_CheckCounter.hxx>
 #include <IFSelect_SignatureList.hxx>
-#include <Interface_Check.hxx>
 #include <Interface_CheckIterator.hxx>
 #include <Interface_EntityIterator.hxx>
-#include <Interface_Graph.hxx>
 #include <Interface_HGraph.hxx>
 #include <Interface_InterfaceModel.hxx>
 #include <Interface_Macros.hxx>
 #include <Interface_MSG.hxx>
-#include <Interface_SignLabel.hxx>
 #include <Interface_Static.hxx>
-#include <Message_Messenger.hxx>
 #include <Message_ProgressScope.hxx>
 #include <ShapeFix.hxx>
-#include <Standard_ErrorHandler.hxx>
-#include <Standard_Failure.hxx>
 #include <Standard_Transient.hxx>
 #include <Standard_Type.hxx>
 #include <TCollection_HAsciiString.hxx>
@@ -48,7 +42,6 @@
 #include <Transfer_TransferOutput.hxx>
 #include <Transfer_TransientProcess.hxx>
 #include <TransferBRep.hxx>
-#include <TransferBRep_BinderOfShape.hxx>
 #include <TransferBRep_ShapeBinder.hxx>
 #include <XSControl_Controller.hxx>
 #include <XSControl_TransferReader.hxx>
@@ -815,7 +808,7 @@ Standard_Integer XSControl_TransferReader::TransferOne
 
   //  seule difference entre TransferRoots et TransferOne
   Standard_Integer res = 0;
-  Handle(Standard_Transient) obj = ent;
+  const Handle(Standard_Transient)& obj = ent;
   TP.Transfer (obj, theProgress);
   if (theProgress.UserBreak())
     return res;
@@ -1183,7 +1176,7 @@ void XSControl_TransferReader::PrintStatsOnList(const Handle(Transfer_TransientP
   if (what >= 1 && what <= 3) {
 
     Standard_Integer stat;
-    Standard_Integer nbv = 0, nbw = 0, nbf = 0, nbr = 0, nbrw = 0, nbrf = 0, nbnr = 0, nbi = 0;
+    Standard_Integer nbw = 0, nbf = 0, nbr = 0, nbrw = 0, nbrf = 0, nbnr = 0, nbi = 0;
     Transfer_IteratorOfProcessForTransient itrp(Standard_True);
     if (what == 1) itrp = TP->RootResult(Standard_True);
     if (what == 2) itrp = TP->CompleteResult(Standard_True);
@@ -1204,8 +1197,8 @@ void XSControl_TransferReader::PrintStatsOnList(const Handle(Transfer_TransientP
 
     for (itrp.Start(); itrp.More(); itrp.Next()) {
       nbi ++;
-      Handle(Transfer_Binder) binder = itrp.Value();
-      Handle(Standard_Transient) ent = itrp.Starting();
+      const Handle(Transfer_Binder)& binder = itrp.Value();
+      const Handle(Standard_Transient)& ent = itrp.Starting();
       if (binder.IsNull())  {
 	nbnr ++;
 	if (notrec) counter->Add(ent,"(not recorded)");
@@ -1221,7 +1214,6 @@ void XSControl_TransferReader::PrintStatsOnList(const Handle(Transfer_TransientP
 	stat = BinderStatus(binder,mess);
         // 0 Binder Null.   1 void  2 Warning seul  3 Fail seul
         // 11 Resultat OK. 12 Resultat+Warning. 13 Resultat+Fail
-	if (stat ==  0 || stat == 1) nbv ++;
 	if (stat ==  2) nbw ++;
 	if (stat ==  3) nbf ++;
 	if (stat == 11) nbr ++;
