@@ -19,8 +19,6 @@
 #include <Aspect_WindowDefinitionError.hxx>
 #include <Aspect_WindowInputListener.hxx>
 #include <Message.hxx>
-#include <Message_Messenger.hxx>
-#include <Standard_NotImplemented.hxx>
 
 #if defined(HAVE_XLIB)
   #include <X11/Xlib.h>
@@ -69,11 +67,10 @@ Xw_Window::Xw_Window (const Handle(Aspect_DisplayConnection)& theXDisplay,
   int      aScreen = DefaultScreen(aDisp);
   Window   aParent = RootWindow   (aDisp, aScreen);
 
-  unsigned long aMask = 0;
   XSetWindowAttributes aWinAttr;
   memset (&aWinAttr, 0, sizeof(aWinAttr));
   aWinAttr.event_mask = ExposureMask | StructureNotifyMask;
-  aMask |= CWEventMask;
+
   if (aVisInfo != NULL)
   {
     aWinAttr.colormap = XCreateColormap(aDisp, aParent, aVisInfo->visual, AllocNone);
