@@ -17,9 +17,6 @@
 #include <gp_Ax1.hxx>
 #include <gp_Ax2.hxx>
 #include <gp_Pnt.hxx>
-#include <gp_Trsf.hxx>
-#include <gp_Vec.hxx>
-#include <Standard_ConstructionError.hxx>
 
 void gp_Circ::Mirror (const gp_Pnt& P)
 { pos.Mirror(P); }
