@@ -19,9 +19,6 @@
 #include <gp_Ax2d.hxx>
 #include <gp_Ax22d.hxx>
 #include <gp_Pnt2d.hxx>
-#include <gp_Trsf2d.hxx>
-#include <gp_Vec2d.hxx>
-#include <Standard_ConstructionError.hxx>
 
 void gp_Circ2d::Mirror (const gp_Pnt2d& P)
 { pos.Mirror(P); }
