@@ -14,14 +14,11 @@
 
 #include <gp_Torus.hxx>
 
-#include <gp.hxx>
 #include <gp_Ax1.hxx>
 #include <gp_Ax2.hxx>
 #include <gp_Ax3.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Trsf.hxx>
-#include <gp_Vec.hxx>
-#include <Standard_ConstructionError.hxx>
 #include <Standard_DimensionError.hxx>
 
 void gp_Torus::Coefficients (TColStd_Array1OfReal& theCoef) const
