@@ -21,14 +21,10 @@
 #include <gp_Vec.hxx>
 
 #include <gp.hxx>
-#include <gp_Ax1.hxx>
 #include <gp_Ax2.hxx>
 #include <gp_Dir.hxx>
-#include <gp_Pnt.hxx>
 #include <gp_Trsf.hxx>
-#include <gp_VectorWithNullMagnitude.hxx>
 #include <gp_XYZ.hxx>
-#include <Standard_ConstructionError.hxx>
 #include <Standard_DomainError.hxx>
 #include <Standard_Dump.hxx>
 #include <Standard_OutOfRange.hxx>
