@@ -62,6 +62,7 @@ Standard_Boolean convertToPluginName (const TCollection_AsciiString& theArgument
   if (anArgument == "dfbrowser")       { thePluginName = "TKDFBrowser"; return Standard_True; }
   else if (anArgument == "shapeview")  { thePluginName = "TKShapeView"; return Standard_True; }
   else if (anArgument == "vinspector") { thePluginName = "TKVInspector"; return Standard_True; }
+  else if (anArgument == "messageview") { thePluginName = "TKMessageView"; return Standard_True; }
 
   return Standard_False;
 }
@@ -305,6 +306,7 @@ static int tinspector (Draw_Interpretor& di, Standard_Integer theArgsNb, const c
       aPlugins.Append ("TKDFBrowser");
       aPlugins.Append ("TKShapeView");
       aPlugins.Append ("TKVInspector");
+      aPlugins.Append ("TKMessageView");
     }
     aPluginNameToActivate = !aPluginNameToActivate.IsEmpty() ? aPluginNameToActivate : aPlugins.First();
   }
@@ -391,10 +393,10 @@ void ToolsDraw::Commands(Draw_Interpretor& theCommands)
     "\n\t\t: Starts tool of inspection."
     "\n\t\t: Options:"
     "\n\t\t:  -plugins enters plugins that should be added in the inspector."
-    "\n\t\t:           Available names are: dfbrowser, vinspector and shapeview."
+    "\n\t\t:           Available names are: dfbrowser, vinspector, shapeview and messageview."
     "\n\t\t:           Plugins order will be the same as defined in arguments."
     "\n\t\t:           'all' adds all available plugins in the order:"
-    "\n\t\t:                 DFBrowser, VInspector and ShapeView."
+    "\n\t\t:                 DFBrowser, VInspector, ShapeView and MessageView."
     "\n\t\t:           If at the first call this option is not used, 'all' option is applied;"
     "\n\t\t:  -activate activates the plugin in the tool view."
     "\n\t\t:           If at the first call this option is not used, the first plugin is activated;"
@@ -404,7 +406,7 @@ void ToolsDraw::Commands(Draw_Interpretor& theCommands)
     "\n\t\t:  -select sets the parameter that should be selected in an active tool view."
     "\n\t\t:          Depending on active tool the parameter is:"
     "\n\t\t:          ShapeView: 'object' is an instance of TopoDS_Shape TShape,"
-    "\n\t\t:          DFBrowser: 'name' is an entry of TDF_Label and name2(optionaly) for TDF_Attribute type name,"
+    "\n\t\t:          DFBrowser: 'name' is an entry of TDF_Label and name2(optionally) for TDF_Attribute type name,"
     "\n\t\t:          VInspector: 'object' is an instance of AIS_InteractiveObject;"
     "\n\t\t:  -show sets Inspector view visible or hidden. The first call of this command will show it."
     "\n\t\t:  -directory sets Inspector temporary directory. Preferences file is stored there."
